@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: adminlog.php 6002 2009-09-18 10:59:43Z ronnyk $
+#$Id: adminlog.php 6738 2010-11-02 18:38:35Z nuno $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -89,7 +89,13 @@ if (check_permission($userid, 'Modify Site Preferences'))
 		$page_string = pagination($page, $totalrows, $limit);
 		echo "<p class=\"pageshowrows\">".$page_string."</p>";
 		echo $themeObject->ShowHeader('adminlog').'</div>';
-		echo '<a href="adminlog.php'.$urlext.'&amp;download=1">'.lang('download').'</a>';
+		echo '<div class="pageoptions">';
+		echo '<p class="pageoptions">';
+		echo '<a href="adminlog.php'.$urlext.'&amp;download=1">';
+		echo $themeObject->DisplayImage('icons/system/attachment.gif', lang('download'),'','','systemicon').'</a>';
+		echo '<a class="pageoptions" href="adminlog.php'.$urlext.'&amp;download=1">'.lang('download').'</a>';
+		echo '</p>';
+		echo '</div>';
 
 		echo "<table cellspacing=\"0\" class=\"pagetable\">\n";
 		echo '<thead>';
