@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listcontent.php 6461 2010-07-03 03:12:46Z calguy1000 $
+#$Id: listcontent.php 6788 2010-11-14 20:17:47Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -133,7 +133,7 @@ function content_setdefault($contentid)
 	setdefault($contentid);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
-	$objResponse->script("new Effect.Highlight('tr_$contentid', { duration: 2.0 });");
+	$objResponse->script("$('#tr_$contentid').effect('highlight', [], 3000);");
 	return $objResponse;
 }
 
@@ -144,7 +144,7 @@ function content_setactive($contentid)
 	setactive($contentid);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
-	$objResponse->script("new Effect.Highlight('tr_$contentid', { duration: 2.0 });");
+	$objResponse->script("$('#tr_$contentid').effect('highlight', [], 3000);");
 	return $objResponse;
 }
 
@@ -155,7 +155,7 @@ function content_setinactive($contentid)
 	setactive($contentid, false);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
-	$objResponse->script("new Effect.Highlight('tr_$contentid', { duration: 2.0 });");
+	$objResponse->script("$('#tr_$contentid').effect('highlight', [], 3000);");
 	return $objResponse;
 }
 
@@ -188,10 +188,13 @@ function expandall()
 	$cs = '';
 	foreach ($all as $thisitem)
 	{
+	  if( is_object($thisitem) && $thisitem instanceof ContentBase )
+	    {
 		if ($thisitem->HasChildren())
 		{
 			$cs .= $thisitem->Id().'=1.';
 		}
+	    }
 	}
 	set_preference($userid, 'collapse', $cs);
 }
@@ -209,7 +212,7 @@ function content_toggleexpand($contentid, $collapse)
 	toggleexpand($contentid, $collapse=='true'?true:false);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
-	$objResponse->script("new Effect.Highlight('tr_$contentid', { duration: 2.0 });");
+	$objResponse->script("$('#tr_$contentid').effect('highlight', [], 3000);");
 	return $objResponse;
 }
 
@@ -219,7 +222,9 @@ function content_delete($contentid)
 	
 	deletecontent($contentid);
 
-	$objResponse->script("new Effect.Fade('tr_$contentid', { afterFinish:function() { xajax_content_list_ajax(); } });");
+	$objResponse->script("$('#tr_$contentid').effect('fade', [], 3000);");
+	$objResponse->clear("contentlist", "innerHTML");
+	$objResponse->assign("contentlist", "innerHTML", display_content_list());
 	return $objResponse;
 }
 
@@ -295,7 +300,7 @@ function content_move($contentid, $parentid, $direction)
 	movecontent($contentid, $parentid, $direction);
 
 	$objResponse->assign("contentlist", "innerHTML", display_content_list());
-	$objResponse->script("new Effect.Highlight('tr_$contentid', { duration: 2.0 });");
+	$objResponse->script("$('#tr_$contentid').effect('highlight', [], 3000);");
 
   // reset lock
   return $objResponse;
@@ -364,24 +369,21 @@ function deletecontent($contentid)
 
 	if ($access)
 	{
-		$node = &$hierManager->getNodeById($contentid);
+		$node = $hierManager->getNodeById($contentid);
 		if ($node)
 		{
 			$contentobj =& $node->getContent(true);
 			$childcount = 0;
 			$parentid = -1;
-			if (isset($node->parentNode))
+			$parent = $node->getParent();
+			if ($parent)
 			{
-				$parent =& $node->parentNode;
-				if (isset($parent))
-				{
-					$parentContent =& $parent->getContent();
-					if (isset($parentContent))
-					{
-						$parentid = $parentContent->Id();
-						$childcount = $parent->getChildrenCount();
-					}
-				}
+			  $parentContent =& $parent->getContent();
+			  if (is_object($parentContent))
+			    {
+			      $parentid = $parentContent->Id();
+			      $childcount = $parent->getChildrenCount();
+			    }
 			}
 
 			if ($contentobj)
@@ -460,7 +462,7 @@ function reorder_display_list()
 {
 	$objResponse = new xajaxResponse();
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 	
 	$userid = get_userid();
 	
@@ -511,7 +513,7 @@ function reorder_process($get)
 	if (check_permission($userid,'Manage All Content'))
 	{
 		global $gCms;
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 		$db =& $gCms->GetDb();
 		$contentops =& $gCms->GetContentOperations();
 	    $hm = $contentops->GetAllContentAsHierarchy(false);
@@ -576,12 +578,15 @@ function check_children(&$root, &$mypages, &$userid)
 		if (!$result)
 		{
 		  $children =& $root->getChildren(false,true);
-			foreach ($children as $child)
-			{
-				$result = check_children($child, $mypages, $userid);
-				if ($result)
-					break;
-			}
+		  if( is_array($children) && count($children) > 0 )
+		  {
+		    foreach ($children as $child)
+		      {
+			$result = check_children($child, $mypages, $userid);
+			if ($result)
+			  break;
+		      }
+		  }
 		}
 	}
 	return $result;
@@ -598,8 +603,8 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$templates, &$users, &
   
   if(empty($currow)) $currow = 'row1';
   
-  $children =& $root->getChildren(false,true);
-  $one =& $root->getContent();
+  $children = $root->getChildren(false,true);
+  $one = $root->getContent();
   $thelist = '';
 
   if (!(isset($one) && $one != NULL))
@@ -685,15 +690,48 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$templates, &$users, &
 		      $txt .= "-&nbsp;&nbsp;&nbsp;";
 		    }
 		} 
+	      $str = $one->mMenuText;
+	      if( get_site_preference('listcontent_showtitle',0) )
+		{
+		  $str = $one->mName;
+		}
 	      if ($display == 'edit')
-		$txt .= '<a href="editcontent.php'.$urlext.'&amp;content_id='.$one->mId.'&amp;page='.$page.'" title="'. cms_htmlentities($one->mName.' ('.$one->mAlias.')', '', '', true). '">'. cms_htmlentities($one->mMenuText, '', '', true) . '</a>';
+		$txt .= '<a href="editcontent.php'.$urlext.'&amp;content_id='.$one->mId.'&amp;page='.$page.'" title="'. cms_htmlentities($one->mName.' ('.$one->mAlias.')', '', '', true). '">'. cms_htmlentities($str, '', '', true) . '</a>';
 	      else
-		$txt .= cms_htmlentities($one->mMenuText, '', '', true);
+		$txt .= cms_htmlentities($str, '', '', true);
 	    }
 	  if( !empty($txt) ) $columns['page'] = $txt;
 	}
 
-      
+      /* alias column */
+      if( $columnstodisplay['alias'] )
+	{
+	  $columns['alias'] = '&nbsp;';
+	  $txt = '';
+	  if( $one->HasUsableLink() && $one->mAlias != '' )
+	    {
+	      $txt = $one->Alias();
+	    }
+	  if( !empty($txt) ) $columns['alias'] = $txt;
+	}
+       
+      /* url column */
+      if( $columnstodisplay['url'] )
+	{
+	  $columns['url'] = '&nbsp;';
+	  $txt = '';
+	  if( $one->HasUsableLink() && $one->URL() != '' )
+	    {
+	      $url = $one->URL();
+	      if( strlen($url) > 30 )
+		{
+		  $url = '...'.substr($url,strlen($url)-27);
+		}
+	      $txt = $url;
+	    }
+	  if( !empty($txt) ) $columns['url'] = $txt;
+	}
+
       /* template column */
       if( $columnstodisplay['template'] )
 	{
@@ -900,6 +938,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$templates, &$users, &
 		   || check_permission($userid,'Manage All Content')) 
 		 )
 		{
+		  //$txt .= "<a href=\"{$thisurl}&amp;deletecontent=".$one->Id()."\" onclick=\"confirm('".cms_html_entity_decode_utf8(lang('deleteconfirm', $one->mName), true)."');\">";
 		  $txt .= "<a href=\"{$thisurl}&amp;deletecontent=".$one->Id()."\" onclick=\"if (confirm('".cms_html_entity_decode_utf8(lang('deleteconfirm', $one->mName), true)."')) xajax_content_delete(".$one->Id()."); return false;\">";
 		  $txt .= $deleteImg;
 		  $txt .= "</a>";
@@ -970,7 +1009,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$templates, &$users, &
 
     $indent = get_preference($userid, 'indent', true);
 
-    if (in_array($one->Id(),$openedArray))
+    if (in_array($one->Id(),$openedArray) && is_array($children) && count($children) )
     {
         foreach ($children as $child)
         { 
@@ -988,11 +1027,14 @@ function display_content_list($themeObject = null)
 	check_login();
 	$userid = get_userid();
 	
+	// setup which columns to display.
 	$mypages = author_pages($userid);
 	$columnstodisplay = array();
 	$columnstodisplay['expand'] = 1;
 	$columnstodisplay['hier'] = 1;
 	$columnstodisplay['page'] = 1;
+	$columnstodisplay['alias'] = get_site_preference('listcontent_showalias',1);
+	$columnstodisplay['url'] = get_site_preference('listcontent_showurl',1);
 	$columnstodisplay['template'] = 1;
 	$columnstodisplay['friendlyname'] = 1;
 	$columnstodisplay['owner'] = 1;
@@ -1054,7 +1096,7 @@ function display_content_list($themeObject = null)
 	}
 
         $hierManager =& $gCms->GetHierarchyManager();
-	$hierarchy = &$hierManager->getRootNode();
+	$hierarchy = &$hierManager;
 
 	$rowcount = 0;
 	if ($hierarchy->hasChildren())
@@ -1070,18 +1112,19 @@ function display_content_list($themeObject = null)
 			$thelist.=$item;
 		}
 
-		$thelist .= '<tr class="invisible"><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td>
-<td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td>
-<td>&nbsp;</td><td><input type="submit" name="reorderpages" value="'.lang('reorderpages').'" /></td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td></tr>';
+		//$thelist .= '<tr class="invisible"><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td>
+		//<td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td>
+		//<td>&nbsp;</td><td><input type="submit" name="reorderpages" value="'.lang('reorderpages').'" /></td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td></tr>';
 
 		$thelist .= '</tbody>';
 		$thelist .= "</table>\n";
 	}
 
+
 	$headoflist = '';
 
 	$headoflist .= '<div class="pageoverflow"><p class="pageoptions">';
-	if ((check_permission($userid, 'Add Pages') && count($mypages)) || check_permission($userid,'Manage All Content'))
+	if (check_permission($userid, 'Add Pages') || check_permission($userid,'Manage All Content'))
 	{
 	  $headoflist .=  '<a href="addcontent.php'.$urlext.'" class="pageoptions">';
 	  $headoflist .= $themeObject->DisplayImage('icons/system/newobject.gif', lang('addcontent'),'','','systemicon').'</a>';
@@ -1097,9 +1140,10 @@ function display_content_list($themeObject = null)
 
 	if (check_permission($userid, 'Manage All Content'))
 	{
-	  $headoflist .= '&nbsp;&nbsp;&nbsp;<a href="'.$thisurl.'&amp;error=jsdisabled" class="pageoptions" onclick="xajax_reorder_display_list();return false;">';
+	  $reorderurl = "ordercontent.php?".CMS_SECURE_PARAM_NAME."=".$_SESSION[CMS_USER_KEY];
+	  $headoflist .= '&nbsp;&nbsp;&nbsp;<a href="'.$reorderurl.'">';
 	  $headoflist .= $themeObject->DisplayImage('icons/system/reorder.gif', lang('reorderpages'),'','','systemicon').'</a>';
-	  $headoflist .= ' <a href="'.$thisurl.'&amp;error=jsdisabled" class="pageoptions" onclick="xajax_reorder_display_list();return false;">'.lang('reorderpages').'</a>';
+	  $headoflist .= ' <a class="pageoptions" href="'.$reorderurl.'">'.lang('reorderpages').'</a>';
 	}
 
 	$headoflist .='</p></div>';
@@ -1109,6 +1153,7 @@ function display_content_list($themeObject = null)
 	$headoflist .= '<thead>';
 	$headoflist .= "<tr>\n";
 
+	// setup column titles.
 	if( $columnstodisplay['expand'] )
 	  {
 	    $headoflist .= "<th>&nbsp;</th>";
@@ -1119,11 +1164,24 @@ function display_content_list($themeObject = null)
 	  }
 	if( $columnstodisplay['page'] )
 	  {
-	    $headoflist .= "<th class=\"pagew25\">".lang('page')."</th>\n";
+	    $str = lang('menutext');
+	    if( get_site_preference('listcontent_showtitle') )
+	      {
+		$str = lang('title');
+	      }
+	    $headoflist .= '<th class="pagew25" title="'.lang('lctitle_page').'">'.lang('page')." <em>({$str})</em></th>\n";
+	  }
+	if( $columnstodisplay['alias'] )
+	  {
+	    $headoflist .= '<th title="'.lang('lctitle_alias').'">'.lang('pagealias')."</th>\n";
+	  }
+	if( $columnstodisplay['url'] )
+	  {
+	    $headoflist .= '<th title="'.lang('lctitle_url').'">'.lang('url')."</th>\n";
 	  }
 	if( $columnstodisplay['template'] )
 	  {
-	    $headoflist .= "<th>".lang('template')."</th>\n";
+	    $headoflist .= '<th title="'.lang('lctitle_template').'">'.lang('template')."</th>\n";
 	  }
 	if( $columnstodisplay['friendlyname'] )
 	  {
@@ -1131,19 +1189,19 @@ function display_content_list($themeObject = null)
 	  }
 	if( $columnstodisplay['owner'] )
 	  {
-	    $headoflist .= "<th>".lang('owner')."</th>\n";
+	    $headoflist .= '<th title="'.lang('lctitle_owner').'">'.lang('owner')."</th>\n";
 	  }
 	if( $columnstodisplay['active'] )
 	  {
-	    $headoflist .= "<th class=\"pagepos\">".lang('active')."</th>\n";
+	    $headoflist .= '<th title="'.lang('lctitle_active').'" class="pagepos">'.lang('active')."</th>\n";
 	  }
 	if( $columnstodisplay['default'] )
 	  {
-	    $headoflist .= "<th class=\"pagepos\">".lang('default')."</th>\n";
+	    $headoflist .= '<th title="'.lang('lctitle_default').'" class="pagepos">'.lang('default')."</th>\n";
 	  }
 	if( $columnstodisplay['move'] )
 	  {
-	    $headoflist .= "<th class=\"move\">".lang('move')."</th>\n";
+	    $headoflist .= '<th title="'.lang('lctitle_move').'" class="move">'.lang('move')."</th>\n";
 	  }
 	if( $columnstodisplay['view'] )
 	  {
@@ -1163,7 +1221,7 @@ function display_content_list($themeObject = null)
 	  }
 	if( $columnstodisplay['multiselect'] )
 	  {
-	    $headoflist .= "<th class=\"checkbox\"><input id=\"selectall\" type=\"checkbox\" onclick=\"select_all();\" /></th>\n"; // checkbox column
+	    $headoflist .= '<th title="'.lang('lctitle_multiselect').'" class="checkbox"><input id="selectall" type="checkbox" onclick="select_all();" /></th>'."\n"; // checkbox column
 	  }
 	$headoflist .= "</tr>\n";
 	$headoflist .= '</thead>';
@@ -1205,7 +1263,7 @@ function display_content_list($themeObject = null)
 ?>
 			<div style="float: left;">
 <?php
-	if ((check_permission($userid, 'Add Pages') && count($mypages)) || check_permission($userid,'Manage All Content'))
+	if (check_permission($userid, 'Add Pages')|| check_permission($userid,'Manage All Content'))
 	{
 ?>
 			<a href="addcontent.php<?php echo $urlext ?>" class="pageoptions">
@@ -1230,7 +1288,8 @@ function display_content_list($themeObject = null)
 		if (check_permission($userid, 'Manage All Content'))
 		{
 			$image_reorder = $themeObject->DisplayImage('icons/system/reorder.gif', lang('reorderpages'),'','','systemicon');
-			echo '&nbsp;&nbsp;&nbsp; <a class="pageoptions" href="'.$thisurl.'&amp;error=jsdisabled" onclick="xajax_reorder_display_list();return false;">'.$image_reorder.'</a> <a class="pageoptions" href="'.$thisurl.'&amp;error=jsdisabled" onclick="xajax_reorder_display_list();return false;">'.lang('reorderpages').'</a>';
+			$reorderurl = "ordercontent.php?".CMS_SECURE_PARAM_NAME."=".$_SESSION[CMS_USER_KEY];
+			echo '&nbsp;&nbsp;&nbsp; <a class="pageoptions" href="'.$reorderurl.'">'.$image_reorder.'</a> <a class="pageoptions" href="'.$reorderurl.'">'.lang('reorderpages').'</a>';
 		}
 ?>
 			</div>
