@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listcss.php 6404 2010-06-25 01:17:04Z calguy1000 $
+#$Id: listcss.php 6805 2010-11-20 17:39:33Z calguy1000 $
 
 /**
  * This page is in charge of listing all CSS, and giving acces to editing and
@@ -205,7 +205,7 @@ if (isset($_GET["message"])) {
 	  {
 ?>
 	    <span style="float: left;">
-	    <a href="addcontent.php<?php echo $urlext ?>">
+	    <a href="addcss.php<?php echo $urlext ?>">
 	    <?php 
 	    echo $themeObject->DisplayImage('icons/system/newobject.gif', lang('addstylesheet'),'','','systemicon').'</a>';
 	    echo ' <a class="pageoptions" href="addcss.php'.$urlext.'">'.lang("addstylesheet");
