@@ -27,10 +27,10 @@ $theme=get_site_preference('logintheme', 'default');
 header("Content-type: text/css");
 if (file_exists(dirname(__FILE__)."/themes/$theme/css/style.css"))
   {
-    readfile(dirname(__FILE__)."/themes/$theme/css/style.css");
+    echo file_get_contents(dirname(__FILE__)."/themes/$theme/css/style.css");
   }
 else
   {
-    readfile(dirname(__FILE__)."/themes/default/css/style.css");
+    echo file_get_contents(dirname(__FILE__)."/themes/default/css/style.css");
   }
 ?>
\ No newline at end of file
