@@ -16,17 +16,19 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: makebookmark.php 5190 2008-10-29 20:38:06Z calguy1000 $ 
+#$Id: makebookmark.php 6420 2010-06-30 22:56:51Z calguy1000 $ 
 
 require_once('../include.php');
+global $CMS_ADMIN_PAGE;
+$CMS_ADMIN_PAGE = 1;
 $urlext='?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
 
 include_once("header.php");
 
 check_login();
-$origlink = $_SERVER['HTTP_REFERER'];
-$link = str_replace($urlext,'[SECURITYTAG]',$origlink);
-
+global $gCms;
+$config = $gCms->GetConfig();
+$link = $_SERVER['HTTP_REFERER'];
 $newmark = new Bookmark();
 $newmark->user_id = get_userid();
 $newmark->url = $link;
@@ -36,7 +38,7 @@ $result = $newmark->save();
 if ($result)
 	{
 	header('HTTP_REFERER: '.$config['root_url'].'/'.$config['admin_dir'].'/index.php');
-	redirect($origlink);
+	redirect($link);
 	}
 else
 	{
