@@ -126,23 +126,31 @@ function get_delete_list($sel_nodes,&$parent,&$final_result,$depth = 0)
 		}
 	      else
 		{
-		  $final_result[] = $content;
+		  if( !isset($final_result[$content->Id()]) )
+		    {
+		      $final_result[$content->Id()] = $content;
+		    }
 		}
 
 	      if( count($tmp) )
 		{
 		  // there are children se can delete.
-		  for( $i = 0; $i < count($tmp); $i++ )
+		  foreach( $tmp as $content_id => $one )
 		    {
-		      $one =& $tmp[$i];
-		      $final_result[] =& $one;
+		      if( !isset($final_result[$content_id]) )
+			{
+			  $final_result[$content_id] = $one;
+			}
 		    }
 		}
 	    }
 	  else
 	    {
 	      // no children
-	      $final_result[] = $content;
+	      if( !isset($final_result[$content->Id()]) )
+		{
+		  $final_result[$content->Id()] = $content;
+		}
 	    }
 	}
       else
@@ -188,7 +196,7 @@ function toggleexpand($contentid, $collapse = false)
 
 function DoContent(&$list, &$node, $checkdefault = true, $checkchildren = true)
 {
-	$content =& $node->GetContent(true);
+	$content = $node->GetContent(true);
 	if (isset($content))
 	{
 		if (!$checkdefault || ($checkdefault && !$content->DefaultContent()))
@@ -228,7 +236,7 @@ if (isset($_POST['idlist']))
 {
 	foreach (explode(':', $_POST['idlist']) as $id)
 	{
-		$node =& $hm->sureGetNodeById($id);
+		$node = $hm->sureGetNodeById($id);
 		if (isset($node))
 		{
 		  $content =& $node->GetContent();
@@ -246,7 +254,7 @@ else
 		if (startswith($k, 'multicontent-'))
 		{
 			$id = substr($k, strlen('multicontent-'));
-			$node =& $hm->sureGetNodeById($id);
+			$node = $hm->sureGetNodeById($id);
 			if (isset($node))
 			{
 				if ($action == 'inactive')
@@ -256,7 +264,7 @@ else
 					DoContent($nodelist, $node, false, false);
 				else if ($action == 'delete')
 				  {
-				    $nodelist[] =& $node;
+				    $nodelist[] = $node;
 				    //DoContent($nodelist, $node, false, true);
 				  }
 			}
@@ -266,7 +274,7 @@ else
 		    if (startswith($k, 'order-'))
 		      {
 			$id = substr($k, strlen('order-'));
-			$node =& $hm->sureGetNodeById($id);
+			$node = $hm->sureGetNodeById($id);
 			$one =& $node->getContent(true);
 			$parentNode = &$node->getParentNode();
 			if (FALSE == empty($reorder_parents_array[$one->ParentId()]) && array_key_exists($v, $reorder_parents_array[$one->ParentId()]))
@@ -303,7 +311,7 @@ else
 	    $order_changed = FALSE;
 	    foreach ($reorder_array AS $page_id => $page_order)
 	      {
-		$node =& $hm->sureGetNodeById($page_id);
+		$node = $hm->sureGetNodeById($page_id);
 		$one =& $node->getContent(true);
 		// Only update if order has changed.
 		if ($one->ItemOrder() != $page_order)
@@ -467,7 +475,8 @@ else
 
 				audit($id, $title, 'Deleted Content');
 			}
-			ContentManager::SetAllHierarchyPositions();
+			$ops = $gCms->GetContentOperations();
+			$ops->SetAllHierarchyPositions();
 			$bulk = true;
 		}
 		//include_once("footer.php");
