@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: siteprefs.php 6478 2010-07-04 23:07:12Z calguy1000 $
+#$Id: siteprefs.php 6863 2011-01-18 02:34:48Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 $CMS_TOP_MENU='admin';
@@ -55,6 +55,7 @@ if (!$access)
 
 global $gCms;
 $db =& $gCms->GetDb();
+$config = $gCms->GetConfig();
 
 $error = "";
 $message = "";
@@ -66,11 +67,13 @@ $disablesafemodewarning = 0;
 $allowparamcheckwarnings = 0;
 $enablenotifications = 1;
 $sitedownexcludes = '';
+$sitedownexcludeadmins = '';
 $basic_attributes = '';
 $xmlmodulerepository = "";
 $urlcheckversion = "";
 $defaultdateformat = "";
 $enablesitedownmessage = "0";
+$use_wysiwyg = "1";
 $sitedownmessage = "<p>Site is currently down.  Check back later.</p>";
 $sitedownmessagetemplate = "-1";
 $metadata = '';
@@ -81,9 +84,19 @@ $nogcbwysiwyg = '0';
 $global_umask = '022';
 $logintheme = "default";
 $auto_clear_cache_age = 0;
+$allow_browser_cache = 0;
+$browser_cache_expiry = 60;
 $pseudocron_granularity = 60;
-
-
+$listcontent_showalias = 1;
+$listcontent_showurl = 1;
+$listcontent_showtitle = 1;
+$content_autocreate_urls = 0;
+$content_autocreate_flaturls = 0;
+$content_mandatory_urls = 0;
+$contentimage_useimagepath = 0;
+$content_imagefield_path = '';
+$content_thumbnailfield_path = '';
+$contentimage_path = '';
 
 if (isset($_POST["cancel"])) {
 	redirect("index.php".$urlext);
@@ -92,6 +105,8 @@ if (isset($_POST["cancel"])) {
 
 
 $pseudocron_granularity = get_site_preference('pseudocron_granularity',$pseudocron_granularity);
+$allow_browser_cache = get_site_preference('allow_browser_cache',$allow_browser_cache);
+$browser_cache_expiry = get_site_preference('browser_cache_expiry',$browser_cache_expiry);
 $auto_clear_cache_age = get_site_preference('auto_clear_cache_age',$auto_clear_cache_age);
 $thumbnail_width = get_site_preference('thumbnail_width',$thumbnail_width);
 $thumbnail_height = get_site_preference('thumbnail_height',$thumbnail_height);
@@ -100,6 +115,7 @@ $frontendlang = get_site_preference('frontendlang',$frontendlang);
 $frontendwysiwyg = get_site_preference('frontendwysiwyg',$frontendwysiwyg);
 $nogcbwysiwyg = get_site_preference('nogcbwysiwyg',$nogcbwysiwyg);
 $enablesitedownmessage = get_site_preference('enablesitedownmessage',$enablesitedownmessage);
+$use_wysiwyg = get_site_preference('sitedown_use_wysiwyg',$use_wysiwyg);
 $sitedownmessage = get_site_preference('sitedownmessage',$sitedownmessage);
 $xmlmodulerepository = get_site_preference('xmlmodulerepository',$xmlmodulerepository);
 $urlcheckversion = get_site_preference('urlcheckversion',$urlcheckversion);
@@ -112,7 +128,17 @@ $disablesafemodewarning = get_site_preference('disablesafemodewarning',$disables
 $allowparamcheckwarnings = get_site_preference('allowparamcheckwarnings',$allowparamcheckwarnings);
 $enablenotifications = get_site_preference('enablenotifications',$enablenotifications);
 $sitedownexcludes = get_site_preference('sitedownexcludes',$sitedownexcludes);
+$sitedownexcludeadmins = get_site_preference('sitedownexcludeadmins',$sitedownexcludeadmins);
 $basic_attributes = get_site_preference('basic_attributes',$basic_attributes);
+$listcontent_showalias = get_site_preference('listcontent_showalias',$listcontent_showalias);
+$listcontent_showurl = get_site_preference('listcontent_showurl',$listcontent_showurl);
+$listcontent_showtitle = get_site_preference('listcontent_showtitle',$listcontent_showtitle);
+$content_autocreate_urls = get_site_preference('content_autocreate_urls',$content_autocreate_urls);
+$content_autocreate_flaturls = get_site_preference('content_autocreate_flaturls',$content_autocreate_flaturls);
+$content_mandatory_urls = get_site_preference('content_mandatory_urls',$content_mandatory_urls);
+$content_imagefield_path = get_site_preference('content_imagefield_path',$content_imagefield_path);
+$content_thumbnailfield_path = get_site_preference('content_thumbnailfield_path',$content_thumbnailfield_path);
+$contentimage_path = get_site_preference('contentimage_path',$contentimage_path);
 
 $active_tab='unknown';
 if( isset($_POST['active_tab']) )
@@ -204,23 +230,19 @@ else if (isset($_POST["editsiteprefs"]))
 	  set_site_preference('thumbnail_height',$thumbnail_height);
 	  break;
 
-	case 'sitedown':
-	  if( isset($_POST['sitedownexcludes']) )
-	    {
-	      $sitedownexcludes = trim($_POST['sitedownexcludes']);
-	    }
-	  if (isset($_POST["enablesitedownmessage"])) $enablesitedownmessage=$_POST['enablesitedownmessage'];
-	  if (isset($_POST["sitedownmessage"])) $sitedownmessage = $_POST["sitedownmessage"];
-	  set_site_preference('enablesitedownmessage', $enablesitedownmessage);
-	  set_site_preference('sitedownmessage', $sitedownmessage);
-	  set_site_preference('sitedownexcludes',$sitedownexcludes);
-	  break;
-
-	case 'setup':
-	  if (isset($_POST["clear_vc_cache"])) $clear_vc_cache = $_POST['clear_vc_cache'];
-	  if (isset($_POST["disablesafemodewarning"])) $disablesafemodewarning = $_POST['disablesafemodewarning'];
-	  if (isset($_POST["allowparamcheckwarnings"])) $allowparamcheckwarnings = $_POST['allowparamcheckwarnings'];
-	  if (isset($_POST["enablenotifications"])) $enablenotifications = $_POST['enablenotifications'];
+	case 'editcontent':
+	  $content_autocreate_urls = (int)$_POST['content_autocreate_urls'];
+	  set_site_preference('content_autocreate_urls',$content_autocreate_urls);
+	  $content_autocreate_flaturls = (int)$_POST['content_autocreate_flaturls'];
+	  set_site_preference('content_autocreate_flaturls',$content_autocreate_flaturls);
+	  $content_mandatory_urls = (int)$_POST['content_mandatory_urls'];
+	  set_site_preference('content_mandatory_urls',$content_mandatory_urls);
+	  $content_imagefield_path = trim($_POST['content_imagefield_path']);
+	  set_site_preference('content_imagefield_path',$content_imagefield_path);
+	  $content_thumbnailfield_path = trim($_POST['content_thumbnailfield_path']);
+	  set_site_preference('content_thumbnailfield_path',$content_thumbnailfield_path);
+	  $contentimage_path = trim($_POST['contentimage_path']);
+	  set_site_preference('contentimage_path',$contentimage_path);
 	  if( isset($_POST['basic_attributes']) )
 	    {
 	      $basic_attributes = implode(',',($_POST['basic_attributes']));
@@ -229,6 +251,39 @@ else if (isset($_POST["editsiteprefs"]))
 	    {
 	      $basic_attributes = '';
 	    }
+	  set_site_preference('basic_attributes',$basic_attributes);
+	  break;
+
+	case 'listcontent':
+	  $listcontent_showalias = (int)$_POST['listcontent_showalias'];
+	  set_site_preference('listcontent_showalias',$listcontent_showalias);
+	  $listcontent_showurl = (int)$_POST['listcontent_showurl'];
+	  set_site_preference('listcontent_showurl',$listcontent_showurl);
+	  $listcontent_showtitle = (int)$_POST['listcontent_showtitle'];
+	  set_site_preference('listcontent_showtitle',$listcontent_showtitle);
+	  break;
+
+	case 'sitedown':
+	  if( isset($_POST['sitedownexcludes']) )
+	    {
+	      $sitedownexcludes = trim($_POST['sitedownexcludes']);
+	    }
+	  $sitedownexcludeadmins = (int)$_POST['sitedownexcludeadmins'];
+	  if (isset($_POST["enablesitedownmessage"])) $enablesitedownmessage=$_POST['enablesitedownmessage'];
+	  if (isset($_POST["sitedownmessage"])) $sitedownmessage = $_POST["sitedownmessage"];
+	  if (isset($_POST["use_wysiwyg"])) $use_wysiwyg = $_POST["use_wysiwyg"];
+	  set_site_preference('enablesitedownmessage', $enablesitedownmessage);
+	  set_site_preference('sitedown_use_wysiwyg', $use_wysiwyg);
+	  set_site_preference('sitedownmessage', $sitedownmessage);
+	  set_site_preference('sitedownexcludes',$sitedownexcludes);
+	  set_site_preference('sitedownexcludeadmins',$sitedownexcludeadmins);
+	  break;
+
+	case 'setup':
+	  if (isset($_POST["clear_vc_cache"])) $clear_vc_cache = $_POST['clear_vc_cache'];
+	  if (isset($_POST["disablesafemodewarning"])) $disablesafemodewarning = $_POST['disablesafemodewarning'];
+	  if (isset($_POST["allowparamcheckwarnings"])) $allowparamcheckwarnings = $_POST['allowparamcheckwarnings'];
+	  if (isset($_POST["enablenotifications"])) $enablenotifications = $_POST['enablenotifications'];
 	  if (isset($_POST["xmlmodulerepository"])) $xmlmodulerepository = $_POST["xmlmodulerepository"];
 	  if (isset($_POST["urlcheckversion"])) $urlcheckversion = $_POST["urlcheckversion"];
 	  if (isset($_POST['global_umask'])) 
@@ -246,7 +301,16 @@ else if (isset($_POST["editsiteprefs"]))
 	  set_site_preference('disablesafemodewarning',$disablesafemodewarning);
 	  set_site_preference('allowparamcheckwarnings',$allowparamcheckwarnings);
 	  set_site_preference('enablenotifications',$enablenotifications);
-	  set_site_preference('basic_attributes',$basic_attributes);
+	  if( isset($_POST['allow_browser_cache']) )
+	    {
+	      $allow_browser_cache = (int)$_POST['allow_browser_cache'];
+	      set_site_preference('allow_browser_cache',$allow_browser_cache);
+	    }
+	  if( isset($_POST['browser_cache_expiry']) )
+	    {
+	      $browser_cache_expiry = (int)$_POST['browser_cache_expiry'];
+	      set_site_preference('browser_cache_expiry',$browser_cache_expiry);
+	    }
 	  if( isset($_POST['auto_clear_cache_age']) )
 	    {
 	      $auto_clear_cache_age = (int)$_POST['auto_clear_cache_age'];
@@ -301,21 +365,15 @@ if (FALSE == is_writable(TMP_CACHE_LOCATION) ||
 
 # give everything to smarty
 $tmp = array_keys($gCms->modules);
+if( !is_array($tmp) || count($tmp) == 0 )
+{
+  echo $themeObject->ShowErrors(lang('error_nomodules'));
+  return;
+}
 $firstmod = $tmp[0];
 $smarty->assign_by_ref('mod',$gCms->modules[$firstmod]['object']);
 
-$tmp = array(''=>lang('nodefault'));
-global $nls;
-asort($nls["language"]);
-foreach( $nls['language'] as $key=>$value )
-{
-  if( isset($nls['englishlang'][$key]) )
-    {
-      $value .= ' ('.$nls['englishlang'][$key].')';
-    }
-  $tmp[$key] = $value;
-}
-$smarty->assign('languages',$tmp);
+$smarty->assign('languages',get_language_list());
 $smarty->assign('templates',$templates);
 
 $tmp = array(''=>lang('none'));
@@ -347,11 +405,9 @@ if ($dir=opendir(dirname(__FILE__)."/themes/"))
 }
 
 
-$smarty->assign('active_general', 0);
-$smarty->assign('active_sitedown', 0);
-$smarty->assign('active_setup', 0);
-
 $smarty->assign('active_general',($active_tab == 'general')?1:0);
+$smarty->assign('active_listcontent',($active_tab == 'listcontent')?1:0);
+$smarty->assign('active_editcontent',($active_tab == 'editcontent')?1:0);
 $smarty->assign('active_sitedown',($active_tab == 'sitedown')?1:0);
 $smarty->assign('active_setup',($active_tab == 'setup')?1:0);
 
@@ -365,7 +421,8 @@ $smarty->assign('frontendwysiwyg',$frontendwysiwyg);
 $smarty->assign('nogcbwysiwyg',$nogcbwysiwyg);
 $smarty->assign('metadata',$metadata);
 $smarty->assign('enablesitedownmessage',$enablesitedownmessage);
-$smarty->assign('textarea_sitedownmessage',create_textarea(true,$sitedownmessage,'sitedownmessage','pagesmalltextarea'));
+$smarty->assign('use_wysiwyg',$use_wysiwyg);
+$smarty->assign('textarea_sitedownmessage',create_textarea($use_wysiwyg,$sitedownmessage,'sitedownmessage','pagesmalltextarea'));
 $smarty->assign('urlcheckversion',$urlcheckversion);
 $smarty->assign('clear_vc_cache',$clear_vc_cache);
 $smarty->assign('disablesafemodewarning',$disablesafemodewarning);
@@ -373,11 +430,23 @@ $smarty->assign('allowparamcheckwarnings',$allowparamcheckwarnings);
 $smarty->assign('defaultdateformat',$defaultdateformat);
 $smarty->assign('enablenotifications',$enablenotifications);
 $smarty->assign('sitedownexcludes',$sitedownexcludes);
+$smarty->assign('sitedownexcludeadmins',$sitedownexcludeadmins);
 $smarty->assign('basic_attributes',explode(',',$basic_attributes));
 $smarty->assign('thumbnail_width',$thumbnail_width);
 $smarty->assign('thumbnail_height',$thumbnail_height);
+$smarty->assign('allow_browser_cache',$allow_browser_cache);
+$smarty->assign('browser_cache_expiry',$browser_cache_expiry);
 $smarty->assign('auto_clear_cache_age',$auto_clear_cache_age);
 $smarty->assign('pseudocron_granularity',$pseudocron_granularity);
+$smarty->assign('listcontent_showalias',$listcontent_showalias);
+$smarty->assign('listcontent_showurl',$listcontent_showurl);
+$smarty->assign('listcontent_showtitle',$listcontent_showtitle);
+$smarty->assign('content_autocreate_urls',$content_autocreate_urls);
+$smarty->assign('content_autocreate_flaturls',$content_autocreate_flaturls);
+$smarty->assign('content_mandatory_urls',$content_mandatory_urls);
+$smarty->assign('content_imagefield_path',$content_imagefield_path);
+$smarty->assign('content_thumbnailfield_path',$content_thumbnailfield_path);
+$smarty->assign('contentimage_path',$contentimage_path);
 
 $tmp = array(15=>lang('cron_15m'),30=>lang('cron_30m'),
 	     60=>lang('cron_60m'),120=>lang('cron_120m'),
@@ -393,6 +462,7 @@ $smarty->assign('lang_autoclearcache',lang('autoclearcache'));
 $smarty->assign('lang_thumbnail_width',lang('thumbnail_width'));
 $smarty->assign('lang_thumbnail_height',lang('thumbnail_height'));
 $smarty->assign('lang_general',lang('general_settings'));
+$smarty->assign('lang_listcontent',lang('listcontent_settings'));
 $smarty->assign('lang_sitedown',lang('sitedown_settings'));
 $smarty->assign('lang_cancel',lang('cancel'));
 $smarty->assign('lang_submit',lang('submit'));
@@ -423,6 +493,8 @@ $smarty->assign('lang_sitedownexcludes',lang('sitedownexcludes'));
 $smarty->assign('lang_info_sitedownexcludes',lang('info_sitedownexcludes'));
 $smarty->assign('lang_basic_attributes',lang('basic_attributes'));
 $smarty->assign('lang_info_basic_attributes',lang('info_basic_attributes'));
+$smarty->assign('lang_editcontent_settings',lang('editcontent_settings'));
+$smarty->assign('lang_enablewysiwyg',lang('enablewysiwyg'));
 
 $all_attributes = array();
 $all_attributes['template'] = lang('template');
@@ -444,8 +516,15 @@ $all_attributes['extra1'] = lang('extra1');
 $all_attributes['extra2'] = lang('extra2');
 $all_attributes['extra3'] = lang('extra3');
 $all_attributes['additionaleditors'] = lang('additionaleditors');
+$all_attributes['page_url'] = lang('url');
 $smarty->assign('all_attributes',$all_attributes);
 
+$yesno = array(0=>lang('no'),1=>lang('yes'));
+$smarty->assign('yesno',$yesno);
+
+$titlemenu = array(0=>lang('menutext'),1=>lang('title'));
+$smarty->assign('titlemenu',$titlemenu);
+
 # begin output
 echo '<div class="pagecontainer">'.$themeObject->ShowHeader('siteprefs')."\n";
 echo $smarty->fetch('siteprefs.tpl');
