@@ -1,6 +1,6 @@
 <?php
 #NCleanGrey Theme - Theme for CMS Made Simple admin side.
-#(c)2008/9 by Author: Nuno Costa - nuno.mfcosta@sapo.pt  /  criacaoweb.net / http://dev.cmsmadesimple.org/users/nuno/
+#(c)2008/10 by Author: Nuno Costa - nuno.mfcosta@sapo.pt  /  criacaoweb.net / http://dev.cmsmadesimple.org/users/nuno/
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -27,9 +27,9 @@
 <link rel="Bookmark" href="themes/NCleanGrey/images/layout/ncleangrey-favicon.ico" />
 <script src="themes/NCleanGrey/includes/standard.js" type="text/javascript"></script>
 <link rel="stylesheet" type="text/css" media="screen, projection" href="loginstyle.php" />
-<base href="<?php global $gCms; $config =& $gCms->GetConfig(); echo $config['root_url'] . '/' . $config['admin_dir'] . '/'; ?>" />
+<base href="<?php global $gCms; $config = $gCms->GetConfig(); echo $config['root_url'] . '/' . $config['admin_dir'] . '/'; ?>" />
 </head>
-<body>
+<body class="body-login">
 <div class="login-all clear">
 <div class="info">
   <h1><?php echo lang('login_info_title')?></h1>
@@ -115,8 +115,6 @@
 
 </div>
 <div class="login-footer"></div>
-<div id="copy"> &copy; <a rel="external" href="http://www.cmsmadesimple.org" >CMS Made Simple</a>
-<br /> 
-Is free software released under the General Public Licence.</div>
+<div id="copy"> &copy; <a rel="external" href="http://www.cmsmadesimple.org" >CMS Made Simple</a>&trade;</div>
 </body>
 </html>
