@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: topadmin.php 6402 2010-06-25 00:44:47Z calguy1000 $
+#$Id: topadmin.php 6787 2010-11-14 17:14:18Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -25,10 +25,6 @@ require_once("../include.php");
 check_login();
 
 $section = 'siteadmin';
-if( isset($_GET['section']) )
-  {
-    $section = trim($_GET['section']);
-  }
 include_once("header.php");
 $themeObject->ShowShortcuts();
 $themeObject->DisplaySectionMenuDivStart();
