@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: index.php 6369 2010-06-08 15:25:33Z calguy1000 $
+#$Id: index.php 6899 2011-02-20 01:09:08Z calguy1000 $
 
 $orig_memory = (function_exists('memory_get_usage')?memory_get_usage():0);
 $dirname = dirname(__FILE__);
@@ -37,6 +37,11 @@ if (!isset($_SERVER['REQUEST_URI']) && isset($_SERVER['QUERY_STRING']))
 	$_SERVER['REQUEST_URI'] = $_SERVER['PHP_SELF'] . '?' . $_SERVER['QUERY_STRING'];
 }
 
+if (!file_exists(CONFIG_FILE_LOCATION) || filesize(CONFIG_FILE_LOCATION) < 800)
+  {
+    // attempt to create the config.php if it doesn't already exist.
+    @touch(CONFIG_FILE_LOCATION);
+  }
 if (!file_exists(CONFIG_FILE_LOCATION) || filesize(CONFIG_FILE_LOCATION) < 800)
 {
     require_once($dirname.'/lib/misc.functions.php');
@@ -77,12 +82,13 @@ else
 
 $params = array_merge($_GET, $_POST);
 
-$smarty = &$gCms->smarty;
+$smarty = cmsms()->GetSmarty();
 $smarty->params = $params;
 
 $page = get_pageid_or_alias_from_url();
+$contentops = cmsms()->GetContentOperations();
 
-$pageinfo = '';
+$contentobj = '';
 if( $page == '__CMS_PREVIEW_PAGE__' && isset($_SESSION['cms_preview']) ) // temporary
   {
     $tpl_name = trim($_SESSION['cms_preview']);
@@ -108,65 +114,102 @@ if( $page == '__CMS_PREVIEW_PAGE__' && isset($_SESSION['cms_preview']) ) // temp
     fclose($fh);
     unset($_SESSION['cms_preview']);
 
-    $pageinfo = PageInfoOperations::LoadPageInfoFromSerializedData($_SESSION['cms_preview_data']);
-    $pageinfo->content_id = '__CMS_PREVIEW_PAGE__';
+    $contentobj = $contentops->LoadContentFromSerializedData($_SESSION['cms_preview_data']);
+    $contentobj->setId('__CMS_PREVIEW_PAGE__');
+  }
+else
+  {
+    $contentobj = $contentops->LoadContentFromAlias($page,true);
   }
 
-if( !is_object($pageinfo) )
+if( !is_object($contentobj) )
   {
-    $pageinfo = PageInfoOperations::LoadPageInfoByContentAlias($page);
+    // specified page not found, load the 404 error page.
+    $contentobj = $contentops->LoadContentFromAlias('error404',true);
+    if( !is_object($contentobj) )
+      {
+	// that wasn't found either... display a hardcoded message.
+	ErrorHandler404();
+	return;
+      }
+    else
+      {
+	header("HTTP/1.0 404 Not Found");
+	header("Status: 404 Not Found");
+      }
   }
 
 // $page cannot be empty here
-if (isset($pageinfo) && $pageinfo !== FALSE)
+if (is_object($contentobj))
 {
-	$gCms->variables['pageinfo'] =& $pageinfo;
-
-	if( isset($pageinfo->template_encoding) && 
-	    $pageinfo->template_encoding != '' )
+  if( !$contentobj->IsViewable() )
+    {
+      $url = $contentobj->GetURL();
+      if( $url != '' && $url != '#' )
 	{
-	  set_encoding($pageinfo->template_encoding);
+	  redirect($url);
 	}
+    }
 
-	if($pageinfo->content_id > 0)
+  if( $contentobj->Secure() && 
+      (! isset($_SERVER['HTTPS']) || empty($_SERVER['HTTPS']) || $_SERVER['HTTPS'] == 'off') )
+    {
+      // if this page is marked to be secure, make sure we redirect to the secure page.
+      redirect($contentobj->GetURL());
+    }
+
+  $allow_cache = (int)get_site_preference('allow_browser_cache',0);
+  $expiry = (int)max(0,get_site_preference('browser_cache_expiry',60));
+  $expiry *= $allow_cache;
+  if( $_SERVER['REQUEST_METHOD'] == 'POST' || !$contentobj->Cachable() ||
+      $page == '__CMS_PREVIEW_PAGE__' || $expiry == 0 )
+    {
+      // Here we adjust headers for non cachable pages
+      header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
+      header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
+      header("Cache-Control: no-store, no-cache, must-revalidate");
+      header("Cache-Control: post-check=0, pre-check=0", false);
+      header("Pragma: no-cache");
+    }
+  else
+    {
+      // as far as we know, the output is cachable at this point... 
+      // so we mark it so that the output can be cached.
+      header('Expires: '.gmdate("D, d M Y H:i:s",time() + $expiry * 60).' GMT');
+      $the_date = time();
+      if( $contentobj->Cachable() )
 	{
-		$manager =& $gCms->GetHierarchyManager();
-		$node =& $manager->sureGetNodeById($pageinfo->content_id);
-		if(is_object($node))
-		{
-		  $contentobj =& $node->GetContent(true,true,false);
-		  if( !$contentobj->IsViewable() )
-		    {
-		      $url = $contentobj->GetURL();
-		      if( $url != '' && $url != '#' )
-			{
-			  redirect($url);
-			}
-		    }
-		  if( is_object($contentobj) )
-		    {
-		      $smarty->assign('content_obj',$contentobj);
-		    }
-		}
+	  $the_date = $contentobj->GetModifiedDate();
 	}
+      header('Last-Modified: ' . gmdate('D, d M Y H:i:s',$the_date) . ' GMT');
+    }
 
-	$gCms->variables['content_id'] = $pageinfo->content_id;
-	$gCms->variables['page'] = $page;
-	$gCms->variables['page_id'] = $page;
+  cmsms()->set_variable('content_obj',$contentobj);
+  $smarty->assign('content_obj',$contentobj);
 
-	$gCms->variables['page_name'] = $pageinfo->content_alias;
-	$gCms->variables['position'] = $pageinfo->content_hierarchy;
-	global $gCms;
-	$contentops =& $gCms->GetContentOperations();
-	$gCms->variables['friendly_position'] = $contentops->CreateFriendlyHierarchyPosition($pageinfo->content_hierarchy);
+  if( $contentobj->Secure() && 
+      (! isset($_SERVER['HTTPS']) || empty($_SERVER['HTTPS']) || $_SERVER['HTTPS'] == 'off') )
+    {
+      // if this page is marked to be secure, make sure we redirect to the secure page.
+      redirect($contentobj->GetURL());
+    }
 
-	$smarty->assign('content_id', $pageinfo->content_id);
-	$smarty->assign('page', $page);
-	$smarty->assign('page_id', $page);
-	$smarty->assign('page_name', $pageinfo->content_alias);
-	$smarty->assign('page_alias', $pageinfo->content_alias);
-	$smarty->assign('position', $pageinfo->content_hierarchy);
-	$smarty->assign('friendly_position', $gCms->variables['friendly_position']);
+  cmsms()->set_variable('content_obj',$contentobj);
+  cmsms()->set_variable('content_id',$contentobj->Id());
+  cmsms()->set_variable('page',$page);
+  cmsms()->set_variable('page_id',$page);
+  cmsms()->set_variable('page_name',$contentobj->Alias());
+  cmsms()->set_variable('position',$contentobj->Hierarchy());
+  cmsms()->set_variable('friendly_position',$contentops->CreateFriendlyHierarchyPosition($contentobj->Hierarchy()));
+
+  $smarty->assign('content_obj',$contentobj);
+  $smarty->assign('content_id', $contentobj->Id());
+  $smarty->assign('page', $page);
+  $smarty->assign('page_id', $page);
+  $smarty->assign('page_name', $contentobj->Alias());
+  $smarty->assign('page_alias', $contentobj->Alias());
+  $smarty->assign('position', $contentobj->Hierarchy());
+  $smarty->assign('friendly_position', $gCms->variables['friendly_position']);
 }
 else
 // else if (get_site_preference('enablecustom404') == '' || get_site_preference('enablecustom404') == "0")
@@ -176,7 +219,6 @@ else
 }
 
 $html = '';
-$cached = '';
 $showtemplate = true;
 
 if ((isset($_REQUEST['showtemplate']) && $_REQUEST['showtemplate'] == 'false') ||
@@ -188,21 +230,32 @@ if ((isset($_REQUEST['showtemplate']) && $_REQUEST['showtemplate'] == 'false') |
 
 if (isset($_GET["print"]))
 {
-	($smarty->is_cached('print:'.$page, '', $pageinfo->template_id)?$cached="":$cached="not ");
-	$html = $smarty->fetch('print:'.$page, '', $pageinfo->template_id) . "\n";
+  $pageinfo = cmsms()->get_variable('pageinfo');
+  $html = $smarty->fetch('print:'.$page, '', $pageinfo->template_id) . "\n";
 }
 else
 {
 	#If this is a case where a module doesn't want a template to be shown, just disable caching
         if( !$showtemplate )
 	{
-		$html = $smarty->fetch('template:notemplate') . "\n";
+	  // snarfed from process_pagedata plugin
+	  $tpl = $contentobj->GetPropertyValue('pagedata','');
+	  if( !empty($tpl) ) 
+	    {
+	      $smarty->_compile_source('preprocess template', $tpl, $_compiled);
+	      @ob_start();
+	      $smarty->_eval('?>' . $_compiled);
+	      $result = @ob_get_contents();
+	      @ob_end_clean();
+	    }
+
+	  // now parse the default content block.
+	  $html = $smarty->fetch('template:notemplate') . "\n";
 	}
 	else
 	{
-		$smarty->caching = false;
-		$smarty->compile_check = true;
-		($smarty->is_cached('template:'.$pageinfo->template_id)?$cached="":$cached="not ");
+	  //$smarty->caching = false;
+	  //	$smarty->compile_check = true;
 
 		// we allow backward compatibility (for a while)
 		// for people that have hacks for setting page title
@@ -210,56 +263,22 @@ else
 		// to a smarty variable, and then displaying it later.
 		if( isset($config['process_whole_template']) && $config['process_whole_template'] === false )
 		  {
-		    $top  = $smarty->fetch('tpl_top:'.$pageinfo->template_id);
-		    $body = $smarty->fetch('tpl_body:'.$pageinfo->template_id);
-		    $head = $smarty->fetch('tpl_head:'.$pageinfo->template_id);
+		    $top  = $smarty->fetch('tpl_top:'.$contentobj->TemplateId());
+		    $body = $smarty->fetch('tpl_body:'.$contentobj->TemplateId());
+		    $head = $smarty->fetch('tpl_head:'.$contentobj->TemplateId());
 		    $html = $top.$head.$body;
 		  }
 		else
 		  {
-		    $html = $smarty->fetch('template:'.$pageinfo->template_id);
+		    $html = $smarty->fetch('template:'.$contentobj->TemplateId());
 		  }
 	}
 }
 
-#if ((get_site_preference('enablecustom404') == '' || get_site_preference('enablecustom404') == "0") && (!$config['debug']))
-#{
-#	set_error_handler($old_error_handler);
-#}
-
-#if (!$cached)
-#{
-	#Perform the content postrendernoncached callback
-#	reset($gCms->modules);
-#	while (list($key) = each($gCms->modules))
-#	{
-#		$value =& $gCms->modules[$key];
-#		if ($gCms->modules[$key]['installed'] == true &&
-#			$gCms->modules[$key]['active'] == true)
-#		{
-#			$gCms->modules[$key]['object']->ContentPostRenderNonCached($html);
-#		}
-#	}
-  // this event doesn't exist in 1.7.x
-	//Events::SendEvent('Core', 'ContentPostRenderNonCached', array(&$html));
-#}
-
-#Perform the content postrender callback
-#reset($gCms->modules);
-#while (list($key) = each($gCms->modules))
-#{
-#	$value =& $gCms->modules[$key];
-#	if ( isset($gCms->modules[$key]['installed']) &&
-#	     $gCms->modules[$key]['installed'] == true &&
-#		$gCms->modules[$key]['active'] == true)
-#	{
-#		$gCms->modules[$key]['object']->ContentPostRender($html);
-#	}
-#}
 
 Events::SendEvent('Core', 'ContentPostRender', array('content' => &$html));
 
-header("Content-Type: " . $gCms->variables['content-type'] . "; charset=" . (isset($pageinfo->template_encoding) && $pageinfo->template_encoding != ''?$pageinfo->template_encoding:get_encoding()));
+header("Content-Type: " . cmsms()->get_variable('content-type') . "; charset=" . get_encoding());
 
 echo $html;
 
@@ -267,7 +286,7 @@ echo $html;
 
 $endtime = microtime();
 
-$db =& $gCms->GetDb();
+$db =& cmsms()->GetDb();
 
 $memory = (function_exists('memory_get_usage')?memory_get_usage():0);
 $memory = $memory - $orig_memory;
@@ -308,5 +327,7 @@ if( $page == '__CMS_PREVIEW_PAGE__' && isset($_SESSION['cms_preview']) ) // temp
   {
     unset($_SESSION['cms_preview']);
   }
+
+
 # vim:ts=4 sw=4 noet
 ?>
