@@ -1,10 +1,14 @@
 <?php
+$lang['setup_flat_urls'] = 'Flat URLs are setup';
+$lang['install_timezone'] = 'Some servers running PHP 5.3 do not have the timezone set correctly. Please select the appropriate timezone from the list below before proceeding. If this is not necessary on your server, you may select &quot;None&quot;. <strong>Note:</strong> Please select your servers timezone, this is not a display setting, but is used in arithmatic related to dates.  This setting can be changed after installation by modifying the config.php file.';
+$lang['timezone'] = 'Timezone';
+$lang['none'] = 'None';
 $lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
 $lang['test_estrict_failed'] = 'E_STRICT is enabled';
 $lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
 $lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
 $lang['test_edeprecated_failed'] = 'E_DEPRECATED is enabled';
-$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see alot of warning messages that could effect the display and functionalty';
+$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see a lot of warning messages that could effect the display and functionality';
 $lang['invalidemail'] = 'The email address entered is invalid';
 $lang['empty_query'] = 'Empty query?? %s';
 $lang['no_db_driver'] = 'No compatible database drivers found';
@@ -49,7 +53,7 @@ $lang['noneed_upgrade_modules'] = 'The core modules are up to date';
 $lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of "%s" module from %s to %s ...';
 $lang['upgrade_event_module_from_to'] = 'Upgrading Events of "%s" module from %s to %s ...';
 $lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a "Site Down for Maintainence" message on your site';
-$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it\'s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as "Needs Upgrade"';
+$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it\'s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Module Manager page and looking in the tab "Available Upgrades"';
 $lang['upgrade_complete'] = 'Upgrade process complete';
 $lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
 $lang['here'] = 'here';
@@ -299,7 +303,7 @@ $lang['test_check_modules_failed'] = 'The modules folder is not writable. You ca
 $lang['test_check_file_get_contents'] = 'Checking for file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'You will probably not be able to use any of functionality that uses this function';
 $lang['test_check_session_save_path'] = 'Checking if session.save_path is writable';
-$lang['test_empty_session_save_path'] = 'Your session.save_path is empty. PHP will use the temporary directory of your OS. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(\'session.use_only_cookies\', 1);  on top of include.php';
+$lang['test_empty_session_save_path'] = 'Your session.save_path is empty. PHP will use the temporary directory of your OS. If you have SESSION problems and ini_set works you can try to enable session cookies by adding: ini_set(\'session.use_only_cookies\', 1);  in the top of your config.php file';
 $lang['test_check_session_save_path_failed'] = 'Your session.save_path is "%s". Not having this as writable may make logins to the Admin Panel not work. You may want to look into making this path writable if you have trouble logging into the Admin Panel. This test may fail if safe_mode is enabled (see below).';
 $lang['test_check_ini_set'] = 'Checking if ini_set works';
 $lang['test_check_ini_set_failed'] = 'Although the ability to override php ini settings is not mandatory, some addon (optional) functionality uses ini_set to extend timeouts, and allow uploading of larger files, etc. You may have difficulty with some addon functionality without this capability. This test may fail if safe_mode is enabled (see below).';
@@ -347,7 +351,7 @@ $lang['install_admin_docroot'] = 'CMS Document root (as seen from the webserver)
 $lang['install_admin_docroot_path'] = 'Path to the Document root';
 $lang['install_admin_querystring'] = 'Query string (leave this alone unless you have trouble, then edit config.php by hand)';
 $lang['invalid_query'] = 'Invalid query: %s';
-$lang['invalid_querys'] = '<b>WARNING<b/>: Invalid queries on your DB!';
+$lang['invalid_querys'] = '<b>WARNING</b>: Invalid queries on your DB!';
 $lang['install_admin_sitedown'] = 'Error: Could not remove the tmp/cache/SITEDOWN file. Please remove manually.';
 $lang['install_admin_update_hierarchy'] = 'Updating hierarchy positions...';
 $lang['install_admin_set_core_event'] = 'Setting up core events...';
