@@ -1,10 +1,12 @@
 <?php
+$lang['invalidemail'] = 'L&#039;adre&ccedil;a d&#039;email no &eacute;s v&agrave;lida';
+$lang['empty_query'] = 'Consulta buida?? %s';
 $lang['no_db_driver'] = 'No s&#039;han trobat drivers de base de dades compatibles';
-$lang['test_check_output_buffering'] = 'Checking output buffering';
-$lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
+$lang['test_check_output_buffering'] = 'Verfificant la capacitat de sortida';
+$lang['test_check_output_buffering_failed'] = 'Output buffering est&agrave; deshabilitat. Altament probable que no puguis utilitzar cap fucni&oacute; que ho requereixi';
 $lang['phpinfo'] = 'Mostra informaci&oacute; de PHP';
-$lang['mod_security'] = 'Apache Mod Security';
-$lang['test_check_tempnam'] = 'Checking for tempnam Function';
+$lang['mod_security'] = 'Mod Security d&#039;Apache';
+$lang['test_check_tempnam'] = 'Verificant la funci&oacute; tempnam';
 $lang['test_check_db_drivers'] = 'Drivers de BD';
 $lang['test_check_db_drivers_failed'] = 'No s&#039;han trobat dirvers de BD';
 $lang['test_check_register_globals'] = 'Verificant l&#039;opcio PHP de registre de globals';
@@ -13,9 +15,9 @@ $lang['test_check_disable_functions'] = 'Verificant funcions PHP deshabilitades'
 $lang['test_check_disable_functions_failed'] = 'Aix&ograve; &eacute;s una llista de funcions deshabilitades en el teu servidor';
 $lang['install_admin_db_port'] = 'Port de base de dades';
 $lang['install_admin_db_port_info'] = 'If you don&#039;t know, leave this blank to use default settings.';
-$lang['install_admin_db_socket'] = 'Database socket';
-$lang['install_admin_db_socket_info'] = 'NOT SUPPORTED.';
-$lang['install_admin_frontendlang'] = 'Default language for the frontend. This adjusts the locale used for various default date handling functions, etc.';
+$lang['install_admin_db_socket'] = 'connector de Base de dades';
+$lang['install_admin_db_socket_info'] = 'NO SUPORTAT';
+$lang['install_admin_frontendlang'] = 'Idioma per defecte de la part d&#039;usuari final. Aix&ograve; ajusta el &#039;locale&#039; utilitzat per diverses funcions de gesti&oacute; de dates, etc.';
 $lang['install_default_encoding'] = 'En la majoria de casos, default_encoding hauria de ser utf-8. Si en volguessis un de diferents, es pot canviar per&ograve; cal considerar que les traduccions a diferents idiomes s&oacute;n totes en utf-8';
 $lang['installer_done'] = '[fet]';
 $lang['installer_failed'] = '[ha fallat]';
@@ -26,33 +28,33 @@ $lang['installing_module'] = 'Instal.lant el m&ograve;dul %s ...';
 $lang['updating_schema_version'] = 'Actualitzant la versi&oacute; d&#039;esquema %s ...';
 $lang['upgrade_config'] = 'Actualitzant config.php';
 $lang['upgrade_config_info'] = 'configuraci&oacute; de l&#039;actualitzaci&oacute;';
-$lang['upgrade_failed_again'] = 'One or more upgrades have failed. Please correct the problem and click the button below to recheck.';
-$lang['upgrade_cache_dirs'] = 'Cleaning cache dirs';
-$lang['cannot_clean_cache_dirs'] = 'Cannot cleaning cache dirs!';
-$lang['upgrade_schema'] = 'Upgrade schema';
-$lang['need_upgrade_schema'] = 'CMS is in need of an upgrade.<br />You are now running schema version %s and you need to be upgraded to version %s';
-$lang['schema_ok'] = 'Now the CMS database is up to date using schema version %s';
-$lang['noneed_upgrade_schema'] = 'The CMS database is up to date using schema version %s';
-$lang['upgrade_modules'] = 'Upgrade modules';
-$lang['noneed_upgrade_modules'] = 'The core modules are up to date';
+$lang['upgrade_failed_again'] = 'Una o m&eacute;s actualitzacions han fallat. Si et plau, corregeix elproblema i pica el bot&oacute; de sota per tornar a verificar';
+$lang['upgrade_cache_dirs'] = 'Esborrant els directoris de mem&ograve;ria cau';
+$lang['cannot_clean_cache_dirs'] = 'No puc esborrar els directoris de mem&ograve;ria cau!';
+$lang['upgrade_schema'] = 'Actualitzant l&#039;esquema';
+$lang['need_upgrade_schema'] = 'CMS necessita una actualitzaci&oacute;.<br />Est&agrave;s treballant amb l&#039;esquema de versi&oacute; %s i necessites pujar fins la versi&oacute; %s';
+$lang['schema_ok'] = 'Ara la base de dades CMS est&agrave; actualitzada. S&#039;est&agrave; utilitzant la versi&oacute; d&#039;esquema %s';
+$lang['noneed_upgrade_schema'] = 'Ara la base de dades CMS est&agrave; actualitzada. S&#039;est&agrave; utilitzant la versi&oacute; d&#039;esquema %s';
+$lang['upgrade_modules'] = 'Actualitzaci&oacute; de m&ograve;duls';
+$lang['noneed_upgrade_modules'] = 'Els m&ograve;duls del nucli b&agrave;sic estan actualitzats';
 $lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of &quot;%s&quot; module from %s to %s ...';
 $lang['upgrade_event_module_from_to'] = 'Upgrading Events of &quot;%s&quot; module from %s to %s ...';
 $lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a &quot;Site Down for Maintainence&quot; message on your site';
 $lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it&#039;s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as &quot;Needs Upgrade&quot;';
-$lang['upgrade_complete'] = 'Upgrade process complete';
+$lang['upgrade_complete'] = 'Proc&eacute;s d&#039;actualitzaci&oacute; acomplert';
 $lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
-$lang['here'] = 'here';
-$lang['go_to_admin'] = 'go to the Admin Panel';
-$lang['errorfilenot'] = 'File string not found!';
-$lang['errorfilenotwritable'] = 'File not writable!';
-$lang['nofiles'] = 'This resource not exist!';
-$lang['is_directory'] = 'This resource is a directory!';
-$lang['is_readable_false'] = 'This resource is not readable!';
-$lang['checksum_match'] = 'Checksum match!';
-$lang['checksum_not_match'] = 'Checksum not match!';
-$lang['not_checksum'] = 'No checksum retrieve!';
+$lang['here'] = 'aqu&iacute;';
+$lang['go_to_admin'] = 'V&eacute;s al penell d&#039;administraci&oacute;';
+$lang['errorfilenot'] = 'Arxiu no localitzat!';
+$lang['errorfilenotwritable'] = 'Arxiu no modificable!';
+$lang['nofiles'] = 'Aquest recurs no existeix';
+$lang['is_directory'] = 'Aquest recurs &eacute;s un directori!';
+$lang['is_readable_false'] = 'Aquest recurs no &eacute;s llegible!';
+$lang['checksum_match'] = 'La signatura encaixa!';
+$lang['checksum_not_match'] = 'La signatura no encaixa!';
+$lang['not_checksum'] = 'No hi ha signatura per recuperar!';
 $lang['format_datetime'] = '%c';
-$lang['upload_err_ini_size'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini!';
+$lang['upload_err_ini_size'] = 'L&#039;arxiu pujat excedeix la directiva upload_max_filesize de l&#039;arxiu php.ini';
 $lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
 $lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
 $lang['upload_err_no_file'] = 'No file was uploaded.';
@@ -330,8 +332,9 @@ username: %s
 password: %s
 
 Log into the site admin here: %s';
-$lang['utma'] = '156861353.3109145977533247500.1225311312.1232346877.1232394560.23';
-$lang['utmz'] = '156861353.1230233047.10.2.utmccn=(referral)|utmcsr=clubcoc.cat|utmcct=//admin/systeminfo.php|utmcmd=referral';
+$lang['utma'] = '156861353.3109145977533247500.1225311312.1259216857.1259266070.48';
+$lang['utmz'] = '156861353.1254088757.35.2.utmccn=(referral)|utmcsr=66.147.244.155|utmcct=/~clubcocc/cmsmadesimple/install/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-894451108-1250455823820';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1232394560';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
