@@ -1,4 +1,14 @@
 <?php
+$lang['setup_flat_urls'] = 'Nastavuj&iacute; se ploch&eacute; URL';
+$lang['install_timezone'] = 'Někter&eacute; server s PHP 5.3 nemaj&iacute; spr&aacute;vně nastavenou časovou z&oacute;nu. vyberte pros&iacute;m odpov&iacute;daj&iacute;c&iacute; časovou z&oacute;nu ze seznamu n&iacute;že před pokračov&aacute;n&iacute;m. Pokud to nen&iacute; nutn&eacute; na Va&scaron;em serveru, můžete vybrat &quot;Ž&aacute;dn&yacute;&quot;. <strong>Pozn&aacute;mka:</strong> Vyberte časovou z&oacute;nu Va&scaron;eho serveru, toto neovlivn&iacute; zobrazen&iacute;, ale je použito při v&yacute;počtech vztahuj&iacute;c&iacute;ch se k datumu. Toto nastaven&iacute; může b&yacute;t změněno po instalaci &uacute;pravou souboru config.php.';
+$lang['timezone'] = 'Časov&aacute; z&oacute;na';
+$lang['none'] = 'Ž&aacute;dn&aacute;';
+$lang['test_error_estrict'] = 'Testuje je error_reporting pro uji&scaron;těn&iacute;, že E_STRICT je zak&aacute;z&aacute;no';
+$lang['test_estrict_failed'] = 'E_STRICT ije pololeno';
+$lang['info_estrict_failed'] = 'Někter&eacute; knihovny použ&iacute;van&eacute; CMSMS nepracuj&iacute; spr&aacute;vně s E_STRICT.  Před pokračov&aacute;n&iacute;m to pros&iacute;m zakažte';
+$lang['test_error_edeprecated'] = 'Testuje se error_reporting pro uji&scaron;těn&iacute;, že E_DEPRECATED je zak&aacute;z&aacute;no';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED je povoleno';
+$lang['info_edeprecated_failed'] = 'Při povolen&eacute;m E_DEPRECATED ve Va&scaron;em logov&aacute;n&iacute; chyb uvid&iacute; uživatel&eacute; mnoho chybov&yacute;ch hl&aacute;&scaron;en&iacute;, což může ovlivnit zobrazen&iacute; nebo funkcionalitu';
 $lang['invalidemail'] = 'Vložen&aacute; emailov&aacute; adresa je neplatn&aacute;';
 $lang['empty_query'] = 'Pr&aacute;zdn&yacute; dotaz?? %s';
 $lang['no_db_driver'] = 'Nenalezeny kompatibiln&iacute; ovladače datab&aacute;ze';
@@ -333,9 +343,9 @@ uživatelsk&eacute; jm&eacute;no: %s
 heslo: %s
 
 Přihl&aacute;sit do administrace se můžete zde: %s';
-$lang['utma'] = '156861353.3769824904990279700.1249913289.1261996808.1263200482.16';
-$lang['utmz'] = '156861353.1249913289.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = '1229762881-19854751-99654968';
-$lang['utmb'] = '156861353.1.10.1263200482';
+$lang['utma'] = '156861353.682233951.1296068669.1297424355.1297458685.21';
+$lang['utmz'] = '156861353.1296946283.16.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-796774439-1296068668929';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
