@@ -1,9 +1,12 @@
 <?php
+$lang['install_timezone'] = 'Some servers running php 5.3 have not set the timezone correctly.  Please select the appropriate timezone from the list before.  If this is not necessary on your server you may select &quot;None&quot;, you can always change this setting later in the config.php.';
+$lang['timezone'] = 'Tidszone';
+$lang['none'] = 'INgen';
 $lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
-$lang['test_estrict_failed'] = 'E_STRICT is enabled';
+$lang['test_estrict_failed'] = 'E_STRICT er sl&aring;et til';
 $lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
 $lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
-$lang['test_edeprecated_failed'] = 'E_DEPRECATED is enabled';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED er sl&aring;et til';
 $lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see alot of warning messages that could effect the display and functionalty';
 $lang['invalidemail'] = 'Den angivne email adresse er ikke gyldig';
 $lang['empty_query'] = 'Tom foresp&oslash;rgsel? %s';
@@ -338,8 +341,8 @@ brugernavn: %s
 kodeord: %s
 
 Log ind i site administrationen her: %s';
-$lang['utma'] = '156861353.2039886585.1231713618.1270923295.1271012110.115';
-$lang['utmz'] = '156861353.1269788432.113.24.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.2039886585.1231713618.1288347746.1288628456.167';
+$lang['utmz'] = '156861353.1286879837.162.50.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,64.0.html';
 $lang['qca'] = '1229601790-85243197-43260713';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
