@@ -1,8 +1,13 @@
 <?php
-$lang['test_error_estrict'] = 'Teste error_reporting, um sicherzustellen, dass E_STRICT deaktiviert ist';
+$lang['setup_flat_urls'] = 'Es sind flache URLs eingestellt';
+$lang['install_timezone'] = 'Bei einigen Server, die PHP 5.3 verwenden, wurde die Zeitzone nicht / nicht korrekt eingestellt. Bitte w&auml;hlen Sie daher die Zeitzone f&uuml;r Ihre Webseite aus der Liste aus. Falls dies auf Ihrem Server nicht erforderlich ist, w&auml;hlen Sie &quot;Keine&quot;.
+<strong>Hinweis:</strong> Bitte w&auml;hlen Sie hier die Zeitzone Ihres Servers. Dies ist nicht die Einstellung f&uuml;r die Datumsanzeige, sondern wird f&uuml;r datumsbezogene Berechnung Terminen verwendet. Diese Einstellung kann nach der Installation in der config.php ge&auml;ndert werden.';
+$lang['timezone'] = 'Zeitzone';
+$lang['none'] = 'Keine';
+$lang['test_error_estrict'] = 'Test der Einstellung error_reporting, um sicherzustellen, dass E_STRICT deaktiviert ist';
 $lang['test_estrict_failed'] = 'E_STRICT ist aktiviert';
-$lang['info_estrict_failed'] = 'Einige Programmbibliotheken, die CMSms verwendet, funktionieren nicht gut mit E_STRICT.  Bitte deaktivieren Sie dies, bevor Sie weitermachen.';
-$lang['test_error_edeprecated'] = 'Teste error_reporting, um sicherzustellen, dass E_DEPRECATED deaktiviert ist';
+$lang['info_estrict_failed'] = 'Einige Programmbibliotheken, die CMSms verwendet, funktionieren nicht gut mit E_STRICT.  Bitte deaktivieren Sie diese Einstellung, bevor Sie weitermachen.';
+$lang['test_error_edeprecated'] = 'Test der Einstellung error_reporting, um sicherzustellen, dass E_DEPRECATED deaktiviert ist';
 $lang['test_edeprecated_failed'] = 'E_DEPRECATED ist aktiviert';
 $lang['info_edeprecated_failed'] = 'Wenn E_DEPRECATED in Ihren error_reporting Einstellungen aktiviert ist, werden eine ganze Reihe von Warnhinweisen angezeigt, die Auswirkungen auf die Anzeige und die Funktionalit&auml;ten haben k&ouml;nnen.';
 $lang['invalidemail'] = 'Die eingegebene Email-Adresse ist ung&uuml;ltig';
@@ -20,31 +25,31 @@ $lang['test_check_register_globals_failed'] = 'PHP register globals ist auf Ihre
 $lang['test_check_disable_functions'] = 'Pr&uuml;fung auf deaktivierte PHP-Funktionen';
 $lang['test_check_disable_functions_failed'] = 'Dies ist eine Liste der Funktionen, die auf Ihrem Server deaktiviert sind.';
 $lang['install_admin_db_port'] = 'Datenbank-Port';
-$lang['install_admin_db_port_info'] = 'Wenn Sie diesen Wert nicht kennen, lassen Sie ihn leer. Dann wird der serverseitig voreingestellte Datenbank-Port verwendet.';
+$lang['install_admin_db_port_info'] = 'Wenn Sie diesen Wert nicht kennen, lassen Sie ihn leer. Dann werden die serverseitigen Voreinstellungen verwendet.';
 $lang['install_admin_db_socket'] = 'Datenbank-Socket';
 $lang['install_admin_db_socket_info'] = 'AKTUELL NICHT UNTERST&Uuml;TZT.';
-$lang['install_admin_frontendlang'] = 'Voreingestellte Sprache f&uuml;r die Webseite. Der Wert dieses Feldes wird f&uuml;r die Voreinstellung verschiedener Funktionen verwendet (z.Bsp. Datums-Funktionen). Lassen Sie dieses Feld leer, wenn Sie eine mehrsprachige Webseite betreiben oder die Voreinstellungen des Servers verwenden m&ouml;chten.';
+$lang['install_admin_frontendlang'] = 'Voreingestellte Sprache f&uuml;r die Webseite. Der Wert dieses Feldes wird f&uuml;r die Voreinstellung verschiedener Funktionen verwendet (z.Bsp. Datums-Funktionen).';
 $lang['install_default_encoding'] = 'In den meisten F&auml;llen sollte die Standard-Kodierung utf-8 sein. Wenn Sie eine andere Kodierung verwenden m&ouml;chten, k&ouml;nnen Sie dies &auml;ndern. Bitte bedenken Sie jedoch, dass die Sprachdateien alle in utf-8 kodiert sind.';
 $lang['installer_done'] = '[erledigt]';
 $lang['installer_failed'] = '[fehlgeschlagen]';
-$lang['create_permission'] = 'Erstelle Berechtigung ...';
-$lang['add_column_sql'] = 'F&uuml;ge der Tabelle %s eine weitere Spalte hinzu ...';
-$lang['update_table_sql'] = 'Aktualisiere die Tabelle %s ...';
-$lang['installing_module'] = 'Installiere das Modul %s ...';
-$lang['updating_schema_version'] = 'Aktualisiere Schema-Version %s ...';
+$lang['create_permission'] = 'Erstellung der Berechtigung ...';
+$lang['add_column_sql'] = 'Erweiterung der Tabelle %s um eine Spalte ...';
+$lang['update_table_sql'] = 'Aktualisierung der Tabelle %s ...';
+$lang['installing_module'] = 'Installation des Moduls %s ...';
+$lang['updating_schema_version'] = 'Aktualisierung der Schema-Version %s ...';
 $lang['upgrade_config'] = 'Die Datei config.php wird aktualisiert';
 $lang['upgrade_config_info'] = 'Aktualisierung wird konfiguriert';
-$lang['upgrade_failed_again'] = 'Ein oder mehrere Aktualisierungspr&uuml;fungen sind fehlgeschlagen. Bitte beheben Sie das Problem und klicken Sie den unten stehenden Button f&uuml;r eine erneute Pr&uuml;fung.';
+$lang['upgrade_failed_again'] = 'Ein oder mehrere Aktualisierungen sind fehlgeschlagen. Bitte beheben Sie das Problem und klicken Sie den unten stehenden Button f&uuml;r eine erneute Pr&uuml;fung.';
 $lang['upgrade_cache_dirs'] = 'Zwischenspeicher wird geleert';
 $lang['cannot_clean_cache_dirs'] = 'Konnte den Zwischenspeicher nicht leeren!';
 $lang['upgrade_schema'] = 'Schema aktualisieren';
 $lang['need_upgrade_schema'] = 'Ihr CMS ben&ouml;tigt eine Aktualisierung.<br />Sie verwenden aktuell Schema-Version %s und m&uuml;ssen auf Version %s aktualisieren';
-$lang['schema_ok'] = 'Jetzt ist Ihre CMS-Datenbank mit der Schema-Version %s aktuell';
-$lang['noneed_upgrade_schema'] = 'Ihre CMS-Datenbank ist mit der verwendeten Schema-Version %s aktuell';
-$lang['upgrade_modules'] = 'Aktualisiere die Module';
+$lang['schema_ok'] = 'Jetzt ist Ihre CMS-Datenbank ist aktuell. Es wird die Schema-Version %s verwendet.';
+$lang['noneed_upgrade_schema'] = 'Jetzt ist Ihre CMS-Datenbank ist aktuell. Es wird die Schema-Version %s verwendet.';
+$lang['upgrade_modules'] = 'Aktualisierung der Module';
 $lang['noneed_upgrade_modules'] = 'Die Core-Module sind auf dem aktuellsten Stand';
-$lang['upgrade_sql_module_from_to'] = 'Aktualisiere die Datenbank des &quot;%s&quot;-Moduls von %s auf %s ...';
-$lang['upgrade_event_module_from_to'] = 'Aktualisiere die Ereignisse des &quot;%s&quot;-Moduls von %s auf %s ...';
+$lang['upgrade_sql_module_from_to'] = 'Aktualisierung der Datenbank des &quot;%s&quot;-Moduls von %s auf %s ...';
+$lang['upgrade_event_module_from_to'] = 'Aktualisierung der Ereignisse des &quot;%s&quot;-Moduls von %s auf %s ...';
 $lang['sitedown_not_removed'] = 'Die Datei <em>tmp/cache/SITEDOWN</em> konnte nicht entfernen werden. Bitte l&ouml;schen Sie diese Datei manuell, bis dahin wird auf Ihrer Webseite eine Wartungsmeldung angezeigt.';
 $lang['upgrade_ok'] = 'Bitte schauen Sie sich die Datei config.php an, &auml;ndern ggf. die neuen Einstellungen nach Ihren Vorstellungen und setzen dann die Berechtigung f&uuml;r diese Datei auf einen sicheren Wert zur&uuml;ck. Sie sollten au&szlig;erdem pr&uuml;fen, dass alle Module aktuell sind. Dies k&ouml;nnen Sie in der Administration unter &quot;Erweiterungen > Module&quot; pr&uuml;fen. Das jeweilige Modul ist dann mit dem Hinweis &quot;Ben&ouml;tigt eine Aktualisierung&quot; versehen.';
 $lang['upgrade_complete'] = 'Die Aktualisierung wurde erfolgreich beendet';
@@ -86,7 +91,8 @@ $lang['checksum_failed'] = 'Die Pr&uuml;fsumme stimmt mit einigen Fehlern &uuml;
 $lang['test_check_open_basedir'] = 'Pr&uuml;fung auf PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen sind bei Ihnen aktiviert. Aufgrund dieser Beschr&auml;nkung k&ouml;nnen bei bestimmten Funktionalit&auml;ten Probleme auftreten.';
 $lang['unlimited'] = 'Keine Einschr&auml;nkung';
-$lang['test_open_basedir_session_save_path'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen scheint bei Ihnen aktiviert zu sein. Wenn Sie Probleme mit Sessions haben, aber der Befehl ini_set ausgef&uuml;hrt werden kann, k&ouml;nnen Sie versuchen, die Option &quot;session by cookies&quot; zu aktivieren, indem Sie der Datei config.php gleich als erste Zeile folgendes hinzuf&uuml;gen: ini_set(&#039;session.use_only_cookies&#039;, 1);';
+$lang['test_open_basedir_session_save_path'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen scheint bei Ihnen aktiviert zu sein. Wenn Sie Probleme mit Sessions haben, aber der Befehl ini_set ausgef&uuml;hrt werden kann, k&ouml;nnen Sie versuchen, die Option &quot;session by cookies&quot; zu aktivieren, indem Sie der Datei config.php gleich als erste Zeile folgendes hinzuf&uuml;gen: 
+<code>ini_set(&#039;session.use_only_cookies&#039;, 1);</code>';
 $lang['install_warn_db_createtables'] = 'Im Normalfall sollte dieses Kontrollfeld aktiviert sein. Sie sollten wissen, was Sie tun, wenn Sie diese Funktion deaktivieren.';
 $lang['install_admin_tablesnotcreated'] = 'Die Installation ist jetzt vollst&auml;ndig. Aufgrund Ihrer Einstellungen wurden die Datenbanktabellen NICHT erzeugt. Die Einstellungen wurden in der Datei config.php wurden gespeichert und alle Tests erfolgreich absolviert.  Vielen Dank, hier ist Ihr';
 $lang['info_create_dir_and_file'] = 'Der httpd-Proze&szlig; konnte keine Datei in eigenen Verzeichnissen erzeugen. Das bedeutet, dass der Safe-Modus auf Ihrem Host aktiviert ist. Ohne diese F&auml;higkeit k&ouml;nnen einige Funktionen von CMS made simple jedoch nicht arbeiten. Die Fortsetzung ist daher nicht m&ouml;glich.';
@@ -94,7 +100,7 @@ $lang['test_create_dir_and_file'] = 'Pr&uuml;fung, ob der httpd-Proze&szlig; ein
 $lang['cms_site'] = 'CMS-Seite';
 $lang['or_greater'] = 'Oder h&ouml;her';
 $lang['sitename'] = 'Name der Webseite';
-$lang['warning_safe_mode'] = '<strong><em>WARNUNG:</em></strong> Der PHP-Safe-Modus ist auf Ihrem Server aktiviert. Beim Hochladen von Bildern, Themes und Modul-XML-Dateien kann es zu Problemen kommen. Fragen Sie den Server-Administrator, ob er den Safe-Modus deaktiviert.';
+$lang['warning_safe_mode'] = '<strong>WARNUNG:</strong> Der PHP-Safe-Modus ist auf Ihrem Server aktiviert. Beim Hochladen von Bildern, Themes und Modul-XML-Dateien kann es zu Problemen kommen. Fragen Sie den Server-Administrator, ob er den Safe-Modus deaktiviert.';
 $lang['test'] = 'Testen';
 $lang['results'] = 'Ergebnisse';
 $lang['untested'] = 'Nicht getestet';
@@ -190,7 +196,7 @@ $lang['username'] = 'Benutzername';
 $lang['usernameincorrect'] = 'Benutzername oder Passwort sind falsch';
 $lang['version'] = 'Version ';
 $lang['install_title'] = 'CMS Made Simple - Installation - Schritt %s';
-$lang['install_system'] = 'Installations-System';
+$lang['install_system'] = 'Systeminstallation';
 $lang['install_thanks'] = 'Vielen Dank f&uuml;r die Installation von CMS made simple';
 $lang['upgrade_title'] = 'CMS made simple - Aktualisierung - Schritt %s';
 $lang['upgrade_system'] = 'Aktualisierungs-System';
@@ -237,7 +243,7 @@ $lang['test_could_not_create_table'] = 'Eine Tabelle konnte nicht erstellt werde
 $lang['test_check_php'] = 'Pr&uuml;fung auf PHP-Version %s+';
 $lang['test_min_recommend'] = '(minimal %s, empfohlen %s oder h&ouml;her)';
 $lang['test_min_recommend_plus'] = '(minimal %s, empfohlen %s+)';
-$lang['test_requires_php_version'] = 'CMS made simple ben&ouml;tigt PHP in der Version 4.3 oder h&ouml;her (Sie haben %s). Um eine maximale Kompatibilit&auml;t mit Erweiterungen von Drittanbietern sicherzustellen, wird die Verwendung von PHP %s oder h&ouml;her empfohlen.';
+$lang['test_requires_php_version'] = 'CMS made simple ben&ouml;tigt PHP in der Version 5.2.4 oder h&ouml;her (Sie haben %s). Um eine maximale Kompatibilit&auml;t mit Erweiterungen von Drittanbietern sicherzustellen, wird die Verwendung von PHP %s oder h&ouml;her empfohlen.';
 $lang['test_check_md5_func'] = 'Pr&uuml;fung auf MD5-Funktionen';
 $lang['test_check_safe_mode'] = 'Pr&uuml;fung auf die Verwendung des Safe-Modus';
 $lang['test_check_safe_mode_failed'] = 'Wenn der PHP-Safe-Modus verwendet wird, kann es beim Hochladen von Dateien und anderen Funktionen zu Problemen kommen. Dies ist davon abh&auml;ngig, wie streng die Einstellungen Ihres Servers bez&uuml;glich des Safe-Modus sind.';
@@ -272,13 +278,13 @@ $lang['test_check_post_max_failed'] = 'Es ist Ihnen nicht m&ouml;glich, (gr&ouml
 $lang['test_check_upload_max'] = 'Pr&uuml;fung der maximal hochladbaren Datei-Gr&ouml;&szlig;e';
 $lang['test_check_upload_max_failed'] = 'Es ist Ihnen nicht m&ouml;glich, (gr&ouml;&szlig;ere) Dateien &uuml;ber die integrierte Dateiverwaltung hochzuladen. Seien Sie sich dieser Einschr&auml;nkung bewusst.';
 $lang['test_check_writable'] = 'Pr&uuml;fung, ob %s beschreibbar ist';
-$lang['test_check_upload_failed'] = 'Das uploads-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen.';
-$lang['test_check_images_failed'] = 'Das Bilder-Verzeichnis (Standard: uploads/images) ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen und zu verwenden.';
-$lang['test_check_modules_failed'] = 'Das modules-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Module &uuml;ber die Administration zu hochzuladen.';
+$lang['test_check_upload_failed'] = 'Das /uploads-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen.';
+$lang['test_check_images_failed'] = 'Das Bilder-Verzeichnis (Standard: /uploads/images) ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen und zu verwenden.';
+$lang['test_check_modules_failed'] = 'Das /modules-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Module &uuml;ber die Administration zu hochzuladen.';
 $lang['test_check_file_get_contents'] = 'Pr&uuml;fung auf die Funktion file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'Ihnen ist es nicht m&ouml;glich, irgend eine Funktionalit&auml;t zu verwenden, die diese Funktion ben&ouml;tigt.';
 $lang['test_check_session_save_path'] = 'Pr&uuml;fung, ob der Pfad session.save_path &uuml;berschreibbar ist';
-$lang['test_empty_session_save_path'] = 'session.save_path ist bei Ihnen leer. PHP wird jetzt den tempor&auml;ren Speicher des Betriebssystems verwenden. Sollten bei Ihnen SESSION-Probleme auftreten und die Funktion ini_set ausf&uuml;hrbar sein, k&ouml;nnten Sie versuchen, Session-Cookies zu aktivieren. F&uuml;gen Sie dazu als erste Zeile folgendes der include.php hinzu: ini_set(&#039;session.use_only_cookies&#039;, 1);';
+$lang['test_empty_session_save_path'] = 'session.save_path ist bei Ihnen leer. PHP wird jetzt den tempor&auml;ren Speicher des Betriebssystems verwenden. Sollten bei Ihnen SESSION-Probleme auftreten und die Funktion ini_set ausf&uuml;hrbar sein, k&ouml;nnten Sie versuchen, Session-Cookies zu aktivieren. F&uuml;gen Sie dazu als erste Zeile folgendes der config.php hinzu: <code>ini_set(&#039;session.use_only_cookies&#039;, 1);</code>';
 $lang['test_check_session_save_path_failed'] = 'Ihr System verwendet aktuell den Pfad &quot;%s&quot;. Wenn der Pfad nicht &uuml;berschreibbar ist, k&ouml;nnen Sie sich unter Umst&auml;nden nicht in der Administration anmelden. Bei eventuell auftretenden Problemen sollten Sie dies zun&auml;chst &uuml;berpr&uuml;fen. Dieser Test kann fehlschlagen, wenn der Safe-Modus aktiviert ist.';
 $lang['test_check_ini_set'] = 'Pr&uuml;fung, ob die Funktion ini_set() ausf&uuml;hrbar ist';
 $lang['test_check_ini_set_failed'] = 'Die M&ouml;glichkeit, Einstellungen der php.ini &uuml;berschreiben zu k&ouml;nnen, ist zwar nicht zwingend. Einige (optionale) Zusatzfunktionen verwenden jedoch ini_set(), um zum Beispiel Zeitlimits zu ver&auml;ndern oder das Hochladen von gr&ouml;&szlig;eren Dateien zu erlauben usw. Ohne diese F&auml;higkeit kann es zu Unterschieden in der Funktionsweise von Modulen kommen. Dieser Test kann fehlschlagen, wenn der Safe-Modus aktiviert ist.';
@@ -305,11 +311,11 @@ $lang['install_admin_db_create'] = 'Tabellen erzeugen (ACHTUNG: bereits existier
 $lang['install_admin_db_prefix'] = 'Tabellen-Prefix';
 $lang['install_admin_db_sample'] = 'Musterdaten (Templates, Inhalte) installieren';
 $lang['retry'] = 'Wiederholen';
-$lang['install_admin_db_create_seq'] = 'Erstelle die sequentielle Tabelle %s ...';
-$lang['install_admin_importing'] = 'Importiere die Beispieldaten ...';
+$lang['install_admin_db_create_seq'] = 'Erstellung der sequentiellen Tabelle %s ...';
+$lang['install_admin_importing'] = 'Import der Beispieldaten ...';
 $lang['invalid_query'] = 'Ung&uuml;ltige Abfrage: %s';
-$lang['install_creating_table'] = '<p>Erstelle die Tabelle %s ... [%s]</p>';
-$lang['install_creating_index'] = '<p>Erzeuge Index in der Tabelle %s ... [%s]</p>';
+$lang['install_creating_table'] = '<p>Erstellung der Tabelle %s ... [%s]</p>';
+$lang['install_creating_index'] = '<p>Erstellung des Index in der Tabelle %s ... [%s]</p>';
 $lang['done'] = 'erledigt';
 $lang['failed'] = 'fehlgeschlagen';
 $lang['install_admin_error_schema'] = 'Fehler im SQL-Schema';
@@ -319,7 +325,7 @@ $lang['install_admin_setup'] = 'Nun geht&#039;s weiter mit den Einstellungen der
 $lang['install_admin_docroot'] = 'CMS Dokumenten-Root (vom Webserver aus gesehen)';
 $lang['install_admin_docroot_path'] = 'Pfad zum Dokumenten-Root';
 $lang['install_admin_querystring'] = 'Abfrage-/Query-String (Wenn keine Probleme auftreten, k&ouml;nnen Sie den Wert unver&auml;ndert lassen. Die Datei config.php kann sp&auml;ter manuell anpasst werden.';
-$lang['invalid_querys'] = '<b>WARNUNG<b/>: Ung&uuml;ltige Abfragen auf Ihre Datenbank!';
+$lang['invalid_querys'] = '<strong>WARNUNG</strong>: Ung&uuml;ltige Abfragen auf Ihre Datenbank!';
 $lang['install_admin_sitedown'] = 'Fehler: Die Datei /tmp/cache/SITEDOWN konnte nicht entfernt werden. Bitte l&ouml;schen Sie diese manuell.';
 $lang['install_admin_update_hierarchy'] = 'Die Seitenhierarchie wird aktualisiert ... ';
 $lang['install_admin_set_core_event'] = 'Die Core-Ereignisse werden erstellt ... ';
@@ -338,8 +344,8 @@ Benutzername: %s
 Passwort: %s
 
 In die Administration Ihrer Seite gelangen Sie hier: %s';
-$lang['utma'] = '156861353.1368086895.1281338275.1281338275.1281338275.1';
+$lang['utma'] = '156861353.178890951.1298889837.1298925031.1299002634.3';
+$lang['utmz'] = '156861353.1298889837.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1281338275.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,46352.msg221259.html|utmcmd=referral';
 ?>
\ No newline at end of file
