@@ -1,24 +1,34 @@
 <?php
+$lang['setup_flat_urls'] = 'URLs simples han sido ajustadas';
+$lang['install_timezone'] = 'Algunos servidores que ejecutan php 5.3 no tiene configurada correctamente la zona horaria. Por favor, seleccione la zona horaria adecuada en la siguiente lista. Si esto no es necesario en su servidor, entonces puede seleccionar &quot;Ninguno&quot;';
+$lang['timezone'] = 'Zona horaria';
+$lang['none'] = 'Ninguno';
+$lang['test_error_estrict'] = 'Comprobando error_reporting para confirmar que E_STRICT est&aacute; desactivado';
+$lang['test_estrict_failed'] = 'E_STRICT est&aacute; activado';
+$lang['info_estrict_failed'] = 'Algunas librer&iacute;as que CMSMS usa no funcionan bien con E_STRICT.  Por favor, desact&iacute;velo antes de continuar';
+$lang['test_error_edeprecated'] = 'Comprobando error_reporting para confirmar que E_DEPRECATED est&aacute; desactivado';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED est&aacute; activo';
+$lang['info_edeprecated_failed'] = 'Si E_DEPRECATED est&aacute; activo, en su informe de errores los usuarios ver&aacute;n una gran cantidad de mensajes de advertencia que pueden afectar a la visualizaci&oacute;n y funcionalidad';
 $lang['invalidemail'] = 'Direcci&oacute;n de correo inv&aacute;lida';
 $lang['empty_query'] = 'Consulta vac&iacute;a? %s';
 $lang['no_db_driver'] = 'No se encontraron manejadores de base de datos compatibles.';
-$lang['test_check_output_buffering'] = 'Revisando salida del buffer';
+$lang['test_check_output_buffering'] = 'Comprobando el buffering de salida';
 $lang['test_check_output_buffering_failed'] = 'Salida del buffer desabilitada. Probablemente no se podr&aacute; utilizar ninguna funci&oacute;n que requiera de ello.';
 $lang['phpinfo'] = 'Mostrar Informaci&oacute;n de PHP';
 $lang['mod_security'] = 'Modulo de Seguridad de Apache';
-$lang['test_check_tempnam'] = 'Revisando la funci&oacute;n para tempnam';
+$lang['test_check_tempnam'] = 'Comprobando la funci&oacute;n para tempnam';
 $lang['test_check_db_drivers'] = 'Manejadores de base de datos';
 $lang['test_check_db_drivers_failed'] = 'No se encontraron manejadores para la base de datos';
-$lang['test_check_register_globals'] = 'Revisando &quot;register globals&quot; de PHP';
+$lang['test_check_register_globals'] = 'Comprobando &quot;register globals&quot; de PHP';
 $lang['test_check_register_globals_failed'] = 'Se ha activado PHP &quot;register globals&quot;. Por razones de seguridad, esto deberia ser desactivado.';
-$lang['test_check_disable_functions'] = 'Revisando funciones PHP de deshabilitaci&oacute;n';
+$lang['test_check_disable_functions'] = 'Comprobando funciones PHP de deshabilitaci&oacute;n';
 $lang['test_check_disable_functions_failed'] = 'Advertencia: this is a list of functions disabled on your server.';
 $lang['install_admin_db_port'] = 'Puerto de la base de datos';
 $lang['install_admin_db_port_info'] = 'Si no sabe, deje esto en blanco para usar los valores predeterminados';
 $lang['install_admin_db_socket'] = 'Toma (Socket) de base de datos ';
 $lang['install_admin_db_socket_info'] = 'NO ES SOPORTADO.';
 $lang['install_admin_frontendlang'] = 'Lenguaje predeterminado para la pagina frontal. Esto ajusta la localizaci&oacute;n para varias funciones que utilizan la manipulaci&oacute;n de fechas, etc.';
-$lang['install_default_encoding'] = 'En casi todos los casos, default_encoding deberia ser utf-8.';
+$lang['install_default_encoding'] = 'En casi todos los casos, default_encoding deber&iacute;a ser utf-8.';
 $lang['installer_done'] = '[fin]';
 $lang['installer_failed'] = '[fallo]';
 $lang['create_permission'] = 'Crear permiso ...';
@@ -28,44 +38,44 @@ $lang['installing_module'] = 'Instalando m&oacute;dulo %s ...';
 $lang['updating_schema_version'] = 'Actualizando esquema versi&oacute;n %s ...';
 $lang['upgrade_config'] = 'Actualizando config.php';
 $lang['upgrade_config_info'] = 'Actualizaci&oacute;n de config';
-$lang['upgrade_failed_again'] = 'Uno o mas actualizaciones fallaron. Por favor corrija el problema y presione el bot&oacute;n abajo para volver a intentar.';
-$lang['upgrade_cache_dirs'] = 'Limpiando directorios de cache';
-$lang['cannot_clean_cache_dirs'] = 'No se pueden limpiar los directorios de cache!';
+$lang['upgrade_failed_again'] = 'Una o m&aacute;s actualizaciones fallaron. Por favor corrija el problema y presione el bot&oacute;n de abajo para volverlo a intentar.';
+$lang['upgrade_cache_dirs'] = 'Limpiando los directorios de cach&eacute;';
+$lang['cannot_clean_cache_dirs'] = '&iexcl;No se pueden limpiar los directorios de cach&eacute;!';
 $lang['upgrade_schema'] = 'Actualizar esquema';
 $lang['need_upgrade_schema'] = 'CMS necesita ser actualizado. Est&aacute; utilizando el esquema versi&oacute;n %s y necesita actualizar a la versi&oacute;n %s';
-$lang['schema_ok'] = 'La base de datos de CMS es la mas reciente. Utilizando esquema versi&oacute;n %s';
-$lang['noneed_upgrade_schema'] = 'La base de datos de CMS es la mas reciente. Utilizando esquema versi&oacute;n %s';
-$lang['upgrade_modules'] = 'Actualizar modulos';
-$lang['noneed_upgrade_modules'] = 'Los modulos n&uacute;cleo son los mas recientes';
+$lang['schema_ok'] = 'La base de datos de CMS es la m&aacute;s reciente. Utilizando esquema versi&oacute;n %s';
+$lang['noneed_upgrade_schema'] = 'La base de datos de CMS es la m&aacute;s reciente. Utilizando esquema versi&oacute;n %s';
+$lang['upgrade_modules'] = 'Actualizar m&oacute;dulos';
+$lang['noneed_upgrade_modules'] = 'Los m&oacute;dulos n&uacute;cleo son los mas recientes';
 $lang['upgrade_sql_module_from_to'] = 'Actualizando SQL de m&oacute;dulo &quot;%s&quot; desde %s a %s ...';
 $lang['upgrade_event_module_from_to'] = 'Actualizando Eventos de m&oacute;dulo &quot;%s&quot; desde %s a %s ...';
-$lang['sitedown_not_removed'] = 'No se pudo remover el archivo tmp/cache/SITEDOWN por favor remuevalo manualmente o el mensaje &quot;Sitio Bajo Mantenimiento&quot; seguir&aacute; siendo mostrado en su sitio.';
-$lang['upgrade_ok'] = 'Por favor revise config.php, modifique cualquier ajuste nuevo que sea necesario y luego asigne los permisos de dicho archivo de vuelta a modo bloqueado. Tambien deberia revisar que todos sus modulos estan actualizados. Para ello vaya a Extensiones > Modulos y busque modulos listados como &quot;Necesita Actualizaci&oacute;n&quot;.';
+$lang['sitedown_not_removed'] = 'No se pudo eliminar el archivo tmp/cache/SITEDOWN por favor, elim&iacute;nelo manualmente o el mensaje &quot;Sitio Bajo Mantenimiento&quot; se seguir&aacute; mostrado en su sitio.';
+$lang['upgrade_ok'] = 'Por favor, revise config.php, modifique cualquier ajuste nuevo que sea necesario y luego asigne los permisos de dicho archivo de nuevo a modo bloqueado. Tambi&eacute;n deber&iacute;a comprobar que todos sus m&oacute;dulos est&aacute;n actualizados. Para ello, vaya a Extensiones > M&oacute;dulos y busque m&oacute;dulos listados como &quot;Necesita Actualizaci&oacute;n&quot;.';
 $lang['upgrade_complete'] = 'Proceso de actualizaci&oacute;n completado';
 $lang['upgrade_end'] = 'Su CMS est&aacute; actualizado. Por favor haga click %s para ir a su sito, o puede %s.';
-$lang['here'] = 'aqui';
+$lang['here'] = 'aqu&iacute;';
 $lang['go_to_admin'] = 'ir al Panel Administrativo';
-$lang['errorfilenot'] = 'Archivo no encontrado!';
-$lang['errorfilenotwritable'] = 'Archivo no tiene permiso de escritura!';
-$lang['nofiles'] = 'Este recurso no existe!';
-$lang['is_directory'] = 'Este recurso es un directorio!';
-$lang['is_readable_false'] = 'Este recurso no tiene permiso de escritura!';
-$lang['checksum_match'] = 'Archivo de revisi&oacute;n coincide!';
-$lang['checksum_not_match'] = 'El archivo de revisi&oacute;n no coincide!';
-$lang['not_checksum'] = 'No se pudo cargar el archivo de revisi&oacute;n!';
+$lang['errorfilenot'] = '&iexcl;Archivo no encontrado!';
+$lang['errorfilenotwritable'] = '&iexcl;Archivo sin permisos de escritura!';
+$lang['nofiles'] = '&iexcl;Este recurso no existe!';
+$lang['is_directory'] = '&iexcl;Este recurso es un directorio!';
+$lang['is_readable_false'] = '&iexcl;Este recurso no tiene permiso de escritura!';
+$lang['checksum_match'] = '&iexcl;El checksum coincide!';
+$lang['checksum_not_match'] = '&iexcl;El checksum no coincide!';
+$lang['not_checksum'] = '&iexcl;No se pudo obtener el checksum!';
 $lang['format_datetime'] = '%c ';
-$lang['upload_err_ini_size'] = 'El archivo cargado excede la directiva upload_max_filesize en php.ini!';
-$lang['upload_err_form_size'] = 'El archivo cargado excede la directiva MAX_FILE_SIZE especificada en la forma HTML.';
-$lang['upload_err_partial'] = 'El archivo fue cargado parcialmente!.';
-$lang['upload_err_no_file'] = 'No se carg&oacute; ningun archivo.';
-$lang['upload_err_no_tmp_dir'] = 'Hace falta una carpeta temporal.';
-$lang['upload_err_cant_write'] = 'Fall&oacute; la escritura a disco.';
-$lang['upload_err_extension'] = 'El archivo cargado fue detenido por su extensi&oacute;n.';
-$lang['upload_err_empty'] = 'El tama&ntilde;o de archivo es cero.';
-$lang['upload_err_unknown'] = 'Problema de cargado desconocido.';
-$lang['function_file_uploads_off'] = 'file_uploads ist&aacute; apagado (off) en su configuraci&oacute;n php!';
-$lang['upload_file_no_readable'] = 'Archivo cargado no se puede leer!';
-$lang['upload_file_multiple'] = 'No se permite cargas multiples de archivos!';
+$lang['upload_err_ini_size'] = '&iexcl;El archivo que se ha subido excede la directiva upload_max_filesize en php.ini!';
+$lang['upload_err_form_size'] = 'El archivo que se ha subido excede la directiva MAX_FILE_SIZE especificada en el formulario HTML.';
+$lang['upload_err_partial'] = '&iexcl;El archivo no se ha subido completamente!.';
+$lang['upload_err_no_file'] = 'No se subi&oacute; ningun archivo.';
+$lang['upload_err_no_tmp_dir'] = 'No se encuentra una carpeta temporal.';
+$lang['upload_err_cant_write'] = 'Fall&oacute; la escritura en disco.';
+$lang['upload_err_extension'] = 'Se detuvo la subida del archivo por su extensi&oacute;n.';
+$lang['upload_err_empty'] = 'El tama&ntilde;o de archivo es cero';
+$lang['upload_err_unknown'] = 'Problema desconocido en la subida de archivo.';
+$lang['function_file_uploads_off'] = '&iexcl;file_uploads est&aacute; apagado (off) en su configuraci&oacute;n de php!';
+$lang['upload_file_no_readable'] = '&iexcl;El archivo subido no se puede leer!';
+$lang['upload_file_multiple'] = '&iexcl;No se permite subidas multiples de archivos!';
 $lang['test_check_magic_quotes_gpc'] = '&quot;Comillas magicas&quot;(Magic quotes) para operaciones Get/Post/Cookie';
 $lang['test_check_magic_quotes_gpc_failed'] = 'Cuando &quot;magic_quotes&quot; est&aacute; activo, todas las comillas singulares, dobles y la barra diagonal son escapadas con una barra diagonal invertida (\) automatica,ente. Esto puede causar ciertos problemas en CMS.';
 $lang['test_check_magic_quotes_runtime'] = '&quot;Comillas magicas&quot;(Magic quotes) en tiempo de ejecuci&oacute;n';
@@ -75,20 +85,20 @@ $lang['upgrade_admin_checksum'] = 'Revise su actualizaci&oacute;n de sistema';
 $lang['checksum'] = 'Prueba con archivo de revisi&oacute;n';
 $lang['checksum_file'] = 'Archivo de revisi&oacute;n';
 $lang['install_test_checksum'] = 'Se puede validar la integridad de los archivos del CMS, comparando con el archivo de suma de verificaci&oacute;n (checksum). Esto puede ayudar a localizar problemas con archivos que no han sido subidos correctamente.';
-$lang['checksum_passed'] = '&iexcl;Todas las sumas de verificaci&oacute;n son concuerdan!';
+$lang['checksum_passed'] = '&iexcl;Todas las sumas de verificaci&oacute;n concuerdan!';
 $lang['checksum_failed'] = 'Las sumas de verificaci&oacute;n concuerdan pero hay errores. Ver &#039;ayuda&#039; para mas informaci&oacute;n.';
 $lang['test_check_open_basedir'] = 'Revisar &#039;PHP Open Basedir&#039;';
 $lang['test_check_open_basedir_failed'] = 'Restricciones de &#039;Open basedir&#039; estan activas. Puede encontrar dificultades con funcionalidades de algunos accesorios (Add-ons) con esta restricci&oacute;n.';
 $lang['unlimited'] = 'Ilimitado';
 $lang['test_open_basedir_session_save_path'] = 'Restricciones de &quot;Open basedir&quot; parecen estar activas. Si tiene problemas con SESSION y con ini_set funciona, puede tratar de abilitar las sesiones con cookies, agregando:ini_set(&#039;session.use_only_cookies&#039;, 1);  al inicio de config.php';
-$lang['install_warn_db_createtables'] = 'Este campo deberia estar seleccionado siempre. Tener precauci&oacute;n al desabilitar  esta opci&oacute;n.';
+$lang['install_warn_db_createtables'] = 'Este campo deber&iacute;a estar seleccionado siempre. Tenga precauci&oacute;n si deshabilita  esta opci&oacute;n.';
 $lang['install_admin_tablesnotcreated'] = 'Proceso completo. El proceso de instalaci&oacute;n se ha completado, como usted lo ha solicitado asi, no se han creado las tablas de la base de datos. Sin embargo, el archivo de configuraci&oacute;n ha sido reestablecido y todas las pruebas de pre-instalaci&oacute;n han sido pasadas. Gracias, y aqui est&aacute; su';
 $lang['info_create_dir_and_file'] = 'El due&ntilde;o del proceso HTTP no puede crear un archivo adentro de un directorio que le pertenece. Esto posiblemente quiere decir que &quot;safe mode&quot; est&aacute; activo de alguna forma. Muchas funciones adentro de &quot;CMS made simple&quot; no se ejecutaran adecuadamente sin esta opci&oacute;n. No se puede continuar.';
-$lang['test_create_dir_and_file'] = 'Revisando si el proceso de httpd puede crear un archivo adentro del directorio que este cre&oacute;.';
+$lang['test_create_dir_and_file'] = 'Comprobando si el proceso httpd puede crear un archivo dentro del directorio que &eacute;ste cre&oacute;.';
 $lang['cms_site'] = 'Sitio CMS';
 $lang['or_greater'] = 'O mayor';
 $lang['sitename'] = 'Nombre del sitio';
-$lang['warning_safe_mode'] = '<strong><em>ADVERTENCIA:</em></strong> El modo &#039;PHP Safe&#039; esta habilitado. Esto puede causar dificultades con archivos subidos a traves de la interfaz web de explorador de archivos, incluyendo imagenes, temas y paquetes XML de m&oacute;dulos. Se recomienda que contacte al administrador del sitio acerca de deshabilitar el modo &#039;PHP Safe&#039;.';
+$lang['warning_safe_mode'] = '<strong><em>ADVERTENCIA:</em></strong> El modo &#039;PHP Safe&#039; esta habilitado. Esto puede causar dificultades con archivos subidos a traves de la interfaz web de explorador de archivos, incluyendo im&aacute;genes, temas y paquetes XML de m&oacute;dulos. Se recomienda que contacte con el administrador del sitio para saber c&oacute;mo deshabilitar el modo &#039;PHP Safe&#039;.';
 $lang['test'] = 'Prueba';
 $lang['results'] = 'Resultados';
 $lang['untested'] = 'Sin probar';
@@ -127,22 +137,22 @@ $lang['write'] = 'Escribir';
 $lang['execute'] = 'Ejecutar';
 $lang['group'] = 'Grupo';
 $lang['other'] = 'Otro';
-$lang['global_umask'] = '&quot;Mask&quot; para creaci&oacute;n de archivos (umask)';
+$lang['global_umask'] = 'M&aacute;scara de Creaci&oacute;n de Archivos (umask)';
 $lang['errorcantcreatefile'] = 'No se pudo crear el archivo (&iquest;problema de permisos?)';
 $lang['add'] = 'Agregar';
 $lang['about'] = 'Acerca';
 $lang['action'] = 'Acci&oacute;n';
-$lang['actionstatus'] = 'Acci&oacute;n/Estatus';
+$lang['actionstatus'] = 'Acci&oacute;n/Estado';
 $lang['active'] = 'Activo';
-$lang['cantremove'] = 'No se puede remover';
+$lang['cantremove'] = 'No se puede eliminar';
 $lang['changepermissions'] = 'Cambiar permisos';
-$lang['changepermissionsconfirm'] = 'USAR PRECAUCI&Oacute;N\n\nEsta acci&oacute;n intentar&aacute; asegurarse que todos los archivos que componen el m&oacute;dulo sean de escritura en el servidor web.\n&iquest;Desea continuar?';
-$lang['success'] = 'Exito';
+$lang['changepermissionsconfirm'] = 'USAR CON PRECAUCI&Oacute;N\n\nEsta acci&oacute;n intentar&aacute; asegurarse de que todos los archivos que componen el m&oacute;dulo sean de escritura en el servidor web.\n&iquest;Desea continuar?';
+$lang['success'] = '&Eacute;xito';
 $lang['advanced'] = 'Avanzado';
 $lang['back'] = 'Volver al Men&uacute;';
 $lang['cancel'] = 'Cancelar';
 $lang['cantchmodfiles'] = 'No se pudo cambiar los permisos de algunos archivos';
-$lang['cantremovefiles'] = 'Problema al remover archivos (&iquest;permisos?)';
+$lang['cantremovefiles'] = 'Problema al eliminar archivos (&iquest;permisos?)';
 $lang['create'] = 'Crear';
 $lang['database'] = 'Base de Datos';
 $lang['databaseprefix'] = 'Prefijo de la Base de Datos';
@@ -170,7 +180,7 @@ $lang['lastname'] = 'Apellido';
 $lang['name'] = 'Nombre';
 $lang['password'] = 'Contrase&ntilde;a';
 $lang['passwordagain'] = 'Contrase&ntilde;a(de nuevo)';
-$lang['remove'] = 'Remover';
+$lang['remove'] = 'Eliminar';
 $lang['saveconfig'] = 'Guardar configuraci&oacute;n';
 $lang['true'] = 'Verdadero';
 $lang['setfalse'] = 'Ajustar a Falso';
@@ -185,12 +195,12 @@ $lang['usernameincorrect'] = 'Nombre de usuario o contrase&ntilde;a incorrectos'
 $lang['version'] = 'Versi&oacute;n';
 $lang['install_title'] = 'Instalaci&oacute;n CMS Made Simple (paso %s)';
 $lang['install_system'] = 'Sistema de Instalaci&oacute;n';
-$lang['install_thanks'] = 'Gracias por instalar CMS Made Simple!';
+$lang['install_thanks'] = '&iexcl;Gracias por instalar CMS Made Simple!';
 $lang['upgrade_title'] = 'Actualizaci&oacute;n de CMS Made Simple (paso %s)';
 $lang['upgrade_system'] = 'Actualizar sistema';
 $lang['upgrade_thanks'] = 'Gracias por actualizar CMS Made Simple a versi&oacute;n';
-$lang['install_please_read'] = 'Por favor lea la guia de <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Problemas de instalaci&oacute;n</a> en el Wiki de Documentaci&oacute;n de CMS Made Simple (guia en ingl&eacute;s)';
-$lang['install_checking'] = 'Revisando permisos y ajustes de PHP';
+$lang['install_please_read'] = 'Por favor lea la gu&iacute;a de <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Problemas de instalaci&oacute;n</a> en el Wiki de Documentaci&oacute;n de CMS Made Simple (gu&iacute;a en ingl&eacute;s)';
+$lang['install_checking'] = 'Comprobando permisos y ajustes de PHP';
 $lang['install_test'] = 'Prueba';
 $lang['install_result'] = 'Resultado';
 $lang['install_required_settings'] = 'Ajustes requeridos';
@@ -228,74 +238,74 @@ $lang['test_no_dbms'] = '&iexcl;No se seleccion&oacute; ningun dbms!';
 $lang['test_could_not_connect_db'] = 'No se pudo establecer una conexi&oacute;n con la base de datos. Verifique el nombre de usuario y la clave, ademas el usuario debe tener acceso a la base de datos dada.';
 $lang['test_could_not_drop_table'] = 'No se pudo eliminar una tabla. Verifique los privilegios para borrar tablas en la base de datos dada.';
 $lang['test_could_not_create_table'] = 'No se pudo crear una tabla. Verifique los privilegios para crear tablas en la base de datos dada.';
-$lang['test_check_php'] = 'Revisando versi&oacute;n de PHP %s+';
+$lang['test_check_php'] = 'Comprobando versi&oacute;n de PHP %s+';
 $lang['test_min_recommend'] = '(m&iacute;nimo %s, recomendado %s o mayor)';
 $lang['test_min_recommend_plus'] = '(m&iacute;n %s, recomendado %s+)';
 $lang['test_requires_php_version'] = 'CMS Made Simple requiere una versi&oacute;n de php 4.3 o superior (usted tiene %s), pero PHP %s o superior es recomendada para garantizar la maxima compatibilidad con accesorios (add-ons) externos.';
-$lang['test_check_md5_func'] = 'Revisando la funci&oacute;n md5';
-$lang['test_check_safe_mode'] = 'Revisando modo seguro (PHP Safe Mode)';
-$lang['test_check_safe_mode_failed'] = 'El modo &#039;PHP safe&#039; puede crear algunos problemas al subir archivos, asi como con otras funciones. Todo depende de que tan estrictos sean los ajustes de servidor.';
-$lang['test_check_tokenizer'] = 'Revisando funciones &#039;tokenizer&#039;';
+$lang['test_check_md5_func'] = 'Comprobando la funci&oacute;n md5';
+$lang['test_check_safe_mode'] = 'Comprobando el modo seguro (PHP Safe Mode)';
+$lang['test_check_safe_mode_failed'] = 'El modo &#039;PHP safe&#039; puede crear algunos problemas con la subida de archivos y otras funciones. Todo depende de lo estricto que sea la configuraci&oacute;n Safe Mode de su servidor.';
+$lang['test_check_tokenizer'] = 'Comprobando funciones &#039;tokenizer&#039;';
 $lang['test_check_tokenizer_failed'] = 'No tener &#039;tokenizer&#039; puede causar que las paginas sean desplegadas totalmente blancas. Se requiere que este sea instalado.';
-$lang['test_check_gd'] = 'Revisando librer&iacute;a GD';
-$lang['test_check_gd_failed'] = 'La librer&iacute;a GD es obligatoria para algunos modulos y ciertas funcionalidades';
-$lang['test_check_write'] = 'Revisando si el permiso de escritura est&aacute; activo';
+$lang['test_check_gd'] = 'Comprobando la librer&iacute;a GD';
+$lang['test_check_gd_failed'] = 'La librer&iacute;a GD es obligatoria para algunos m&oacute;dulos y ciertas funcionalidades';
+$lang['test_check_write'] = 'Comprobando si el permiso de escritura est&aacute; activo';
 $lang['test_may_not_exist'] = 'El archivo puede que no exista aun. Si es asi, deber&aacute; crear un archivo en blanco con este nombre. Tambie asegurese de que este tiene permiso de escritura.';
 $lang['could_not_retrieve_a_value'] = 'No se pudo obtener un valor... se pasar&aacute; por alto.';
 $lang['displaying_the_value_originally'] = '<br />Mostrando el valor original de el archivo config (est&oacute; puede no ser atinado).';
-$lang['test_check_xml_func'] = 'Revisando soporte basico de XML (expat)';
-$lang['test_check_xml_failed'] = 'El soporte de XML no ha sido compilado en su instalaci&oacute;n de PHP. Aun asi puede utilizar el sistema, pero no podr&aacute; usar ninguna de las funciones remotas para instalar modulos.';
-$lang['test_allow_url_fopen_failed'] = 'Cuando la opci&oacute;n de Permitir &#039;url fopen&#039; esta deshabilitada, no podr&aacute; accesar objetos de URL utilizando los protocolos FTP o HTTP.';
+$lang['test_check_xml_func'] = 'Comprobando el soporte b&aacute;sico de XML (expat)';
+$lang['test_check_xml_failed'] = 'El soporte de XML no se ha compilado en su instalaci&oacute;n de PHP. A&uacute;n as&iacute; puede utilizar el sistema, pero no podr&aacute; usar ninguna de las funciones remotas para instalar m&oacute;dulos.';
+$lang['test_allow_url_fopen_failed'] = 'Cuando la opci&oacute;n de Permitir &#039;url fopen&#039; esta deshabilitada, no podr&aacute; acceder a objetos de URL como archivo utilizando los protocolos FTP o HTTP.';
 $lang['test_remote_url'] = 'Probar URL remota';
 $lang['test_remote_url_failed'] = 'Probablemente no podr&aacute; abrir un archivo en un servidor remoto.';
-$lang['connection_error'] = '&iexcl;Conexiones http salientes parecen no estar trabajando! &iquest;Existe alg&uacute;n firewal o ACL para conexiones externas? Esto provocar&aacute; que el Administrador de Modulos y posiblemente otras funcionalidades fallen.';
-$lang['remote_connection_timeout'] = '&iexcl;El intervalo de espera se excedi&oacute;!';
+$lang['connection_error'] = '&iexcl;Parece que no funcionan las Conexiones http salientes! &iquest;Existe alg&uacute;n cortafuegos o ACL para las conexiones externas? Esto provocar&aacute; que falle el Administrador de M&oacute;dulos y posiblemente tambi&eacute;n otras funcionalidades.';
+$lang['remote_connection_timeout'] = '&iexcl;Se cumpli&oacute; el intervalo de espera!';
 $lang['search_string_find'] = '&iexcl;Conexi&oacute;n establecida!';
-$lang['connection_failed'] = '&iexcl;Conexi&oacute;n no se estableci&oacute;!';
+$lang['connection_failed'] = '&iexcl;Fall&oacute; la conexi&oacute;n!';
 $lang['remote_response_ok'] = 'Respuesta remota: ok!';
 $lang['remote_response_404'] = 'Respuesta remota: no encontrado!';
 $lang['remote_response_error'] = 'Respuesta remota: error!';
-$lang['test_check_file_upload'] = 'Revisando archivos subidos';
-$lang['test_check_file_failed'] = 'Cuando se desabilitan envios de archivos (uploads) no podra usar ninguna de las facilidades para subir archivos en CMS Made Simple. Si es posible, esta restricci&oacute;n deber&aacute; ser omitida por el administrador de su sistema para poder usar apropiadamente las caracteristicas de administraci&oacute;n de archivos del sistema. Proceda con precauci&oacute;n.';
-$lang['test_check_memory'] = 'Revisando el l&iacute;mite de memoria de PHP';
+$lang['test_check_file_upload'] = 'Comprobando subidas de archivos';
+$lang['test_check_file_failed'] = 'Cuando se desabilitan las subidas de archivos no podr&aacute; usar ninguna de las funcionalidades para subir archivos incluidas CMS Made Simple. Si es posible, esta restricci&oacute;n debe ser anulada por el administrador de su sistema para poder usar apropiadamente las caracter&iacute;sticas de administraci&oacute;n de archivos del sistema. Proceda con precauci&oacute;n.';
+$lang['test_check_memory'] = 'Comprobando el l&iacute;mite de memoria de PHP';
 $lang['test_check_memory_failed'] = 'Puede que no tenga suficiente memoria para ejecutar CMS Made Simple correctamente, &oacute; con todos los accesorios deseados. Si es posible, hable con el administrador de su sistema para que aumente este valor. Proceda con precauci&oacute;n.';
-$lang['test_check_time_limit'] = 'Revisando el tiempo limite de PHP en segundos';
+$lang['test_check_time_limit'] = 'Comprobando el tiempo limite de PHP en segundos';
 $lang['test_check_time_limit_failed'] = 'N&uacute;mero de segundos que son permitidos para ejecutar un script. Si este es alcanzado, el script regresa un error fatal.';
-$lang['test_check_post_max'] = 'Revisando el tama&ntilde;o m&aacute;ximo del envio (post).';
+$lang['test_check_post_max'] = 'Comprobando el tama&ntilde;o m&aacute;ximo del env&iacute;o (post).';
 $lang['test_check_post_max_failed'] = 'Probablemente no se podr&aacute; enviar informaci&oacute;n de mayor tama&ntilde;o. Por favor tenga esta restricci&oacute;n en mente.';
-$lang['test_check_upload_max'] = 'Revisando el tama&ntilde;o m&aacute;ximo para subir archivos.';
-$lang['test_check_upload_max_failed'] = 'Probablemente no se podr&aacute; enviar informaci&oacute;n de mayor tama&ntilde;o. Incluyendo funciones de administraci&oacute;n de archivos. Por favor mantenga esta restricci&oacute;n en mente.';
-$lang['test_check_writable'] = 'Revisando si %s es de escritura.';
+$lang['test_check_upload_max'] = 'Comprobando el tama&ntilde;o m&aacute;ximo para subir archivos.';
+$lang['test_check_upload_max_failed'] = 'Probablemente no se podr&aacute; enviar informaci&oacute;n de mayor tama&ntilde;o. Incluyendo funciones de administraci&oacute;n de archivos. Por favor, tenga en mente esta restricci&oacute;n.';
+$lang['test_check_writable'] = 'Comprobando si %s es de escritura.';
 $lang['test_check_upload_failed'] = 'El directorio &quot;uploads&quot; no de escritura. Aun puede instalar el sistema, pero no podr&aacute; subir archivos a traves del panel administrativo.';
 $lang['test_check_images_failed'] = 'El directorio &quot;images&quot; no de escritura. Aun puede instalar el sistema, pero no podr&aacute; subir imagenes a traves del panel administrativo.';
 $lang['test_check_modules_failed'] = 'El directorio &quot;modules&quot; no de escritura. Aun puede instalar el sistema, pero no podr&aacute; subir m&oacute;dulos a traves del panel administrativo.';
-$lang['test_check_file_get_contents'] = 'Revisando &quot;file_get_contents&quot;';
+$lang['test_check_file_get_contents'] = 'Comprobando &quot;file_get_contents&quot;';
 $lang['test_check_file_get_contents_failed'] = 'Es posible que no pueda usar ninguna funcionalidad que utiliza esta funci&oacute;n.';
-$lang['test_check_session_save_path'] = 'Revisando si &quot;session.save_path&quot; es de escritura';
-$lang['test_empty_session_save_path'] = 'El archivo &quot;session.save_path&quot; est&aacute; vacio. PHP usar&aacute; el directorio temporal de su sistema operativo. Si tiene problemas con SESSION y &quot;ini_set&quot; si funciona, puede tratar de abilitar cookies de sesion agregando: ini_set(&#039;session.use_only_cookies&#039;, 1);  al inicio de include.php';
-$lang['test_check_session_save_path_failed'] = 'Su &quot;session.save_path&quot; es &quot;%s&quot;. Si este archivo no es de escritura puede provocar que los usuarios del panel administrativo no puedan accesarlo. Puede intentar hacer este sendero de escritura si tiene problemas de acceso al panel administrativo. Esta prueba puede fallar si &quot;safe_mode&quot; esta habilitado (vea abajo).';
-$lang['test_check_ini_set'] = 'Revisando si &quot;ini_set&quot; funciona';
-$lang['test_check_ini_set_failed'] = 'Aunque la capacidad de anular ajustes de php ini no es obligatorio, algunas funciones de agregados (addons) usan ini_set para extender los tiempos de espera, y permitir subir archivos grandes, etc. Puede que se encuentre cierta dificultad con la funcionalidad de algunos agregados (addons) si no se usa esta opci&oacute;n. Esta prueba puede fallar si safe_mode est&aacute; activado (ver abajo).';
-$lang['install_admin_header'] = 'Informaci&oacute;n de la cuenta de panel administrativo';
-$lang['install_admin_info'] = 'Seleccione un nombre de usuario, contrase&ntilde;a y direcci&oacute;n de correo para su cuenta administrativa. Asegurese de guardar su contrase&ntilde;a en otro lugar.';
+$lang['test_check_session_save_path'] = 'Comprobando si &quot;session.save_path&quot; es de escritura';
+$lang['test_empty_session_save_path'] = 'El archivo &quot;session.save_path&quot; est&aacute; vacio. PHP usar&aacute; el directorio temporal de su sistema operativo. Si tiene problemas con SESSION y &quot;ini_set&quot; si funciona, puede tratar de habilitar cookies de sesion agregando: ini_set(&#039;session.use_only_cookies&#039;, 1);  al inicio de include.php';
+$lang['test_check_session_save_path_failed'] = 'Su &quot;session.save_path&quot; es &quot;%s&quot;. Si este archivo no es de escritura puede provocar que los usuarios del panel administrativo no puedan acceder. Puede intentar hacer esta ruta de escritura si tiene problemas de acceso al panel administrativo. Esta prueba puede fallar si &quot;safe_mode&quot; esta habilitado (vea abajo).';
+$lang['test_check_ini_set'] = 'Comprobando si &quot;ini_set&quot; funciona';
+$lang['test_check_ini_set_failed'] = 'Aunque la capacidad de anular ajustes de php.ini no es obligatorio, algunas funciones de agregados (addons) usan ini_set para extender los tiempos de espera, y permitir subir archivos grandes, etc. Puede que se encuentre cierta dificultad con la funcionalidad de algunos agregados (addons) si no se usa esta opci&oacute;n. Esta prueba puede fallar si safe_mode est&aacute; activado (ver m&aacute;s abajo).';
+$lang['install_admin_header'] = 'Informaci&oacute;n de la cuenta del panel administrativo';
+$lang['install_admin_info'] = 'Seleccione un nombre de usuario, contrase&ntilde;a y direcci&oacute;n de correo para su cuenta administrativa. Aseg&uacute;rese de guardar su contrase&ntilde;a en otro lugar.';
 $lang['install_admin_email'] = 'Direcci&oacute;n de e-mail';
 $lang['install_admin_email_info'] = 'Enviar informaci&oacute;n de la cuenta administrativa en un correo electronico';
-$lang['install_admin_email_note'] = '<strong>Note:</strong> Esto usa la funci&oacute;n &quot;mail&quot; de php. Si no recibe el correo, puede ser un indicio de que su servidor no est&aacute; configurado correctamente y deber&aacute; contactar a su administrador.';
-$lang['install_admin_sitename'] = 'Este es el nombre de su sitio. Este ser&aacute; usado en varios lugares de la instalaci&oacute;n por defecto y puee ser accecedido desde cualquier contenido con la etiqueta {sitename}.';
+$lang['install_admin_email_note'] = '<strong>Note:</strong> Esto usa la funci&oacute;n &quot;mail&quot; de php. Si no recibe el correo, puede ser un indicio de que su servidor no est&aacute; configurado correctamente y deber&aacute; contactar con el administrador de su hospedaje.';
+$lang['install_admin_sitename'] = 'Este es el nombre de su sitio. Ser&aacute; usado en varios lugares de las plantillas por defecto y se puede usar donde quiera con la etiqueta {sitename}.';
 $lang['install_admin_db'] = 'Informaci&oacute;n de la base de datos';
-$lang['install_admin_db_info'] = '<p>Asegurese de que cre&oacute; su base de datos y concedi&oacute; privilegios completos a un usuario para usar dicha base de datos</p>
+$lang['install_admin_db_info'] = '<p>Aseg&uacute;rese de que cre&oacute; su base de datos y concedi&oacute; privilegios completos a un usuario para usar dicha base de datos</p>
 <p>Para MySQL, use lo siguiente:</p>
-<p>Accesda a mysql desde la consola y ejecute los siguientes comandos:</p>
+<p>Acceda a mysql desde la consola y ejecute los siguientes comandos:</p>
 <ol>
-<li>create database cms; (use el nombre que desee pero asegurese de recordarlo, necesitar&aacute; ingresarlo en esta pagina)</li>
+<li>create database cms; (use el nombre que desee pero aseg&uacute;rese de recordarlo, necesitar&aacute; ingresarlo en esta p&aacute;gina)</li>
 <li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;</li>
 </ol>';
-$lang['install_admin_follow'] = 'Por favor complete los siguientes campos';
+$lang['install_admin_follow'] = 'Por favor, complete los siguientes campos';
 $lang['install_admin_db_type'] = 'Tipo de base de datos';
-$lang['install_admin_no_db'] = 'No se encontraron manejadores de base de datos complilados en su instalaci&oacute;n de PHP. Por favor confirme que tiene  mysql, mysqli, y/o postgres7 e intente de nuevo.';
+$lang['install_admin_no_db'] = 'No se encontraron manejadores de base de datos complilados en su instalaci&oacute;n de PHP. Por favor, confirme que tiene  mysql, mysqli, y/o postgres7 e int&eacute;ntelo de nuevo.';
 $lang['install_admin_db_host'] = 'Direcci&oacute;n huesped de la base de datos';
 $lang['install_admin_db_name'] = 'Nombre de la base de datos';
-$lang['install_admin_db_create'] = 'Crear tablas (Precauci&oacute;n: Informaci&oacute;n existente ser&aacute; eliminada)';
+$lang['install_admin_db_create'] = 'Crear tablas (Precauci&oacute;n: La informaci&oacute;n existente ser&aacute; eliminada)';
 $lang['install_admin_db_prefix'] = 'Prefijo de las tablas';
 $lang['install_admin_db_sample'] = 'Instalar contenido de ejemplo y plantillas';
 $lang['retry'] = 'Intentar de nuevo';
@@ -305,25 +315,25 @@ $lang['invalid_query'] = 'Consulta inv&aacute;lida: %s';
 $lang['install_creating_table'] = '<p>Creando %s tabla... [%s]</p>';
 $lang['install_creating_index'] = '<p>Creando &iacute;ndice en tabla %s ... [%s]</p>';
 $lang['done'] = 'completo';
-$lang['failed'] = 'fallo';
+$lang['failed'] = 'fall&oacute;';
 $lang['install_admin_error_schema'] = 'Error al cargar el esquema SQL';
-$lang['install_admin_set_account'] = 'Ajustando informaci&oacute;n de cuenta administrativa...';
-$lang['install_admin_set_sitename'] = 'Ajustando nombre del sitio...';
-$lang['install_admin_setup'] = 'Ahora continuemos a instalar el archivo de configuraci&oacute;n, ya tenemos casi todo lo que necesitamos. Lo mas seguro es que pueda usar estos valores, cuando est&eacute; listo presione Continuar.';
-$lang['install_admin_docroot'] = 'Ra&iacute;z para documentos de CMS (visto desde el servidor)';
-$lang['install_admin_docroot_path'] = 'Ruta a la raiz de los Documentos';
-$lang['install_admin_querystring'] = 'Cadena de consulta (no toque esto a menos que tenga algun problema, luego edite config.php a mano)';
+$lang['install_admin_set_account'] = 'Configurando la informaci&oacute;n de cuenta administrativa...';
+$lang['install_admin_set_sitename'] = 'Configurando el nombre del sitio...';
+$lang['install_admin_setup'] = 'Ahora continuemos instalando el archivo de configuraci&oacute;n; ya tenemos casi todo lo que necesitamos. Lo m&aacute;s seguro es que puedan usar estos valores, as&iacute; que cuando est&eacute; listo presione Continuar.';
+$lang['install_admin_docroot'] = 'Ra&iacute;z de documentos de CMS (visto desde el servidor)';
+$lang['install_admin_docroot_path'] = 'Ruta a la ra&iacute;z de Documentos';
+$lang['install_admin_querystring'] = 'Cadena de consulta (no toque esto a menos que tenga algun problema; luego edite config.php a mano)';
 $lang['invalid_querys'] = '<b>ADVERTENCIA<b/>: Consultas inv&aacute;lidas en su base de datos';
-$lang['install_admin_sitedown'] = 'Error: No se pudo borrar el archivo the tmp/cache/SITEDOWN Por favor borrelo manualmente.';
-$lang['install_admin_update_hierarchy'] = 'Actualizando las posiciones de jerarquia...';
-$lang['install_admin_set_core_event'] = 'Ajustando eventos n&uacute;cleo...';
-$lang['install_admin_install_modules'] = 'Instalando modulos...';
-$lang['install_admin_index_search'] = 'Busqueda de indices...';
-$lang['install_admin_clear_cache'] = 'Borrando el cach&eacute; (si lo hay)...';
+$lang['install_admin_sitedown'] = 'Error: No se pudo eliminar el archivo the tmp/cache/SITEDOWN Por favor elim&iacute;nelo manualmente.';
+$lang['install_admin_update_hierarchy'] = 'Actualizando las posiciones de jerarqu&iacute;a...';
+$lang['install_admin_set_core_event'] = 'Ajustando eventos de n&uacute;cleo...';
+$lang['install_admin_install_modules'] = 'Instalando m&oacute;dulos...';
+$lang['install_admin_index_search'] = 'Busqueda de &iacute;ndices...';
+$lang['install_admin_clear_cache'] = 'Borrando la cach&eacute; del sitio (si la hay)...';
 $lang['install_admin_emailing'] = 'Enviando correo de cuenta administrativa...';
-$lang['install_admin_congratulations'] = 'Felicitaciones! est&aacute; todo listo - aqui est&aacute; su';
-$lang['could_not_connect_db'] = 'No se pudo conectar a la base de datos. Verifique que el nombre de usuario y contrase&ntilde;as son validos, y que dicho usuario tiene acceso a la base de datos.';
-$lang['cannot_write_config'] = 'Error: No se puede escribir a  %s.';
+$lang['install_admin_congratulations'] = '&iexcl;Felicidades! ha terminado la instalaci&oacute;n - aqu&iacute; est&aacute; su';
+$lang['could_not_connect_db'] = 'No se pudo conectar a la base de datos. Verifique que el nombre de usuario y la contrase&ntilde;a son v&aacute;lidos, y que dicho usuario tiene acceso a la base de datos.';
+$lang['cannot_write_config'] = 'Error: No se puede escribir en  %s.';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple - Informaci&oacute;n de cuenta administrativa';
 $lang['email_accountinfo_message'] = 'Gracias por instalar CMS Made Simple.
 
@@ -331,10 +341,10 @@ Esta es la informaci&oacute;n de su nueva cuenta:
 usuario: %s
 clave: %s
 
-Acceda al panel administrativo aqui: %s';
-$lang['qca'] = 'P0-2096054370-1259803615939';
-$lang['utma'] = '156861353.238606854.1259804368.1267925726.1267940197.71';
-$lang['utmz'] = '156861353.1267925726.70.33.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+Acceda al panel administrativo aqu&iacute;: %s';
+$lang['qca'] = 'P0-672577724-1291068511180';
+$lang['utmz'] = '156861353.1291068584.1.2.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['utma'] = '156861353.761306410.1291068511.1297984934.1298856162.17';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
