@@ -1,4 +1,8 @@
 <?php
+$lang['setup_flat_urls'] = 'Litte&auml;t URL-osoitteet ovat asetettu';
+$lang['install_timezone'] = 'Jotkin palvelimet joilla on php 5.3 k&auml;yt&ouml;ss&auml;, eiv&auml;t ole asettaneet aikavy&ouml;hykett&auml; oikein.  Ole hyv&auml; ja valitse mielest&auml;si sopivin aikavy&ouml;hyke.  Mik&auml;li t&auml;m&auml; ei ole tarpeellista palvelimellasi, voit valita &amp;quot;Ei mit&auml;&auml;n&amp;quot;. Halutessasi voit vaihtaa t&auml;t&auml; asetusta config.php:sta.';
+$lang['timezone'] = 'Aikavy&ouml;hyke';
+$lang['none'] = 'Ei mit&auml;&auml;n';
 $lang['test_error_estrict'] = 'Testataan error_reporting varmistaaksemme, ett&auml; E_STRICT on pois p&auml;&auml;lt&auml;';
 $lang['test_estrict_failed'] = 'E_STRICT on p&auml;&auml;ll&auml;';
 $lang['info_estrict_failed'] = 'Osa kirjastoista, joita CMSMS k&auml;ytt&auml;&auml; eiv&auml;t toimi hyvin E_STRICT:n kanssa.  Ole hyv&auml; ja ota se pois k&auml;yt&ouml;st&auml; ennen jatkamista';
@@ -11,7 +15,7 @@ $lang['no_db_driver'] = 'Yhteensopivia tietokanta-ajureita ei l&ouml;ytynyt';
 $lang['test_check_output_buffering'] = 'Tarkistetaan ulosannin puskurointia';
 $lang['test_check_output_buffering_failed'] = 'Ulosannin puskurointi on pois p&auml;&auml;lt&auml;. Et todenn&auml;k&ouml;isesti voi k&auml;ytt&auml;&auml; toiminnallisuuksia, jotka vaativat t&auml;t&auml;';
 $lang['phpinfo'] = 'N&auml;yt&auml; PHP-tiedot';
-$lang['mod_security'] = 'Apache Mod Security';
+$lang['mod_security'] = 'Apachen Mod Security';
 $lang['test_check_tempnam'] = 'Tarkistetaan tempnam-funktiota';
 $lang['test_check_db_drivers'] = 'Tietokanta-ajurit';
 $lang['test_check_db_drivers_failed'] = 'Tietokanta-ajureita ei l&ouml;ytynyt';
@@ -21,7 +25,7 @@ $lang['test_check_disable_functions'] = 'Tarkistetaan PHP disable -funktiot';
 $lang['test_check_disable_functions_failed'] = 'Varoitus: t&auml;m&auml; on lista funktioita, jotka ovat pois p&auml;&auml;lt&auml; palvelimellasi.';
 $lang['install_admin_db_port'] = 'Tietokantaportti';
 $lang['install_admin_db_port_info'] = 'Jos et tied&auml; t&auml;t&auml;, j&auml;t&auml; se tyhj&auml;ksi. Siin&auml; tapauksessa k&auml;ytet&auml;&auml;n oletusarvoa.';
-$lang['install_admin_db_socket'] = 'Database socket';
+$lang['install_admin_db_socket'] = 'Tietokannan socket';
 $lang['install_admin_db_socket_info'] = 'EI TUETTU.';
 $lang['install_admin_frontendlang'] = 'Oletuskieli julkiselle sivustolle. T&auml;m&auml; s&auml;&auml;t&auml;&auml; oletus kieliasetusta, jota k&auml;ytet&auml;&auml;n esimerkiksi p&auml;iv&auml;m&auml;&auml;r&auml;- ja aikamuodoissa yms.';
 $lang['install_default_encoding'] = 'L&auml;hes kaikissa tapauksissa, oletuksena tulisi olla utf-8.';
@@ -50,7 +54,7 @@ $lang['upgrade_ok'] = 'Ole hyv&auml; ja tarkista config.php -tiedosto, muokkaa u
 $lang['upgrade_complete'] = 'P&auml;ivitys on valmis';
 $lang['upgrade_end'] = 'CMS on ajantasalla. Klikkaa %s siirty&auml;ksesi sivustolle tai voit %s.';
 $lang['here'] = 't&auml;st&auml;';
-$lang['go_to_admin'] = 'menn&auml; hallintapaneeliin';
+$lang['go_to_admin'] = 'Mene hallintapaneeliin';
 $lang['errorfilenot'] = 'Tiedostoa ei l&ouml;ydy!';
 $lang['errorfilenotwritable'] = 'Tiedostoon ei voida kirjoittaa!';
 $lang['nofiles'] = 'T&auml;t&auml; resurssia ei ole olemassa!';
@@ -72,9 +76,9 @@ $lang['upload_err_unknown'] = 'Tuntematon virhe tiedoston l&auml;hetyksess&auml;
 $lang['function_file_uploads_off'] = 'file_uploads on pois p&auml;&auml;lt&auml; php-asetuksissa!';
 $lang['upload_file_no_readable'] = 'L&auml;hetetty&auml; tiedostoa ei voida lukea!';
 $lang['upload_file_multiple'] = 'Useamman tiedoston l&auml;hett&auml;minen ei ole sallittua!';
-$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
+$lang['test_check_magic_quotes_gpc'] = 'Magic quotes Get/Post/Cookie operaatioille';
 $lang['test_check_magic_quotes_gpc_failed'] = 'Kun magic_quotes on p&auml;&auml;ll&auml;, kaikki lainausmerkit merkit&auml;&auml;n automaattisesti kauttaviivalla. T&auml;m&auml; voi aiheuttaa ongelmia CMS:ss&auml;.';
-$lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
+$lang['test_check_magic_quotes_runtime'] = 'Magic quotes suoritusaika';
 $lang['test_check_magic_quotes_runtime_failed'] = 'KunWhen magic_quotes on p&auml;&auml;ll&auml;, mitk&auml; tahansa funktiot, jotka palauttavat tietoa mist&auml; tahansa ulkoisesta l&auml;hteest&auml; mukaan lukien tietokannat ja tekstitiedostot sis&auml;lt&auml;v&auml;t lainausmerkit merkittyn&auml; kauttaviivoilla. T&auml;m&auml; aiheuttaa ongelmia CMS Made Simplen kanssa.';
 $lang['install_admin_checksum'] = 'Tarkista asennuksesi';
 $lang['upgrade_admin_checksum'] = 'Tarkista j&auml;rjestelm&auml;si p&auml;ivitys';
@@ -116,7 +120,7 @@ $lang['memory_limit'] = 'PHP:n muistiraja';
 $lang['server_db_type'] = 'Palvelimen tietokanta';
 $lang['server_db_version'] = 'Palvelimen tietokantaversio';
 $lang['phpversion'] = 'PHP-versio';
-$lang['safe_mode'] = 'PHP Safe Mode';
+$lang['safe_mode'] = 'PHP:n Safe Mode';
 $lang['php_information'] = 'PHP:n tiedot';
 $lang['cms_install_information'] = 'CMS:n asennustiedot';
 $lang['cms_version'] = 'CMS-versio';
@@ -338,9 +342,9 @@ K&auml;ytt&auml;j&auml;tunnus: %s
 Salasana: %s
 
 Kirjaudu hallintaan: %s';
-$lang['utma'] = '156861353.572491444.1274267548.1274270099.1274275175.3';
+$lang['qca'] = 'P0-143593381-1287469720325';
+$lang['utmz'] = '156861353.1289907526.70.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,48780.0.html';
+$lang['utma'] = '156861353.386609350.1282051258.1289907526.1289915269.71';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1274270099.2.2.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
-$lang['qca'] = 'P0-1477326709-1274267548700';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1289915269';
 ?>
\ No newline at end of file
