@@ -1,13 +1,17 @@
 <?php
+$lang['setup_flat_urls'] = 'URL courtes en service';
+$lang['install_timezone'] = 'Certains serveurs PHP 5.3 n&#039;ont pas configur&eacute; le bon fuseau horaire. Merci de s&eacute;lectionner le fuseau horaire appropri&eacute; dans la liste. Si ce n&#039;est pas n&eacute;cessaire sur votre serveur, vous pouvez s&eacute;lectionner &quot;Aucun&quot;. <strong>Note :</strong> Choisez le fuseau horaire de votre serveur, ce n&#039;est pas un param&egrave;tre d&#039;affichage mais il sera utilis&eacute; dans le calcul des dates. Vous pouvez toujours modifier ce param&egrave;tre ult&eacute;rieurement dans le fichier config.php.';
+$lang['timezone'] = 'Fuseau horaire';
+$lang['none'] = 'Aucun';
 $lang['test_error_estrict'] = 'Test error_reporting pour assurer que E_STRICT est d&eacute;sactiv&eacute;';
 $lang['test_estrict_failed'] = 'E_STRICT est activ&eacute;';
-$lang['info_estrict_failed'] = 'Certaines biblioth&egrave;ques utilis&eacute;es par CMSMS ne fonctionnent pas bien avec E_STRICT. Merci de les d&eacute;sactiver avant de continuer';
+$lang['info_estrict_failed'] = 'Certaines biblioth&egrave;ques utilis&eacute;es par CMSMS&trade; ne fonctionnent pas bien avec E_STRICT. Merci de les d&eacute;sactiver avant de continuer';
 $lang['test_error_edeprecated'] = 'Test error_reporting pour assurer que E_DEPRECATED est d&eacute;sactiv&eacute;';
 $lang['test_edeprecated_failed'] = 'E_DEPRECATED est activ&eacute;';
-$lang['info_edeprecated_failed'] = 'Si E_DEPRECATED est activ&eacute;, les utilisateurs verront de nombreux messages d&#039;avertissement qui pourraient affecter l&#039;affichage et le fonctionnement du site';
+$lang['info_edeprecated_failed'] = 'Si E_DEPRECATED est activ&eacute; dans error_reporting, les utilisateurs verront de nombreux messages d&#039;avertissement qui pourraient affecter l&#039;affichage et le fonctionnement du site';
 $lang['invalidemail'] = 'L&#039;adresse de courriel entr&eacute;e est invalide !';
 $lang['empty_query'] = 'Base de donn&eacute;es vide ?? %s';
-$lang['no_db_driver'] = 'Aucun driver de Base de Donn&eacute;es compatible CMSMS';
+$lang['no_db_driver'] = 'Aucun driver de Base de Donn&eacute;es compatible CMSMS&trade;';
 $lang['test_check_output_buffering'] = 'V&eacute;rification des buffers de sortie';
 $lang['test_check_output_buffering_failed'] = 'Les buffers de sortie sont d&eacute;sactiv&eacute;s. Vous ne serez probablement pas en mesure d&#039;utiliser toutes les fonctionnalit&eacute;s de cette fonction';
 $lang['phpinfo'] = 'Affichage des informations PHP';
@@ -38,7 +42,7 @@ $lang['upgrade_failed_again'] = 'Une ou plusieurs mises &agrave; niveau ont &eac
 $lang['upgrade_cache_dirs'] = 'Effacement des fichiers du dossier de cache';
 $lang['cannot_clean_cache_dirs'] = 'Impossible d&#039;effacer les fichiers du dossier de cache !';
 $lang['upgrade_schema'] = 'Upgrade du sch&eacute;ma version&nbsp;';
-$lang['need_upgrade_schema'] = 'CMSMS a besoin d&#039;une mise &agrave; niveau.<br />Vous utilisez le sch&eacute;ma version %s et vous devez mettre &agrave; niveau vers le sch&eacute;ma version %s';
+$lang['need_upgrade_schema'] = 'CMSMS&trade; a besoin d&#039;une mise &agrave; niveau.<br />Vous utilisez le sch&eacute;ma version %s et vous devez mettre &agrave; niveau vers le sch&eacute;ma version %s';
 $lang['schema_ok'] = 'Maintenant, la base de donn&eacute;es de CMS est &agrave; jour et utilise le sch&eacute;ma version %s';
 $lang['noneed_upgrade_schema'] = 'La base de donn&eacute;es de CMS est &agrave; jour et utilise le sch&eacute;ma version %s';
 $lang['upgrade_modules'] = 'Mise &agrave; niveau des modules';
@@ -46,9 +50,9 @@ $lang['noneed_upgrade_modules'] = 'Les modules du noyau sont &agrave; jour';
 $lang['upgrade_sql_module_from_to'] = 'Mise &agrave; niveau SQL du module &quot;%s&quot; depuis %s vers %s ...';
 $lang['upgrade_event_module_from_to'] = 'Mise &agrave; niveau des &eacute;v&eacute;nements du module &quot;%s&quot; depuis  %s vers %s ...';
 $lang['sitedown_not_removed'] = 'Impossible de supprimer le fichier tmp/cache/SITEDOWN. Merci de le faire manuellement ou votre site affichera le message de maintenance.';
-$lang['upgrade_ok'] = 'V&eacute;rifier le fichier config.php, modifier &eacute;ventuellement la configuration et remettre les permissions &agrave; 444 pour des raisons de s&eacute;curit&eacute;. Vous pouvez aussi v&eacute;rifier si vos modules sont &agrave; la derni&egrave;re version, en allant au menu Extensions -> Modules et regarder si l&#039;indication &quot;Mise &agrave; niveau n&eacute;cessaire&quot; existe.';
+$lang['upgrade_ok'] = 'V&eacute;rifier le fichier config.php, modifier &eacute;ventuellement la configuration et remettre les permissions &agrave; 444 pour des raisons de s&eacute;curit&eacute;. Vous pouvez aussi v&eacute;rifier si vos modules sont &agrave; la derni&egrave;re version, en allant au menu Extensions -> Modules et regarder dans l&#039;onglet &quot;Mises &agrave; jour disponibles&quot;.';
 $lang['upgrade_complete'] = 'Mise &agrave; niveau termin&eacute;e';
-$lang['upgrade_end'] = 'CMSMS est &agrave; jour. Cliquez %s pour aller sur votre site ou aller sur %s.';
+$lang['upgrade_end'] = 'CMSMS&trade; est &agrave; jour. Cliquez %s pour aller sur votre site ou aller sur %s.';
 $lang['here'] = 'ici';
 $lang['go_to_admin'] = 'Administration';
 $lang['errorfilenot'] = 'Fichier non trouv&eacute; !';
@@ -75,12 +79,12 @@ $lang['upload_file_multiple'] = 'Les uploads multiples ne sont pas autoris&eacut
 $lang['test_check_magic_quotes_gpc'] = 'V&eacute;rification de &quot;magic_quotes&quot; pour les op&eacute;rations Get/Post/Cookie';
 $lang['test_check_magic_quotes_gpc_failed'] = 'Lorsque les &quot;magic_quotes&quot; sont &agrave; &quot;On&quot;, les guillemets simples, doubles et antislash sont &eacute;chapp&eacute;s avec un antislash automatiquement. Vous pouvez avoir des probl&egrave;mes avec les gabarits.';
 $lang['test_check_magic_quotes_runtime'] = 'V&eacute;rification de magic_quotes_runtime';
-$lang['test_check_magic_quotes_runtime_failed'] = 'Lorsque les &quot;magic_quotes&quot; sont &agrave; &quot;On&quot;, la plupart des fonctions qui retournent des donn&eacute;es externes, comme ceux des bases de donn&eacute;es ou des fichiers texte, auront &eacute;t&eacute; &eacute;chapp&eacute; avec un anti-slash. Vous pouvez avoir des probl&egrave;mes avec CMS made simple.';
+$lang['test_check_magic_quotes_runtime_failed'] = 'Lorsque les &quot;magic_quotes&quot; sont &agrave; &quot;On&quot;, la plupart des fonctions qui retournent des donn&eacute;es externes, comme ceux des bases de donn&eacute;es ou des fichiers texte, auront &eacute;t&eacute; &eacute;chapp&eacute; avec un anti-slash. Vous pouvez avoir des probl&egrave;mes avec CMS made simple&trade;.';
 $lang['install_admin_checksum'] = 'V&eacute;rification de votre installation';
 $lang['upgrade_admin_checksum'] = 'V&eacute;rification de votre installation avant mise &agrave; niveau';
 $lang['checksum'] = 'Test de contr&ocirc;le (checksum)';
 $lang['checksum_file'] = 'Fichier de contr&ocirc;le (checksum)';
-$lang['install_test_checksum'] = 'Vous pouvez valider l&#039;int&eacute;grit&eacute; de vos fichiers CMSMS en comparant avec le fichier de contr&ocirc;le (cmsmadesimple-x.x.x-xxxx-checksum.dat). Il peut vous aider &agrave; trouver des probl&egrave;mes sur le transfert des fichiers.';
+$lang['install_test_checksum'] = 'Vous pouvez valider l&#039;int&eacute;grit&eacute; de vos fichiers CMSMS&trade; en comparant avec le fichier de contr&ocirc;le (cmsmadesimple-x.x.x-xxxx-checksum.dat). Il peut vous aider &agrave; trouver des probl&egrave;mes sur le transfert des fichiers.';
 $lang['checksum_passed'] = 'Tous les contr&ocirc;les (checksums) correspondent !';
 $lang['checksum_failed'] = 'Les contr&ocirc;les (checksums) ne correspondent pas. Voir l&#039;aide pour les autres informations';
 $lang['test_check_open_basedir'] = 'V&eacute;rification de PHP open_basedir';
@@ -89,9 +93,9 @@ $lang['unlimited'] = 'Illimit&eacute;';
 $lang['test_open_basedir_session_save_path'] = 'La restriction sp&eacute;cifi&eacute;e par open_basedir est activ&eacute;e. Si vous avez des probl&egrave;mes avec SESSION et que ini_set fonctionne, vous pouvez essayer d&#039;activer les sessions par cookies en ajoutant : ini_set (\&#039;session.use_only_cookies\&#039;, 1); en haut de la page include.php';
 $lang['install_warn_db_createtables'] = 'Normalement, ce champ doit rester coch&eacute;.<br /> Soyez prudent lors de la d&eacute;sactivation de cette fonctionnalit&eacute;';
 $lang['install_admin_tablesnotcreated'] = 'Processus termin&eacute;. Le processus d&#039;installation est termin&eacute;, &agrave; votre demande les tables de la base de donn&eacute;es n&#039;ont pas &eacute;t&eacute; cr&eacute;&eacute;s. Cependant, le fichier de configuration a &eacute;t&eacute; r&eacute;initialis&eacute; et tous les tests de pr&eacute;-installation sont pass&eacute;s. Merci, et voici&nbsp;';
-$lang['info_create_dir_and_file'] = 'Le processus HTTP du propri&eacute;taire ne peut cr&eacute;er un fichier dans un dossier du CMS. Cela signifie probablement que le safe_mode est activ&eacute;. De nombreuses fonctions de CMS Made Simple ne fonctionneront donc pas correctement. Impossible de continuer.';
+$lang['info_create_dir_and_file'] = 'Le processus HTTP du propri&eacute;taire ne peut cr&eacute;er un fichier dans un dossier du CMS. Cela signifie probablement que le safe_mode est activ&eacute;. De nombreuses fonctions de CMS Made Simple&trade; ne fonctionneront donc pas correctement. Impossible de continuer.';
 $lang['test_create_dir_and_file'] = 'V&eacute;rification si le processus httpd peut cr&eacute;er un fichier dans un nouveau dossier.';
-$lang['cms_site'] = 'le site CMS Made Simple';
+$lang['cms_site'] = 'le site CMS Made Simple&trade;';
 $lang['or_greater'] = 'Ou plus';
 $lang['sitename'] = 'Nom du site';
 $lang['warning_safe_mode'] = '<strong><em>ATTENTION :</em></strong>Le PHP safe_mode est activ&eacute;. Cela causera des difficult&eacute;s avec les fichiers t&eacute;l&eacute;charg&eacute;s via l&#039;interface de navigation Web, y compris les images, les th&egrave;mes et la gestion des modules XML. Vous &ecirc;tes invit&eacute; &agrave; prendre contact avec votre h&eacute;bergeur pour le consulter afin de d&eacute;sactiver le safe_mode.';
@@ -121,11 +125,11 @@ $lang['php_information'] = 'Informations PHP';
 $lang['cms_install_information'] = 'Informations d&#039;Installation du CMS';
 $lang['cms_version'] = 'Version de CMS ';
 $lang['systeminfo_copy_paste'] = 'Merci de faire un copier coller de cette s&eacute;lection dans le post du forum';
-$lang['help_systeminformation'] = 'Les informations affich&eacute;es ci-dessous sont collect&eacute;es depuis diff&eacute;rents endroits, et permettent d&#039;informer pour un diagnostic ou une aide sur l&#039;installation de CMS Made Simple.';
+$lang['help_systeminformation'] = 'Les informations affich&eacute;es ci-dessous sont collect&eacute;es depuis diff&eacute;rents endroits, et permettent d&#039;informer pour un diagnostic ou une aide sur l&#039;installation de CMS Made Simple&trade;.';
 $lang['systeminfo'] = 'Informations syst&egrave;me';
 $lang['systeminfodescription'] = 'Affiche diff&eacute;rentes informations sur votre syst&egrave;me pour aider &agrave; diagnostiquer des probl&egrave;mes.';
 $lang['error'] = 'Erreur';
-$lang['new_version_available'] = '<em>Remarque :</em> une nouvelle version de CMS Made Simple est disponible. Informez-en votre administrateur.';
+$lang['new_version_available'] = '<em>Remarque :</em> une nouvelle version de CMS Made Simple&trade; est disponible. Informez-en votre administrateur.';
 $lang['info_urlcheckversion'] = 'Si cette URL utilise le mot &quot;none&quot;, aucun contr&ocirc;le ne sera effectu&eacute;.<br/>Une cha&icirc;ne vide utilisera l&#039;URL par d&eacute;faut.';
 $lang['urlcheckversion'] = 'V&eacute;rifier les nouvelles versions CMS &agrave; l&#039;aide de cette URL&nbsp;';
 $lang['read'] = 'Lecture';
@@ -189,13 +193,13 @@ $lang['usermanagement'] = 'Management Utilisateurs';
 $lang['username'] = 'Nom d&#039;utilisateur ';
 $lang['usernameincorrect'] = 'Nom d&#039;utilisateur ou mot de passe incorrect';
 $lang['version'] = 'Version&nbsp;';
-$lang['install_title'] = 'Installation de CMS Made Simple (&eacute;tape %s)';
+$lang['install_title'] = 'Installation de CMS Made Simple&trade; (&eacute;tape %s)';
 $lang['install_system'] = 'Installation du Syst&egrave;me';
-$lang['install_thanks'] = 'Merci pour l&#039;installation de CMS Made Simple';
-$lang['upgrade_title'] = 'CMS Made Simple mise &agrave; niveau (&eacute;tape %s)';
+$lang['install_thanks'] = 'Merci pour l&#039;installation de CMS Made Simple&trade;';
+$lang['upgrade_title'] = 'CMS Made Simple&trade; mise &agrave; niveau (&eacute;tape %s)';
 $lang['upgrade_system'] = 'Mise &agrave; niveau du syst&egrave;me';
-$lang['upgrade_thanks'] = 'Merci pour la mise &agrave; niveau de CMS Made Simple vers';
-$lang['install_please_read'] = 'Merci de lire <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/fr">R&eacute;solution de probl&egrave;mes durant l&#039;installation</a> du Wiki de CMS Made Simple.';
+$lang['upgrade_thanks'] = 'Merci pour la mise &agrave; niveau de CMS Made Simple&trade; vers';
+$lang['install_please_read'] = 'Merci de lire <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/fr">R&eacute;solution de probl&egrave;mes durant l&#039;installation</a> du Wiki de CMS Made Simple&trade;.';
 $lang['install_checking'] = 'V&eacute;rification des permissions et de la configuration PHP';
 $lang['install_test'] = 'Test&nbsp;';
 $lang['install_result'] = 'R&eacute;sultat';
@@ -237,7 +241,7 @@ $lang['test_could_not_create_table'] = 'Impossible de cr&eacute;er une table. V&
 $lang['test_check_php'] = 'V&eacute;rification version PHP %s+';
 $lang['test_min_recommend'] = '(mini %s, recommand&eacute; %s ou plus)';
 $lang['test_min_recommend_plus'] = '(mini %s, recommand&eacute;; %s+)';
-$lang['test_requires_php_version'] = 'CMS Made Simple a besoin de la version PHP 5.2.4 ou plus (vous avez %s), mais PHP %s ou plus est recommand&eacute; pour des probl&egrave;mes de compatibilit&eacute; avec les modules tierces parties';
+$lang['test_requires_php_version'] = 'CMS Made Simple&trade; a besoin de la version PHP 5.2.4 ou plus (vous avez %s), mais PHP %s ou plus est recommand&eacute; pour des probl&egrave;mes de compatibilit&eacute; avec les modules tierces parties';
 $lang['test_check_md5_func'] = 'V&eacute;rification de la fonction md5';
 $lang['test_check_safe_mode'] = 'V&eacute;rification de PHP safe_mode';
 $lang['test_check_safe_mode_failed'] = 'le safe_mode de PHP peut causer des difficult&eacute;s avec les fichiers upload&eacute;s et pour d&#039;autres fonctions. Tout d&eacute;pend de la fa&ccedil;on dont le serveur est configur&eacute;.';
@@ -246,7 +250,7 @@ $lang['test_check_tokenizer_failed'] = 'Ne pas utiliser les fonctions tokenizer
 $lang['test_check_gd'] = 'V&eacute;rification de version de la librairie GD';
 $lang['test_check_gd_failed'] = 'La librairie GD est obligatoire pour certains modules et fonctionnalit&eacute;s.';
 $lang['test_check_write'] = 'V&eacute;rification des permissions en &eacute;criture sur';
-$lang['test_may_not_exist'] = 'Ce fichier n&#039;existe peut-&ecirc;tre pas encore. Si c&#039;est le cas, cr&eacute;ez un fichier vide nomm&eacute; &quot;config.php&quot;. Enregistrez-le dans le dossier principal de &quot;CMSMS&quot;. V&eacute;rifier les permissions de ce fichier (permissions &agrave; 666)';
+$lang['test_may_not_exist'] = 'Ce fichier n&#039;existe peut-&ecirc;tre pas encore. Si c&#039;est le cas, cr&eacute;ez un fichier vide nomm&eacute; &quot;config.php&quot;. Enregistrez-le dans le dossier principal de &quot;CMSMS&trade;&quot;. V&eacute;rifier les permissions de ce fichier (permissions &agrave; 666)';
 $lang['could_not_retrieve_a_value'] = 'Valeur non trouv&eacute;e... On passe...&nbsp;';
 $lang['displaying_the_value_originally'] = '<br />Affiche la valeur originelle contenue dans le fichier de configuration (Peut ne pas &ecirc;tre correct).';
 $lang['test_check_xml_func'] = 'V&eacute;rification du support basic XML (expat)';
@@ -262,9 +266,9 @@ $lang['remote_response_ok'] = 'R&eacute;ponse protocole Remote : Ok';
 $lang['remote_response_404'] = 'R&eacute;ponse protocole Remote : Non trouv&eacute;e !';
 $lang['remote_response_error'] = 'R&eacute;ponse protocole Remote : Erreur !';
 $lang['test_check_file_upload'] = 'V&eacute;rification d&#039;uploads de fichiers';
-$lang['test_check_file_failed'] = 'Lorsque les uploads de fichiers sont d&eacute;sactiv&eacute;s, vous ne serez pas en mesure d&#039;utiliser les possibilit&eacute;s d&#039;uploader des fichiers incluses dans CMS Made Simple. Dans la mesure du possible, cette restriction devrait &ecirc;tre lev&eacute;e par votre administrateur syst&egrave;me afin d&#039;utiliser correctement toutes les fonctionnalit&eacute;s de gestion de fichiers du syst&egrave;me. Proc&eacute;dez avec prudence.';
+$lang['test_check_file_failed'] = 'Lorsque les uploads de fichiers sont d&eacute;sactiv&eacute;s, vous ne serez pas en mesure d&#039;utiliser les possibilit&eacute;s d&#039;uploader des fichiers incluses dans CMS Made Simple&trade;. Dans la mesure du possible, cette restriction devrait &ecirc;tre lev&eacute;e par votre administrateur syst&egrave;me afin d&#039;utiliser correctement toutes les fonctionnalit&eacute;s de gestion de fichiers du syst&egrave;me. Proc&eacute;dez avec prudence.';
 $lang['test_check_memory'] = 'V&eacute;rification de PHP memory_limit';
-$lang['test_check_memory_failed'] = 'Vous pouvez ne pas avoir assez de m&eacute;moire pour utiliser CMSMS correctement, ou avec tous vos modules d&eacute;sir&eacute;s. Si possible, essayer d&#039;augmenter cette valeur en liaison avec votre h&eacute;bergeur. Proc&eacute;dez avec prudence.';
+$lang['test_check_memory_failed'] = 'Vous pouvez ne pas avoir assez de m&eacute;moire pour utiliser CMSMS&trade; correctement, ou avec tous vos modules d&eacute;sir&eacute;s. Si possible, essayer d&#039;augmenter cette valeur en liaison avec votre h&eacute;bergeur. Proc&eacute;dez avec prudence.';
 $lang['test_check_time_limit'] = 'V&eacute;rification de PHP max_execution_time (secondes)<br />';
 $lang['test_check_time_limit_failed'] = 'Nombre de secondes allou&eacute;es pour ex&eacute;cuter un script. Si cela est atteint, le script renvoie une erreur fatale.';
 $lang['test_check_post_max'] = 'V&eacute;rification de post_max_size';
@@ -278,7 +282,7 @@ $lang['test_check_modules_failed'] = 'Le dossier /modules n&#039;a pas les permi
 $lang['test_check_file_get_contents'] = 'V&eacute;rification de file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'Vous ne sera probablement pas en mesure d&#039;utiliser l&#039;une des fonctionnalit&eacute;s qui utilise cette fonction.';
 $lang['test_check_session_save_path'] = 'V&eacute;rification des permissions d&#039;&eacute;criture sur session.save_path';
-$lang['test_empty_session_save_path'] = 'Votre session.save_path est vide. PHP utilisera le dossier temporaire de votre syst&egrave;me d&#039;exploitation. Si vous avez des probl&egrave;mes de SESSION et que ini_set fonctionne, vous pouvez essayer d&#039;activer la session de cookies en ajoutant : ini_set(&#039;session.use_only_cookies&#039;, 1); en haut de include.php';
+$lang['test_empty_session_save_path'] = 'Votre session.save_path est vide. PHP utilisera le dossier temporaire de votre syst&egrave;me d&#039;exploitation. Si vous avez des probl&egrave;mes de SESSION et que ini_set fonctionne, vous pouvez essayer d&#039;activer la session de cookies en ajoutant : ini_set(&#039;session.use_only_cookies&#039;, 1); en haut du fichier config.php';
 $lang['test_check_session_save_path_failed'] = 'Votre session.save_path est &quot;%s&quot;. Le fait qu&#039;il ne soit pas inscriptible pourrait emp&ecirc;cher la connexion au panneau d&#039;administration. Vous devriez essayer de rendre ce chemin inscriptible si vous avez des probl&egrave;mes &agrave; vous connecter au panneau d&#039;administration. Ce test pourrait &eacute;chouer si safe_mode est activ&eacute; (voir plus bas).';
 $lang['test_check_ini_set'] = 'V&eacute;rification si ini_set fonctionne';
 $lang['test_check_ini_set_failed'] = 'Bien que la capacit&eacute; de passer outre les param&egrave;tres de php ini n&#039;est pas obligatoire, certaines fonctionnalit&eacute;s de module (facultatif) utilisent ini_set pour proroger des d&eacute;lais d&#039;expiration, et pour permettre le t&eacute;l&eacute;chargement de fichiers volumineux, etc. Vous pouvez avoir des difficult&eacute;s avec certaines fonctionnalit&eacute;s sans cette possibilit&eacute;. Ce test peut &eacute;chouer si le safe_mode est activ&eacute; (voir ci-dessous).';
@@ -318,7 +322,7 @@ $lang['install_admin_setup'] = 'Continuons maintenant avec l&#039;installation d
 $lang['install_admin_docroot'] = 'La racine du CMS (adresse du site web)';
 $lang['install_admin_docroot_path'] = 'Chemin de la racine du CMS';
 $lang['install_admin_querystring'] = 'Symbole apr&egrave;s &quot;index.php?&quot; (exemple. http://www.monsite.fr/index.php?page=xxx ). Laissez tel quel et &eacute;ventuellement &eacute;ditez le fichier config.php &agrave; la main';
-$lang['invalid_querys'] = '<b>ATTENTION<b/> : requ&ecirc;te invalide sur la base de donn&eacute;es !';
+$lang['invalid_querys'] = '<b>ATTENTION</b> : requ&ecirc;te invalide sur la base de donn&eacute;es !';
 $lang['install_admin_sitedown'] = 'Erreur : Impossible de supprimer le fichier tmp/cache/SITEDOWN. Merci de le supprimer manuellement.';
 $lang['install_admin_update_hierarchy'] = 'Mise &agrave; jour de la hi&eacute;rarchie ...&nbsp;';
 $lang['install_admin_set_core_event'] = 'Configuration du noyau CMS Made Simple ...&nbsp;';
@@ -329,17 +333,16 @@ $lang['install_admin_emailing'] = 'Mail d&#039;information sur le compte Adminis
 $lang['install_admin_congratulations'] = 'Merci pour l&#039;installation de CMS Made Simple, la configuration est termin&eacute;e - Se connecter sur&nbsp; ';
 $lang['could_not_connect_db'] = 'Impossible de se connecter &agrave; la base de donn&eacute;es. V&eacute;rifiez que le nom d&#039;utilisateur et/ou le mot de passe sont correct, et que les acc&egrave;s sont autoris&eacute;s pour l&#039;utilisateur.';
 $lang['cannot_write_config'] = 'Erreur : Impossible d&#039;&eacute;crire sur %s.';
-$lang['email_accountinfo_subject'] = 'CMS Made Simple - Information sur le compte administrateur';
-$lang['email_accountinfo_message'] = 'Merci d&#039;avoir install&eacute; CMS Made Simple.
+$lang['email_accountinfo_subject'] = 'CMS Made Simple&trade; - Information sur le compte administrateur';
+$lang['email_accountinfo_message'] = 'Merci d&#039;avoir install&eacute; CMS Made Simple&trade;.
 
 Vos informations sur le nouveau compte Administrateur :
 Nom utilisateur : %s
 Mot de passe : %s
 
 Se connecter &agrave; l&#039;administration : %s';
-$lang['utma'] = '156861353.2003866910.1245652859.1281456650.1281561723.184';
-$lang['utmz'] = '156861353.1281561723.184.168.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
-$lang['qca'] = '4a3d1b41-5eb36-c9570-f49ea';
+$lang['utma'] = '156861353.2076458313.1290499132.1290499132.1290499132.1';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1281561723';
+$lang['utmz'] = '156861353.1290499132.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
