@@ -1,4 +1,8 @@
 <?php
+$lang['setup_flat_urls'] = 'Gli URL abbreviati sono impostati';
+$lang['install_timezone'] = 'Alcuni server che eseguono php 5.3 hanno un fuso orario impostato non correttamente.  Selezionate il fuso orario appropriato dalla lista precedente.  Se non &egrave; necessario nel vostro server, potete selezionare &quot;Nessuno&quot;, potete modificare questa impostazione nel file config.php anche in seguito.';
+$lang['timezone'] = 'Fuso Orario';
+$lang['none'] = 'Nessuno';
 $lang['test_error_estrict'] = 'Controllo error_reporting per accertare che E_STRICT sia disabilitato';
 $lang['test_estrict_failed'] = 'E_STRICT &egrave; abilitato';
 $lang['info_estrict_failed'] = 'Alcune librerie utilizzate da CMSMS non funzionano correttamente con E_STRICT.  Vi preghiamo di disabilitarlo prima di procedere';
@@ -338,5 +342,8 @@ nome utente: %s
 password: %s
 
 Potete accedere all&#039;area di amministrazione da qui: %s';
-$lang['qca'] = 'P0-250679722-1271187168764';
+$lang['utma'] = '156861353.974349155.1299072468.1299072468.1299072468.1';
+$lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
