@@ -1,20 +1,29 @@
 <?php
+$lang['install_timezone'] = 'Some servers running php 5.3 have not set the timezone correctly.  Please select the appropriate timezone from the list before.  If this is not necessary on your server you may select "None"';
+$lang['timezone'] = 'タイムゾーン';
+$lang['none'] = 'なし';
+$lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
+$lang['test_estrict_failed'] = 'E_STRICT は有効です。';
+$lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
+$lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED は有効です。';
+$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see alot of warning messages that could effect the display and functionalty';
 $lang['invalidemail'] = '入力されたメールアドレスが無効です。';
 $lang['empty_query'] = 'Empty query?? %s';
 $lang['no_db_driver'] = 'データベースドライバに互換性がありません。';
 $lang['test_check_output_buffering'] = 'Checking output buffering';
 $lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
 $lang['phpinfo'] = 'PHP情報を表示する。';
-$lang['mod_security'] = 'Apache Mod Security';
+$lang['mod_security'] = 'Apache セキュリティモジュール';
 $lang['test_check_tempnam'] = 'Checking for tempnam Function';
 $lang['test_check_db_drivers'] = 'データベースドライバ';
 $lang['test_check_db_drivers_failed'] = 'データベースドライバが見つかりません。';
 $lang['test_check_register_globals'] = 'Checking PHP register globals';
 $lang['test_check_register_globals_failed'] = 'PHP register globals is active. For security reasons, this should be disabled.';
 $lang['test_check_disable_functions'] = 'Checking PHP disable functions';
-$lang['test_check_disable_functions_failed'] = 'Warning: this is a list of functions disabled on your server.';
+$lang['test_check_disable_functions_failed'] = '警告: サーバで無効な機能の一覧があります。';
 $lang['install_admin_db_port'] = 'データベースポート';
-$lang['install_admin_db_port_info'] = 'If you don\'t know, leave this blank to use default settings.';
+$lang['install_admin_db_port_info'] = '分からないようであれば、空白にすることでデフォルト値を設定します。';
 $lang['install_admin_db_socket'] = 'データベースソケット';
 $lang['install_admin_db_socket_info'] = 'サポートしていません。';
 $lang['install_admin_frontendlang'] = 'Default language for the frontend. This adjusts the locale used for various default date handling functions, etc.';
@@ -22,10 +31,10 @@ $lang['install_default_encoding'] = 'In almost all cases, default_encoding shoul
 $lang['installer_done'] = '[完了]';
 $lang['installer_failed'] = '[失敗]';
 $lang['create_permission'] = '権限を作成する ...';
-$lang['add_column_sql'] = 'Adding column to %s table ...';
-$lang['update_table_sql'] = 'Updating table %s ...';
-$lang['installing_module'] = 'Installing module %s ...';
-$lang['updating_schema_version'] = 'Updating schema version %s ...';
+$lang['add_column_sql'] = 'テーブルにカラムを追加中・・・ %s';
+$lang['update_table_sql'] = 'テーブルを更新中・・・ %s ';
+$lang['installing_module'] = 'モジュールをインストール中・・・ %s';
+$lang['updating_schema_version'] = 'スキーマバージョンを更新中・・・ %s';
 $lang['upgrade_config'] = 'config.php更新します。';
 $lang['upgrade_config_info'] = '設定の更新';
 $lang['upgrade_failed_again'] = 'One or more upgrades have failed. Please correct the problem and click the button below to recheck.';
@@ -47,19 +56,19 @@ $lang['here'] = 'ここ';
 $lang['go_to_admin'] = '管理者ページへ進む';
 $lang['errorfilenot'] = 'ファイルが見つかりません！';
 $lang['errorfilenotwritable'] = 'ファイルが書き込めません！';
-$lang['nofiles'] = 'This resource does not exist!';
-$lang['is_directory'] = 'This resource is a directory!';
-$lang['is_readable_false'] = 'This resource is not readable!';
-$lang['checksum_match'] = 'Checksum matches!';
-$lang['checksum_not_match'] = 'Checksum does not match!';
-$lang['not_checksum'] = 'Could not retrieve checksum!';
+$lang['nofiles'] = 'このリソースは存在しません！';
+$lang['is_directory'] = 'このリソースはディレクトリです！';
+$lang['is_readable_false'] = 'このリソースは読み込めません！';
+$lang['checksum_match'] = 'チェックサムが一致しました！';
+$lang['checksum_not_match'] = 'チェックサムが一致しませんでした！';
+$lang['not_checksum'] = 'チェックサムを検索できませんでした！';
 $lang['format_datetime'] = '%c';
 $lang['upload_err_ini_size'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini!';
 $lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
 $lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
 $lang['upload_err_no_file'] = '更新されたファイルがありません。';
-$lang['upload_err_no_tmp_dir'] = 'Missing a temporary folder.';
-$lang['upload_err_cant_write'] = 'Failed to write file to disk.';
+$lang['upload_err_no_tmp_dir'] = 'テンポラリフォルダが間違っています。';
+$lang['upload_err_cant_write'] = 'ファイルをディスクに書き込めませんでした。';
 $lang['upload_err_extension'] = 'File upload stopped by extension.';
 $lang['upload_err_empty'] = '0バイトのファイルです。';
 $lang['upload_err_unknown'] = '不明なアップロード時の問題です。';
@@ -295,36 +304,36 @@ $lang['install_admin_db_type'] = 'データベースタイプ';
 $lang['install_admin_no_db'] = 'No valid database drivers appear to be compiled into your PHP install. Please confirm that you have mysql, mysqli, and/or postgres7 support installed, and try again.';
 $lang['install_admin_db_host'] = 'データベースアドレス';
 $lang['install_admin_db_name'] = 'データベース名';
-$lang['install_admin_db_create'] = 'Create Tables (Warning: Deletes existing data)';
-$lang['install_admin_db_prefix'] = 'Table prefix';
-$lang['install_admin_db_sample'] = 'Install sample content and templates';
+$lang['install_admin_db_create'] = 'テーブルを作成します。 (警告: データは削除されます)';
+$lang['install_admin_db_prefix'] = 'テーブル・プレフィックス';
+$lang['install_admin_db_sample'] = 'サンプルコンテンツとテンプレートをインストールします。';
 $lang['retry'] = 'リトライ';
-$lang['install_admin_db_create_seq'] = 'Creating %s table sequence...';
-$lang['install_admin_importing'] = 'Importing sample data...';
+$lang['install_admin_db_create_seq'] = 'テーブルシーケンスを作成しています。 %s';
+$lang['install_admin_importing'] = 'サンプルデータをインポートしています。';
 $lang['invalid_query'] = 'Invalid query: %s';
 $lang['install_creating_table'] = '<p>Creating %s table... [%s]</p>';
 $lang['install_creating_index'] = '<p>Creating index in %s table... [%s]</p>';
-$lang['done'] = '完了';
-$lang['failed'] = '失敗';
-$lang['install_admin_error_schema'] = 'Error in retrieve SQL schema';
-$lang['install_admin_set_account'] = 'Setting admin account information...';
-$lang['install_admin_set_sitename'] = 'Setting sitename...';
+$lang['done'] = '完了しました。';
+$lang['failed'] = '失敗しました。';
+$lang['install_admin_error_schema'] = 'SQLスキーマの検索でエラーが発生しました。';
+$lang['install_admin_set_account'] = 'admin account 情報を設定しました。';
+$lang['install_admin_set_sitename'] = 'サイト名を設定しました。';
 $lang['install_admin_setup'] = 'Now let\'s continue to setup your configuration file, we already have most of the stuff we need. Chances are you can leave all these values alone, so when you are ready, click Continue.';
 $lang['install_admin_docroot'] = 'CMS Document root (as seen from the webserver)';
-$lang['install_admin_docroot_path'] = 'Path to the Document root';
+$lang['install_admin_docroot_path'] = 'Document root のパス';
 $lang['install_admin_querystring'] = 'Query string (leave this alone unless you have trouble, then edit config.php by hand)';
 $lang['invalid_querys'] = '<b>WARNING<b/>: Invalid queries on your DB!';
-$lang['install_admin_sitedown'] = 'Error: Could not remove the tmp/cache/SITEDOWN file. Please remove manually.';
+$lang['install_admin_sitedown'] = 'エラー: Could not remove the tmp/cache/SITEDOWN file. Please remove manually.';
 $lang['install_admin_update_hierarchy'] = 'Updating hierarchy positions...';
 $lang['install_admin_set_core_event'] = 'Setting up core events...';
 $lang['install_admin_install_modules'] = 'モジュールのインストール...';
-$lang['install_admin_index_search'] = 'Index Search...';
+$lang['install_admin_index_search'] = 'インデックス検索・・・';
 $lang['install_admin_clear_cache'] = 'Clearing site cache (if any)...';
-$lang['install_admin_emailing'] = 'E-mailing admin account information...';
+$lang['install_admin_emailing'] = 'アカウント情報をadminにメールしました。';
 $lang['install_admin_congratulations'] = 'Congratulations, you are all setup - here is your ';
 $lang['could_not_connect_db'] = 'Could not connect to the database. Verify that username and password are correct, and that the user has access to the given database.';
-$lang['cannot_write_config'] = 'Error: Cannot write to %s.';
-$lang['email_accountinfo_subject'] = 'CMS Made Simple Admin Account Information';
+$lang['cannot_write_config'] = 'エラー: 書き込みできませんでした。 %s.';
+$lang['email_accountinfo_subject'] = 'CMS Made Simple のAdmin アカウント情報';
 $lang['email_accountinfo_message'] = 'CMS Made Simpleをご利用いただき、ありがとうございます！
 
 以下はアカウント情報になります:
@@ -332,8 +341,9 @@ $lang['email_accountinfo_message'] = 'CMS Made Simpleをご利用いただき、
 パスワード: %s
 
 ここからサイトの管理ページへログインしてください: %s';
-$lang['utma'] = '156861353.3775144692282817500.1248653923.1248653923.1248653923.1';
-$lang['utmb'] = '156861353.1.10.1248653923';
+$lang['utma'] = '156861353.1025915730.1283783986.1283783986.1283783986.1';
+$lang['utmb'] = '156861353.1.10.1283783986';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1248653923.1.1.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['utmz'] = '156861353.1283783986.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-494958194-1283783986906';
 ?>
\ No newline at end of file
