@@ -1,4 +1,7 @@
 <?php
+$lang['invalidemail'] = 'The email address entered is invalid';
+$lang['empty_query'] = 'Empty query?? %s';
+$lang['no_db_driver'] = 'No compatible database drivers found';
 $lang['test_check_output_buffering'] = 'Tikrinimo rezultatų kaupimas';
 $lang['test_check_output_buffering_failed'] = 'Tikrinimo rezultatų kaupimas i&scaron;jungtas. Jūs tikriausiai negalėsite naudoti bet kurią i&scaron; funkcijų, kuriomis reikalauja kaupimo';
 $lang['phpinfo'] = 'Rodyti PHP Informatcija';
@@ -323,7 +326,6 @@ $lang['install_admin_congratulations'] = 'Sveikiname, jūs jau įdiegėte - &sca
 $lang['could_not_connect_db'] = 'Neįmanoma prisijungti prie duomenų bazės. Patikrinkite ar prisijungimo vardas ir slaptažodis teisingi ir turi tinkamus leidimus.
 ';
 $lang['cannot_write_config'] = 'Klaida: Neįmanoma įra&scaron;yti %s.';
-$lang['install_additional_modules'] = 'Įdiekita papildomus modulius';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple Administratoriaus paskyros informacija';
 $lang['email_accountinfo_message'] = 'Dėkojame, kad įdiegėte CMS Made Simple.
 
@@ -331,8 +333,9 @@ $lang['email_accountinfo_message'] = 'Dėkojame, kad įdiegėte CMS Made Simple.
 prisijungimo vardas: %s
 slaptažodis: %s
 Prisijungti galite čia: %s';
-$lang['utma'] = '156861353.1129899627.1215092715.1225795281.1225802101.31';
-$lang['utmz'] = '156861353.1225111254.29.17.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,33.0.html';
+$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1259353230.1259355475.2152';
+$lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.2.10.1259355475';
 ?>
\ No newline at end of file
