@@ -1,28 +1,32 @@
 <?php
+$lang['setup_flat_urls'] = 'Flate URLer er aktiverte';
+$lang['install_timezone'] = 'Noen servere som kj&oslash;rer php 5.3 har ikke satt tidssonen korrekt. Vennligst velg den korrekte tidssonen fra listen nedenfor f&oslash;r du fortsetter. Om dette ikke er n&oslash;dvendig p&aring; din server s&aring; kan du velge &quot;Ingen&quot;.  <strong>Merk:</strong> Vennligst velg din servers tidssone, dette er ikke en visningsinnstilling, men er benyttet i beregninger relatert til datoer.  This setting can be changed after installation by modifying the config.php file. Denne innstilling kan endres etter installasjonen ved &aring; endre i config.php filen.';
+$lang['timezone'] = 'Tdssone';
+$lang['none'] = 'Ingen';
 $lang['test_error_estrict'] = 'Tester error_reporting for &aring; sikre at E_STRICT ikke er aktivert';
 $lang['test_estrict_failed'] = 'E_STRICT er aktivert';
 $lang['info_estrict_failed'] = 'Noen biblioteker som CMS Made Simple benytter fungerer ikke godt med E_STRICT. Vennligst sl&aring; av denne f&oslash;r du fortsetter';
 $lang['test_error_edeprecated'] = 'Tester error_reporting for &aring; sikre at E_DEPRECATED ikke er aktivert';
 $lang['test_edeprecated_failed'] = 'E_DEPRECATED er aktivert';
-$lang['info_edeprecated_failed'] = 'Om E_DEPRECATED er aktivert i din feilrapportering s&aring; vil brukere se mange advarselsmeldinger som kan ha innvirkning p&aring; visningen og funksjonaliteten';
+$lang['info_edeprecated_failed'] = 'Om E_DEPRECATED er aktivert i din feilrapportering s&aring; vil brukere se mange advarselmeldinger som kan ha innvirkning p&aring; visningen og funksjonaliteten';
 $lang['invalidemail'] = 'E-postadressen som er oppgitt er ugyldig';
 $lang['empty_query'] = 'Tom sp&oslash;rring?? %s';
 $lang['no_db_driver'] = 'Ingen kompatible databasedrivere ble funnet';
 $lang['test_check_output_buffering'] = 'Tester for output buffring';
-$lang['test_check_output_buffering_failed'] = 'Output buffring er avsl&aring;tt. Du vil trolig f&aring;r problemer med &aring; benytte de funksjoner som benytter denne funksjonen';
+$lang['test_check_output_buffering_failed'] = 'Output buffering er avsl&aring;tt. Du vil trolig f&aring;r problemer med &aring; benytte de funksjoner som benytter denne funksjonen';
 $lang['phpinfo'] = 'Se p&aring; PHP Informasjon';
 $lang['mod_security'] = 'Apache Mod Security ';
 $lang['test_check_tempnam'] = 'Tester for tempnam Function';
 $lang['test_check_db_drivers'] = 'DB drivere';
 $lang['test_check_db_drivers_failed'] = 'Ingen DB drivere ble funnet';
 $lang['test_check_register_globals'] = 'Tester PHP register globals';
-$lang['test_check_register_globals_failed'] = 'PHP register globals er aktiv. For sikkerhetskyld be om dette sl&aring;s av.';
+$lang['test_check_register_globals_failed'] = 'PHP register globals er aktiv. For sikkerhetskyld be om at dette sl&aring;s av.';
 $lang['test_check_disable_functions'] = 'Tester PHP disable functions';
 $lang['test_check_disable_functions_failed'] = 'Dette er en liste med funksjoner som er avsl&aring;tt p&aring; din server.';
 $lang['install_admin_db_port'] = 'Database port ';
 $lang['install_admin_db_port_info'] = 'Om du ikke kjenner denne - lar du dette felte forbli blankt for &aring; benytte standard port';
 $lang['install_admin_db_socket'] = 'Database socket ';
-$lang['install_admin_db_socket_info'] = 'NOT WORK YET. Work with mysqli DB driver only';
+$lang['install_admin_db_socket_info'] = 'IKKE ST&Oslash;TTET.';
 $lang['install_admin_frontendlang'] = 'Standard spr&aring;k for frontend. Dette justerer lokalitet(locale) som benyttes for diverse standard datobehandlingsfunksjoner, osv.. ';
 $lang['install_default_encoding'] = 'I nesten alle tilfeller,b&oslash;r default_encoding v&aelig;re utf-8.';
 $lang['installer_done'] = '[utf&oslash;rt]';
@@ -35,8 +39,8 @@ $lang['updating_schema_version'] = 'Oppdaterer skjemaversjon %s ...';
 $lang['upgrade_config'] = 'Oppgraderer config.php';
 $lang['upgrade_config_info'] = 'config oppgradert';
 $lang['upgrade_failed_again'] = 'En eller flere oppgraderinger har feilet. Vennligst korriger problemet og klikk knappen nedenfor for en ny test.';
-$lang['upgrade_cache_dirs'] = 'Renser ut fra cache katalogene';
-$lang['cannot_clean_cache_dirs'] = 'Klarer ikke &aring; rense ut fra cache katalogene!';
+$lang['upgrade_cache_dirs'] = 'T&oslash;mmer cache katalogene';
+$lang['cannot_clean_cache_dirs'] = 'Klarer ikke &aring; t&oslash;mme fra cache katalogene!';
 $lang['upgrade_schema'] = 'Oppgrader skjema';
 $lang['need_upgrade_schema'] = 'CMS trenger en oppgradering.<br />Du kj&oslash;rer n&aring; p&aring; skjema versjon %s og du trenger &aring; oppgradere til versjon %s';
 $lang['schema_ok'] = 'N&aring; er CMS databasen oppdatert og benytter skjema versjon %s';
@@ -73,7 +77,7 @@ $lang['function_file_uploads_off'] = 'file_uploads er avsl&aring;tt i din php!';
 $lang['upload_file_no_readable'] = 'Opplastet fil er ikke lesbar!';
 $lang['upload_file_multiple'] = 'Flere filopplastinger ikke tillatt!';
 $lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operasjoner';
-$lang['test_check_magic_quotes_gpc_failed'] = 'N&aring;r magic_quotes er p&aring;, vil alle apostrofer, anf&oslash;rselstegn og omvendt skr&aring;strek bli markert(escaped) med omvendt skr&aring;strek automatisk. Kan ogs&aring; ha problemer med lagring av maler.';
+$lang['test_check_magic_quotes_gpc_failed'] = 'N&aring;r magic_quotes er p&aring;, vil alle apostrofer, anf&oslash;rselstegn og omvendt skr&aring;strek bli markert(escaped) med omvendt skr&aring;strek automatisk. Dette kan gi mange problemer i CMS.';
 $lang['test_check_magic_quotes_runtime'] = 'Test om Magic quotes er aktivert';
 $lang['test_check_magic_quotes_runtime_failed'] = 'N&aring;r magic_quotes er p&aring;, vil de fleste funksjoner som returnerer data fra enhver form for ekstern kilde - inkludert databaser og tekstfiler ha anf&oslash;rselstegn markert(escaped) med omvendt skr&aring;strek. Dette vil gi problemer med CMS Made Simple.';
 $lang['install_admin_checksum'] = 'Test din installasjon';
@@ -86,7 +90,7 @@ $lang['checksum_failed'] = 'Checksum hadde feil. Se i hjelp for mer informasjon'
 $lang['test_check_open_basedir'] = 'Test for PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Open basedir restriksjoner er effektive. Du vil trolig ha problemer med noe tilleggsfunksjonalitet med denne restriksjonen.';
 $lang['unlimited'] = 'Ubegrenset';
-$lang['test_open_basedir_session_save_path'] = 'Open basedir restriksjoner ser ut til &aring; v&aelig;re i effekt. Om du har SESSION problemer og ini_set fungerer kan du fors&oslash;ke &aring; sl&aring; p&aring; session cookies ved &aring; legge til: ini_set(&#039;session.use_only_cookies&#039;, 1); til toppen av include.php fila';
+$lang['test_open_basedir_session_save_path'] = 'Open basedir restriksjoner ser ut til &aring; v&aelig;re i effekt. Om du har SESSION problemer og ini_set fungerer kan du fors&oslash;ke &aring; sl&aring; p&aring; session cookies ved &aring; legge til: ini_set(&#039;session.use_only_cookies&#039;, 1); til toppen av config.php fila';
 $lang['install_warn_db_createtables'] = 'Normal skal dette feltet alltid v&aelig;re avkrysset. V&aelig;r forsiktig om du sl&aring;r av denne egenskapen.';
 $lang['install_admin_tablesnotcreated'] = 'Prosessering ferdig. Installasjonsprosessen er fullf&oslash;rt, p&aring; din begj&aelig;ring ble ikke databasetabeller opprettet. Men config filen har blitt tilbakestilt og alle f&oslash;r-installasjonstester ble gjennomf&oslash;rt. Takk, og her er din';
 $lang['info_create_dir_and_file'] = 'HTTP prosessens eier kan ikke opprette en fil inne i en katalog som den eier. Dette betyr sannsynligvis at safe mode er sl&aring;tt p&aring; p&aring; en eller annen m&aring;te. Mange funksjoner inne i CMS Made Simple vil ikke fungere skikkelig uten denne muligheten. &Aring; fortsette er ikke mulig.';
@@ -164,8 +168,8 @@ $lang['edit'] = 'Rediger';
 $lang['email'] = 'E-postadresse';
 $lang['errordeletingfile'] = 'Kan ikke slette filen, Rettighetsproblem?';
 $lang['errordirectorynotwritable'] = 'Har ikke rettighet til &aring; skrive til katalog. Dette kan for&aring;rsakes av filrettigheter og eierskap. Safe_mode kan ogs&aring; v&aelig;re i effekt.';
-$lang['cachenotwritable'] = 'Cache mappen er ikke skrivbar. &Aring; t&oslash;mme cache vil ikke fungere. Vennligst endre tmp/cache katalogen til &aring; ha full lese/skrive/utf&oslash;re(read/write/execute) rettigheter (chmod 777). Du trenger kanskje ogs&aring; &aring; sl&aring; av safe mode.';
-$lang['modulesnotwritable'] = 'Modules mappen er ikke skrivbar. Om du &oslash;nsker &aring; installere moduler ved &aring; laste opp en XML-fil s&aring; trenger du &aring; endre modules-mappen til &aring; ha fulle lese/skrive/utf&oslash;r(read/write/execute) rettigheter (chmod 777).  Safe mode kan ogs&aring; v&aelig;re i effekt.';
+$lang['cachenotwritable'] = 'Cache mappen er ikke skrivbar. &Aring; t&oslash;mme cache vil ikke fungere. Vennligst endre tmp/cache katalogen til &aring; ha full lese/skrive/utf&oslash;re(read/write/execute) rettigheter (chmod 777) for PHP-prosessen. Du trenger kanskje ogs&aring; &aring; sl&aring; av safe mode.';
+$lang['modulesnotwritable'] = 'Modules mappen er ikke skrivbar. Om du &oslash;nsker &aring; installere moduler ved &aring; laste opp en XML-fil s&aring; trenger du &aring; endre modules-mappen til &aring; ha fulle lese/skrive/utf&oslash;r(read/write/execute) rettigheter (chmod 777) for PHP-prosessen.  Safe mode kan ogs&aring; v&aelig;re i effekt.';
 $lang['false'] = 'Usann';
 $lang['settrue'] = 'Sett sann';
 $lang['filename'] = 'Filnavn';
@@ -251,7 +255,7 @@ $lang['could_not_retrieve_a_value'] = 'Klarte ikke lese verdien.... fortsetter a
 $lang['displaying_the_value_originally'] = '<br />Viser verdien opprinnelig satt i config filen (dette kan v&aelig;re uriktig).';
 $lang['test_check_xml_func'] = 'Tester om grunnleggende XML (expat) st&oslash;tte';
 $lang['test_check_xml_failed'] = 'XML st&oslash;tte er ikke kompilert inn i din php installasjon. Du kan fortsatt benytte systemet, men vil ikke kunne benytte noen av fjerninstallasjonsfunksjonene for moduler.';
-$lang['test_allow_url_fopen_failed'] = 'N&aring;r &#039;allow url fopen&#039; er sl&aring;tt av vil du ikke v&aelig;re i stand til &aring; n&aring; URL objekter som fil ved &aring; benytte ftp eller http protokollene.';
+$lang['test_allow_url_fopen_failed'] = 'N&aring;r &#039;allow url fopen&#039; er sl&aring;tt av vil du ikke v&aelig;re i stand til &aring; n&aring; URL objekter som filer ved &aring; benytte ftp eller http protokollene.';
 $lang['test_remote_url'] = 'Test for fjern URL';
 $lang['test_remote_url_failed'] = 'Du vil trolig ikke kunne &aring;pne en fil p&aring; en fjern-webserver.';
 $lang['connection_error'] = 'Utg&aring;ende http forbindelser ser ikke ut til &aring; fungere! Det er en brannmur eller en eller annen ACL for eksterne forbindelser? Dette vil medf&oslash;re at modulbehandleren, og potensielt annen funksjonalitet feiler.';
@@ -264,7 +268,7 @@ $lang['remote_response_error'] = 'Fjern respons: feil!';
 $lang['test_check_file_upload'] = 'Tester filopplasting';
 $lang['test_check_file_failed'] = 'N&aring;r filopplasting er sl&aring;tt av vil du ikke kunne benytte noen av filopplastingsfasilitetene inkludert i CMS Made Simple. Om mulig, b&oslash;r denne restriksjonen fjernes av din systemadministrator for at du skal kunne benytte alle filbehandlingsfunksjonene i systemet. Fortsett med forsiktighet.';
 $lang['test_check_memory'] = 'Tester PHP memory limit';
-$lang['test_check_memory_failed'] = 'Det er mulig du ikke har nok minne for &aring; kj&oslash;re CMSMS ordentlig, eller med alle &oslash;nskede tillegg. Om mulig,, b&oslash;r du fors&oslash;ke &aring; f&aring; din systemadministrator til &aring; heve denne verdien. Fortsett med forsiktighet.';
+$lang['test_check_memory_failed'] = 'Det er mulig du ikke har nok minne for &aring; kj&oslash;re CMSMS godt, eller med alle &oslash;nskede tillegg. Om mulig,, b&oslash;r du fors&oslash;ke &aring; f&aring; din systemadministrator til &aring; heve denne verdien. Fortsett med forsiktighet.';
 $lang['test_check_time_limit'] = 'Tester PHP time limit';
 $lang['test_check_time_limit_failed'] = 'Antall sekunder et skript er tillatt &aring; kj&oslash;re. Om denne verdi n&aring;s vil skriptet returnere en fatal error(=alvorlig feil).';
 $lang['test_check_post_max'] = 'Tester max post size';
@@ -278,8 +282,8 @@ $lang['test_check_modules_failed'] = 'modules mappa er ikke skrivbar. Du kan for
 $lang['test_check_file_get_contents'] = 'Tester file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'Du vil trolig ikke kunne benytte funksjonalitet som benytter denne funksjonen';
 $lang['test_check_session_save_path'] = 'Sjekker om session.save_path er skrivbar';
-$lang['test_empty_session_save_path'] = 'Din session.save_path er tom. PHP vil benytte den midlertidige mappa for din vert. Om du har SESSION problemer og ini_set fungerer kan du fors&oslash;ke &aring; sl&aring; p&aring; session cookies ved &aring; legge til: ini_set(&#039;session.use_only_cookies&#039;, 1);  til toppen av include.php';
-$lang['test_check_session_save_path_failed'] = 'Din session.save_path er &quot;%s&quot;. &Aring; ikke ha denne satt som skrivbar kan for&aring;rsake at innlogginger til administrasjonspanelet ikke fungerer. Du b&oslash;r fors&oslash;ke &aring; gj&oslash;re denne stien skrivbar om du har problemer med innlogging til administrasjonspanelet. Denne testen kan feile om safe_mode er aktivert (se nedenfor).';
+$lang['test_empty_session_save_path'] = 'Din session.save_path er tom. PHP vil benytte den midlertidige mappa for din vert. Om du har SESSION problemer og ini_set fungerer kan du fors&oslash;ke &aring; sl&aring; p&aring; session cookies ved &aring; legge til: ini_set(&#039;session.use_only_cookies&#039;, 1);    til toppen av config.php filen';
+$lang['test_check_session_save_path_failed'] = 'Din session.save_path er &quot;%s&quot;. &Aring; ikke ha denne satt som skrivbar kan for&aring;rsake at innlogging til administrasjonspanelet ikke fungerer. Du b&oslash;r fors&oslash;ke &aring; gj&oslash;re denne stien skrivbar om du har problemer med innlogging til administrasjonspanelet. Denne testen kan feile om safe_mode er aktivert (se nedenfor).';
 $lang['test_check_ini_set'] = 'Sjekker om ini_set fungerer';
 $lang['test_check_ini_set_failed'] = 'Selv om muligheten til &aring; overstyre php ini innstillinger ikke er n&oslash;dvendig, noen tillegg (valgfri) funksjonalitet benytter ini_set for &aring; utvide tidsavbrudd, og tillater da opplasting av st&oslash;rre filer, osv. Du kan f&aring; vanskeligheter med noen tilleggsfunksjoner om du ikke har denne muligheten. Denne testen kan feile om safe_mode er aktivert (se nedenfor).';
 $lang['install_admin_header'] = 'Admin kontoinformasjon';
@@ -301,7 +305,7 @@ $lang['install_admin_db_type'] = 'Databasetype';
 $lang['install_admin_no_db'] = 'Ingen gyldige database drivere synes &aring; v&aelig;re kompilert inn i din PHP installasjon. Vennligst bekreft at du har mysql, mysqli, og/eller postgres7 st&oslash;tte installert, og fors&oslash;k s&aring; igjen.';
 $lang['install_admin_db_host'] = 'Database vertsadresse(host address)';
 $lang['install_admin_db_name'] = 'Databasenavn';
-$lang['install_admin_db_create'] = 'Opprett kataloger (Advarsel: Sletter eksisterende data)';
+$lang['install_admin_db_create'] = 'Opprett kataloger (Advarsel: Dette sletter eksisterende data)';
 $lang['install_admin_db_prefix'] = 'Table prefiks';
 $lang['install_admin_db_sample'] = 'Installer standarddata og maler';
 $lang['retry'] = 'Fors&oslash;k igjen';
@@ -338,9 +342,9 @@ brukernavn: %s
 passord: %s
 
 Logg inn i nettstedets administrasjon her: %s';
-$lang['utma'] = '156861353.4516254727077762000.1214829895.1269862427.1271013637.210';
-$lang['utmz'] = '156861353.1258366036.187.21.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['qca'] = '1214401694-66536492-18746566';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1296948797.3555.80.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1299195788.1299276386.3643';
+$lang['qca'] = '1210971690-27308073-81952832';
+$lang['utmb'] = '156861353.1.10.1299276386';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
