@@ -1,4 +1,8 @@
 <?php
+$lang['setup_flat_urls'] = 'Platte Url&#039;s worden weer aangemaakt!';
+$lang['install_timezone'] = 'Sommige webservers met PHP 5.3 hebben de Tijdzone niet goed ingesteld. Selecteer hier &uacute;w juiste tijdzone. Als dit voor uw webserver niet van toepassing is, dan kiest u &quot;Geen&quot;. <strong>Opmerking:</strong> Dit is geen display instelling, maar is gerelateerd aan datum en tijd instellingen. U kunt deze instelling later altijd nog weer wijzigen in de config.php.';
+$lang['timezone'] = 'Tijdzone';
+$lang['none'] = 'Geen';
 $lang['test_error_estrict'] = 'Error_reporting testen om er zeker van te zijn dat E_STRICT is uitgeschakeld';
 $lang['test_estrict_failed'] = 'E_STRICT is ingeschakeld';
 $lang['info_estrict_failed'] = 'Bepaalde functionaliteiten die CMSMS gebruikt, werken niet goed met E_STRICT.  Schakel deze alstublieft uit voordat u verder gaat';
@@ -28,15 +32,15 @@ $lang['install_default_encoding'] = 'In vrijwel alle gevalen, zal default_encodi
 $lang['installer_done'] = '[voltooid]';
 $lang['installer_failed'] = '[mislukt]';
 $lang['create_permission'] = 'Rechten aanmaken ...';
-$lang['add_column_sql'] = 'Rij toevoegen aan %s table ...';
-$lang['update_table_sql'] = 'Bezig met het bijwerken van %s table ...';
+$lang['add_column_sql'] = 'Rij toevoegen aan tabel %s ...';
+$lang['update_table_sql'] = 'Bezig met het bijwerken van tabel %s ...';
 $lang['installing_module'] = 'Bezig met het installeren van de %s module ...';
-$lang['updating_schema_version'] = 'Bezig met het upgraden van schema versie %s ...';
+$lang['updating_schema_version'] = 'Bezig met het upgraden naar schema versie %s ...';
 $lang['upgrade_config'] = 'Bezig met het bijwerken van config.php';
-$lang['upgrade_config_info'] = 'configuratie upgrade';
-$lang['upgrade_failed_again'] = 'Een of meer upgrades zijn mislukt. Verhelp het probleem en klik op de knop om opnieuw te controleren.';
-$lang['upgrade_cache_dirs'] = 'Legen van cache mappen';
-$lang['cannot_clean_cache_dirs'] = 'Kan cache mappen niet legen!';
+$lang['upgrade_config_info'] = 'Configuratie Upgrade';
+$lang['upgrade_failed_again'] = 'E&eacute;n of meer upgrades zijn mislukt. Verhelp het probleem en klik op de knop om het opnieuw te controleren.';
+$lang['upgrade_cache_dirs'] = 'Legen van buffer mappen';
+$lang['cannot_clean_cache_dirs'] = 'Kan de buffer mappen niet legen!';
 $lang['upgrade_schema'] = 'Bijwerken van schema';
 $lang['need_upgrade_schema'] = 'CMS heeft een update nodig.<br />U gebruikt nu schema versie %s en u moet deze bijwerken naar schema versie %s';
 $lang['schema_ok'] = 'De CMS database is bijgewerkt en gebruikt schema versie %s';
@@ -44,11 +48,11 @@ $lang['noneed_upgrade_schema'] = 'De CMS database is bijgewerkt en gebruikt sche
 $lang['upgrade_modules'] = 'Bezig met bijwerken van modules';
 $lang['noneed_upgrade_modules'] = 'De core modules zijn bijgewerkt';
 $lang['upgrade_sql_module_from_to'] = 'Bijwerken SQL van &quot;%s&quot; module van %s naar %s ...';
-$lang['upgrade_event_module_from_to'] = 'Bijwerken Events van &quot;%s&quot; module van %s naar %s ...';
-$lang['sitedown_not_removed'] = 'Kan tmp/cache/SITEDOWN bestand niet verwijderen. Verwijder dit bestand handmatig of anders zal uw site een &quot;Site Down for Maintenance&quot; melding weergeven.';
-$lang['upgrade_ok'] = 'Controleer uw config.php, wijzig enkele nieuwe instellingen en stel het bestand daarna weer in als &#039;Alleen lezen&#039; (444). U moet ook controleren of al uw modules up-to-date zijn. Hiervoor gaat u naar Uitbreidingen -> Modules en zoek in de lijst naar &#039;Vereist Upgrade&#039;.';
+$lang['upgrade_event_module_from_to'] = 'Bijwerken Gebeurtenissen van &quot;%s&quot; module van %s naar %s ...';
+$lang['sitedown_not_removed'] = 'Kan tmp/cache/SITEDOWN bestand niet verwijderen. Verwijder dit bestand handmatig, anders zal uw site een &quot;Site Down for Maintenance&quot; melding blijven weergeven.';
+$lang['upgrade_ok'] = 'Controleer uw config.php, wijzig de mogelijke nieuwe instellingen en stel het bestand daarna weer in als &#039;Alleen lezen&#039; (CHMOD444). U moet ook controleren of al uw modules up-to-date zijn. Hiervoor gaat u naar Uitbreidingen -> Module Manager en kijk in de tab &#039;Beschikbare Upgrades&#039;.';
 $lang['upgrade_complete'] = 'Update proces voltooid';
-$lang['upgrade_end'] = 'CMS is up-to-date. Klik op %s om naar uw CMS site te gaan of ga naar %s.';
+$lang['upgrade_end'] = 'Het CMS is up-to-date. Klik op %s om naar uw website te gaan, of %s.';
 $lang['here'] = 'hier';
 $lang['go_to_admin'] = 'ga naar het Beheerpaneel';
 $lang['errorfilenot'] = 'Bestand niet gevonden!';
@@ -62,22 +66,22 @@ $lang['not_checksum'] = 'Geen checksum gevonden!';
 $lang['format_datetime'] = '%c ';
 $lang['upload_err_ini_size'] = 'Het ge&uuml;ploade bestand overschrijdt upload_max_filesize instelling in php.ini!';
 $lang['upload_err_form_size'] = 'Het ge&uuml;ploade bestand overschrijdt MAX_FILE_SIZE instelling die is op gegeven in het HTML formulier.';
-$lang['upload_err_partial'] = 'Het ge&uuml;ploade bestand is slechts gedeeltelijk geupload.';
+$lang['upload_err_partial'] = 'Het ge&uuml;ploade bestand is slechts gedeeltelijk ge&uuml;pload.';
 $lang['upload_err_no_file'] = 'Er is geen bestand ge&uuml;pload.';
 $lang['upload_err_no_tmp_dir'] = 'Mist een tijdelijke map.';
 $lang['upload_err_cant_write'] = 'Fout bij het wegschrijven van bestand naar schijf.';
 $lang['upload_err_extension'] = 'Bestandupload gestopt door extensie.';
 $lang['upload_err_empty'] = 'Bestand heeft geen grootte (0kb).';
-$lang['upload_err_unknown'] = 'Onbekende uploadfout.';
-$lang['function_file_uploads_off'] = 'file_uploads is uitgeschakeld in uw php configuratie!';
+$lang['upload_err_unknown'] = 'Onbekende upload fout.';
+$lang['function_file_uploads_off'] = 'file_uploads is in uw php configuratie uitgeschakeld!';
 $lang['upload_file_no_readable'] = 'Ge&uuml;pload bestand is onleesbaar.';
 $lang['upload_file_multiple'] = 'Meerdere bestandsuploads zijn niet toegestaan!';
-$lang['test_check_magic_quotes_gpc'] = 'Magic quotes voor Get/Post/Cookie operaties';
+$lang['test_check_magic_quotes_gpc'] = 'Magic quotes voor Get/Post/Cookie bewerkingen';
 $lang['test_check_magic_quotes_gpc_failed'] = 'Enkele aanhalingstekens, dubbele aanhalingstekens en backslashes worden automatisch verwijderd. U kunt daardoor problemen krijgen bij het gebruik van het CMS.';
 $lang['test_check_magic_quotes_runtime'] = 'Er bevinden zich magic quotes in de runtime.';
-$lang['test_check_magic_quotes_runtime_failed'] = 'Als magic_quotes zijn ingeschakeld, zullen de meeste functies data met elke soort van externe verbinding, inclusief databases en teksbestanden, de quotes vervangen met een backslash. Dit kan problemen veroorzaken.';
+$lang['test_check_magic_quotes_runtime_failed'] = 'Als magic_quotes zijn ingeschakeld, zullen de meeste functies data met elke soort van externe verbinding, inclusief databases en tekstbestanden, de quotes vervangen met een backslash. Dit kan problemen veroorzaken.';
 $lang['install_admin_checksum'] = 'Controleer uw installatie';
-$lang['upgrade_admin_checksum'] = 'Controleer uw systeemupgrade';
+$lang['upgrade_admin_checksum'] = 'Controleer uw systeem upgrade';
 $lang['checksum'] = 'Checksum test ';
 $lang['checksum_file'] = 'Checksum bestand';
 $lang['install_test_checksum'] = 'U kunt de echtheid van de bestanden van uw CMS vergelijken met de originele bestanden door middel van een checksum. Het kan helpen met het opsporen van problemen bij uploads.';
@@ -88,13 +92,13 @@ $lang['test_check_open_basedir_failed'] = '&#039;Open basedir&#039; beperking is
 $lang['unlimited'] = 'Ongelimiteerd';
 $lang['test_open_basedir_session_save_path'] = '&#039;Open basedir&#039; beperkingen lijken van invloed te zijn. Als u SESSION problemen krijgt en ini_set is toepasbaar, kunt u proberen om sessions door middel van cookies aan te zetten door: ini_set(&#039;session.use_only_cookies&#039;, 1);  boven in het config.php bestand te plaatsen.';
 $lang['install_warn_db_createtables'] = 'Normaal dient dit veld aangevinkt te zijn. Wees voorzichtig met het uitschakelen van deze optie.';
-$lang['install_admin_tablesnotcreated'] = 'Proces gereed. De installatie is klaar. Op je verzoek zijn geen tabellen aangemaakt. De config.php is echter ge-reset en alle pre-installatie testen zijn gedaan. Bedankt en hier is je';
+$lang['install_admin_tablesnotcreated'] = 'Proces gereed. De installatie is gereed. Op uw verzoek zijn er g&eacute;&eacute;n tabellen in de database aangemaakt. De config.php is echter gereset en alle pre-installatie testen zijn uitgevoerd. Bedankt, hier is uw';
 $lang['info_create_dir_and_file'] = 'De HTTP proces eigenaar kan geen bestand aanmaken in een directory waar deze eigenaar van is. Dit betekent waarschijnlijk dat safe mode is ingeschakeld. Veel functies binnen CMS Made Simple zullen waarschijnlijk niet goed werken als dit niet mogelijk is. Doorgaan is niet mogelijk.';
 $lang['test_create_dir_and_file'] = 'Controleert of het httpd proces een bestand kan aanmaken in een (door het proces) aangemaakte directory.';
 $lang['cms_site'] = 'CMS Website ';
 $lang['or_greater'] = 'Of groter';
 $lang['sitename'] = 'Website naam';
-$lang['warning_safe_mode'] = '<strong><em>WAARSCHUWING:</em></strong> PHP Safe mode is ingeschakeld. Dit geeft problemen bij het uploaden van bestanden middels de web browser interface, waaronder afbeeldingen, thema&#039;s en module XML installaties. Het is aangeraden contact op te nemen met de systeem beheerder en safe mode uit te laten schakelen.';
+$lang['warning_safe_mode'] = '<strong><em>WAARSCHUWING:</em></strong> PHP Safe Mode is ingeschakeld. Dit geeft mogelijk problemen bij het uploaden van bestanden met de webbrowser interface, waaronder afbeeldingen, thema&#039;s en module XML installaties. Het is aan te raden om contact op te nemen met de Host, en deze de Safe Mode te laten uitschakelen.';
 $lang['test'] = 'Test ';
 $lang['results'] = 'Resultaten';
 $lang['untested'] = 'Niet getest';
@@ -125,9 +129,9 @@ $lang['help_systeminformation'] = 'De hieronder getoonde informatie, uit verschi
 $lang['systeminfo'] = 'Systeem Informatie';
 $lang['systeminfodescription'] = 'Tonen van verschillende informatie elementen van het systeem die kunnen worden gebruikt bij probleem analyse';
 $lang['error'] = 'Fout';
-$lang['new_version_available'] = '<em>Opmerking:</em> Er is een nieuwere versie van het CMS beschikbaar. Neem contact op met uw webmaster.';
-$lang['info_urlcheckversion'] = 'Wanneer  &quot;none&quot; wordt opgegeven wordt geen controle gedaan .<br/>Een lege URL zal gebruik maken van de standaard-link.';
-$lang['urlcheckversion'] = 'Controleer op nieuwe versie van het CMS door deze link';
+$lang['new_version_available'] = '<em>Opmerking:</em> Er is een nieuwere versie van CMS Made Simple beschikbaar. Neem contact op met uw websitebeheerder.';
+$lang['info_urlcheckversion'] = 'Wanneer &quot;none&quot; wordt opgegeven wordt geen controle gedaan .<br/>Een lege URL zal gebruik maken van de standaard-link.';
+$lang['urlcheckversion'] = 'Controleer op nieuwe versie van het CMS door het gebruik van deze link';
 $lang['read'] = 'Lezen';
 $lang['write'] = 'Schrijven';
 $lang['execute'] = 'Uitvoeren';
@@ -160,7 +164,7 @@ $lang['deleteconfirm'] = 'Ben u zeker dat je dit wilt verwijderen - %s - ?';
 $lang['description'] = 'Omschrijving';
 $lang['directoryexists'] = 'Deze directory bestaat al';
 $lang['down'] = 'Beneden';
-$lang['edit'] = 'Bewerk';
+$lang['edit'] = 'Bewerken';
 $lang['email'] = 'E-mail Adres';
 $lang['errordeletingfile'] = 'Kan bestand niet verwijderen. Controleer of dit een rechtenprobleem is.';
 $lang['errordirectorynotwritable'] = 'Geen rechten om in map te schrijven. Dit kan veroorzaakt worden door bestands- en eigendomsrechten. De veilige modus (PHP safe mode) kan ook aanstaan.';
@@ -209,20 +213,20 @@ $lang['install_value_passed'] = 'Een verplichte test is geslaagd';
 $lang['install_value_failed'] = 'Een verplichte test is mislukt';
 $lang['install_error_fragment'] = 'Info Hulp bij Installatie';
 $lang['install_value_required'] = 'Een instelling voldoet niet aan de minimale eisen';
-$lang['install_value_recommended'] = 'Een instelling is boven de vereiste, maar onder de aanbevolen waarde<br />of... een onderdeel dat <em>mischien</em> vereist is voor optionele functionaliteit is niet beschikbaar';
-$lang['install_value_exceed'] = 'Een instelling valt binnen of boven de aanbevolen drempelwaardes<br />of... een onderdeel dat <em>misschien<em> vereist is voor optionele functionaliteit is beschikbaar
+$lang['install_value_recommended'] = 'Een instelling is boven de vereiste, maar onder de aanbevolen waarde<br />of... een onderdeel dat <em>misschien</em> vereist is voor optionele functionaliteit is niet beschikbaar';
+$lang['install_value_exceed'] = 'Een instelling valt binnen of boven de aanbevolen drempel waardes<br />of... een onderdeel dat <em>misschien<em> vereist is voor optionele functionaliteit is beschikbaar
 ';
-$lang['install_test_failed'] = 'Een of meer van de tests zijn niet gelukt. Het systeem kan wel geinstalleerd worden, maar sommige functionaliteiten zullen misschien niet correct functioneren.<br />Probeer de situatie te corrigeren en klik op &quot;Probeer opnieuw&quot;, of klik op &quot;Volgende&quot;.
+$lang['install_test_failed'] = 'Een of meer van de tests zijn niet gelukt. Het systeem kan wel ge&iuml;nstalleerd worden, maar sommige functionaliteiten zullen misschien niet correct functioneren.<br />Probeer de situatie te corrigeren en klik op &quot;Probeer opnieuw&quot;, of klik op &quot;Volgende&quot;.
 ';
 $lang['install_test_passed'] = 'Alle testen zijn gelukt (in ieder geval op het minimale niveau). Klik de &quot;Volgende&quot; button.';
-$lang['install_failed_again'] = 'E&eacute;n of meer testen zijn mislukt. Herstel de problemen en voer de test opnieuw uit.';
+$lang['install_failed_again'] = 'E&eacute;n of meerdere testen zijn mislukt. Herstel de problemen en voer de test opnieuw uit.';
 $lang['install_try_again'] = 'Probeer opnieuw';
 $lang['install_continue'] = 'Volgende';
 $lang['failure'] = 'Mislukt';
 $lang['caution'] = 'Voorzichtig';
 $lang['install_admin_umask'] = 'Test umask server';
 $lang['install_test_umask'] = 'Klik de Test knop om te controleren ...';
-$lang['test_umask_text'] = 'umask (afgekort van user file creation mode mask) is een functie in POSIX omgevingen die de standaard systeem instellingen voor nieuw (door het huidige proces) aangemaakte bestanden en directories beinvloedt. Het bepaalt welke bestands permissies niet worden ingesteld voor ieder nieuw aangemaakt bestand.';
+$lang['test_umask_text'] = 'umask (afgekort van user file creation mode mask) is een functie in POSIX omgevingen die de standaard systeem instellingen voor nieuw (door het huidige proces) aangemaakte bestanden en directories be&iuml;nvloedt. Het bepaalt welke bestandsrechten niet worden ingesteld voor ieder nieuw aangemaakt bestand.';
 $lang['test_check_umask'] = 'Resultaat test op bestand aangemaakt in';
 $lang['test_umask_not_given'] = 'Umask niet opgegeven';
 $lang['test_check_umask_failed'] = 'Test umask mislukt';
@@ -233,7 +237,7 @@ $lang['test_passwd_not_match'] = 'Wachtwoorden komen niet overeen!';
 $lang['test_email_accountinfo'] = 'E-mail accountinfo geselecteerd, maar geen e-mail adres opgegeven!';
 $lang['test_database_prefix'] = 'Database voorvoegsel bevat foutieve karakters';
 $lang['test_no_dbms'] = 'Geen dbms geselecteerd!';
-$lang['test_could_not_connect_db'] = 'Kan geen verbinding maken met de database. Controleer je gebuikersnaam en wachtwoord en probeer het opnieuw.';
+$lang['test_could_not_connect_db'] = 'Kan geen verbinding maken met de database. Controleer je gebruikersnaam en wachtwoord en probeer het opnieuw.';
 $lang['test_could_not_drop_table'] = 'Niet mogelijk tabel te verwijderen. Controleer de rechten van de gebruiker op de database.';
 $lang['test_could_not_create_table'] = 'Niet mogelijk tabel aan te maken. Controleer de rechten van de gebruiker op de database.';
 $lang['test_check_php'] = 'Controleer voor PHP versie %s+';
@@ -283,7 +287,7 @@ $lang['test_check_modules_failed'] = 'De modules map is niet beschrijfbaar. Je k
 $lang['test_check_file_get_contents'] = 'Controle van file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'U zal hoogstwaarschijnlijk geen gebruik kunnen maken van functionaliteiten die deze functie gebruikt';
 $lang['test_check_session_save_path'] = 'Controleer of session.save_path beschrijfbaar is';
-$lang['test_empty_session_save_path'] = 'session.save_path is leeg. PHP gebruikt de tijdelijke directory van uw OS. Als er sessie problemen optreden en ini_set werkt, kunt u proberen sessie cookies in te schakelen door: ini_set(&quot;session.use_only_cookies&quot;, 1);  toe te voegen bovenaan in include.php';
+$lang['test_empty_session_save_path'] = 'session.save_path is leeg. PHP gebruikt de tijdelijke directory van uw OS. Als er sessie problemen optreden en ini_set werkt, kunt u proberen sessie cookies in te schakelen door: ini_set(&#039;session.use_only_cookies&#039;, 1);  toe te voegen bovenaan in config.php';
 $lang['test_check_session_save_path_failed'] = 'session.save_path is &quot;%s&quot;. Als dit pad niet beschrijfbaar is kan inloggen op het beheerpaneel niet werken. Zorg ervoor dat dit pad schrijfbaar is als u problemen heeft met het inloggen op het beheerpaneel. Deze test kan falen als safe_mode is ingeschakeld (zie hieronder).';
 $lang['test_check_ini_set'] = 'Controleer of ini_set werkt';
 $lang['test_check_ini_set_failed'] = 'Hoewel de mogelijkheid om php ini instellingen te overschrijven niet verplicht is, gebruiken sommige (optionele) functionaliteiten ini_set om timeouts te verlengen, uploaden van grotere bestanden toe te staan, etc. Het is mogelijk dat bepaalde optionele functionaliteit niet werkt zonder deze mogelijkheid. Deze test kan falen als PHP safe_mode is ingeschakeld (zie hieronder).
@@ -307,7 +311,7 @@ $lang['install_admin_db_type'] = 'Database Type ';
 $lang['install_admin_no_db'] = 'Er lijken geen ondersteunde database drivers in de PHP installatie te zijn gecompileerd. Verzeker uzelf ervan dat mysql, mysqli en/of postgres7 ondersteuning is geinstalleerd en probeer opnieuw.';
 $lang['install_admin_db_host'] = 'Database hostadres ';
 $lang['install_admin_db_name'] = 'Database naam';
-$lang['install_admin_db_create'] = 'Maak tabellen (Waarschuwing: Verwijdert reeds opgeslagen data)';
+$lang['install_admin_db_create'] = 'Maak tabellen (Waarschuwing: Overschrijft bestaande data!!!)';
 $lang['install_admin_db_prefix'] = 'Tabel prefix';
 $lang['install_admin_db_sample'] = 'Installeer voorbeeld templates en teksten';
 $lang['retry'] = 'Opnieuw';
@@ -325,7 +329,7 @@ $lang['install_admin_setup'] = 'Instellen van het configuratie bestand. De meest
 $lang['install_admin_docroot'] = 'CMS Website root (zoals gezien vanaf de webserver)';
 $lang['install_admin_docroot_path'] = 'Pad naar de website root';
 $lang['install_admin_querystring'] = 'Query string (ongewijzigd laten tenzij u problemen ondervindt, bewerk dan config.php handmatig)';
-$lang['invalid_querys'] = '<b>WAARSCHUWING<b/>: Foute queries in de database!';
+$lang['invalid_querys'] = '<b>WAARSCHUWING</b>: Foute queries in de database!';
 $lang['install_admin_sitedown'] = 'Fout: Kan het bestand tmp/cache/SITEDOWN niet verwijderen. Verwijder deze handmatig.';
 $lang['install_admin_update_hierarchy'] = 'Bijwerken van hierarchie posities...';
 $lang['install_admin_set_core_event'] = 'Opzetten van core events...';
@@ -333,7 +337,7 @@ $lang['install_admin_install_modules'] = 'Bezig met installeren van modules...';
 $lang['install_admin_index_search'] = 'Indexeren voor zoekfunctie... ';
 $lang['install_admin_clear_cache'] = 'Verwijder site cache (indien aanwezig)';
 $lang['install_admin_emailing'] = 'E-mail mijn admin account informatie...';
-$lang['install_admin_congratulations'] = 'Gefeliciteerd, installatie gelukt - hier is uw';
+$lang['install_admin_congratulations'] = 'Gefeliciteerd, de installatie gelukt - hier is uw';
 $lang['could_not_connect_db'] = 'Kan geen verbinding maken met de database. Controleer de gebruikersnaam en het wachtwoord, en controleer of de gebruiker rechten heeft op de opgeven database.';
 $lang['cannot_write_config'] = 'Fout: Kan niet schrijven in %s.';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple Admin Account Informatie';
@@ -344,9 +348,9 @@ gebruikersnaam: %s
 wachtwoord: %s
 
 Log hier in op het beheerpaneel van de website: %s';
-$lang['utma'] = '156861353.1269027775.1259416186.1271008961.1271013397.628';
-$lang['utmz'] = '156861353.1271013397.628.109.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,42884.0/topicseen.html';
-$lang['qca'] = 'P0-431297011-1259416186230';
+$lang['utma'] = '156861353.1335698708.1284586217.1290451061.1290455497.421';
+$lang['utmz'] = '156861353.1290369177.415.45.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,48374.0.html';
+$lang['qca'] = 'P0-1551306179-1284586216711';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1271013397';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
