@@ -1,4 +1,10 @@
 <?php
+$lang['test_error_estrict'] = 'Testare error_reporting pentru a verifica ca E_STRICT este dezactivat';
+$lang['test_estrict_failed'] = 'E_STRICT este activat';
+$lang['info_estrict_failed'] = 'Unele din librariile pe care CMSMS le foloseste nu functioneaza bine cu E_STRICT.  Dezactivati inainte de a continua';
+$lang['test_error_edeprecated'] = 'Testare error_reporting pentru a verifica ca E_DEPRECATED este dezactivat';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED este activat';
+$lang['info_edeprecated_failed'] = 'Daca E_DEPRECATED este activat in error_reporting utilizatorii vor vedea o multime de mesaje de verificare care pot influenta aspectul si functionalitatea sitului';
 $lang['invalidemail'] = 'Adresa de e-mail introdusa este goala';
 $lang['empty_query'] = 'Interogare goala?? %s';
 $lang['no_db_driver'] = 'Nu s-au gasit driveri de baze de date compatibili';
@@ -332,9 +338,9 @@ Nume utilizator: %s
 Parola: %s
 
 Autentificati-va in Panoul de Administrare aici: %s';
+$lang['utma'] = '156861353.912274264.1270642313.1270642313.1270642313.1';
+$lang['utmb'] = '156861353.1.10.1270642313';
 $lang['utmc'] = '156861353';
-$lang['utma'] = '156861353.3573843717708992500.1250056267.1250058559.1250061299.3';
-$lang['qcb'] = '1912438266';
-$lang['qca'] = '1249980835-92593492-79567608';
-$lang['utmz'] = '156861353.1250056267.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1270642313.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-1330130568-1270642313682';
 ?>
\ No newline at end of file
