@@ -1,4 +1,14 @@
 <?php
+$lang['setup_flat_urls'] = 'Flat URLs могут быть сконфигурированы';
+$lang['install_timezone'] = 'На некоторых серверах с версией PHP 5.3 неправильно установлен часовой пояс (timezone).  Пожалуйста, выберите соответствующий часовой пояс из списка.  Или выберите "Нет", если часовой пояс для Вас неважен.';
+$lang['timezone'] = 'Часовой пояс';
+$lang['none'] = 'Нет';
+$lang['test_error_estrict'] = 'Тестирование уровня error_reporting (E_STRICT должен быть отключен)';
+$lang['test_estrict_failed'] = 'E_STRICT включен';
+$lang['info_estrict_failed'] = 'Некоторые библиотеки CMS Made Simple работают некоректно при включенном E_STRICT. Пожалуйста, отключите прежде чем продолжить.';
+$lang['test_error_edeprecated'] = 'Тестирование уровня error_reporting (E_DEPRECATED должен быть отключен)';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED включен';
+$lang['info_edeprecated_failed'] = 'При включенном E_DEPRECATED Ваши пользователи увидят большое количество предупреждений на странице, что может негативно повлиять на дизайн и функциональность сайта.';
 $lang['invalidemail'] = 'Данный электронный адрес недействителен';
 $lang['empty_query'] = 'Пустой запрос?? %s';
 $lang['no_db_driver'] = 'Нет найдено ни одного драйвера базы данных';
@@ -94,8 +104,8 @@ $lang['results'] = 'Результат';
 $lang['untested'] = 'Не протестирован';
 $lang['owner'] = 'Владелец';
 $lang['permissions'] = 'Права';
-$lang['off'] = 'Отключен';
-$lang['on'] = 'Включен';
+$lang['off'] = 'отключено';
+$lang['on'] = 'включено';
 $lang['permission_information'] = 'Информация о правах';
 $lang['server_os'] = 'Операционная система';
 $lang['server_api'] = 'Программный интерфейс';
@@ -259,7 +269,7 @@ $lang['test_check_file_upload'] = 'Проверка загрузки файло
 $lang['test_check_file_failed'] = 'Если отключена переменная file_uploads, то Вы не сможете воспользоваться функциями загрузки файлов в CMS Made Simple. По возможности это ограничение должно быть снято администратором сервера для правильного использования всех функции управления файлами в системе. Будьте осторожны.';
 $lang['test_check_memory'] = 'Проверка переменной memory_limit';
 $lang['test_check_memory_failed'] = 'Возможно, Ваш сервер не имеет достаточно памяти для запуска CMSMS со всеми нужными модулями. Если возможно, Вам следует попросить администратора сервера поднять это значение. Будьте осторожны.';
-$lang['test_check_time_limit'] = 'Проверка переменной time_limit';
+$lang['test_check_time_limit'] = 'Проверка переменной max_execution_time';
 $lang['test_check_time_limit_failed'] = 'Количество секунд, для запуска скриптов. Если это время будет превышено, то скрипт возвратит фатальную ошибку.';
 $lang['test_check_post_max'] = 'Проверка переменной post_max_size';
 $lang['test_check_post_max_failed'] = 'Вероятно Вы не сможете передавать большее количество данных через формы. Учитывайте это ограничение в работе.';
@@ -283,7 +293,7 @@ $lang['install_admin_email_info'] = 'Учетная информация адр
 $lang['install_admin_email_note'] = '<strong>Примечание:</strong>Эта функция использует php функцию mail. Если Вы не получите это письмо, это может быть свидетельством того, что ваш сервер не правильно настроен, и что вам необходимо связаться с администратором Вашего сервера.';
 $lang['install_admin_sitename'] = 'Это название Вашего сайта. Оно будет использоваться в шаблонах и может быть использована в любом другом месте при вставке тега {sitename}.';
 $lang['install_admin_db'] = 'Информация о базе данных';
-$lang['install_admin_db_info'] = '<p>Убедитесь, что вы создали базу данных и заданный пользователь достаточно прав для использования этой базы.</p>
+$lang['install_admin_db_info'] = '<p>Убедитесь, что вы создали базу данных и заданный пользователь имеет достаточно прав для использования этой базы.</p>
 <p>Для MySQL:</p>
 <p>Войдите в mysql из консоли и выполните следующие команды:</p>
 <ol>
@@ -332,9 +342,9 @@ $lang['email_accountinfo_message'] = 'Спасибо за установку  CM
 Пароль: %s
 
 Вход в административный интерфейс сайта: %s';
-$lang['utmz'] = '156861353.1249691644.74.46.utmccn=(referral)|utmcsr=localhost|utmcct=/msnew/install/index.php|utmcmd=referral';
-$lang['utma'] = '156861353.1512485689.1236874721.1249691644.1250401334.75';
+$lang['qca'] = 'P0-1938388883-1277855813144';
+$lang['utma'] = '156861353.429593658.1277855813.1287171834.1288916189.31';
+$lang['utmz'] = '156861353.1286799193.22.13.utmccn=(organic)|utmcsr=google|utmctr=cmsmadesimple translation center|utmcmd=organic';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['qca'] = 'P0-738804097-1250401341499';
-$lang['utmb'] = '156861353.1.10.1250401334';
 ?>
\ No newline at end of file
