@@ -1,4 +1,8 @@
 <?php
+$lang['setup_flat_urls'] = 'Nastavenie  priamych URL';
+$lang['install_timezone'] = 'Niektor&eacute; servery bežiace na php 5.3 maju sle nastaven&eacute; časov&eacute; p&aacute;smo .  Prośim vyberte časov&uacute; z&oacute;nu zo zoznamu niž&scaron;ie.  Ak nechcete vyberať, vyberte voľbu &quot;Žiadne&quot;';
+$lang['timezone'] = 'Časov&aacute; z&oacute;na';
+$lang['none'] = 'Žiadne';
 $lang['test_error_estrict'] = 'Test  error_reporting a vypnutie E_STRICT';
 $lang['test_estrict_failed'] = 'E_STRICT je zapnut&yacute;';
 $lang['info_estrict_failed'] = 'Niektor&eacute; knižnice CMSMS nebud&uacute; pracovať spr&aacute;vne s E_STRICT. Pros&iacute;m vypnute toto nastavenie pred pokračovan&iacute;m';
@@ -21,8 +25,8 @@ $lang['test_check_disable_functions'] = 'Kontrola vypnut&yacute;ch funkci&iacute
 $lang['test_check_disable_functions_failed'] = 'Varovanie: zoznam funkc&iacute; vypnut&yacute;ch na vačom serveri';
 $lang['install_admin_db_port'] = 'Port datab&aacute;zy';
 $lang['install_admin_db_port_info'] = 'V pr&iacute;pade že neviete, nechajte pr&aacute;zdne';
-$lang['install_admin_db_socket'] = 'Socket datab&acute;=azy';
-$lang['install_admin_db_socket_info'] = 'NEPODPOROVANĚ';
+$lang['install_admin_db_socket'] = 'Socket datab&aacute;zy';
+$lang['install_admin_db_socket_info'] = 'NEPODPOROVAN&Eacute;';
 $lang['install_admin_frontendlang'] = 'Prednastaven&yacute; jazyk pre web (frontend). Toto nastavuje spr&aacute;vanie pre prednastaven&eacute; hodnoty d&aacute;tumy a podobne.';
 $lang['install_default_encoding'] = 'Prednastaven&eacute; k&oacute;dovanie vo v&auml;č&scaron;ine pr&iacute;padov b&yacute;va utf-8.';
 $lang['installer_done'] = '[ok]';
@@ -59,7 +63,7 @@ $lang['is_readable_false'] = 'Tento zdroj nem&aacute; pr&aacute;va na č&iacute;
 $lang['checksum_match'] = 'Porovnanie kontroln&yacute;ch s&uacute;čtov!';
 $lang['checksum_not_match'] = 'Bez kontroly kontroln&yacute;ch s&uacute;čtov!';
 $lang['not_checksum'] = 'Neviem skontrolovať kontroln&eacute; s&uacute;čty!';
-$lang['format_datetime'] = '%c';
+$lang['format_datetime'] = '%c ';
 $lang['upload_err_ini_size'] = 'Nahr&aacute;van&yacute; s&uacute;bor je v&auml;č&scaron;&iacute; ako povolen&yacute; limit  v upload_max_filesize v php.ini!';
 $lang['upload_err_form_size'] = 'Nahr&aacute;van&yacute; s&uacute;bor je v&auml;č&scaron;&iacute; ako povolen&yacute; limit  v  MAX_FILE_SIZE, ktor&yacute; je zadan&yacute; v html vo formul&aacute;ri.';
 $lang['upload_err_partial'] = 'Nahr&aacute;van&yacute; s&uacute;bor bol nahran&yacute; len čiastočne.';
@@ -95,7 +99,7 @@ $lang['cms_site'] = 'CMS str&aacute;nka';
 $lang['or_greater'] = 'Alebo v&auml;č&scaron;&iacute;';
 $lang['sitename'] = 'N&aacute;zov str&aacute;nky';
 $lang['warning_safe_mode'] = '<strong><em>Varovanie:</em></strong> PHP Safe m&oacute;d zapnut&yacute;.  Toto m&ocirc;že sp&ocirc;sobiť probl&eacute;my pri nahr&aacute;van&iacute; s&uacute;borov cez administr&aacute;ciu (obrazky, s&uacute;bory, t&eacute;my, XML moduly) atď. Požiadajte svojho administr&aacute;tora o vypnutie tejto direktivy.';
-$lang['test'] = 'Test';
+$lang['test'] = 'Test ';
 $lang['results'] = 'V&yacute;sledky';
 $lang['untested'] = 'Netestovan&eacute;';
 $lang['owner'] = 'Vlastn&iacute;k';
@@ -197,7 +201,7 @@ $lang['upgrade_system'] = 'Update syst&eacute;mu';
 $lang['upgrade_thanks'] = 'Ďakujeme za aktualiz&aacute;ciu CMS Made simple na verziu';
 $lang['install_please_read'] = 'Pros&iacute;m, preč&iacute;tajte si <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">dokument&aacute;ciu k in&scaron;tal&aacute;cii</a> k CMS Made Simple.';
 $lang['install_checking'] = 'Kontrola pr&aacute;v a nastaven&iacute; PHP';
-$lang['install_test'] = 'Test';
+$lang['install_test'] = 'Test ';
 $lang['install_result'] = 'V&yacute;sledky';
 $lang['install_required_settings'] = 'Vyžadovan&eacute; nastavenia';
 $lang['install_recommended_settings'] = 'Doporučen&eacute; nastavenia';
@@ -338,10 +342,9 @@ už&iacute;vateľsk&eacute; meno: %s
 heslo: %s
 
 Prihl&aacute;ste sa pre administr&aacute;ciu str&aacute;nky: %s';
-$lang['qca'] = 'P0-1608926040-1271144175783';
-$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
-$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
-$lang['chartbeat2'] = '87v0u4nbwegh3lki';
+$lang['utma'] = '156861353.1064856217.1281704360.1298295362.1298881088.23';
+$lang['utmz'] = '156861353.1298881088.23.25.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-799401210-1281704360909';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
