@@ -1,8 +1,96 @@
 <?php
+$lang['setup_flat_urls'] = 'Flat URL ja nastavljen';
+$lang['install_timezone'] = 'Nekateri strežniki s PHP 5.3 niso pravilno nastavili časovni pas. Prosimo, izberite ustrezen časovni pas iz seznama. Če to ni potrebno, na va&scaron;em strežniku, lahko izberete &quot;None&quot;. Opomba: Prosimo, izberite strežnikov časovni pas, to ni nastavitev zaslona, vendar se uporablja v aritmatični zvezi z datumi. To nastavitev lahko spremeni&scaron; po namestitvi s spremembo v config.php datoteki.';
+$lang['timezone'] = 'Časovni pas';
+$lang['none'] = 'Nič';
+$lang['test_error_estrict'] = 'Testiranje error_reporting da se zagotovi da je E_STRICT izključen';
+$lang['test_estrict_failed'] = 'E_STRICT je vključen';
+$lang['info_estrict_failed'] = 'Nekatere knjižnice, ki CMSMS uporabja ne delujejo dobro z E_STRICT.  Prosimo izključite to pred nadaljevanjem';
+$lang['test_error_edeprecated'] = 'Testiranje error_reporting da se zagotovi da je E_DEPRECATED izključen';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED je vključen';
+$lang['info_edeprecated_failed'] = 'Če je E_DEPRECATED omogočen v va&scaron;em poročanju napak, bodo uporabniki videli veliko opozorilnih sporočil, ki bi lahko vplivali na zaslonu in funkcionalnosti';
+$lang['invalidemail'] = 'Vnesen E-po&scaron;tni naslov ni veljaven';
+$lang['empty_query'] = 'Prazen query?? %s';
+$lang['no_db_driver'] = 'Kompatibilnigonilniki baze niso najdeni';
+$lang['test_check_output_buffering'] = 'Preverja output buffering';
+$lang['test_check_output_buffering_failed'] = 'Output buffering je izključen. Verjetno ne boste mogli uporabljati vse funkcionalnosti, ki to zahtevajo';
+$lang['phpinfo'] = 'Prikaži PHP informacije';
+$lang['mod_security'] = 'Apache Mod Varnost';
+$lang['test_check_tempnam'] = 'Preverjanje tempnam funkcije';
+$lang['test_check_db_drivers'] = 'DB gonliniki';
+$lang['test_check_db_drivers_failed'] = 'DB gonilniki niso najdeni';
+$lang['test_check_register_globals'] = 'Preverja PHP register globals';
+$lang['test_check_register_globals_failed'] = 'PHP register globals je aktiviran. Zaradi varnostnih razlogov bi moral biti izklopljen.';
+$lang['test_check_disable_functions'] = 'Preverjanje PHP disable functions';
+$lang['test_check_disable_functions_failed'] = 'Opozorilo: To je seznam funkcij onemogočenih na va&scaron;em strežniku.';
+$lang['install_admin_db_port'] = 'Port baze';
+$lang['install_admin_db_port_info'] = 'Če ne veste, pustite to polje prazno, da uporabite privzete nastavitve.';
+$lang['install_admin_db_socket'] = 'Socket baze';
+$lang['install_admin_db_socket_info'] = 'NE PODPIRA.';
+$lang['install_admin_frontendlang'] = 'Privzeti jezik za frontend. To prilagaja locale uporabo za različne funkcije kot privzeto ravnanje datuma itd.';
+$lang['install_default_encoding'] = 'V skoraj vseh primerih mora biti default_encoding utf-8.';
+$lang['installer_done'] = '[opravljeno]';
+$lang['installer_failed'] = '[ni uspelo]';
+$lang['create_permission'] = 'Ustvari dovoljenja ...';
+$lang['add_column_sql'] = 'Dodaja stolpec %s v tabeli ...';
+$lang['update_table_sql'] = 'Posodablja tabelo %s ...';
+$lang['installing_module'] = 'Namestitev modula %s ...';
+$lang['updating_schema_version'] = 'Posodablja schema verzijo %s ...';
+$lang['upgrade_config'] = 'Nadrgajuje config.php';
+$lang['upgrade_config_info'] = 'config nadgradnja';
+$lang['upgrade_failed_again'] = 'Eden ali več nadgradenj ni uspelo. Popravite problem in kliknite na gumb spodaj, da ponovno preverite.';
+$lang['upgrade_cache_dirs'] = 'Či&scaron;čenje imenikov predpomnilnika';
+$lang['cannot_clean_cache_dirs'] = 'Ne morem očistiti imenikov predpomnilnika!';
+$lang['upgrade_schema'] = 'Nadgradi schema';
+$lang['need_upgrade_schema'] = 'CMS potrebuje nadgradnjo.<br />Vi uporabljate schemo v verziji %s katera mora biti nadgrajena v verzijo %s';
+$lang['schema_ok'] = 'CMS baza podatkov je posodobljena.  Uporablja schemo v verziji %s';
+$lang['noneed_upgrade_schema'] = 'CMS baza podatkov je posodobljena.  Uporablja schemo v verziji %s';
+$lang['upgrade_modules'] = 'Nadgradi module';
+$lang['noneed_upgrade_modules'] = 'Moduli so posodobljeni';
+$lang['upgrade_sql_module_from_to'] = 'Nadgrajuje SQL od &quot;%s&quot; modul iz %s v %s ...';
+$lang['upgrade_event_module_from_to'] = 'Nadgrajuje dogodke v &quot;%s&quot; modul iz %s v %s ...';
+$lang['sitedown_not_removed'] = 'Datoteka tmp/cache/SITEDOWN ni mogla biti odstranjena. Prosimo, odstranite datoteko ročno ali pa bo &scaron;e naprej prikazano sporočilo &quot;Site Down for Maintainence&quot; na va&scaron;i spletni strani';
+$lang['upgrade_ok'] = 'Prosimo, preglejte config.php, spremenite nove nastavitve, kot je potrebno, nato pa ponovno nastavite permissions na zaklenjeno stanje. Prav tako preverite da so vsi va&scaron;i moduli obnovljeni, pojdite na Extensions -> Modules stran in i&scaron;čite vse ki so navedeni kot &quot;Potrebuje Nadgradnjo&quot;';
+$lang['upgrade_complete'] = 'Postopek nadgradnje je končan';
+$lang['upgrade_end'] = 'CMS je posodobljen. Prosimo, kliknite %s da pridete na va&scaron;o spletno stran CMS ali pa %s.';
+$lang['here'] = 'tukaj';
+$lang['go_to_admin'] = 'pojdite Administracijo';
+$lang['errorfilenot'] = 'Datoteka ni bila najdena!';
+$lang['errorfilenotwritable'] = 'Datoteka ni writable!';
+$lang['nofiles'] = 'Ta vir ne obstaja!';
+$lang['is_directory'] = 'Ta vir je imenik!';
+$lang['is_readable_false'] = 'Ta vir ni readable!';
+$lang['checksum_match'] = 'Checksum se ujema!';
+$lang['checksum_not_match'] = 'Checksum se ne ujema!';
+$lang['not_checksum'] = 'Ne more naložiti checksum!';
+$lang['format_datetime'] = '%c';
+$lang['upload_err_ini_size'] = 'Naložena datoteka presega upload_max_filesize nastavitev v php.ini!';
+$lang['upload_err_form_size'] = 'Naložena datoteka presega MAX_FILE_SIZE nastavitev katera je bila nastavljena v HTML obrazcu.';
+$lang['upload_err_partial'] = 'Naložena datoteka je bila le delno naložena.';
+$lang['upload_err_no_file'] = 'Nobena datoteka ni bila naložena.';
+$lang['upload_err_no_tmp_dir'] = 'Temporary mapa ne obstaja.';
+$lang['upload_err_cant_write'] = 'Ni mogoče zapisati datoteke na trdi disk.';
+$lang['upload_err_extension'] = 'Nalaganje datoteke je ustavljeno zaradi extension.';
+$lang['upload_err_empty'] = 'Datoteka ima velikost nič';
+$lang['upload_err_unknown'] = 'Neznan problem pri nalaganju datoteke.';
+$lang['function_file_uploads_off'] = 'file_uploads je izključen v va&scaron;ei php konfiguraciji!';
+$lang['upload_file_no_readable'] = 'Naloženo datoteko ni mogoče prebrati!';
+$lang['upload_file_multiple'] = 'Večkratno nalaganje datotek ni dovoljeno!';
+$lang['test_check_magic_quotes_gpc'] = 'Magic quotesza Get/Post/Cookie operacije';
+$lang['test_check_magic_quotes_gpc_failed'] = 'Ko je magic_quotes aktiven, so vsi single-quote, double quote in backslash escaped samodejno. To lahko povzroči veliko težav v CMS.';
+$lang['test_check_magic_quotes_runtime'] = 'Magic quotes v runtime';
+$lang['test_check_magic_quotes_runtime_failed'] = 'Ko je magic_quotes vključen, večina funkcij, katere bodo vrnile podatke iz katerega koli zunanjega vira vključno z bazam podatkov in besedilne datoteke bodo imele quotes escaped in backslash. To bo povzročilo težave pri CMS-u.';
+$lang['install_admin_checksum'] = 'Preverite svojo namestitev';
+$lang['upgrade_admin_checksum'] = 'Preverite nadgradnjo va&scaron;ega sistema';
+$lang['checksum'] = 'Checksum test';
+$lang['checksum_file'] = 'Checksum datoteka';
+$lang['install_test_checksum'] = 'Vi lahko potrdite celovitost datotek CMS s primerjavo glede na prvotni checksum CMS-a. To lahko pomaga pri iskanju težave z nalaganjem.';
+$lang['checksum_passed'] = 'Vsi checksumi se ujemajo!';
+$lang['checksum_failed'] = 'Checksum se ujemajo z napakami. Poglejte pomoč za več informacij';
 $lang['test_check_open_basedir'] = 'Preveri prisotnost PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Omogočena je PHP nastavitev Open Basedir. Morda boste imeli težave z nekaterimi funkcionalnostmi dodatkov zaradi te omejitve.';
 $lang['unlimited'] = 'Neomejeno';
-$lang['test_open_basedir_session_save_path'] = 'Open basedir je nastavitev. Če imate težave s sejo (SESSION) in vam deluje ukaz ini_set, lahko poizkusite vklopiti session pi&scaron;kotke tako, da dodate: ini_set(&#039;session.use_only_cookies&#039;, 1);  na začetek datoteke include.php';
+$lang['test_open_basedir_session_save_path'] = 'Open basedir je nastavitev. Če imate težave s sejo (SESSION) in vam deluje ukaz ini_set, lahko poizkusite vklopiti session pi&scaron;kotke tako, da dodate: ini_set(&#039;session.use_only_cookies&#039;, 1);  na začetek datoteke config.php';
 $lang['install_warn_db_createtables'] = 'V večini primerov mora biti ta nastavitev odkljukana ves čas. Bodite pazljivi, če onemogočite to funkcionalnost.';
 $lang['install_admin_tablesnotcreated'] = 'Postopek namestitve zaključen. Postopek namestitve je bil zaključen, na va&scaron;o željo pa tabele v bazi niso bile ustvarjene. Datoteka z nastavitvami (config) je bila ponastavljena in vsi testi pred namestitvijo so bili uspe&scaron;ni. Zahvaljujemo se vam, tukaj pa je va&scaron;';
 $lang['info_create_dir_and_file'] = 'Lastnik procesa HTTP (web strežnika) ne more ustvarjati datoteke znotraj mape v njegovi lasti. To najverjetneje pomeni, da je omogočen varni način delovanja. &Scaron;tevilne funkcije v CMS made simple ne bodo delovale pravilno brez te možnosti zapisovanja. Nadaljevanje ni mogoče.';
@@ -82,7 +170,7 @@ $lang['errordeletingfile'] = 'Ne morem izbrisati datoteke. Težava s pravicami?'
 $lang['errordirectorynotwritable'] = 'Nimam pravic za pisanje v mapo. Do te napake lahko pride zaradi pomanjkanja pravic ali lastni&scaron;tva. Morda je aktiviran tudi varni način (safe mode).';
 $lang['cachenotwritable'] = 'Mapa za datoteke predpomnilnika (cache) ni zapisljiva. Brisanje predpomnilnika ne bo delovalo. Prosimo preverite, da ima mapa tmp/cache polne pravice za pisanje/branje/izvajanje (chmod 777). Morda morate izklopiti varni način (safe mode).';
 $lang['modulesnotwritable'] = 'Mapa za datoteke modulov ni zapisljiva. Če boste želeli namestiti module s prenosom XML datotek, morate poskrbeti, da bo imela mapa modules  polne pravice za pisanje/branje/izvajanje (chmod 777). Morda morate izklopiti varni način (safe mode).';
-$lang['false'] = 'False';
+$lang['false'] = 'Neaktivno';
 $lang['settrue'] = 'Nastavi True';
 $lang['filename'] = 'Datoteka';
 $lang['filesize'] = 'Velikost';
@@ -94,7 +182,7 @@ $lang['password'] = 'Geslo';
 $lang['passwordagain'] = 'Ponovite geslo';
 $lang['remove'] = 'Odstrani';
 $lang['saveconfig'] = 'Shrani nastavitve';
-$lang['true'] = 'True';
+$lang['true'] = 'Aktivno';
 $lang['setfalse'] = 'Nastavi False';
 $lang['type'] = 'Tip';
 $lang['typenotvalid'] = 'Tip ni pravilen';
@@ -108,6 +196,9 @@ $lang['version'] = 'Različica';
 $lang['install_title'] = 'Namestitev CMS Made Simple (korak %s)';
 $lang['install_system'] = 'Namesti sistem';
 $lang['install_thanks'] = 'Zahvaljujemo se vam za namestitev CMS Made Simple';
+$lang['upgrade_title'] = 'CMS Made Simple nadgradnja (step %s)';
+$lang['upgrade_system'] = 'Nadgradi sistem';
+$lang['upgrade_thanks'] = 'Hvala za nadgradnjo CMS Made Simpla v';
 $lang['install_please_read'] = 'Prosimo, preberite dokument <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Težave pri namestitvi</a> v sklopu Wiki dokumentacije sistema CMS Made Simple.';
 $lang['install_checking'] = 'Preverjanje pravic in PHP nastavitev';
 $lang['install_test'] = 'Test';
@@ -120,6 +211,7 @@ $lang['install_symbol'] = 'Simbol';
 $lang['install_definition'] = 'Definicija';
 $lang['install_value_passed'] = 'Obvezni test uspe&scaron;en';
 $lang['install_value_failed'] = 'Obvezni test neuspe&scaron;en';
+$lang['install_error_fragment'] = 'Info o namestitvi in odpravljanju težav';
 $lang['install_value_required'] = 'Nastavitev je nižja od minimalne vrednosti';
 $lang['install_value_recommended'] = 'Nastavitev je vi&scaron;ja od zahtevane vrednosti, toda nižja od priporočene vrednosti.<br />ali... Kapaciteta ki <em>bi lahko</em> bila obvezna za nekatere dodatne funkcionalnosti ni na voljo.';
 $lang['install_value_exceed'] = 'Nastavitev zadostuje ali presega priporočeno vrednost.<br />ali... Kapaciteta ki <em>bi lahko</em> bila obvezna za nekatere dodatne funkcionalnosti je na voljo.';
@@ -131,7 +223,7 @@ $lang['install_continue'] = 'Nadaljuj';
 $lang['failure'] = 'Napaka';
 $lang['caution'] = 'Opozorilo';
 $lang['install_admin_umask'] = 'Testiranje maske za ustvarjanje datotek';
-$lang['install_test_umask'] = 'Prosimo, kliknite gumb Test za preverjanje  ..............................';
+$lang['install_test_umask'] = 'Prosimo, kliknite gumb Test za preverjanje  ...';
 $lang['test_umask_text'] = 'umask je funkcija, ki v POSIX okoljih vpliva na privzeti način za ustvarjanje novih datotek in map trenutnega procesa. Nadzoruje, katere pravice bodo nastavljene na novo ustvarjenim datotekam.';
 $lang['test_check_umask'] = 'Rezultati testa datoteke, ustvarjene v';
 $lang['test_umask_not_given'] = 'Umask ni podan';
@@ -166,8 +258,13 @@ $lang['test_check_xml_failed'] = 'XML podpora ni vključena v va&scaron;o namest
 $lang['test_allow_url_fopen_failed'] = 'Če je možnost &quot;allow url fopen&quot; onemogočena ne boste mogli dostopati URL objektov, kot na primer datotek preko FTP ali HTTP protokola.';
 $lang['test_remote_url'] = 'Test za oddaljeni URL';
 $lang['test_remote_url_failed'] = 'Najverjetneje ne boste mogli odpreti datoteke na oddaljenem spletnem strežniku.';
-$lang['use_fsockopen'] = 'Možnost &quot;allow_url_fopen&quot; je onemogočena, kljub temu da so izhodne povezave dovoljene. Kontaktirajte va&scaron;ega administratorja in ga zaprosite za aktivacijo te možnosti.';
-$lang['use_fsockopen_error'] = 'Izhodne HTTP povezave ne delujejo. To pomeni, da upravljalec modulov ter morebitne druge funkcionalnosti ne bodo delovali.';
+$lang['connection_error'] = 'Odhodne povezave http-ja očitno ne delajo! Imaste firewall ali nekak ACL za zunanje priključke?. To bo vplivalo v modul managerju in morebiti tudi drugih funkcijah.';
+$lang['remote_connection_timeout'] = 'Povezava Timed Out!';
+$lang['search_string_find'] = 'Povezava je uspela!';
+$lang['connection_failed'] = 'Povezava ni uspela!';
+$lang['remote_response_ok'] = 'Remote odgovor: ok!';
+$lang['remote_response_404'] = 'Remote odgovor: ni najden!';
+$lang['remote_response_error'] = 'Remote odgovor: napaka!';
 $lang['test_check_file_upload'] = 'Preverjanje nalaganja datotek';
 $lang['test_check_file_failed'] = 'Če je nalaganje (upload) datotek onemogočeno, ne boste mogli uporabljati možnosti za nalaganje datotek v CMS Made Simple. Če je možno svetujemo, da va&scaron; administrator to možnost omogoči, saj boste le tako lahko uporabljali vse funkcionalnosti sistema. Nadaljujte pazljivo.';
 $lang['test_check_memory'] = 'Preverjanje PHP omejitve pomnilnika';
@@ -237,7 +334,6 @@ $lang['install_admin_emailing'] = 'Po&scaron;iljanje podrobnosti o administrator
 $lang['install_admin_congratulations'] = 'Čestitamo, namestitev je uspe&scaron;na - tukaj imate va&scaron;e';
 $lang['could_not_connect_db'] = 'Ne morem vzpostaviti povezave na bazo. Preverite, če sta uporabni&scaron;ko ime in geslo pravilna in ali ima ta uporabnik dovoljenje za dostop do te podatkovne baze.';
 $lang['cannot_write_config'] = 'Napaka: Ne morem pisati v %s.';
-$lang['install_additional_modules'] = 'Namestitev dodatnih modulov';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple informacije o administratorskem računu';
 $lang['email_accountinfo_message'] = 'Zahvaljujemo se vam za namestitev sistema CMS Made Simple.
 
@@ -248,8 +344,9 @@ uporabni&scaron;ko ime: %s
 V administracijo se prijavite na naslovu: %s
 
 ';
-$lang['utma'] = '156861353.587959277.1217433595.1218884702.1218893504.11';
-$lang['utmz'] = '156861353.1218827009.7.4.utmccn=(organic)|utmcsr=google|utmctr=cms made simple email obfuscate|utmcmd=organic';
+$lang['qca'] = 'P0-1458450664-1284573084918';
+$lang['utmz'] = '156861353.1290205935.467.38.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['utma'] = '156861353.1164361908.1285153768.1290336477.1290362844.479';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1290362844';
 ?>
\ No newline at end of file
