@@ -1,4 +1,8 @@
 <?php
+$lang['setup_flat_urls'] = 'Flat URLs &auml;r aktiverat';
+$lang['install_timezone'] = 'Vissa servrar som k&ouml;r med php 5,3 har inte r&auml;tt tidszon inst&auml;lld. V&auml;lj r&auml;tt tidszon fr&aring;n listan innan. Om detta inte &auml;r n&ouml;dv&auml;ndigt p&aring; din server kan du v&auml;lja &quot;Ingen&quot;';
+$lang['timezone'] = 'Tidszon';
+$lang['none'] = 'Ingen';
 $lang['test_error_estrict'] = 'Testar error_reporting f&ouml;r att kontrollera att E_STRICT &auml;r deaktiverat';
 $lang['test_estrict_failed'] = 'E_STRICT &auml;r aktiverat';
 $lang['info_estrict_failed'] = 'Vissa paket som CMSMS anv&auml;nder fungerar inte bra med E_STRICT. Var v&auml;nlig deaktivera detta innan du forts&auml;tter.';
@@ -338,9 +342,9 @@ anv&auml;ndarnamn: %s
 l&ouml;senord: %s
 
 Logga in p&aring; adminsidorna: %s';
-$lang['qca'] = 'P0-245748072-1251504180990';
-$lang['utmz'] = '156861353.1269352899.20.14.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
-$lang['utma'] = '156861353.2917280715391859000.1251504181.1269540149.1269891113.22';
+$lang['qca'] = 'P0-1661890032-1292100548202';
+$lang['utma'] = '156861353.1934215823.1299187594.1299227132.1299275456.3';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1299187594.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353.1.10.1299275456';
 ?>
\ No newline at end of file
