@@ -16,18 +16,10 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSInstallPage4.class.php 149 2009-03-17 22:22:13Z alby $
+#$Id: CMSInstallPage4.class.php 296 2010-10-17 22:31:18Z calguy1000 $
 
 class CMSInstallerPage4 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	*/
-	function CMSInstallerPage4(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(4, $smarty, $errors, $debug);
-	}
-
 	function assignVariables()
 	{
 		$values = array();
