@@ -16,18 +16,10 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSInstallPage5.class.php 159 2009-05-05 10:47:28Z alby $
+#$Id: CMSInstallPage5.class.php 296 2010-10-17 22:31:18Z calguy1000 $
 
 class CMSInstallerPage5 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	*/
-	function CMSInstallerPage5(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(5, $smarty, $errors, $debug);
-	}
-	
 	function assignVariables()
 	{
 		$values = array();
@@ -41,6 +33,7 @@ class CMSInstallerPage5 extends CMSInstallerPage
 		$values['db']['db_port'] = isset($_POST['db_port']) ? $_POST['db_port'] : '';
 		// $values['db']['db_socket'] = isset($_POST['db_socket']) ? $_POST['db_socket'] : '';
 
+		$values['timezone'] = isset($_POST['timezone']) ? $_POST['timezone'] : '';
 		$values['umask'] = isset($_POST['umask']) ? $_POST['umask'] : '';
 		$values['admininfo']['username'] = $_POST['adminusername'];
 		$values['admininfo']['email'] = $_POST['adminemail'];
@@ -63,6 +56,19 @@ class CMSInstallerPage5 extends CMSInstallerPage
 				$dbms_options[] = $db;
 			}
 		}
+
+		$tmp = timezone_identifiers_list();
+		if( is_array($tmp) )
+		  {
+		    $timezones = array();
+		    $timezones[''] = ilang('none');
+		    foreach( $tmp as $zone )
+		      {
+			$timezones[$zone] = $zone;
+		      }
+		    $this->smarty->assign('timezones',$timezones);
+		  }
+
 		$this->smarty->assign('extra_sql', is_file(cms_join_path(CMS_INSTALL_BASE, 'schemas', 'extra.sql')));
 		$this->smarty->assign('dbms_options', $dbms_options);
 		$this->smarty->assign('values', $values);
