@@ -16,18 +16,10 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSInstallPage6.class.php 164 2009-05-13 14:58:14Z calguy1000 $
+#$Id: CMSInstallPage6.class.php 296 2010-10-17 22:31:18Z calguy1000 $
 
 class CMSInstallerPage6 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	*/
-	function CMSInstallerPage6(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(6, $smarty, $errors, $debug);
-	}
-
 	function assignVariables()
 	{
 		$values = array();
@@ -40,6 +32,7 @@ class CMSInstallerPage6 extends CMSInstallerPage
 		$values['db']['db_port'] = isset($_POST['db_port']) ? $_POST['db_port'] : '';
 		// $values['db']['db_socket'] = isset($_POST['db_socket']) ? $_POST['db_socket'] : '';
 
+		$values['timezone'] = isset($_POST['timezone']) ? $_POST['timezone'] : '';
 		$values['umask'] = isset($_POST['umask']) ? $_POST['umask'] : '';
 		$values['admininfo']['username'] = $_POST['adminusername'];
 		$values['admininfo']['email'] = $_POST['adminemail'];
@@ -69,7 +62,7 @@ class CMSInstallerPage6 extends CMSInstallerPage
 
 			include_once(cms_join_path(CMS_INSTALL_BASE, 'schemas', 'schema.php'));
 
-			echo "<p>" . lang('install_admin_importing');
+			echo "<p>" . ilang('install_admin_importing');
 
 			$handle = '';
 			if(isset($_POST["createextra"]))
@@ -96,20 +89,20 @@ class CMSInstallerPage6 extends CMSInstallerPage
 						$s = str_replace('\\"', '"', $s);
 						$result = $db->Execute($s);
 						if (!$result) {
-							die(lang('invalid_query', $s));
+							die(ilang('invalid_query', $s));
 						}
 					}
 				}
 				fclose($handle);
-				echo " [" . lang('done') . "]</p>";
+				echo " [" . ilang('done') . "]</p>";
 			}
 			else
 			{
-				echo lang('install_admin_error_schema') . "</p>";
+				echo ilang('install_admin_error_schema') . "</p>";
 			}
 
 
-			echo "<p>" . lang('install_admin_set_account');
+			echo "<p>" . ilang('install_admin_set_account');
 
 			$sql_error = false;
 
@@ -117,26 +110,26 @@ class CMSInstallerPage6 extends CMSInstallerPage
 			$dbresult = $db->Execute($sql, array($_POST['adminusername'], md5($_POST['adminpassword']), $_POST['adminemail']));
 			if (!$dbresult)
 			{
-				echo lang('invalid_query', $db->$sql) ."</p>";
+				echo ilang('invalid_query', $db->$sql) ."</p>";
 				$sql_error = true;
 			}
 			else
 			{
-				echo " [" . lang('done') . "]</p>";
+				echo " [" . ilang('done') . "]</p>";
 			}
 
-			echo "<p>" . lang('install_admin_set_sitename');
+			echo "<p>" . ilang('install_admin_set_sitename');
 
 			$query = "INSERT INTO ". $db_prefix ."siteprefs (sitepref_name, sitepref_value) VALUES (?,?)";
 			$dbresult = $db->Execute($query, array('sitename', htmlentities($_POST['sitename'], ENT_QUOTES, 'UTF-8')));
 			if (!$dbresult)
 			{
-				echo lang('invalid_query', $db->sql) ."</p>";
+				echo ilang('invalid_query', $db->sql) ."</p>";
 				$sql_error = true;
 			}
 			else
 			{
-				echo " [" . lang('done') . "]</p>";
+				echo " [" . ilang('done') . "]</p>";
 			}
 
 			include_once(cms_join_path(CMS_INSTALL_BASE, 'schemas', 'createseq.php'));
@@ -145,11 +138,11 @@ class CMSInstallerPage6 extends CMSInstallerPage
 
 			if (!$sql_error)
 			{
-				echo '<p class="success">' . lang('success') . '!</p>';
+				echo '<p class="success">' . ilang('success') . '!</p>';
 			}
 			else
 			{
-				echo '<p class="error">' . lang('invalid_querys') . '!</p>';
+				echo '<p class="error">' . ilang('invalid_querys') . '!</p>';
 			}
 		}
 	}
