@@ -16,18 +16,10 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSInstallPage7.class.php 284 2010-07-29 11:15:51Z wishy $
+#$Id: CMSInstallPage7.class.php 311 2011-01-16 22:55:19Z wishy $
 
 class CMSInstallerPage7 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	*/
-	function CMSInstallerPage7(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(7, $smarty, $errors, $debug);
-	}
-
 	function assignVariables()
 	{
 		$values = array();
@@ -36,7 +28,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		$values['admininfo']['email'] = $_POST['adminemail'];
 		$values['admininfo']['password'] = $_POST['adminpassword'];
 		$base_url = str_replace(" ", "%20", rtrim($_POST['docroot'], '/'));
-		$link = '<a href="'.$base_url.'">'.lang('cms_site').'</a>';
+		$link = '<a href="'.$base_url.'">'.ilang('cms_site').'</a>';
 
 		$this->smarty->assign('base_url', $base_url);
 		$this->smarty->assign('values', $values);
@@ -57,7 +49,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		if (! empty($_POST['db_port'])) $db->port = $_POST['db_port'];
 		if (! $db->Connect($_POST['host'],$_POST['username'],$_POST['password'],$_POST['database']))
 		{
-			$this->errors[] = lang('could_not_connect_db');
+			$this->errors[] = ilang('could_not_connect_db');
 			return;
 		}
 
@@ -72,7 +64,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
                 // $newconfig['db_socket'] = $_POST['db_socket'];
 
 		$newconfig['root_url'] = rtrim($_POST['docroot'], '/');
-		$newconfig['ssl_url'] = str_replace('http://','https://',$newconfig['root_url']);
+		$newconfig['ssl_url'] = (!startswith($newconfig['root_url'], 'https')) ? str_replace('http://','https://',$newconfig['root_url']) : $newconfig['root_url'];
 		$newconfig['root_path'] = rtrim($_POST['docpath'], '\\/');
 		$newconfig['query_var'] = $_POST['querystr'];
 		$newconfig['use_bb_code'] = false;
@@ -81,7 +73,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		$newconfig['uploads_path'] = cms_join_path($newconfig['root_path'], 'uploads');
 		// Note: leave the / slashes for the URLs
 		$newconfig['uploads_url'] = '/uploads';
-		$newconfig['ssl_uploads_url'] = str_replace('http://','https://',$newconfig['uploads_url']);
+		$newconfig['ssl_uploads_url'] = (!startswith($newconfig['root_url'], 'https')) ? str_replace('http://','https://',$newconfig['uploads_url']) : $newconfig['uploads_url'];
 		$newconfig['image_uploads_path'] = cms_join_path($newconfig['uploads_path'], 'images');
 		// Note: leave the / slashes for the URLs
 		$newconfig['image_uploads_url'] = $newconfig['uploads_url'] . '/images';
@@ -108,6 +100,8 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		{
 			$maxFileSize = 1000000;
 		}
+
+		$newconfig['timezone'] = $_POST['timezone'];
 		$newconfig['max_upload_size'] = $maxFileSize;
 		$newconfig['debug'] = false;
 		//$newconfig['assume_mod_rewrite'] = false; //Not in use now
@@ -128,6 +122,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		$newconfig['wiki_url'] = 'http://wiki.cmsmadesimple.org/index.php/User_Handbook/Admin_Panel';
 		$newconfig['set_names'] = true;
 		$newconfig['url_rewriting'] = 'none';
+		$newconfig['auto_create_url'] = 'none';
 	
 		$configfile = CONFIG_FILE_LOCATION;
 		## build the content for config file
@@ -137,7 +132,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		}
 		else 
 		{
-			echo lang('cannot_write_config', $configfile);
+			echo ilang('cannot_write_config', $configfile);
 			exit;
 		}
 
@@ -145,7 +140,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		{
 			if (!unlink(cms_join_path(TMP_CACHE_LOCATION, 'SITEDOWN')))
 			{
-				echo lang('install_admin_sitedown');
+				echo ilang('install_admin_sitedown');
 			}
 		}
 
@@ -154,7 +149,7 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		if (isset($_POST["createtables"]) && $_POST['createtables'] != 0 )
 		{
 			global $DONT_SET_DB;
-			echo '<p>' . lang('install_admin_update_hierarchy');
+			echo '<p>' . ilang('install_admin_update_hierarchy');
 
 			#Set $gCms->config - somehow it doesn't get set by include.php
 			$gCms->config = $newconfig;
@@ -169,18 +164,20 @@ class CMSInstallerPage7 extends CMSInstallerPage
 			$contentops =& $gCms->GetContentOperations();
 			$contentops->SetAllHierarchyPositions();
 
-			echo " [" . lang('done') . "]</p>";
+			echo " [" . ilang('done') . "]</p>";
 
 
-			echo '<p>' . lang('install_admin_set_core_event');
+			echo '<p>' . ilang('install_admin_set_core_event');
 
 			Events::SetupCoreEvents();
 
-			echo " [" . lang('done') . "]</p>";
+			echo " [" . ilang('done') . "]</p>";
 
 
-			echo '<p>' . lang('install_admin_install_modules');
+			echo '<p>' . ilang('install_admin_install_modules');
 
+			$loader = $gCms->GetModuleLoader();
+			$loader->LoadModules(TRUE);
 			foreach ($gCms->modules as $modulename=>$value)
 			{
 			  // only deal with system modules
@@ -228,10 +225,10 @@ class CMSInstallerPage7 extends CMSInstallerPage
 								$content = @ob_get_contents();
 								@ob_end_clean();
 								echo '<div class="pagecontainer">';
-								echo '<p class="pageheader">'.lang('moduleinstallmessage', array($module)).'</p>';
+								echo '<p class="pageheader">'.ilang('moduleinstallmessage', array($module)).'</p>';
 								echo $content;
 								echo "</div>";
-								echo '<p class="pageback"><a class="pageback" href="listmodules.php">&#171; '.lang('back').'</a></p>';
+								echo '<p class="pageback"><a class="pageback" href="listmodules.php">&#171; '.ilang('back').'</a></p>';
 								include_once("footer.php");
 								exit;
 
@@ -241,12 +238,12 @@ class CMSInstallerPage7 extends CMSInstallerPage
 					}
 				}
 			}
-			echo " [" . lang('done') . "]</p>";
+			echo " [" . ilang('done') . "]</p>";
 
 
-			echo '<p>' . lang('install_admin_clear_cache');
+			echo '<p>' . ilang('install_admin_clear_cache');
 			$contentops->ClearCache();
-			echo " [" . lang('done') . "]</p>";
+			echo " [" . ilang('done') . "]</p>";
 
 			// Insert new site preferences
 			set_site_preference('global_umask', $_POST['umask']);
@@ -264,15 +261,15 @@ class CMSInstallerPage7 extends CMSInstallerPage
 		if ( ($_POST['email_accountinfo'] == 1) && (! empty($_POST['adminemail'])) )
 		{
 
-			echo '<p>' . lang('install_admin_emailing');
+			echo '<p>' . ilang('install_admin_emailing');
 			$to      = $_POST['adminemail'];
-			$subject = lang('email_accountinfo_subject');
-			$message = lang('email_accountinfo_message', $_POST['adminusername'], $_POST['adminpassword'], "$link/admin/");
+			$subject = ilang('email_accountinfo_subject');
+			$message = ilang('email_accountinfo_message', $_POST['adminusername'], $_POST['adminpassword'], "$link/admin/");
 			$message = html_entity_decode($message, ENT_QUOTES); // Encoded from TC
 			echo (
 				@mail($to, $subject, $message)
-					? " [" . lang('done') . "]"
-					: "<strong>[" . lang('failed') . "]</strong>"
+					? " [" . ilang('done') . "]"
+					: "<strong>[" . ilang('failed') . "]</strong>"
 			);
 			echo "</p>";
 
