@@ -16,21 +16,10 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSUpgradePage1.class.php 149 2009-03-17 22:22:13Z alby $
+#$Id: CMSUpgradePage1.class.php 296 2010-10-17 22:31:18Z calguy1000 $
 
 class CMSInstallerPage1 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	 * @var object $smarty
-	 * @var array  $errors
-	 * @var bool   $debug
-	 */
-	function CMSInstallerPage1(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(1, $smarty, $errors, $debug);
-	}
-
 	function assignVariables()
 	{
 		if(isset($_POST['recheck']))
@@ -44,7 +33,7 @@ class CMSInstallerPage1 extends CMSInstallerPage
 			}
 			elseif(count($test->files) > 1)
 			{
-				$error = lang('upload_file_multiple');
+				$error = ilang('upload_file_multiple');
 			}
 			else
 			{
@@ -59,7 +48,7 @@ class CMSInstallerPage1 extends CMSInstallerPage
 					else             $handle = @fopen($checksum_file, 'rb');
 					if(! $handle)
 					{
-						$error = lang('upload_file_no_readable');
+						$error = ilang('upload_file_no_readable');
 					}
 				}
 			}
@@ -83,7 +72,7 @@ class CMSInstallerPage1 extends CMSInstallerPage
 					$file = str_replace('/', DIRECTORY_SEPARATOR, $file); // avoid windows suck
 
 					$test_file = CMS_BASE . DIRECTORY_SEPARATOR . $file;
-					$test = testFileChecksum(0, '', $test_file, $md5sum, '', lang('format_datetime'), $this->debug);
+					$test = testFileChecksum(0, '', $test_file, $md5sum, '', ilang('format_datetime'), $this->debug);
 					if($test->res == 'green') continue; // ok, skip
 
 					$results[] = $test;
