@@ -16,22 +16,14 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSUpgradePage6.class.php 264 2010-04-19 23:03:41Z silmarillion $
+#$Id: CMSUpgradePage6.class.php 296 2010-10-17 22:31:18Z calguy1000 $
 
 class CMSInstallerPage6 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	*/
-	function CMSInstallerPage6(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(6, $smarty, $errors, $debug);
-	}
-
 	function assignVariables()
 	{
 		$test = $this->module_autoupgrade();
-		$test->messages[] = lang('noneed_upgrade_modules');
+		$test->messages[] = ilang('noneed_upgrade_modules');
 		$this->smarty->assign('test', $test);
 
 		$this->smarty->assign('errors', $this->errors);
@@ -59,7 +51,7 @@ class CMSInstallerPage6 extends CMSInstallerPage
 				$dbresult = $db->Execute($query, array($modulename));
 				if(! $dbresult)
 				{
-					$test->messages[] = lang('invalid_query', $query);
+					$test->messages[] = ilang('invalid_query', $query);
 					$test->error = true;
 				}
 				else
@@ -76,24 +68,24 @@ class CMSInstallerPage6 extends CMSInstallerPage
 				{
 					if(version_compare($file_version, $module_version) == 1)
 					{
-						$_msg = lang('upgrade_sql_module_from_to', $modulename, $module_version, $file_version);
+						$_msg = ilang('upgrade_sql_module_from_to', $modulename, $module_version, $file_version);
 						$gCms->modules[$modulename]['object']->Upgrade($module_version, $file_version);
 						$query = "UPDATE " . cms_db_prefix() . "modules SET version = ?, admin_only = ? WHERE module_name = ?";
 						$dbresult = $db->Execute($query, array($file_version, ($gCms->modules[$modulename]['object']->IsAdminOnly()==true?1:0), $modulename));
 						if(!$dbresult)
 						{
-							$_msg .= lang('invalid_query', $query);
+							$_msg .= ilang('invalid_query', $query);
 							$test->error = true;
 						}
 						else
 						{
-							$_msg .= " [" . lang('done') . "]";
+							$_msg .= " [" . ilang('done') . "]";
 						}
 						$test->message[] = $_msg; 
 
-						$_msg = lang('upgrade_event_module_from_to', $modulename, $module_version, $file_version);
+						$_msg = ilang('upgrade_event_module_from_to', $modulename, $module_version, $file_version);
 						Events::SendEvent('Core', 'ModuleUpgraded', array('name' => $modulename, 'oldversion' => $module_version, 'newversion' => $file_version));
-						$_msg .= " [" . lang('done') . "]";
+						$_msg .= " [" . ilang('done') . "]";
 						$test->message[] = $_msg; 
 					}
 				}
