@@ -16,18 +16,10 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSUpgradePage7.class.php 264 2010-04-19 23:03:41Z silmarillion $
+#$Id: CMSUpgradePage7.class.php 296 2010-10-17 22:31:18Z calguy1000 $
 
 class CMSInstallerPage7 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	*/
-	function CMSInstallerPage7(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(7, $smarty, $errors, $debug);
-	}
-
 	function assignVariables()
 	{
 		global $gCms;
@@ -45,13 +37,13 @@ class CMSInstallerPage7 extends CMSInstallerPage
 
 			if (! $_test)
 			{
-				$test->messages[] = lang('sitedown_not_removed');
+				$test->messages[] = ilang('sitedown_not_removed');
 				$test->error = true;
 			}
 		}
 
-		$test->messages[] = lang('upgrade_ok');
-		$test->messages[] = lang('upgrade_end', '<a href="../index.php">'.lang('here').'</a>', '<a href="../'.$config['admin_dir'].'">'.lang('go_to_admin').'</a>');
+		$test->messages[] = ilang('upgrade_ok');
+		$test->messages[] = ilang('upgrade_end', '<a href="../index.php">'.ilang('here').'</a>', '<a href="../'.$config['admin_dir'].'">'.ilang('go_to_admin').'</a>');
 		$this->smarty->assign('test', $test);
 
 		$this->smarty->assign('errors', $this->errors);
