@@ -105,8 +105,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."additional_users", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'additional_users', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'additional_users', $ado_ret);
 
 
 
@@ -118,13 +118,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."admin_bookmarks", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'admin_bookmarks', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'admin_bookmarks', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_admin_bookmarks_by_user_id', $db_prefix."admin_bookmarks", 'user_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'admin_bookmarks', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'admin_bookmarks', $ado_ret);
 
 
 
@@ -138,8 +138,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."adminlog", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'adminlog', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'adminlog', $ado_ret);
 
 
 
@@ -152,8 +152,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."admin_recent_pages", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'admin_recent_pages', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'admin_recent_pages', $ado_ret);
 
 
 
@@ -184,27 +184,28 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 		last_modified_by I,
 		create_date DT,
 		modified_date DT,
-                secure I1
+                secure I1,
+                page_url C(255)
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."content", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'content', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_by_content_alias_active', $db_prefix."content", 'content_alias, active');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_by_default_content', $db_prefix."content", 'default_content');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_by_parent_id', $db_prefix."content", 'parent_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -221,13 +222,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."content_props", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'content_props', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'content_props', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_props_by_content_id', $db_prefix."content_props", 'content_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -242,18 +243,18 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."crossref", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'crossref', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'crossref', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_crossref_by_child_type_child_id', $db_prefix."crossref", 'child_type, child_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_crossref_by_parent_type_parent_id', $db_prefix."crossref", 'parent_type, parent_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -267,13 +268,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."css", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'css', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'css', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_css_by_css_name', $db_prefix."css", 'css_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -287,18 +288,18 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."css_assoc", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'css_assoc', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'css_assoc', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_css_assoc_by_assoc_to_id', $db_prefix."css_assoc", 'assoc_to_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_css_assoc_by_assoc_css_id', $db_prefix."css_assoc", 'assoc_css_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 	
 
@@ -312,8 +313,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."event_handlers", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'event_handlers', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'event_handlers', $ado_ret);
 
 
 
@@ -324,18 +325,18 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."events", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'events', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'events', $ado_ret);
 	
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'originator', $db_prefix."events", 'originator');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
     
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'event_name', $db_prefix."events", 'event_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 	
 	
 
@@ -348,13 +349,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."group_perms", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'group_perms', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'group_perms', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_group_perms_by_group_id_permission_id', $db_prefix."group_perms", 'group_id, permission_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -367,8 +368,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."groups", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'groups', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'groups', $ado_ret);
 
 
 
@@ -376,19 +377,21 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 		htmlblob_id I KEY,
 		htmlblob_name C(255),
 		html X,
+                description X,
+                use_wysiwyg I1,
 		owner I,
 		create_date DT,
 		modified_date DT
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."htmlblobs", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'htmlblobs', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'htmlblobs', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_htmlblobs_by_htmlblob_name', $db_prefix."htmlblobs", 'htmlblob_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -399,13 +402,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."additional_htmlblob_users", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'additional_htmlblob_users', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'additional_htmlblob_users', $ado_ret);
 
 
 
 	$flds = "
-		module_name C(160),
+		module_name C(160) KEY,
 		status C(255),
 		version C(255),
 		admin_only I1 DEFAULT 0,
@@ -413,13 +416,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."modules", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'modules', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'modules', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_modules_by_module_name', $db_prefix."modules", 'module_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -432,8 +435,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."module_deps", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'module_deps', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'module_deps', $ado_ret);
 
 
 
@@ -446,13 +449,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."module_templates", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'module_templates', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'module_templates', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_module_templates_by_module_name_template_name', $db_prefix."module_templates", 'module_name, template_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -465,8 +468,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."permissions", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'permissions', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'permissions', $ado_ret);
 
 
 
@@ -478,8 +481,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."siteprefs", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'siteprefs', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'siteprefs', $ado_ret);
 
 
 
@@ -496,13 +499,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."templates", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'templates', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'templates', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_templates_by_template_name', $db_prefix."templates", 'template_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -514,8 +517,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."user_groups", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'user_groups', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'user_groups', $ado_ret);
 
 
 
@@ -527,13 +530,13 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."userprefs", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'userprefs', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'userprefs', $ado_ret);
 
 	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_userprefs_by_user_id', $db_prefix."userprefs", 'user_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_index', 'content', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_index', 'content', $ado_ret);
 
 
 
@@ -551,8 +554,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."users", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'users', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'users', $ado_ret);
 
 
 
@@ -565,8 +568,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."userplugins", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'userplugins', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'userplugins', $ado_ret);
 
 
 
@@ -575,8 +578,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."version", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'version', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'version', $ado_ret);
 
 
 
@@ -592,8 +595,8 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."sequence", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
-	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
-	echo lang('install_creating_table', 'sequence', $ado_ret);
+	$ado_ret = ($return == 2) ? ilang('done') : ilang('failed');
+	echo ilang('install_creating_table', 'sequence', $ado_ret);
 	*/
 }
 
