@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: class.admintheme.inc.php 6479 2010-07-05 20:41:27Z ajprog $
+#$Id: class.admintheme.inc.php 6786 2010-11-13 21:09:11Z calguy1000 $
 
 /**
  * @package CMS 
@@ -498,6 +498,7 @@ class AdminTheme
     {
       if (get_preference($this->userid, 'bookmarks')) {
 	$urlext='?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
+	echo "<div class=\"sections\">\n";
 	echo '<div class="itemmenucontainer shortcuts" style="float:left;">';
 	echo '<div class="itemoverflow">';
 	echo '<h2>'.lang('bookmarks').'</h2>';
@@ -626,28 +627,14 @@ class AdminTheme
      */
     function OutputHeaderJavascript()
     {
-?>
-<script type="text/javascript">
-<!-- Needed for correct display in IE only -->
-<!--
-	cssHover = function() {
-		var sfEls = document.getElementById("nav").getElementsByTagName("LI");
-		for (var i=0; i<sfEls.length; i++) {
-			sfEls[i].onmouseover=function() {
-				this.className+=" cssHover";
-			}
-			sfEls[i].onmouseout=function() {
-				this.className=this.className.replace(new RegExp(" cssHover\\b"), "");
-			}
-		}
-	}
-	if (window.attachEvent) window.attachEvent("onload", cssHover);
--->
-</script>
-<?php
-        echo "<script type=\"text/javascript\" src=\"";
-        echo $this->cms->config['root_url'];
-        echo "/lib/dynamic_tabs/tabs.js\"></script>\n";
+		//echo '<script type="text/javascript" src="themes/default/includes/standard.js"></script>'."\n";
+		echo '<script type="text/javascript" src="../lib/jquery/js/jquery-1.4.2.min.js"></script>'."\n";
+		echo '<script type="text/javascript" src="../lib/jquery/js/jquery-ui-1.8.4.custom.min.js"></script>'."\n";
+		echo '<script type="text/javascript" src="../lib/jquery/js/jquery.ui.nestedSortable.js"></script>'."\n";
+		echo '<script type="text/javascript" src="../lib/jquery/js/jquery.json-2.2.js"></script>'."\n";
+//         echo "<script type=\"text/javascript\" src=\"";
+//         echo $this->cms->config['root_url'];
+//         echo "/lib/dynamic_tabs/tabs.js\"></script>\n";
 	}
 
     /**
@@ -719,7 +706,7 @@ debug_buffer('before menu items');
 //	    'dashboard'=>array('url'=>'dashboard.php','parent'=>'main',
 //			       'title'=>$this->FixSpaces(lang('dashboard')),
 //			       'description'=>'','show_in_menu'=>true),
-            'viewsite'=>array('url'=>'../index.php','parent'=>'main',
+            'viewsite'=>array('url'=>$this->_viewsite_url,'parent'=>'main',
 			      'title'=>$this->FixSpaces(lang('viewsite')),
 			      'type'=>'external',
                     'description'=>'','show_in_menu'=>true, 'target'=>'_blank'),
@@ -885,7 +872,7 @@ debug_buffer('after menu items');
 
 
 	// slightly cleaner syntax
-	$this->menuItems['ecommerce'] = array('url'=>'topadmin.php?section=ecommerce','parent'=>-1,
+	$this->menuItems['ecommerce'] = array('url'=>'topecomm.php','parent'=>-1,
 					      'title'=>$this->FixSpaces(lang('ecommerce')),
 					      'description'=>lang('ecommerce_desc'),
 					      'show_in_menu'=>true);
@@ -1029,60 +1016,61 @@ debug_buffer('after menu items');
 
 	// resolve the tree to be doubly-linked,
 	// and make sure the selections are selected            
-        foreach ($this->menuItems as $sectionKey=>$sectionArray)
+	foreach ($this->menuItems as $sectionKey=>$sectionArray)
 	  {
-            // link the children to the parents; a little clumsy since we can't
-            // assume php5-style references in a foreach.
-            $this->menuItems[$sectionKey]['children'] = array();
-            foreach ($this->menuItems as $subsectionKey=>$subsectionArray)
-	      {
-            	if ($subsectionArray['parent'] == $sectionKey)
-		  {
-		    $this->menuItems[$sectionKey]['children'][] = $subsectionKey;
-		  }
-	      }
-            // set selected
-	    if ($this->script == 'moduleinterface.php')
-	      {
-                $a = preg_match('/(module|mact)=([^&,]+)/',$this->query,$matches);
-                if ($a > 0 && $matches[2] == $sectionKey)
-		  {
-		    $this->menuItems[$sectionKey]['selected'] = true;
-		    $this->title .= $sectionArray['title'];
-		    if ($sectionArray['parent'] != -1)
-		      {
-			$parent = $sectionArray['parent'];
-			while ($parent != -1)
+		  // link the children to the parents; a little clumsy since we can't
+		  // assume php5-style references in a foreach.
+		  $this->menuItems[$sectionKey]['children'] = array();
+		  foreach ($this->menuItems as $subsectionKey=>$subsectionArray)
 			  {
-			    $this->menuItems[$parent]['selected'] = true;
-			    $parent = $this->menuItems[$parent]['parent'];
+				  if ($subsectionArray['parent'] == $sectionKey)
+					  {
+						  $this->menuItems[$sectionKey]['children'][] = $subsectionKey;
+					  }
+			  }
+
+		  // set selected
+		  if ($this->script == 'moduleinterface.php')
+			  {
+				  $a = preg_match('/(module|mact)=([^&,]+)/',$this->query,$matches);
+				  if ($a > 0 && $matches[2] == $sectionKey)
+					  {
+						  $this->menuItems[$sectionKey]['selected'] = true;
+						  $this->title .= $sectionArray['title'];
+						  if ($sectionArray['parent'] != -1)
+							  {
+								  $parent = $sectionArray['parent'];
+								  while ($parent != -1)
+									  {
+										  $this->menuItems[$parent]['selected'] = true;
+										  $parent = $this->menuItems[$parent]['parent'];
+									  }
+							  }
+					  }
+				  else
+					  {
+						  $this->menuItems[$sectionKey]['selected'] = false;
+					  }
+			  }
+		  else if (strstr($sectionArray['url'],$this->script) !== FALSE &&
+				   (!isset($sectionArray['type']) || $sectionArray['type'] != 'external'))
+			  {
+				  $this->menuItems[$sectionKey]['selected'] = true;
+				  $this->title .= $sectionArray['title'];
+				  if ($sectionArray['parent'] != -1)
+					  {
+						  $parent = $sectionArray['parent'];
+						  while ($parent != -1)
+							  {
+								  $this->menuItems[$parent]['selected'] = true;
+								  $parent = $this->menuItems[$parent]['parent'];
+							  }
+					  }
+			  }
+		  else
+			  {
+				  $this->menuItems[$sectionKey]['selected'] = false;
 			  }
-		      }
-		  }
-		else
-		  {
-		    $this->menuItems[$sectionKey]['selected'] = false;
-		  }
-	      }
-            else if (strstr($sectionArray['url'],$this->script) !== FALSE &&
-		     (!isset($sectionArray['type']) || $sectionArray['type'] != 'external'))
-	      {
-            	$this->menuItems[$sectionKey]['selected'] = true;
-            	$this->title .= $sectionArray['title'];
-            	if ($sectionArray['parent'] != -1)
-		  {
-		    $parent = $sectionArray['parent'];
-		    while ($parent != -1)
-		      {
-			$this->menuItems[$parent]['selected'] = true;
-			$parent = $this->menuItems[$parent]['parent'];
-		      }
-		  }
-	      }
-            else
-	      {
-            	$this->menuItems[$sectionKey]['selected'] = false;
-	      }
 	  }
 	// fix subtitle, if any
 	if ($subtitle != '')
@@ -1404,7 +1392,7 @@ debug_buffer('after menu items');
     {
 ?>
 <div id="Footer">
-<a href="http://www.cmsmadesimple.org">CMS Made Simple</a> is Free Software released under the GNU/GPL License
+<a href="http://www.cmsmadesimple.org">CMS Made Simple&trade;</a> is Free Software released under the GNU/GPL License
 </div>
 <?php
     }
@@ -1427,9 +1415,25 @@ debug_buffer('after menu items');
      */
     function DisplayHTMLStartTag()
     {
-    	echo $this->cms->nls['direction'] == 'rtl' ? "<html dir=\"rtl\"\n>" : "<html>\n";
+		global $gCms;
+		$nls =& $gCms->nls;
+    	echo (isset($nls['direction']) && $nls['direction'] == 'rtl') ? "<html dir=\"rtl\"\n>" : "<html>\n";
     }
-
+	/**
+	 * @since 1.9
+     * ThemeHeader
+     * This method outputs the HEAD section of the html page in the admin Theme section,
+     * after OutputHeaderJavascript() and before $addt.
+     */
+	function ThemeHeader(){
+		
+		if(file_exists('themes/'. $this->themeName. '/includes/stndard.js'))
+		{
+			echo '<script type="text/javascript" src="themes/'. $this->themeName. '/includes/standard.js"></script>'."\n";
+		}else{
+			echo '<script type="text/javascript" src="themes/default/includes/standard.js"></script>'."\n";
+		}
+	}
     /**
      * DisplayHTMLHeader
      * This method outputs the HEAD section of the html page in the admin section.
@@ -1437,12 +1441,12 @@ debug_buffer('after menu items');
     function DisplayHTMLHeader($showielink = false, $addt = '')
     {
 		global $gCms;
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 ?><head>
 <meta name="Generator" content="CMS Made Simple - Copyright (C) 2004-9 Ted Kulp. All rights reserved." />
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 <meta name="robots" content="noindex, nofollow" />
-<title><?php echo $this->title ?></title>
+<title><?php echo $this->cms->siteprefs['sitename'] ." - ". $this->title ?></title>
 <link rel="stylesheet" type="text/css" href="style.php" />
 <?php
 	if ($showielink) {
@@ -1455,6 +1459,7 @@ debug_buffer('after menu items');
 ?>
 <!-- THIS IS WHERE HEADER STUFF SHOULD GO -->
 <?php $this->OutputHeaderJavascript(); ?>
+<?php $this->ThemeHeader(); ?>
 <?php echo $addt ?>
 <base href="<?php echo $config['root_url'] . '/' . $config['admin_dir'] . '/'; ?>" />
 </head>
@@ -1511,7 +1516,10 @@ debug_buffer('after menu items');
      */
     function DisplaySectionMenuDivEnd()
     {
-        echo "</div>\n";
+        echo "</div><!-- END .MainMenu-->\n";
+		if (get_preference($this->userid, 'bookmarks')) {
+			echo "</div><!-- END .sections-->\n";
+		}
     }
 
 
@@ -1703,7 +1711,7 @@ debug_buffer('after menu items');
     function ShowHeader($title_name, $extra_lang_param=array(), $link_text = '', $module_help_type = FALSE)
     {
       $cms = $this->cms;
-      $config =& $cms->GetConfig();             
+      $config = $cms->GetConfig();             
       $header  = '<div class="pageheader">';
       if (FALSE != $module_help_type)
 	{
@@ -1851,7 +1859,7 @@ debug_buffer('after menu items');
     function ShowErrors($errors, $get_var = '')
     {
       global $gCms;
-      $config =& $gCms->GetConfig();
+      $config = $gCms->GetConfig();
       $wikiUrl = $config['wiki_url'];
       if ($wikiUrl !='none'){
 		      if (FALSE == empty($_REQUEST['module'])  || FALSE == empty($_REQUEST['mact']))
@@ -1933,10 +1941,10 @@ debug_buffer('after menu items');
 	/**
 	 * Based on the current user's prefernces, get the current theme object.
 	 */
-	function &GetThemeObject()
+	static function &GetThemeObject()
 	{
 		global $gCms;
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 		$themeName = get_preference(get_userid(), 'admintheme', 'default');
 		$themeObjectName = $themeName."Theme";
 		$userid = get_userid();
@@ -1951,7 +1959,7 @@ debug_buffer('after menu items');
 			$themeObject = new AdminTheme($gCms, $userid, $themeName);
 		}
 
-		$gCms->variables['admintheme']=&$themeObject;
+		$gCms->variables['admintheme'] = $themeObject;
 		
 		return $themeObject;
 	
