@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: class.content.inc.php 6524 2010-07-29 11:04:34Z wishy $
+#$Id: class.content.inc.php 6905 2011-02-20 22:23:40Z calguy1000 $
 
 /**
  * @package CMS
@@ -152,7 +152,12 @@ class ContentBase
     /**
      * Secure?
      */
-    var $mSecure;
+    protected $mSecure;
+
+    /**
+     * URL
+     */
+    protected $mURL;
 
     /**
      * Does this content have a preview function?
@@ -254,6 +259,7 @@ class ContentBase
 	$this->mMarkup         = 'html' ;
 	$this->mChildCount     = 0;
 	$this->mPropertiesLoaded = false;
+        $this->mURL = '';
     }
 
     /**
@@ -265,7 +271,8 @@ class ContentBase
       $this->AddContentProperty('target',10);
       $this->AddBaseProperty('title',1,1);
       $this->AddBaseProperty('menutext',2,1);
-      $this->AddBaseProperty('parent',3,1);
+      $this->AddBaseProperty('page_url',3);
+      $this->AddBaseProperty('parent',4,1);
       $this->AddBaseProperty('active',5);
       $this->AddBaseProperty('showinmenu',5);
       $this->AddBaseProperty('secure',6);
@@ -299,8 +306,8 @@ class ContentBase
 
     function SetId($id)
     {
-	$this->DoReadyForEdit();
 	$this->mId = $id;
+	$this->DoReadyForEdit();
     }
 
     /**
@@ -399,14 +406,26 @@ class ContentBase
 	return $this->mTitleAttribute;
     }
 
+
+    /**
+     * Retreive the creation date of this content object.
+     *
+     * @return int Unix Timestamp of the creation date
+     */
     function GetCreationDate()
     {
-	return $this->mCreationDate;
+      return strtotime($this->mCreationDate);
     }
 	
+
+    /**
+     * Retreive the date of the last modification of this content object.
+     *
+     * @return int Unix Timestamp of the modification date.
+     */
     function GetModifiedDate()
     {
-	return $this->mModifiedDate;
+      return strtotime($this->mModifiedDate);
     }
 
     function SetTitleAttribute($titleattribute)
@@ -601,13 +620,23 @@ class ContentBase
       return $this->mSecure;
     }
 
-
     function SetSecure($secure)
     {
 	$this->DoReadyForEdit();
 	$this->mSecure = $secure;
     }
 	
+    public function URL()
+    {
+      return $this->mURL;
+    }
+
+    public function SetURL($url)
+    {
+      $this->DoReadyForEdit();
+      $this->mURL = $url;
+    }
+
 	function Markup()
 	{
 		return $this->mMarkup;
@@ -644,7 +673,7 @@ class ContentBase
 	{
 		$this->DoReadyForEdit();
 		global $gCms;
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		$tolower = false;
 
@@ -708,7 +737,12 @@ class ContentBase
      */
 	function ChildCount()
 	{
-		return $this->mChildCount;
+	  $hm = cmsms()->GetHierarchyManager();
+	  $node = $hm->getNodeById($this->mId);
+	  if( $node )
+	    {
+	      return $node->count_children();
+	    }
 	}
 
     /**
@@ -825,7 +859,7 @@ class ContentBase
 	{
 		global $gCms, $sql_queries, $debug_errors;
 		$db = &$gCms->GetDb();
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		$result = false;
 
@@ -863,6 +897,7 @@ class ContentBase
 				$this->mShowInMenu                 = ($row->fields["show_in_menu"] == 1    ? true : false);
 				$this->mCachable                   = ($row->fields["cachable"] == 1        ? true : false);
 				$this->mSecure                     = $row->fields['secure'];
+				$this->mURL                        = $row->fields['page_url'];
 				$this->mLastModifiedBy             = $row->fields["last_modified_by"];
 				$this->mCreationDate               = $row->fields["create_date"];
 				$this->mModifiedDate               = $row->fields["modified_date"];
@@ -934,7 +969,7 @@ class ContentBase
 	function LoadFromData(&$data, $loadProperties = false)
 	{
 	  global $gCms, $debug_errors;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 
 		$result = true;
 
@@ -966,6 +1001,8 @@ class ContentBase
 		$this->mCachable                   = ($data["cachable"] == 1        ? true : false);
 		if( isset($data['secure']) )
 		  $this->mSecure                   = $data["secure"];
+		if( isset($data['page_url']) )
+		  $this->mURL                      = $data["page_url"];
 		$this->mLastModifiedBy             = $data["last_modified_by"];
 		$this->mCreationDate               = $data["create_date"];
 		$this->mModifiedDate               = $data["modified_date"];
@@ -1070,7 +1107,7 @@ class ContentBase
 	{
 		global $gCms, $sql_queries, $debug_errors;
 		$db = &$gCms->GetDb();
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		$result = false;
 
@@ -1095,7 +1132,7 @@ class ContentBase
 
 		$this->mModifiedDate = trim($db->DBTimeStamp(time()), "'");
 
-		$query = "UPDATE ".cms_db_prefix()."content SET content_name = ?, owner_id = ?, type = ?, template_id = ?, parent_id = ?, active = ?, default_content = ?, show_in_menu = ?, cachable = ?, secure = ?, menu_text = ?, content_alias = ?, metadata = ?, titleattribute = ?, accesskey = ?, tabindex = ?, modified_date = ?, item_order = ?, markup = ?, last_modified_by = ? WHERE content_id = ?";
+		$query = "UPDATE ".cms_db_prefix()."content SET content_name = ?, owner_id = ?, type = ?, template_id = ?, parent_id = ?, active = ?, default_content = ?, show_in_menu = ?, cachable = ?, secure = ?, page_url = ?, menu_text = ?, content_alias = ?, metadata = ?, titleattribute = ?, accesskey = ?, tabindex = ?, modified_date = ?, item_order = ?, markup = ?, last_modified_by = ? WHERE content_id = ?";
 		$dbresult = $db->Execute($query, array(
 			$this->mName,
 			$this->mOwner,
@@ -1107,6 +1144,7 @@ class ContentBase
 			($this->mShowInMenu == true     ? 1 : 0),
 			($this->mCachable == true       ? 1 : 0),
 			$this->mSecure,
+			$this->mURL,
 			$this->mMenuText,
 			$this->mAlias,
 			$this->mMetadata,
@@ -1178,7 +1216,7 @@ class ContentBase
 	{
 		global $gCms, $sql_queries, $debug_errors;
 		$db = &$gCms->GetDb();
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		$result = false;
 
@@ -1206,7 +1244,7 @@ class ContentBase
 
 		$this->mModifiedDate = $this->mCreationDate = trim($db->DBTimeStamp(time()), "'");
 
-		$query = "INSERT INTO ".$config["db_prefix"]."content (content_id, content_name, content_alias, type, owner_id, parent_id, template_id, item_order, hierarchy, id_hierarchy, active, default_content, show_in_menu, cachable, secure, menu_text, markup, metadata, titleattribute, accesskey, tabindex, last_modified_by, create_date, modified_date) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
+		$query = "INSERT INTO ".$config["db_prefix"]."content (content_id, content_name, content_alias, type, owner_id, parent_id, template_id, item_order, hierarchy, id_hierarchy, active, default_content, show_in_menu, cachable, secure, page_url, menu_text, markup, metadata, titleattribute, accesskey, tabindex, last_modified_by, create_date, modified_date) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
 
 		$dbresult = $db->Execute($query, array(
 			$newid,
@@ -1224,6 +1262,7 @@ class ContentBase
 			($this->mShowInMenu == true     ? 1 : 0),
 			($this->mCachable == true       ? 1 : 0),
 			$this->mSecure,
+			$this->mURL,
 			$this->mMenuText,
 			$this->mMarkup,
 			$this->mMetadata,
@@ -1237,6 +1276,7 @@ class ContentBase
 
 		if (! $dbresult)
 		{
+		  die($db->sql.'<br/>'.$db->ErrorMsg());
 			if ($config["debug"] == true)
 			{
 				# :TODO: Translate the error message
@@ -1330,6 +1370,72 @@ class ContentBase
 		}
 	    }
 
+	  $auto_type = content_assistant::auto_create_url();
+	  if( $this->mURL == '' && get_site_preference('content_autocreate_urls') )
+	    {
+	      // create a valid url.
+	      if( !$this->DefaultContent() )
+		{
+		  if( get_site_preference('content_autocreate_flaturls',0) )
+		    {
+		      // the default url is the alias... but not synced to the alias.
+		      $this->mURL = $this->mAlias;
+		    }
+		  else
+		    {
+		      // if it don't explicitly say 'flat' we're creating a hierarchical url.
+		      global $gCms;
+		      $tree = $gCms->GetHierarchyManager();
+		      $node = $tree->find_by_tag('id',$this->ParentId());
+		      $stack = array($this->mAlias);
+		      $parent_url = '';
+		      $count = 0;
+		      while( $node )
+			{
+			  $tmp_content = $node->GetContent();
+			  if( $tmp_content )
+			    {
+			      $tmp = $tmp_content->URL();
+			      if( $tmp != '' && $count == 0 )
+				{
+				  // try to build the url out of the parent url.
+				  $parent_url = $tmp;
+				  break;
+				}
+			      array_unshift($stack,$tmp_content->Alias());
+			    }
+			  $node = $node->GetParent();
+			  $count++;
+			}
+
+		      if( $parent_url != '' )
+			{
+			  // woot, we got a prent url.
+			  $this->mURL = $parent_url.'/'.$this->mAlias;
+			}
+		      else
+			{
+			  $this->mURL = implode('/',$stack);
+			}
+		    }
+		}
+	    }
+	  if( $this->mURL == '' && get_site_preference('content_mandatory_urls') && !$this->mDefaultContent )
+	    {
+	      // page url is empty and mandatory
+	      $errors[] = lang('content_mandatory_urls');
+	    }
+	  else if( $this->mURL != '' )
+	    {
+	      // page url is not empty, check for validity.
+	      $this->mURL = strtolower(trim($this->mURL," /\t\r\n\0\x08")); // silently delete bad chars. and convert to lowercase.
+	      if( $this->mURL != '' && !content_assistant::is_valid_url($this->mURL,$this->mId) )
+		{
+		  // and validate the URL.
+		  $errors[] = lang('invalid_url');
+		}
+	    }
+
 	  return (count($errors) > 0?$errors:FALSE);
 	}
 
@@ -1340,7 +1446,7 @@ class ContentBase
 	function Delete()
 	{
 		global $gCms, $sql_queries, $debug_errors;
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		foreach($gCms->modules as $key=>$value)
 		{
@@ -1419,7 +1525,7 @@ class ContentBase
     /**
      * Function for the subclass to parse out data for it's parameters (usually from $_POST)
      */
-    function FillParams($params)
+    function FillParams($params,$editing = false)
     {
       // content property parameters
       $parameters = array('extra1','extra2','extra3','image','thumbnail');
@@ -1475,9 +1581,15 @@ class ContentBase
 
       // alias
       $tmp = '';
-      if (isset($params['alias']))
+      if( isset($params['alias']) )
 	{
 	  $tmp = trim($params['alias']);
+	}
+      if( !$editing || $tmp )
+	{
+	  // the alias param may not exist (depending upon permissions)
+	  // this method will set the alias to the supplied value if it is set
+	  // or auto-generate one, when adding a new page.
 	  $this->SetAlias($tmp);
 	}
 
@@ -1530,6 +1642,16 @@ class ContentBase
 	  $this->_handleRemovedBaseProperty('secure','mSecure');
 	}
 
+      // url
+      if (isset($params['page_url']))
+	{
+	  $this->mURL = $params['page_url'];
+	}
+      else
+	{
+	  $this->_handleRemovedBaseProperty('page_url','mURL');
+	}
+
       // owner
       if (isset($params["ownerid"]))
 	{
@@ -1557,7 +1679,7 @@ class ContentBase
 	function GetURL($rewrite = true)
 	{
 		global $gCms;
-		$config = &$gCms->GetConfig();
+		$config = $gCms->GetConfig();
 		$url = "";
 		$alias = ($this->mAlias != ''?$this->mAlias:$this->mId);
 
@@ -1582,33 +1704,38 @@ class ContentBase
 
 		if ($config["url_rewriting"] == 'mod_rewrite' && $rewrite == true)
 		{
-			if ($config['use_hierarchy'] == true)
-			{
-				$url = $base_url. '/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
-			}
-			else
-			{
-				$url = $base_url . '/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
-			}
+		  $str = $this->HierarchyPath();
+		  if( isset($config['use_hierarchy']) && $config['use_hierarchy'] == false )
+		    {
+		      $str = $alias;
+		    }
+
+		  if( $this->mURL != '')
+		    {
+		      // we have a url path
+		      $str = $this->mURL;
+		    }
+		  $url = $base_url. '/' . $str . (isset($config['page_extension'])?$config['page_extension']:'.html');
+		}
+		else if (isset($_SERVER['PHP_SELF']) && $config['url_rewriting'] == 'internal' && $rewrite == true)
+		{
+		  $str = $this->HierarchyPath();
+		  if( isset($config['use_hierarchy']) && $config['use_hierarchy'] == false )
+		    {
+		      $str = $alias;
+		    }
+
+		  if( $this->mURL != '')
+		    {
+		      // we have a url path
+		      $str = $this->mURL;
+		    }
+		  $url = $base_url . '/index.php/' . $str . (isset($config['page_extension'])?$config['page_extension']:'.html');
 		}
 		else
-		{
-			if (isset($_SERVER['PHP_SELF']) && $config['url_rewriting'] == 'internal')
-			{
-				if ($config['use_hierarchy'] == true)
-				{
-					$url = $base_url . '/index.php/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
-				}
-				else
-				{
-					$url = $base_url . '/index.php/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
-				}
-			}
-			else
-			{
-				$url = $base_url . '/index.php?' . $config['query_var'] . '=' . $alias;
-			}
-		}
+		  {
+		    $url = $base_url . '/index.php?' . $config['query_var'] . '=' . $alias;
+		  }
 		return $url;
 	}
 
@@ -1681,34 +1808,25 @@ class ContentBase
      */
 	function HasChildren($activeonly = false)
 	{
-		if( $activeonly && !($this->Active() || $this->ShowInMenu()))
-			{
-				return false;
-			}
+	  $hm = cmsms()->GetHierarchyManager();
+	  $node = $hm->getNodeById($this->mId);
+	  if( !$node->has_children() ) return false;
+	  if( $activeonly == false) return true;
 
-		global $gCms, $sql_queries, $debug_errors;
-		$db = &$gCms->GetDb();
-		$config =& $gCms->GetConfig();
-
-		$result = false;
-
-		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE parent_id = ?";
-		$parms = array($this->mId);
-		if( $activeonly )
-			{
-				$query .= ' AND show_in_menu = 1 AND active = 1';
-			}
-
-		$row = &$db->GetRow($query, array($parms));
-
-		if ($row)
+	  $children = $node->get_children();
+	  if( $children )
+	    {
+	      for( $i = 0; $i < count($children); $i++ )
 		{
-			$result = true;
+		  $content = $children[$i]->getContent();
+		  if( $content->Active() ) return true;
 		}
+	    }
 
-		return $result;
+	  return false;
 	}
 
+
 	function GetAdditionalEditors()
 	{
 		if (!isset($this->mAdditionalEditors))
@@ -1746,10 +1864,10 @@ class ContentBase
 		$text .= '<select name="additional_editors[]" multiple="multiple" size="5">';
 
 		global $gCms;
-		$userops =& $gCms->GetUserOperations();
-		$groupops =& $gCms->GetGroupOperations();
-		$allusers =& $userops->LoadUsers();
-		$allgroups =& $groupops->LoadGroups();
+		$userops = $gCms->GetUserOperations();
+		$groupops = $gCms->GetGroupOperations();
+		$allusers = $userops->LoadUsers();
+		$allgroups = $groupops->LoadGroups();
 		if( $addteditors == '' )
 		  {
 		    $addteditors = $this->GetAdditionalEditors();
@@ -1979,7 +2097,11 @@ class ContentBase
 	  $ret = array();
 	  foreach( $attributelist as $one )
 	    {
-	      $ret[] = $this->display_single_element($one[0],$adding);
+	      $tmp = $this->display_single_element($one[0],$adding);
+	      if( is_array($tmp) )
+		{
+		  $ret[] = $tmp;
+		}
 	    }
 	  return $ret;
 	}
@@ -1988,12 +2110,12 @@ class ContentBase
 	function display_single_element($one,$adding)
 	{
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 
 	  switch( $one )
 	    {
 	    case 'cachable':
-	      return array(lang('cachable').':','<input type="hidden" name="cachable" value="0"/><input class="pagecheckbox" type="checkbox" value="1" name="cachable"'.($this->mCachable?' checked="checked"':'').' />');
+	      return array(lang('cachable').':','<input type="hidden" name="cachable" value="0"/><input class="pagecheckbox" type="checkbox" value="1" name="cachable"'.($this->mCachable?' checked="checked"':'').' />',lang('help_page_cachable'));
 	      break;
 	
 	    case 'title':
@@ -2036,13 +2158,14 @@ class ContentBase
 		$text .= '<option value="_parent"'.($this->GetPropertyValue('target')=='_parent'?' selected="selected"':'').'>_parent</option>';
 		$text .= '<option value="_self"'.($this->GetPropertyValue('target')=='_self'?' selected="selected"':'').'>_self</option>';
 		$text .= '<option value="_top"'.($this->GetPropertyValue('target')=='_top'?' selected="selected"':'').'>_top</option>';
-		return array(lang('target').':','<select name="target">'.$text.'</select>');
+		return array(lang('target').':','<select name="target">'.$text.'</select>',
+			     lang('info_target'));
 		
 	      }
 	      break;
 	      
 	    case 'alias':
-	      return array(lang('pagealias').':','<input type="text" name="alias" value="'.$this->mAlias.'" />');
+	      return array(lang('pagealias').':','<input type="text" name="alias" value="'.$this->mAlias.'" />',lang('help_page_alias'));
 	      break;
 	      
 	    case 'secure':
@@ -2058,20 +2181,35 @@ class ContentBase
 	      }
 	      break;
 
+	    case 'page_url':
+	      if( !$this->DefaultContent() )
+		{
+		  $str = '<input type="text" name="page_url" value="'.$this->mURL.'" size="50" maxlength="255"/>';
+		  $prompt = lang('page_url').':';
+		  if( get_site_preference('content_mandatory_urls',0) )
+		    {
+		      $prompt = '*'.$prompt;
+		    }
+		  return array($prompt,$str,lang('help_page_url'));
+		}
+	      break;
+
 	    case 'image':
 	      {
-		$dir = $config['image_uploads_path'];
+		$dir = cms_join_path($config['image_uploads_path'],get_site_preference('content_imagefield_path'));
 		$data = $this->GetPropertyValue('image');
 		$dropdown = create_file_dropdown('image',$dir,$data,'jpg,jpeg,png,gif','',true,'','thumb_');
+		if( !$dropdown ) return;
 		return array(lang('image').':',$dropdown);
 	      }
 	      break;
 	      
 	    case 'thumbnail':
 	      {
-		$dir = $config['image_uploads_path'];
+		$dir = cms_join_path($config['image_uploads_path'],get_site_preference('content_thumbnailfield_path'));
 		$data = $this->GetPropertyValue('thumbnail');
 		$dropdown = create_file_dropdown('thumbnail',$dir,$data,'jpg,jpeg,png,gif','',true,'','thumb_',0);
+		if( !$dropdown ) return FALSE;
 		return array(lang('thumbnail').':',$dropdown);
 	      }
 	      break;
@@ -2236,6 +2374,7 @@ class ContentProperties
 
 	function Load($content_id)
 	{
+	  if( $content_id <= 0 ) return;
 		if (count($this->mPropertyNames) > 0)
 		{
 			global $gCms, $sql_queries, $debug_errors;
@@ -2270,7 +2409,7 @@ class ContentProperties
 			global $gCms, $sql_queries, $debug_errors;
 			
 			$db        =& $gCms->GetDb();
-			$config    =& $gCms->GetConfig();
+			$config    = $gCms->GetConfig();
 			$concat    =  '';
 			$timestamp =  $db->DBTimeStamp(time());
 
