@@ -40,32 +40,26 @@ require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'class.content.inc.php');
  */
 class ContentOperations
 {
-	/**
-	 * Loads a content type into the system by it's name.
-	 *
-	 * @param string $type The content type to load
-	 * @return boolean Returns true if the content type was found and loaded
-	 */
-	function LoadContentType($type)
-	{
-		$type = strtolower($type);
+	private $_content_types;
 
+	/**
+	 * Return a content object for the currently requested page.
+	 *
+	 * @since 1.9
+	 * @return getContentObject()
+	 */
+	function &getContentObject()
+	{
 		global $gCms;
-		$contenttypes =& $gCms->contenttypes;
-		
-		if (isset($contenttypes[$type]))
+		$res = null;
+		if( isset($gCms->variables['content_obj']) && is_object($gCms->variables['content_obj']) )
 		{
-			$placeholder =& $contenttypes[$type];
-			if ($placeholder->loaded == false)
-			{
-				include_once($placeholder->filename);
-				$placeholder->loaded = true;
-			}
-			return true;
+			$res = $gCms->variables['content_obj'];
 		}
-		return false;
+		return $res;
 	}
 
+
 	/**
 	 * Given an array of content_type and seralized_content, reconstructs a 
 	 * content object.  It will handled loading the content type if it hasn't
@@ -80,29 +74,70 @@ class ContentOperations
 	  $contenttype = 'content';
 	  if( isset($data['content_type']) ) $contenttype = $data['content_type'];
 
-	  $contentobj =& ContentOperations::CreateNewContent($contenttype);
+	  $contentobj = $this->CreateNewContent($contenttype);
 	  $contentobj = unserialize($data['serialized_content']);
 	  return $contentobj;
 	}
 
+
+	/**
+	 * Load a specific content type
+	 *
+	 * This method is called from the autoloader.  There is no need to call it internally
+	 *
+	 * @internal
+	 * @final
+	 * @since 1.9
+	 * @param mixed The type.  Either a string, or an instance of CmsContentTypePlaceHolder
+	 */
+	final public function LoadContentType($type)
+	{
+		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) 
+			{
+				$type = $type->type;
+			}
+
+		$ctph = $this->_get_content_type($type);
+		if( is_object($ctph) )
+			{
+				if( !class_exists( $ctph->class ) && file_exists( $ctph->filename ) )
+					{
+						include_once( $ctph->filename );
+					}
+			}
+
+	}
+
 	/**
 	 * Creates a new, empty content object of the given type.
 	 *
+	 * if the content type is registered with the system,
+	 * and the class does not exist, the appropriate filename will be included
+	 * and then, if possible a new object of the designated type will be
+	 * instantiated.
+	 *
+	 * @param mixed The type.  Either a string, or an instance of CmsContentTypePlaceHolder
 	 * @return mixed The new content object
 	 */
 	function &CreateNewContent($type)
 	{
-		$type = strtolower($type);
-
+		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) 
+			{
+				$type = $type->type;
+			}
 		$result = NULL;
-		
-		if (ContentOperations::LoadContentType($type))
-		{
-			$result = new $type;
-		}
-		
+
+		$ctph = $this->_get_content_type($type);
+		if( is_object($ctph) )
+			{
+				if( class_exists($ctph->class) )
+					{
+						$result = new $ctph->class;
+					}
+			}
 		return $result;
 	}
+
 	
     /**
      * Given a content id, load and return the loaded content object.
@@ -113,6 +148,11 @@ class ContentOperations
      */
 	function &LoadContentFromId($id,$loadprops=false)
 	{
+		if( cms_content_cache::content_exists($id) )
+		{
+			return cms_content_cache::get_content($id);
+		}
+
 		$result = FALSE;
 
 		global $gCms;
@@ -122,28 +162,19 @@ class ContentOperations
 		$row = &$db->GetRow($query, array($id));
 		if ($row)
 		{
-			#Make sure the type exists.  If so, instantiate and load
-			if (in_array($row['type'], array_keys(ContentOperations::ListContentTypes())))
+			$classtype = strtolower($row['type']);
+			$contentobj = $this->CreateNewContent($classtype);
+			if ($contentobj)
 			{
-				$classtype = strtolower($row['type']);
-				$contentobj =& ContentOperations::CreateNewContent($classtype);
-				if ($contentobj)
-				{
-					$contentobj->LoadFromData($row, $loadprops);
-				}
+				$contentobj->LoadFromData($row, $loadprops);
+				cms_content_cache::add_content($id,$row['content_alias'],$contentobj);
 				return $contentobj;
 			}
-			else
-			{
-				return $result;
-			}
-		}
-		else
-		{
-			return $result;
 		}
+		return $result;
 	}
 
+
     /**
      * Given a content alias, load and return the loaded content object.
      *
@@ -153,11 +184,15 @@ class ContentOperations
      */
 	function &LoadContentFromAlias($alias, $only_active = false)
 	{
+		if( cms_content_cache::content_exists($alias) )
+		{
+			return cms_content_cache::get_content($alias);
+		}
+
 		global $gCms;
-		$db = &$gCms->GetDb();
+		$db = $gCms->GetDb();
 
 		$row = '';
-
 		if (is_numeric($alias) && strpos($alias,'.') === FALSE && strpos($alias,',') === FALSE) //Fix for postgres
 		{
 			$query = "SELECT * FROM ".cms_db_prefix()."content WHERE content_id = ?";
@@ -180,11 +215,12 @@ class ContentOperations
 		if ($row)
 		{
 			#Make sure the type exists.  If so, instantiate and load
-			if (in_array($row['type'], array_keys(ContentOperations::ListContentTypes())))
+			if (in_array($row['type'], array_keys($this->ListContentTypes())))
 			{
 				$classtype = strtolower($row['type']);
-				$contentobj =& ContentOperations::CreateNewContent($classtype);
+				$contentobj = $this->CreateNewContent($classtype);
 				$contentobj->LoadFromData($row, TRUE);
+				cms_content_cache::add_content($row['content_id'],$row['content_alias'],$contentobj);
 				return $contentobj;
 			}
 			else
@@ -198,219 +234,20 @@ class ContentOperations
 		}
 	}
 
-     /**
-      * Load the content of the object from a list of ids
-      * Private method.
-      *
-      * @access private
-      * @param array $ids List of of element ids to load
-      * @param boolean $loadProperties Whether or not to load the properties
-      * @return array Array of content objects (empty if not found)
-      */
-	function &LoadMultipleFromId($ids, $loadProperties = false)
-	{
-		global $gCms, $sql_queries, $debug_errors;
-		$cpt = count($ids);
-		$contents=array();
-		if ($cpt==0) 
-		{
-			return $contents;
-		}
-		$config = &$gCms->GetConfig();
-		$db = &$gCms->GetDb();
-		$id_list = '(';
-		for ($i=0;$i<$cpt;$i++) 
-		{
-			$id_list .= (int)$ids[$i];
-			if ($i<$cpt-1)
-			{
-				$id_list .= ',';
-			}
-		}
-		$id_list .= ')';
-		if ($id_list=='()') 
-		{
-		  return $contents;
-		}
-		$result = false;
-		$query  = "SELECT * FROM ".cms_db_prefix()."content WHERE content_id IN $id_list";
-		$rows   =& $db->Execute($query);
-
-		if ($rows)
-		{
-			while (isset($rows) && $row = &$rows->FetchRow())
-			{
-				if (in_array($row['type'], array_keys(ContentOperations::ListContentTypes()))) 
-				{
-					$classtype = strtolower($row['type']);
-					$contentobj =& ContentOperations::CreateNewContent($classtype);
-					$contentobj->LoadFromData($row,false);
-					$contents[]=$contentobj;
-					$result = true;
-				}
-			}
-			$rows->Close();
-		}
-		if (!$result)
-		{
-			if (true == $config["debug"])
-			{
-				# :TODO: Translate the error message
-				$debug_errors .= "<p>Could not retrieve content from db</p>\n";
-			}
-		}
-
-		if ($result && $loadProperties)
-		{
-			foreach ($contents as $content) 
-			{
-				if ($content->mPropertiesLoaded == false)
-				{
-					debug_buffer("load from id is loading properties");
-					$content->mProperties->Load($content->mId);
-					$content->mPropertiesLoaded = true;
-				}
-
-				if (NULL == $content->mProperties)
-				{
-					$result = false;
-
-					# debug mode
-					if (true == $config["debug"])
-					{
-						# :TODO: Translate the error message
-						$debug_errors .= "<p>Could not load properties for content</p>\n";
-					}
-				}
-			}
-		}
-
-		foreach ($contents as $content) 
-		{
-			$content->Load();
-		}
-
-		return $contents;
-	}
-	
-    /**
-    * Load the content of the object from a list of content aliases.
-    * Private method.
-    *
-    * @access private
-    * @param array $ids List of of content aliases to load
-    * @param boolean $loadProperties Whether or not to load the properties
-    * @return array Array of content objects (empty if not found)
-     */
-	function &LoadMultipleFromAlias($ids, $loadProperties = false)
-	{
-		global $gCms, $sql_queries, $debug_errors;
-		$contents=array();
-		if (!is_array($ids) || count($ids) == 0)
-		{
-			return $contents;
-		}
-		$db = &$gCms->GetDb();
-		$config =& $gCms->GetConfig();
-
-		$param_qs = array();
-		for ($i=0; $i<count($ids); $i++) 
-		{
-			$param_qs[] = '?';
-		}
-
-		$result = false;
-		$query  = "SELECT * FROM ".cms_db_prefix()."content WHERE content_alias IN " . join(', ', $param_qs);
-		$rows   =& $db->Execute($query, $ids);
-
-		while (isset($rows) && $row=&$rows->FetchRow())
-		{
-			#Make sure the type exists.  If so, instantiate and load
-			if (in_array($row['type'], array_keys(ContentOperations::ListContentTypes()))) 
-			{
-				$classtype = strtolower($row['type']);
-				$contentobj =& ContentOperations::CreateNewContent($classtype);
-				$contentobj->LoadFromData($row,false);
-				$contents[] =& $contentobj;
-				$result = true;
-			}
-		}
-
-		if ($rows) $rows->Close();
-
-		if (!$result)
-		{
-			if (true == $config["debug"])
-			{
-				# :TODO: Translate the error message
-				$debug_errors .= "<p>Could not retrieve content from db</p>\n";
-			}
-		}
-
-		if ($result && $loadProperties)
-		{
-			foreach ($contents as $content) 
-			{
-				if ($content->mPropertiesLoaded == false)
-				{
-					debug_buffer("load from id is loading properties");
-					$content->mProperties->Load($content->mId);
-					$content->mPropertiesLoaded = true;
-				}
-
-				if (NULL == $content->mProperties)
-				{
-					$result = false;
-
-					# debug mode
-					if (true == $config["debug"])
-					{
-						# :TODO: Translate the error message
-						$debug_errors .= "<p>Could not load properties for content</p>\n";
-					}
-				}
-			}
-		}
-		foreach ($contents as $content) 
-		{
-			$content->Load();
-		}
-		return $contents;
-	}
-
-
-	/**
-	 * Displays the content of the given content object
-	 *
-	 * @param mixed $content Content object
-	 * @return void
-	 */
-	function DisplayContent($content)
-	{
-		//This should be straight forward, since the content will pretty much determine how it is displayed
-		$content->Show();
-	}
-
-	/**
-	 * @ignore
-	 */
-    function IsCached($id)
-    {
-    }
 
 	/**
 	 * Returns the id of the content marked as default.
 	 *
 	 * @return integer The id of the default content page
 	 */
-	function & GetDefaultContent()
+	function GetDefaultContent()
 	{
 	  global $gCms;
 	  if( isset($gCms->variables['default_content_id']) )
 	    {
 	      return $gCms->variables['default_content_id'];
 	    }
-		$db =& $gCms->GetDb();
+		$db = $gCms->GetDb();
 
 		$result = -1;
 
@@ -435,39 +272,139 @@ class ContentOperations
 		return $result;
 	}
 
+
+	/**
+	 * Load standard CMS content types
+	 *
+	 * This internal method looks through the contenttypes directory
+	 * and loads the placeholders for them.
+	 *
+	 * @since 1.9
+	 * @access private
+	 * @internal
+	 */
+	private function _load_std_content_types()
+	{
+		if (isset(cmsms()->variables['contenttypes'])) 
+		{
+			return;
+		}
+
+		$result = array();
+		$dir = dirname(__FILE__).'/contenttypes';
+		$files = glob($dir.'/*.inc.php');
+		if( is_array($files) )
+		{
+			foreach( $files as $one )
+			{
+				$obj = new CmsContentTypePlaceHolder();
+				$class = basename($one,'.inc.php');
+				$type  = strtolower($class);
+
+				$obj->class = $class;
+				$obj->type = strtolower($class);
+				$obj->filename = $one;
+				$obj->loaded = false;
+				if( $obj->type == 'link' )
+					{
+						// cough... big hack... cough.
+						$obj->friendlyname_key = 'contenttype_redirlink';
+					}
+				else
+					{
+						$obj->friendlyname_key = 'contenttype_'.$obj->type;
+					}
+				//$obj->friendlyname = $class;
+				$result[$type] = $obj;
+			}
+		}
+
+		cmsms()->variables['contenttypes'] = $result;
+	}
+
+
+	/**
+	 * Function to return a content type given it's name
+	 *
+	 * @since 1.9
+	 * @access private
+	 * @internal
+	 * @param string The content type name
+	 * @return CmsContentTypePlaceHolder placeholder object.
+	 */
+	private function _get_content_type($name)
+	{
+		$name = strtolower($name);
+		$this->_load_std_content_types();
+		$types = cmsms()->variables['contenttypes'];
+		if( is_array($types) )
+		{
+			foreach( $types as $key => $obj )
+			{
+				if( $key == $name && $obj instanceof CmsContentTypePlaceHolder )
+					{
+						return $obj;
+					}
+			}
+		}
+	}
+
+
+	/**
+	 * Register a new content type
+	 *
+	 * @since 1.9
+	 * @param CmsContentTypePlaceHolder Reference to placeholder object
+	 */
+	public function register_content_type(CmsContentTypePlaceHolder& $obj)
+	{
+		$this->_load_std_content_types();
+		$types = cmsms()->variables['contenttypes'];
+		if( isset($types[$obj->type]) ) return;
+
+		$types[$obj->type] = $obj;
+		cmsms()->variables['contenttypes'] = $types;
+	}
+
+
+
 	/**
      * Returns a hash of valid content types (classes that extend ContentBase)
-     * The key is the name of the class that would be saved into the dabase.  The
+     * The key is the name of the class that would be saved into the database.  The
      * value would be the text returned by the type's FriendlyName() method.
 	 *
-	 * @return array Lost of content types registerd in the system.
+	 * @param boolean optionally return keys as class names.
+	 * @return array List of content types registered in the system.
 	 */
-	function &ListContentTypes()
+	function ListContentTypes($byclassname = false)
 	{
-		global $gCms;
-		$contenttypes =& $gCms->contenttypes;
-		
-		if (isset($gCms->variables['contenttypes']))
+		$this->_load_std_content_types();
+		$types = cmsms()->variables['contenttypes'];
+		if ( isset($types) )
 		{
-			$variables =& $gCms->variables;
-			return $variables['contenttypes'];
+			$result = array();
+			foreach( $types as $obj )
+				{
+					global $CMS_ADMIN_PAGE;
+					if( !isset($obj->friendlyname) && isset($obj->friendlyname_key) && isset($CMS_ADMIN_PAGE) )
+						{
+							$txt = lang($obj->friendlyname_key); 
+							$obj->friendlyname = $txt;
+						}
+					if( $byclassname )
+						{
+							$result[$obj->class] = $obj->friendlyname;
+						}
+					else
+						{
+							$result[$obj->type] = $obj->friendlyname;
+						}
+				}
+			return $result;
 		}
-		
-		$result = array();
-		
-		reset($contenttypes);
-		while (list($key) = each($contenttypes))
-		{
-			$value =& $contenttypes[$key];
-			$result[] = $value->type;
-		}
-		
-		$variables =& $gCms->variables;
-		$variables['contenttypes'] =& $result;
-
-		return $result;
 	}
 
+
     /**
      * Updates the hierarchy position of one item
 	 *
@@ -477,7 +414,7 @@ class ContentOperations
 	function SetHierarchyPosition($contentid)
 	{
 		global $gCms;
-		$db =& $gCms->GetDb();
+		$db = $gCms->GetDb();
 
 		$current_hierarchy_position = '';
 		$current_id_hierarchy_position = '';
@@ -523,8 +460,11 @@ class ContentOperations
 
 		$query = "UPDATE ".cms_db_prefix()."content SET hierarchy = ?, id_hierarchy = ?, hierarchy_path = ?, prop_names = ? WHERE content_id = ?";
 		$db->Execute($query, array($current_hierarchy_position, $current_id_hierarchy_position, $current_hierarchy_path, implode(',', $prop_name_array), $contentid));
+
+		cms_content_cache::clear();
 	}
 
+
 	/**
 	 * Updates the hierarchy position of all items
 	 *
@@ -540,12 +480,14 @@ class ContentOperations
 
 		while ($dbresult && !$dbresult->EOF)
 		{
-			ContentOperations::SetHierarchyPosition($dbresult->fields['content_id']);
+		    $this->SetHierarchyPosition($dbresult->fields['content_id']);
 			$dbresult->MoveNext();
 		}
 		
 		if ($dbresult) $dbresult->Close();
+		cms_content_cache::clear();
 	}
+
 	
 	/**
 	 * Loads a set of content objects into the cached tree.
@@ -556,112 +498,114 @@ class ContentOperations
 	 *                             don't load the content objects
 	 * @return mixed The cached tree of content
 	 */
-	function &GetAllContentAsHierarchy($loadprops, $onlyexpanded=null, $loadcontent = false)
+	function &GetAllContentAsHierarchy($loadcontent = false)
 	{
 		debug_buffer('', 'starting tree');
 
-		require_once(dirname(dirname(__FILE__)).'/Tree/Tree.php');
-
-		$nodes = array();
 		global $gCms;
 		$db = &$gCms->GetDb();
-
+		$tree = null;
 		$cachefilename = TMP_CACHE_LOCATION . '/contentcache.php';
-		$usecache = true;
-		if (isset($onlyexpanded) || isset($CMS_ADMIN_PAGE))
-		{
-			#$usecache = false;
-		}
-
 		$loadedcache = false;
 
-		if ($usecache)
+		if (isset($gCms->variables['pageinfo']) && file_exists($cachefilename))
 		{
-			if (isset($gCms->variables['pageinfo']) && file_exists($cachefilename))
+			if( !isset($gCms->variables['last_content_modification']) )
 			{
-				$pageinfo =& $gCms->variables['pageinfo'];
-				//debug_buffer('content cache file exists... file: ' . filemtime($cachefilename) . ' content:' . $pageinfo->content_last_modified_date);
-				if (isset($pageinfo->content_last_modified_date) && $pageinfo->content_last_modified_date < filemtime($cachefilename))
+				$query = 'SELECT UNIX_TIMESTAMP(modified_date) FROM '.cms_db_prefix().'content ORDER BY modified_date DESC';
+				$gCms->variables['last_content_modification'] = $db->GetOne($query);
+			}
+			$last_modified = $gCms->variables['last_content_modification'];
+			if ($last_modified > 0 && $last_modified < filemtime($cachefilename))
+			{
+				debug_buffer('file needs loading');
+				
+				$handle = fopen($cachefilename, "r");
+				$data = fread($handle, filesize($cachefilename));
+				fclose($handle);
+				
+				$tree = unserialize(substr($data, 16));
+				
+				if (strtolower(get_class($tree)) == 'cms_content_tree')
 				{
-					debug_buffer('file needs loading');
-
-					$handle = fopen($cachefilename, "r");
-					$data = fread($handle, filesize($cachefilename));
-					fclose($handle);
-
-					$tree = unserialize(substr($data, 16));
-
-					#$variables =& $gCms->variables;
-					#$variables['contentcache'] =& $tree;
-					if (strtolower(get_class($tree)) == 'tree')
-					{
-						$loadedcache = true;
-					}
-					else
-					{
-						$loadedcache = false;
-					}
+					$loadedcache = true;
+				}
+				else
+				{
+					die('problem loading cache');
+					$loadedcache = false;
 				}
 			}
 		}
 
 		if (!$loadedcache)
 		{
-			$query = "SELECT id_hierarchy FROM ".cms_db_prefix()."content ORDER BY hierarchy";
-			$dbresult =& $db->Execute($query);
-
+			$query = "SELECT id_hierarchy,content_alias FROM ".cms_db_prefix()."content ORDER BY hierarchy";
+			$dbresult = $db->Execute($query);
+			$nodes = array();
 			if ($dbresult && $dbresult->RecordCount() > 0)
 			{
 				while ($row = $dbresult->FetchRow())
 				{
-					$nodes[] = $row['id_hierarchy'];
+					$nodes[] = $row['id_hierarchy'].','.$row['content_alias'];
 				}
+				$dbresult->Close();
 			}
 
-			$tree = new Tree();
 			debug_buffer('', 'Start Loading Children into Tree');
-			$tree = Tree::createFromList($nodes, '.');
+			$tree = cms_tree_operations::load_from_list($nodes);
 			debug_buffer('', 'End Loading Children into Tree');
 		}
 
-		if (!$loadedcache && $usecache)
+		if (!$loadedcache)
 		{
 			debug_buffer("Serializing...");
-			$handle = fopen($cachefilename, "w");
-			fwrite($handle, '<?php return; ?>'.serialize($tree));
-			fclose($handle);
+			@file_put_contents($cachefilename, '<?php return; ?>'.serialize($tree));
 		}
 
 		if( $loadcontent )
 		  {
-		    ContentOperations::LoadChildrenIntoTree(-1, $tree, false, true);
+		    $this->LoadChildren(-1, true, true);
 		  }
 
 		debug_buffer('', 'ending tree');
 
 		return $tree;
 	}
+
 	
 	/**
 	 * Loads additional, active children into a given tree object
 	 *
 	 * @param integer $id The parent of the content objects to load into the tree
-	 * @param mixed $tree The passed tree object (reference)
 	 * @param boolean $loadprops If true, load the properties of all loaded content objects
 	 * @param boolean $all If true, load all content objects, even inactive ones.
 	 * @return void
 	 * @author Ted Kulp
 	 */
-	function LoadChildrenIntoTree($id, &$tree, $loadprops = false, $all = false)
+	function LoadChildren($id, $loadprops = false, $all = false, $explicit_ids = array() )
 	{	
 		global $gCms;
-		$db = &$gCms->GetDb();
+		$db = $gCms->GetDb();
 
-		// get the content rows
-		$query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? AND active = 1 ORDER BY hierarchy";
-		if( $all )
-		  $query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? ORDER BY hierarchy";
-		$contentrows =& $db->GetArray($query, array($id));
+		$contentrows = '';
+		if( is_array($explicit_ids) && count($explicit_ids) )
+		{
+			$expr = 'content_id IN ('.implode(',',$explicit_ids).')';
+			if( !$all ) $expr .= ' AND active = 1';
+
+			$query = 'SELECT * FROM '.cms_db_prefix().'content WHERE '.$expr.' ORDER BY hierarchy';
+			$contentrows = $db->GetArray($query);
+		}
+		else 
+		{
+			if( !$id ) { $id = -1; }
+			// get the content rows
+			$query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? AND active = 1 ORDER BY hierarchy";
+			if( $all )
+				$query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? ORDER BY hierarchy";
+			$contentrows = $db->GetArray($query, array($id));
+		}
 		$contentprops = '';
 
 		// get the content ids from the returned data
@@ -670,64 +614,66 @@ class ContentOperations
 		    $child_ids = array();
 		    for( $i = 0; $i < count($contentrows); $i++ )
 		      {
-			$child_ids[] = $contentrows[$i]['content_id'];
+				  $child_ids[] = $contentrows[$i]['content_id'];
 		      }
 		    
 		    // get all the properties for the child_ids
 		    $query = 'SELECT * FROM '.cms_db_prefix().'content_props WHERE content_id IN ('.implode(',',$child_ids).') ORDER BY content_id';
-		    $tmp =& $db->GetArray($query);
+		    $tmp = $db->GetArray($query);
 
 		    // re-organize the tmp data into a hash of arrays of properties for each content id.
 		    if( $tmp )
 		      {
-			$contentprops = array();
-			for( $i = 0; $i < count($contentrows); $i++ )
-			  {
-			    $content_id = $contentrows[$i]['content_id'];
-			    $t2 = array();
-			    for( $j = 0; $j < count($tmp); $j++ )
-			      {
-				if( $tmp[$j]['content_id'] == $content_id )
-				  {
-				    $t2[] = $tmp[$j];
-				  }
-			      }
-			    $contentprops[$content_id] = $t2;
-			  }
+				  $contentprops = array();
+				  for( $i = 0; $i < count($contentrows); $i++ )
+					  {
+						  $content_id = $contentrows[$i]['content_id'];
+						  $t2 = array();
+						  for( $j = 0; $j < count($tmp); $j++ )
+							  {
+								  if( $tmp[$j]['content_id'] == $content_id )
+									  {
+										  $t2[] = $tmp[$j];
+									  }
+							  }
+						  $contentprops[$content_id] = $t2;
+					  }
 		      }
 		  }
 		
+
 		// build the content objects
 		for( $i = 0; $i < count($contentrows); $i++ )
 		  {
-		    $row =& $contentrows[$i];
+		    $row = $contentrows[$i];
 		    $id = $row['content_id'];
 
-		    if (!in_array($row['type'], array_keys(ContentOperations::ListContentTypes()))) continue;
-		    $contentobj =& ContentOperations::CreateNewContent($row['type']);
+		    if (!in_array($row['type'], array_keys($this->ListContentTypes()))) continue;
+
+		    $contentobj = $this->CreateNewContent($row['type']);
+
 		    if ($contentobj)
 		      {
-			$contentobj->LoadFromData($row, false);
-			if( $loadprops && $contentprops && isset($contentprops[$id]) )
-			  {
-			    // load the properties from local cache.
-			    $props =& $contentprops[$id];
-			    $obj =& $contentobj->mProperties;
-			    $obj->mPropertyNames = array();
-			    $obj->mPropertyTypes = array();
-			    $obj->mPropertyValues = array();
-			    foreach( $props as $oneprop )
-			      {
-				$obj->mPropertyNames[] = $oneprop['prop_name'];
-				$obj->mPropertyTypes[$oneprop['prop_name']] = $oneprop['type'];
-				$obj->mPropertyValues[$oneprop['prop_name']] = $oneprop['content'];
-			      }
-			    $contentobj->mPropertiesLoaded = true;
-			  }
-
-			// cache the content objects
-			$contentcache =& $tree->content;
-			$contentcache[$id] =& $contentobj;
+				  $contentobj->LoadFromData($row, false);
+				  if( $loadprops && $contentprops && isset($contentprops[$id]) )
+					  {
+						  // load the properties from local cache.
+						  $props =& $contentprops[$id];
+						  $obj =& $contentobj->mProperties;
+						  $obj->mPropertyNames = array();
+						  $obj->mPropertyTypes = array();
+						  $obj->mPropertyValues = array();
+						  foreach( $props as $oneprop )
+							  {
+								  $obj->mPropertyNames[] = $oneprop['prop_name'];
+								  $obj->mPropertyTypes[$oneprop['prop_name']] = $oneprop['type'];
+								  $obj->mPropertyValues[$oneprop['prop_name']] = $oneprop['content'];
+							  }
+						  $contentobj->mPropertiesLoaded = true;
+					  }
+				  
+				  // cache the content objects
+				  cms_content_cache::add_content($id,$contentobj->Alias(),$contentobj);
 		      }
 		  }
 	}
@@ -759,6 +705,7 @@ class ContentOperations
 		$one->Save();
 	}
 
+
 	/**
 	 * Returns an array of all content objects in the system, active or not.
 	 *
@@ -770,54 +717,22 @@ class ContentOperations
 		debug_buffer('get all content...');
 
 		global $gCms;
+		$tree = $gCms->GetHierarchyManager();
+		$list = $tree->getFlatList();
 
-		$contentcache = array();
-
-		$db = &$gCms->GetDb();
-		$query = "SELECT * FROM ".cms_db_prefix()."content ORDER BY hierarchy";
-		$dbresult = &$db->Execute($query);
-
-		$map = array();
-		$count = 0;
-
-		while ($dbresult && !$dbresult->EOF)
+		$output = array();
+		foreach( $list as &$one )
 		{
-			#Make sure the type exists.  If so, instantiate and load
-			if (in_array($dbresult->fields['type'], array_keys(ContentOperations::ListContentTypes())))
-			{
-				$contentobj =& ContentOperations::CreateNewContent($dbresult->fields['type']);
-				if (isset($contentobj))
-				{
-					$tmp = $dbresult->FetchRow();
-					$contentobj->LoadFromData($tmp, false);
-					$map[$contentobj->Id()] = $count;
-					$contentcache[] = $contentobj;
-					$count++;
-				}
-				else
-				{
-					$dbresult->MoveNext();
-				}
-			}
-			else
-			{
-				$dbresult->MoveNext();
-			}
+			$tmp = $one->GetContent();
+			if( is_object($tmp) )
+				$output[] = $tmp;
 		}
 
-		if ($dbresult) $dbresult->Close();
-
-		for ($i=0;$i<$count;$i++)
-		{
-			if ($contentcache[$i]->ParentId() != -1 && isset($map[$contentcache[$i]->ParentId()]))
-			{
-				$contentcache[$map[$contentcache[$i]->ParentId()]]->mChildCount++;
-			}
-		}
-
-		return $contentcache;
+		debug_buffer('end get all content...');
+		return $output;
 	}
 
+
 	/**
 	 * Create a hierarchical ordered dropdown of all the content objects in the system for use
 	 * in the admin and various modules.  If $current or $parent variables are passed, care is taken
@@ -840,7 +755,7 @@ class ContentOperations
 		$result = '';
 		$userid = -1;
 
-		$allcontent =& ContentOperations::GetAllContent();
+		$allcontent = $this->GetAllContent(false);
 
 		if ($allcontent !== FALSE && count($allcontent) > 0)
 		{
@@ -858,6 +773,7 @@ class ContentOperations
 
 			foreach ($allcontent as $one)
  			{
+				if( !is_object($one) ) continue;
 			  $value = $one->Id();
 			  if ($value == $current)
 			    {
@@ -932,6 +848,7 @@ class ContentOperations
 		return $result;
 	}
 
+
 	/**
 	 * Gets the content id of the page marked as default
 	 *
@@ -939,25 +856,10 @@ class ContentOperations
 	 */
 	function GetDefaultPageID()
 	{
-	  
-	  global $gCms;
-	  if( isset($gCms->variables['default_content_id']) )
-	    {
-	      return $gCms->variables['default_content_id'];
-	    }
-
-		$db = &$gCms->GetDb();
-
-		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE default_content = 1";
-		$row = &$db->GetRow($query);
-		if (!$row)
-		{
-			return false;
-		}
-		$gCms->variables['default_content_id'] = $row['content_id'];
-		return $row['content_id'];
+		return $this->GetDefaultContent();
 	}
 
+
 	/**
 	 * Returns the content id given a valid content alias.
 	 *
@@ -966,6 +868,9 @@ class ContentOperations
 	 */
 	function GetPageIDFromAlias( $alias )
 	{
+		$res = cms_content_cache::get_id_from_alias($alias);
+		if( $res !== FALSE ) return $res;
+
 		global $gCms;
 		$db = &$gCms->GetDb();
 
@@ -985,6 +890,7 @@ class ContentOperations
 		
 		return $row['content_id'];
 	}
+
 	
 	/**
 	 * Returns the content id given a valid hierarchical position.
@@ -998,7 +904,7 @@ class ContentOperations
 		$db = &$gCms->GetDb();
 
 		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE hierarchy = ?";
-		$row = $db->GetRow($query, array(ContentOperations::CreateUnfriendlyHierarchyPosition($position)));
+		$row = $db->GetRow($query, array($this->CreateUnfriendlyHierarchyPosition($position)));
 
 		if (!$row)
 		{
@@ -1007,6 +913,7 @@ class ContentOperations
 		return $row['content_id'];
 	}
 
+
 	/**
 	 * Returns the content alias given a valid content id.
 	 *
@@ -1015,6 +922,9 @@ class ContentOperations
 	 */
 	function GetPageAliasFromID( $id )
 	{
+		$res = cms_content_cache::get_alias_from_id($id);
+		if( $res !== FALSE ) return $res;
+
 		global $gCms;
 		$db = &$gCms->GetDb();
 
@@ -1034,6 +944,7 @@ class ContentOperations
 		return $row['content_alias'];
 	}
 
+
 	/**
 	 * Checks to see if a content alias is valid and not in use.
 	 *
@@ -1084,8 +995,10 @@ class ContentOperations
 	function ClearCache()
 	{
 		global $gCms;
-		$smarty =& $gCms->GetSmarty();
+		$smarty = $gCms->GetSmarty();
 
+		cms_content_cache::clear();
+		unset($gCms->hrinstance);
 		$smarty->clear_all_cache();
 		$smarty->clear_compiled_tpl();
 
@@ -1140,7 +1053,32 @@ class ContentOperations
 		$tmp = rtrim($tmp, '.');
 		return $tmp;
 	}
-	
+
+
+	/**
+	 * Grab URLs from the content table and register them with the route manager.
+	 *
+	 * @since 1.9
+	 * @author Robert Campbell <calguy1000@hotmail.com>
+	 * @internal
+	 */
+	public function register_routes()
+	{
+ 		global $gCms;
+ 		$db = $gCms->GetDb();
+
+		$query = 'SELECT content_id,page_url FROM '.cms_db_prefix().'content
+                   WHERE active = 1 AND default_content = 0 AND page_url != \'\'';
+		$data = $db->GetArray($query);
+ 		if( is_array($data) )
+ 		{
+ 			foreach( $data as $onerow )
+ 			{
+ 				$route = new CmsRoute($onerow['page_url'],$onerow['content_id'],'',TRUE);
+				cms_route_manager::register($route);
+			}
+		}
+	}
 }
 
 /**
