@@ -103,6 +103,9 @@ class Events
 	 */
 	static public function SendEvent( $modulename, $eventname, $params = array() )
 	{
+		global $CMS_INSTALL_PAGE;
+		if( isset($CMS_INSTALL_PAGE) ) return;
+
 		global $gCms;
 		$usertagops =& $gCms->GetUserTagOperations();
 
@@ -202,6 +205,10 @@ class Events
 		$db = &$gCms->GetDb();
 
 		$q = "SELECT * FROM ".cms_db_prefix()."events ORDER BY originator,event_name";
+		$q = 'SELECT e.*, count(eh.event_id) as usage_count FROM '.cms_db_prefix().
+			'events e left outer join '.cms_db_prefix().
+			'event_handlers eh on e.event_id=eh.event_id GROUP BY e.event_id ORDER BY originator,event_name';
+		
 		$dbresult = $db->Execute( $q );
 		if( $dbresult == false )
 		{
@@ -433,7 +440,7 @@ class Events
 	 * @return string Returns the description string for the event.  Empty string if nothing
 	 *                is found.
 	 */
-	function GetEventDescription($eventname)
+	static public function GetEventDescription($eventname)
 	{
 		return lang('event_desc_'.strtolower($eventname));
 	}
@@ -519,4 +526,4 @@ class Events
 
 } // class
 # vim:ts=4 sw=4 noet
-?>
\ No newline at end of file
+?>
