@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: class.global.inc.php 6433 2010-07-02 02:59:39Z calguy1000 $
+#$Id: class.global.inc.php 6916 2011-02-28 17:24:26Z calguy1000 $
 
 /**
  * Global class for easy access to all important variables.
@@ -34,6 +34,9 @@
  * @package CMS
  * @since 0.5
  */
+
+require_once(dirname(__FILE__).'/class.cms_variables.php');
+
 class CmsObject {
 
 	/**
@@ -56,7 +59,7 @@ class CmsObject {
 
 	/**
 	 * Modules object - holds references to all registered modules
-	 *	@access private
+	 * @access private
 	 */
 	var $cmsmodules;
 
@@ -68,13 +71,13 @@ class CmsObject {
 
 	/**
 	 * Plugins object - holds list of all registered plugins 
-	 *	@access private
+	 * @access private
 	 */
 	var $cmsplugins;
 
 	/**
 	 * User Plugins object - holds list and function pointers of all registered user plugins
-	 *	@access private
+	 * @access private
 	 */
 	var $userplugins;
 
@@ -138,10 +141,19 @@ class CmsObject {
 	 */
 	var $contenttypes;
 
+	/**
+	 * module list - list of installed and available modules.
+	 * includes references to the module objects.
+	 *
+	 * @access private
+	 */
+	var $modules;
+
+
 	/**
 	 * Constructor
 	 */
-	function CmsObject()
+	public function CmsObject()
 	{
 		$this->cmssystemmodules = 
 		  array( 'FileManager','nuSOAP', 'MenuManager', 'ModuleManager', 'Search', 'CMSMailer', 'News', 'TinyMCE', 'Printing', 'ThemeManager' );
@@ -151,6 +163,7 @@ class CmsObject {
 		$this->contenttypes = array();
 		$this->TemplateCache = array();
 		$this->StylesheetCache = array();
+		$this->variables = cms_variables::get_instance();
 		$this->variables['content-type'] = 'text/html';
 		$this->variables['modulenum'] = 1;
 		$this->variables['routes'] = array();
@@ -165,6 +178,127 @@ class CmsObject {
 		register_shutdown_function(array(&$this, 'dbshutdown'));
 	}
 
+
+	/**
+	 * Retrieve the list of errors
+	 *
+	 * @since 1.9
+	 * @internal
+	 * return array
+	 */
+	public function get_errors()
+	{
+		return $this->errors;
+	}
+
+
+	/**
+	 * Add an error to the list
+	 *
+	 * @since 1.9
+	 * @internal
+	 * @param string The error message.
+	 */
+	public function add_error($str)
+	{
+		if( !is_array($this->errors) ) $this->errors = array();
+		$this->errors[] = $str;
+	}
+
+
+	/**
+	 * Retrieve the value of an internal variable.
+	 *
+	 * @internal
+	 * @since 1.9
+	 * @param string The variable name to get
+	 * @return mixed The value of the internal variable, or null.
+	 */
+	public function get_variable($key)
+	{
+		if( $key != '' && isset($this->variables[$key]) )
+		{
+			return $this->variables[$key];
+		}
+	}
+
+	
+	/**
+	 * Set a variable
+	 *
+	 * Set a variable for later usage.
+	 *
+	 * @internal
+	 * @since 1.9
+	 * @param string The variable name to set
+	 * @param mixed  The value
+	 */
+	public function set_variable($key,$value)
+	{
+		$this->variables[$key] = $value;
+	}
+
+
+	/**
+	 * Get a list of all installed and available modules
+	 *
+	 * This method will return an array of module names that are installed, loaded and ready for use.
+	 * suotable for iteration with GetModuleInstance
+	 *
+	 * @see CmsObject::GetModuleInstance()
+	 * @since 1.9
+	 * @return array
+	 */
+	public function GetAvailableModules()
+	{
+		$results = array();
+		foreach( $this->modules as $module_name => &$data )
+		{
+			if( isset($data['installed']) && $data['installed'] &&
+				isset($data['object']) && is_object($data['object']) )
+			{
+				$results[] = $module_name;
+			}
+		}
+		return $results;
+	}
+
+
+	/**
+	 * Get a reference to an installed module instance.
+	 *
+	 * This method will return a reference to the module object specified if it is installed, and available.
+	 * Optionally, a version check can be performed to test if the version of the requeted module matches
+	 * that specified.
+	 *
+	 * @since 1.9
+	 * @param string Module Name.
+	 * @param string (optional) version number for a check.  
+	 * @return object Reference to the module object, or null.
+	 */
+	public function & GetModuleInstance($module_name,$version = '')
+	{
+		if( empty($module_name) && isset($this->variables['module']))
+			{
+				$module_name = $this->variables['module'];
+			}
+
+		$obj = null;
+		if( isset($this->modules[$module_name]) &&
+			isset($this->modules[$module_name]['object']) )
+			{
+				$obj = $this->modules[$module_name]['object'];
+			}
+		if( is_object($obj) && !empty($version) )
+			{
+				$res = version_compare($obj->GetVersion,$version);
+				if( $res < 1 OR $res === FALSE ) 
+					$obj = null;
+			}
+		return $obj;
+	}
+
+
 	/**
 	* Get a handle to the ADODB database object. You can then use this
 	* to perform all kinds of database operations.
@@ -173,7 +307,7 @@ class CmsObject {
 	* @final
 	* @return ADOConnection a handle to the ADODB database object
 	*/
-	function & GetDb()
+	public function & GetDb()
 	{
 		global $DONT_LOAD_DB;
 
@@ -195,14 +329,12 @@ class CmsObject {
 	* @final
 	* @return mixed an associative array of configuration values
 	*/
-	function & GetConfig()
+	public function GetConfig()
 	{
-        if (!isset($this->config))
+		if( !$this->config )
 		{
-			$configinstance = cms_config_load(true);
-			$this->config = &$configinstance;
+			$this->config = cms_config::get_instance();
 		}
-
 		return $this->config;
 	}
 	
@@ -214,7 +346,7 @@ class CmsObject {
 	* @see ModuleLoader
 	* @return ModuleLoader handle to the ModuleLoader object
 	*/
-	function & GetModuleLoader()
+	public function & GetModuleLoader()
 	{
         if (!isset($this->moduleloader))
 		{
@@ -234,7 +366,7 @@ class CmsObject {
 	* @see ModuleOperations
 	* @return ModuleOperations handle to the ModuleOperations object
 	*/
-	function & GetModuleOperations()
+	public function & GetModuleOperations()
 	{
         if (!isset($this->moduleoperations))
 		{
@@ -254,7 +386,7 @@ class CmsObject {
 	* @see UserOperations
 	* @return UserOperations handle to the UserOperations object
 	*/
-	function & GetUserOperations()
+	public function & GetUserOperations()
 	{
         if (!isset($this->useroperations))
 		{
@@ -276,7 +408,7 @@ class CmsObject {
 	* @see ContentOperations
 	* @return ContentOperations handle to the ContentOperations object
 	*/
-	function & GetContentOperations()
+	public function & GetContentOperations()
 	{
         if (!isset($this->contentoperations))
 		{
@@ -298,7 +430,7 @@ class CmsObject {
 	* @see BookmarkOperations
 	* @return BookmarkOperations handle to the BookmarkOperations object, useful only in the admin
 	*/	
-	function & GetBookmarkOperations()
+	public function & GetBookmarkOperations()
 	{
         if (!isset($this->bookmarkoperations))
 		{
@@ -318,7 +450,7 @@ class CmsObject {
 	* @see TemplateOperations
 	* @return TemplateOperations handle to the TemplateOperations object
 	*/
-	function & GetTemplateOperations()
+	public function & GetTemplateOperations()
 	{
         if (!isset($this->templateoperations))
 		{
@@ -338,7 +470,7 @@ class CmsObject {
 	* @see StylesheetOperations
 	* @return StylesheetOperations handle to the StylesheetOperations object
 	*/	
-	function & GetStylesheetOperations()
+	public function & GetStylesheetOperations()
 	{
         if (!isset($this->stylesheetoperations))
 		{
@@ -358,7 +490,7 @@ class CmsObject {
 	* @see GroupOperations
 	* @return GroupOperations handle to the GroupOperations object
 	*/
-	function & GetGroupOperations()
+	public function & GetGroupOperations()
 	{
         if (!isset($this->groupoperations))
 		{
@@ -380,7 +512,7 @@ class CmsObject {
 	* @see GlobalContentOperations
 	* @return GlobalContentOperations handle to the GlobalContentOperations object
 	*/
-	function & GetGlobalContentOperations()
+	public function & GetGlobalContentOperations()
 	{
         if (!isset($this->globalcontentoperations))
 		{
@@ -400,7 +532,7 @@ class CmsObject {
 	* @see UserTagOperations
 	* @return UserTagOperations handle to the UserTagOperations object
 	*/
-	function & GetUserTagOperations()
+	public function & GetUserTagOperations()
 	{
         if (!isset($this->usertagoperations))
 		{
@@ -422,13 +554,13 @@ class CmsObject {
 	* @link http://www.smarty.net/manual/en/
 	* @return Smarty_CMS handle to the Smarty object
 	*/
-	function & GetSmarty()
+	public function & GetSmarty()
 	{
 		/* Check to see if a Smarty object has been instantiated yet,
 		  and, if not, go ahead an create the instance. */
 		if (!isset($this->smarty))
 		{
-			$conf =& $this->GetConfig();
+			$conf = $this->GetConfig();
 
 			if (!defined('SMARTY_DIR'))
 			{
@@ -449,7 +581,7 @@ class CmsObject {
 	* @see HierarchyManager
 	* @return HierarchyManager handle to the HierarchyManager object
 	*/
-	function & GetHierarchyManager()
+	public function & GetHierarchyManager()
 	{
 		/* Check to see if a HierarchyManager has been instantiated yet,
 		  and, if not, go ahead an create the instance. */
@@ -457,7 +589,7 @@ class CmsObject {
 		{
 			debug_buffer('', 'Start Loading Hierarchy Manager');
 			$contentops =& $this->GetContentOperations();
-			$this->hrinstance =& $contentops->GetAllContentAsHierarchy(false, array());
+			$this->hrinstance =& $contentops->GetAllContentAsHierarchy(false);
 			debug_buffer('', 'End Loading Hierarchy Manager');
 		}
 
@@ -468,9 +600,10 @@ class CmsObject {
 	* Disconnect from the database.
 	*
 	* @final
+	* @internal
 	* @access private
 	*/
-	function dbshutdown()
+	public function dbshutdown()
 	{
 		if (isset($this->db))
 		{
@@ -488,7 +621,7 @@ class CmsObject {
 	* @final
 	* @access private
 	*/
-	function clear_cached_files($age_days = -100)
+	public function clear_cached_files($age_days = -100)
 	{
 	  $the_time = time() - $age_days * 24*60*60;
 
@@ -498,27 +631,19 @@ class CmsObject {
 	      $dirIterator = new RecursiveDirectoryIterator($start_dir);
  	      $dirContents = new RecursiveIteratorIterator($dirIterator);
 	      foreach( $dirContents as $one )
-		{
-		  if( $one->isFile() && $one->getMTime() <= $the_time )
-		    {
- 		      @unlink($one->getPathname());
-		    }
-		}
+			  {
+				  if( $one->isFile() && $one->getMTime() <= $the_time )
+					  {
+						  @unlink($one->getPathname());
+					  }
+			  }
 	    }
+
+		@touch(cms_join_path(TMP_CACHE_LOCATION,'index.html'));
+		@touch(cms_join_path(TMP_TEMPLATES_C_LOCATION,'index.html'));
 	}
 }
 
-/**
- * Simple global convenience object to hold CMS route information.
- * 
- * @package CMS
- */
-class CmsRoute
-{
-	var $module;
-	var $regex;
-	var $defaults;
-}
 
 /**
  * Simple global convenience object to hold CMS Content Type structure.
