@@ -54,7 +54,7 @@ class GlobalContentOperations
 		if (!isset($variables['authorblobs']))
 		{
 			$db = &$gCms->GetDb();
-			$variables['authorblobs'] = array();
+			$authorblobs = array();
 
 			// get the list of html blobs where this user is a direct owner
 			// todo.
@@ -64,7 +64,7 @@ class GlobalContentOperations
 			$result = &$db->Execute($query, array($userid));
 			while ($result && !$result->EOF)
 			{
-				$variables['authorblobs'][] = $result->fields['htmlblob_id'];
+				$authorblobs[] = $result->fields['htmlblob_id'];
 				$result->MoveNext();
 			}
 			if( $result ) $result->Close();
@@ -76,21 +76,23 @@ class GlobalContentOperations
 			$tmp = array();
 			while ($result && !$result->EOF)
 			  {
-			    $tmp[] = $result->fields['group_id'] * -1;
-			    $result->MoveNext();
+				  $tmp[] = $result->fields['group_id'] * -1;
+				  $result->MoveNext();
 			  }
 			if( $result ) $result->Close();
-                        if( count($tmp) > 0 ) {
-			  $query = 'SELECT htmlblob_id FROM '.cms_db_prefix().'additional_htmlblob_users WHERE user_id IN (';
-			  $query .= implode(',',$tmp).')';
-			  $result = &$db->Execute($query);
-			  while ($result && !$result->EOF)
-			    {
-			      $variables['authorblobs'][] = $result->fields['htmlblob_id'];
-			      $result->MoveNext();
-			    }
-			  if( $result ) $result->Close();
-                        }
+			if( count($tmp) > 0 ) {
+				$query = 'SELECT htmlblob_id FROM '.cms_db_prefix().'additional_htmlblob_users WHERE user_id IN (';
+				$query .= implode(',',$tmp).')';
+				$result = &$db->Execute($query);
+				while ($result && !$result->EOF)
+					{
+						$authorblobs[] = $result->fields['htmlblob_id'];
+						$result->MoveNext();
+					}
+				if( $result ) $result->Close();
+			}
+
+			$variables['authorblobs'] = $authorblobs;
 		}
 
 		return $variables['authorblobs'];
@@ -108,7 +110,7 @@ class GlobalContentOperations
 
 		$result = array();
 
-		$query = "SELECT htmlblob_id, htmlblob_name, html, owner, modified_date FROM ".cms_db_prefix()."htmlblobs ORDER BY htmlblob_name";
+		$query = "SELECT htmlblob_id, htmlblob_name, html, owner, modified_date, use_wysiwyg, description FROM ".cms_db_prefix()."htmlblobs ORDER BY htmlblob_name";
 		$dbresult = &$db->Execute($query);
 
 		while (is_object($dbresult) && !$dbresult->EOF)
@@ -118,6 +120,8 @@ class GlobalContentOperations
 			$oneblob->name = $dbresult->fields['htmlblob_name'];
 			$oneblob->content = $dbresult->fields['html'];
 			$oneblob->owner = $dbresult->fields['owner'];
+			$oneblob->description = $dbresult->fields['description'];
+			$oneblob->use_wysiwyg = $dbresult->fields['use_wysiwyg'];
 			$oneblob->modified_date = $db->UnixTimeStamp($dbresult->fields['modified_date']);
 			$result[] = $oneblob;
 			$dbresult->MoveNext();
@@ -139,7 +143,7 @@ class GlobalContentOperations
 		global $gCms;
 		$db = &$gCms->GetDb();
 
-		$query = "SELECT htmlblob_id, htmlblob_name, html, owner, modified_date FROM ".cms_db_prefix()."htmlblobs WHERE htmlblob_id = ?";
+		$query = "SELECT htmlblob_id, htmlblob_name, html, owner, modified_date, description, use_wysiwyg FROM ".cms_db_prefix()."htmlblobs WHERE htmlblob_id = ?";
 		$row = &$db->GetRow($query, array($id));
 
 		if ($row)
@@ -149,6 +153,8 @@ class GlobalContentOperations
 			$oneblob->name = $row['htmlblob_name'];
 			$oneblob->content = $row['html'];
 			$oneblob->owner = $row['owner'];
+			$oneblob->description = $row['description'];
+			$oneblob->use_wysiwyg = $row['use_wysiwyg'];
 			$oneblob->modified_date = $db->UnixTimeStamp($row['modified_date']);
 			$result =& $oneblob;
 		}
@@ -176,7 +182,7 @@ class GlobalContentOperations
 			return $cache[$name];
 		}
 
-		$query = "SELECT htmlblob_id, htmlblob_name, html, owner, modified_date FROM ".cms_db_prefix()."htmlblobs WHERE htmlblob_name = ?";
+		$query = "SELECT htmlblob_id, htmlblob_name, html, owner, use_wysiwyg, description, modified_date FROM ".cms_db_prefix()."htmlblobs WHERE htmlblob_name = ?";
 		$row = &$db->GetRow($query, array($name));
 
 		if ($row)
@@ -186,6 +192,8 @@ class GlobalContentOperations
 			$oneblob->name = $row['htmlblob_name'];
 			$oneblob->content = $row['html'];
 			$oneblob->owner = $row['owner'];
+			$oneblob->use_wysiwyg = $row['use_wysiwyg'];
+			$oneblob->description = $row['description'];
 			$oneblob->modified_date = $db->UnixTimeStamp($row['modified_date']);
 			$result =& $oneblob;
 
@@ -213,8 +221,8 @@ class GlobalContentOperations
 
 		$new_htmlblob_id = $db->GenID(cms_db_prefix()."htmlblobs_seq");
 		$time = $db->DBTimeStamp(time());
-		$query = "INSERT INTO ".cms_db_prefix()."htmlblobs (htmlblob_id, htmlblob_name, html, owner, create_date, modified_date) VALUES (?,?,?,?,".$time.",".$time.")";
-		$dbresult = $db->Execute($query, array($new_htmlblob_id, $htmlblob->name, $htmlblob->content, $htmlblob->owner));
+		$query = "INSERT INTO ".cms_db_prefix()."htmlblobs (htmlblob_id, htmlblob_name, html, owner, use_wysiwyg, description, create_date, modified_date) VALUES (?,?,?,?,?,?,".$time.",".$time.")";
+		$dbresult = $db->Execute($query, array($new_htmlblob_id, $htmlblob->name, $htmlblob->content, $htmlblob->owner, $htmlblob->use_wysiwyg, $htmlblob->description));
 		if ($dbresult !== false)
 		{
 			$result = $new_htmlblob_id;
@@ -237,8 +245,8 @@ class GlobalContentOperations
 		$db = &$gCms->GetDb();
 
 		$time = $db->DBTimeStamp(time());
-		$query = "UPDATE ".cms_db_prefix()."htmlblobs SET htmlblob_name = ?, html = ?, owner = ?, modified_date = ".$time." WHERE htmlblob_id = ?";
-		$dbresult = $db->Execute($query,array($htmlblob->name,$htmlblob->content,$htmlblob->owner,$htmlblob->id));
+		$query = "UPDATE ".cms_db_prefix()."htmlblobs SET htmlblob_name = ?, html = ?, owner = ?, use_wysiwyg = ?, description = ?, modified_date = ".$time." WHERE htmlblob_id = ?";
+		$dbresult = $db->Execute($query,array($htmlblob->name,$htmlblob->content,$htmlblob->owner,$htmlblob->use_wysiwyg,$htmlblob->description,$htmlblob->id));
 		if ($dbresult !== false)
 		{
 			$result = true;
