@@ -456,17 +456,17 @@ class ModuleOperations
     global $gCms;
     if( !isset( $gCms->modules[$module] ) )
       {
-	if( $loadifnecessary == false )
-	  {
-	    return array(false,lang('errormodulenotloaded'));
-	  }
-	else
-	  {
-	    if( !ModuleOperations::LoadNewModule( $module ) )
-	      {
-		return array(false,lang('errormodulewontload'));
-	      }
-	  }
+		  if( $loadifnecessary == false )
+			  {
+				  return array(false,lang('errormodulenotloaded'));
+			  }
+		  else
+			  {
+				  if( !$this->LoadNewModule( $module ) )
+					  {
+						  return array(false,lang('errormodulewontload'));
+					  }
+			  }
       }
  
     $db =& $gCms->GetDb();
@@ -521,7 +521,7 @@ class ModuleOperations
    * @param string $modulename The name of the module to load
    * @return boolean Whether or not the module load was successful
    */
-  function LoadNewModule( $modulename )
+  private function LoadNewModule( $modulename )
   {
     global $gCms;
     $db =& $gCms->GetDb();
@@ -587,6 +587,62 @@ class ModuleOperations
     return true;
   }
 
+  /**
+   * Uninstall a module
+   *
+   * @param string $module The name of the module to upgrade
+   * @return boolean Whether or not the upgrade was successful
+   */
+  function UninstallModule( $module)
+  {
+    global $gCms;
+    $db =& $gCms->GetDb();
+
+    if (!isset($gCms->modules[$module]))
+      {
+		return false;
+      }
+
+    $modinstance = $gCms->modules[$module]['object'];
+    $cleanup = $modinstance->AllowUninstallCleanup();
+	$result = $modinstance->Uninstall();
+	// clean up
+	if (!isset($result) || $result === FALSE)
+	{
+		// now delete the record
+		$query = "DELETE FROM ".cms_db_prefix()."modules WHERE module_name = ?";
+		$db->Execute($query, array($module));
+
+		// delete any dependencies
+		$query = "DELETE FROM ".cms_db_prefix()."module_deps WHERE child_module = ?";
+		$db->Execute($query, array($module));
+		
+		// clean up, if permitted
+		if ($cleanup)
+			{
+			$db->Execute('DELETE FROM '.cms_db_prefix().
+				'module_templates where module_name=?',array($module));
+			$db->Execute('DELETE FROM '.cms_db_prefix().
+				'event_handlers where module_name=?',array($module));
+			$db->Execute('DELETE FROM '.cms_db_prefix().
+				'events where originator=?',array($module));
+			$db->Execute('DELETE FROM '.cms_db_prefix().
+				"siteprefs where sitepref_name like '".
+					str_replace("'",'',$db->qstr($module)).
+				"_mapi_pref%'");
+			}
+
+		Events::SendEvent('Core', 'ModuleUninstalled', array('name' => $module));
+	}
+	else
+	{
+		$this->setError($result);
+		return false;
+	}
+    return true;
+  }
+
+
   /**
    * Returns a hash of all loaded modules.  This will include all
    * modules loaded by LoadModules, which could either be all or them,
@@ -623,15 +679,15 @@ class ModuleOperations
 	    $obj =& $data['object'];
 	    if( $obj->HasCapability($capability,$args) )
 	      {
-		$output->append($obj);
+		$output[] = $obj;
 	      }
 	  }
       }
 
-    if( count($output) ) return FALSE;
+    if( !count($output) ) return FALSE;
     return $output;
   }
 }
 
 # vim:ts=4 sw=4 noet
-?>
\ No newline at end of file
+?>
