@@ -17,7 +17,7 @@
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-#$Id: Content.inc.php 6483 2010-07-07 14:06:41Z ajprog $
+#$Id: Content.inc.php 6845 2011-01-09 18:27:28Z calguy1000 $
 
 /**
  * Class definition and methods for Content
@@ -120,7 +120,7 @@ class Content extends ContentBase
 	 * @param array $params hash of parameters to load into content attributes
 	 * @return void
 	 */
-    function FillParams($params)
+    function FillParams($params,$editing = false)
     {
 	global $gCms;
 	$config =& $gCms->config;
@@ -143,7 +143,7 @@ class Content extends ContentBase
 	  $this->parse_content_blocks();
 	  foreach($this->_contentBlocks as $blockName => $blockInfo)
 	    {
-	      $this->AddExtraProperty($blockName);
+	      $this->AddExtraProperty($blockInfo['id']);
 	      $parameters[] = $blockInfo['id'];
 
 	      if( isset($blockInfo['type']) && $blockInfo['type'] == 'module' )
@@ -174,7 +174,7 @@ class Content extends ContentBase
 
 	}
 
-	parent::FillParams($params);
+	parent::FillParams($params,$editing);
     }
 
 	/**
@@ -259,7 +259,7 @@ class Content extends ContentBase
 
 	  foreach($this->_contentBlocks as $blockName => $blockInfo)
 	    {
-	      $this->AddExtraProperty($blockName);
+  		  $this->AddExtraProperty($blockInfo['id']);
 	      $parameters[] = $blockInfo['id'];
 	    }
 
@@ -305,6 +305,7 @@ class Content extends ContentBase
 	function ValidateData()
 	{
 		$errors = parent::ValidateData();
+		$gCms = cmsms();
 		if( $errors === FALSE )
 		{
 			$errors = array();
@@ -627,6 +628,7 @@ class Content extends ContentBase
 			  $this->_contentBlocks[$name]['type'] = 'module';
 			  $this->_contentBlocks[$name]['blocktype'] = $blocktype;
 			  $this->_contentBlocks[$name]['id'] = $id;
+			  $this->_contentBlocks[$name]['label'] = $label;
 			  $this->_contentBlocks[$name]['module'] = $module;
 			  $this->_contentBlocks[$name]['params'] = $parms;
 			}
@@ -672,7 +674,7 @@ class Content extends ContentBase
       case 'template':
 	{
 	  $templateops =& $gCms->GetTemplateOperations();
-	  return array(lang('template').':', $templateops->TemplateDropdown('template_id', $this->mTemplateId, 'onchange="document.contentform.submit()"'));
+	  return array(lang('template').':', $templateops->TemplateDropdown('template_id', $this->mTemplateId, 'onchange="document.Edit_Content.submit()"'));
 	}
 	break;
 	
@@ -697,7 +699,8 @@ class Content extends ContentBase
 	    }
 	  return array(lang('searchable').':',
 			'<div class="hidden" ><input type="hidden" name="searchable" value="0" /></div>
-                           <input type="checkbox" name="searchable" value="1" '.($searchable==1?'checked="checked"':'').' />');
+            <input type="checkbox" name="searchable" value="1" '.($searchable==1?'checked="checked"':'').' />',
+				   lang('help_page_searchable'));
 	}
 	break;
 	
@@ -758,17 +761,22 @@ class Content extends ContentBase
 	private function _display_image_block($blockInfo,$value,$adding)
 	{
 		global $gCms;
-		$config =& $gCms->GetConfig();
-		$dir = cms_join_path($config['uploads_path'],$blockInfo['dir']);
-		$optprefix = 'uploads';
-		if( !empty($blockInfo['dir']) ) $optprefix .= '/'.$blockInfo['dir'];
+		$config = $gCms->GetConfig();
+		$adddir = get_site_preference('contentimage_path');
+		if( $blockInfo['dir'] != '' )
+			{
+				$adddir = $blockInfo['dir'];
+			}
+		$dir = cms_join_path($config['uploads_path'],$adddir);
+		$optprefix = '';
+		//$optprefix = 'uploads';
+		//if( !empty($blockInfo['dir']) ) $optprefix .= '/'.$blockInfo['dir'];
 		$inputname = $blockInfo['id'];
 		if( isset($blockInfo['inputname']) )
 		{
 			$inputname = $blockInfo['inputname'];
 		}
-		$dropdown = create_file_dropdown($inputname,$dir,$value,'jpg,jpeg,png,gif',
-			$optprefix,true);
+		$dropdown = create_file_dropdown($inputname,$dir,$value,'jpg,jpeg,png,gif',$optprefix,true);
 		if( $dropdown === false )
 		{
 			$dropdown = lang('error_retrieving_file_list');
