@@ -24,11 +24,6 @@
  * @license GPL
  */
 
-/**
- * include content class defintion
- */
-require_once('Content.inc.php');
-
 /**
  * Main class for CMS Made Simple ErrorPage content type
  *
@@ -48,10 +43,11 @@ class ErrorPage extends Content
     global $CMS_ADMIN_PAGE;
     if( isset($CMS_ADMIN_PAGE) )
       {
-	$this->error_types = array('404' => lang('404description'));
+		  $this->error_types = array('404' => lang('404description'));
       }
     $this->doAliasCheck = false;
     $this->doAutoAliasIfEnabled = false;
+	$this->mType = strtolower(get_class($this)) ;
   }
 
   function HandlesAlias()
@@ -82,6 +78,7 @@ class ErrorPage extends Content
     $this->RemoveProperty('titleattribute','');
     $this->RemoveProperty('active',true);
     $this->RemoveProperty('cachable',false);
+	$this->RemoveProperty('page_url','');
 
     $this->RemoveProperty('alias','');
     $this->AddBaseProperty('alias',10,1);
@@ -123,9 +120,9 @@ class ErrorPage extends Content
     return FALSE;
   }
 
-  function FillParams($params)
+  function FillParams($params,$editing = false)
   {
-    parent::FillParams($params);
+	  parent::FillParams($params,$editing);
     $this->mParentId = -1;
     $this->mShowInMenu = false;
     $this->mCachable = false;
