@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: SectionHeader.inc.php 6447 2010-07-02 06:40:08Z sjg $
+#$Id: SectionHeader.inc.php 6914 2011-02-27 19:42:22Z calguy1000 $
 
 /**
  * Class definition and methods for Section Header content type
@@ -49,6 +49,8 @@ class SectionHeader extends ContentBase
       //$this->RemoveProperty('showinmenu',true);
       $this->RemoveProperty('cachable',true);
       $this->RemoveProperty('target','');
+	  //$this->RemoveProperty('alias','');
+	  $this->RemoveProperty('page_url','');
 
       #Turn off caching
       $this->mCachable = false;
@@ -56,10 +58,15 @@ class SectionHeader extends ContentBase
 
     function HasUsableLink()
     {
-	return false;
+		return false;
     }
 
 
+	function RequiresAlias()
+	{
+		return FALSE;
+	}
+
     function TabNames()
     {
       $res = array(lang('main'));
