@@ -52,8 +52,8 @@ function cms_module_CreateFormStart(&$modinstance, $id, $action='default', $retu
 	$goto = 'moduleinterface.php';
 	if( $returnid != '' )
 	{
-	  $hm =& $gCms->GetHierarchyManager();
-	  $node =& $hm->sureGetNodeById($returnid);
+	  $hm = $gCms->GetHierarchyManager();
+	  $node = $hm->sureGetNodeById($returnid);
 	  if( $node )
 	    {
 	      $content_obj =& $node->getContent();
@@ -257,7 +257,7 @@ function cms_module_CreateInputSubmit(&$modinstance, $id, $name, $value='', $add
   $image = cms_htmlentities($image);
 
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 
 	$text = '<input class="cms_submit" name="'.$id.$name.'" id="'.$id.$name.'" value="'.$value.'" type=';
 
@@ -448,63 +448,13 @@ function cms_module_CreateLink(&$modinstance, $id, $action, $returnid='', $conte
   $prettyurl = cms_htmlentities($prettyurl);
 
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 
 	$class = (isset($params['class'])?cms_htmlentities($params['class']):'');
 
-	if ($prettyurl != '' && $config['url_rewriting'] == 'mod_rewrite' && $config['use_hierarchy'] == true)
-	{
-		$text = $config['root_url'] . '/' . $prettyurl . $config['page_extension'];
-	}
-	else if ($prettyurl != '' && $config['url_rewriting'] == 'internal' && $config['use_hierarchy'] == true)
-	{
-		$text = $config['root_url'] . '/index.php/' . $prettyurl . $config['page_extension'];
-	}
-	else
-	{
-		$text = '';
-		if ($targetcontentonly || ($returnid != '' && !$inline))
-		{
-			$id = 'cntnt01';
-		}
-		$goto = 'index.php';
-		if ($returnid == '')
-		{
-			$goto = 'moduleinterface.php';
-		}
-		if (!$onlyhref)
-		{
-		}
-		$text .= $config['root_url'];
-		if (!($returnid != '' && $returnid > -1))
-		{
-			$text .= '/'.$config['admin_dir'];
-		}
-
-		$secureparam = '';
-		if( $returnid == '' )
-		  {
-		    $secureparam='&amp;'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
-		  }
-		#$text .= '/'.$goto.'?module='.$modinstance->GetName().'&amp;id='.$id.'&amp;'.$id.'action='.$action.$secureparam;
-		$text .= '/'.$goto.'?mact='.$modinstance->GetName().','.$id.','.$action.','.($inline == true?1:0).$secureparam;
-
-		foreach ($params as $key=>$value)
-		{
-		  $key = cms_htmlentities($key);
-		  $value = cms_htmlentities($value);
-			if ($key != 'module' && $key != 'action' && $key != 'id')
-				$text .= '&amp;'.$id.$key.'='.rawurlencode($value);
-		}
-		if ($returnid != '')
-		{
-			$text .= '&amp;'.$id.'returnid='.$returnid;
-			if ($inline)
-			{
-				$text .= '&amp;'.$config['query_var'].'='.$returnid;
-			}
-		}
-	}
+	// create url....
+	$text = cms_module_create_url($modinstance,$id,$action,$returnid,$params,
+								  $inline,$targetcontentonly,$prettyurl);
 
 	if (!$onlyhref)
 	{
@@ -530,6 +480,89 @@ function cms_module_CreateLink(&$modinstance, $id, $action, $returnid='', $conte
 	return $text;
 }
 
+
+/**
+ * @access private
+ */
+function cms_module_create_url(&$modinstance,$id,$action,$returnid='',$params=array(),
+							   $inline=false,$targetcontentonly=false,$prettyurl='')
+{
+	$config = cmsms()->GetConfig();
+
+	$text = '';
+	if( empty($prettyurl) && $config['url_rewriting'] != 'none' )
+	{
+		// attempt to get a pretty url from the module... this is useful
+		// incase this method is being called from outside the source module.
+		// i.e: comments module wants a link to the article the comments are about
+		// or something.
+		$prettyurl = $modinstance->get_pretty_url($id,$action,$returnid,$params,$inline);
+	}
+
+	$base_url = $config['root_url'];
+	
+	// get the destination content object
+	if( $returnid != '' )
+	{
+		$content_obj = cmsms()->GetContentOperations()->LoadContentFromId($returnid);
+		if( is_object($content_obj) && $content_obj->Secure() )
+		{
+			$base_url = $config['ssl_url'];
+		}
+	}
+	   
+	if ($prettyurl != '' && $config['url_rewriting'] == 'mod_rewrite')
+	{
+		$text = $base_url . '/' . $prettyurl . $config['page_extension'];
+	}
+	else if ($prettyurl != '' && $config['url_rewriting'] == 'internal')
+	{
+		$text = $base_url . '/index.php/' . $prettyurl . $config['page_extension'];
+	}
+	else
+	{
+		$text = '';
+		if ($targetcontentonly || ($returnid != '' && !$inline))
+		{
+			$id = 'cntnt01';
+		}
+		$goto = 'index.php';
+		if ($returnid == '')
+		{
+			$goto = 'moduleinterface.php';
+		}
+		$text .= $base_url;
+		if (!($returnid != '' && $returnid > -1))
+			{
+				$text .= '/'.$config['admin_dir'];
+			}
+		
+		$secureparam = '';
+		if( $returnid == '' )
+			{
+				$secureparam='&amp;'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
+			}
+		$text .= '/'.$goto.'?mact='.$modinstance->GetName().','.$id.','.$action.','.($inline == true?1:0).$secureparam;
+		foreach ($params as $key=>$value)
+			{
+				$key = cms_htmlentities($key);
+				$value = cms_htmlentities($value);
+				if ($key != 'module' && $key != 'action' && $key != 'id')
+					$text .= '&amp;'.$id.$key.'='.rawurlencode($value);
+			}
+		if ($returnid != '')
+			{
+				$text .= '&amp;'.$id.'returnid='.$returnid;
+				if ($inline)
+					{
+						$text .= '&amp;'.$config['query_var'].'='.$returnid;
+					}
+			}
+	}
+
+	return $text;
+}
+
 /**
  * @access private
  */
@@ -539,7 +572,7 @@ function cms_module_CreateContentLink(&$modinstance, $pageid, $contents='')
   $contents = cms_htmlentities($contents);
 
 	global $gCms;
-	$config = &$gCms->GetConfig();
+	$config = $gCms->GetConfig();
 	$text = '<a href="';
 	if ($config["url_rewriting"] == 'mod_rewrite')
 	{
@@ -576,9 +609,9 @@ function cms_module_CreateReturnLink(&$modinstance, $id, $returnid, $contents=''
 
 	$text = '';
 	global $gCms;
-	$config = &$gCms->GetConfig();
+	$config = $gCms->GetConfig();
 	$manager =& $gCms->GetHierarchyManager();
-	$node =& $manager->sureGetNodeById($returnid);
+	$node = $manager->sureGetNodeById($returnid);
 	if (isset($node))
 	{
 		$content =& $node->GetContent();
