@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: content.functions.php 6439 2010-07-02 03:32:12Z calguy1000 $
+#$Id: content.functions.php 6863 2011-01-18 02:34:48Z calguy1000 $
 
 /**
  * Handles content related functions
@@ -66,21 +66,16 @@ class Smarty_CMS extends Smarty {
 		}
 		$this->compile_dir = TMP_TEMPLATES_C_LOCATION;
 		$this->cache_dir = TMP_CACHE_LOCATION;
-		#$this->plugins_dir = array($config["root_path"].'/lib/smarty/plugins',$config["root_path"].'/plugins',$config["root_path"].'/plugins/cache');
 		$this->plugins_dir = array($config["root_path"].'/lib/smarty/plugins',$config["root_path"].'/plugins');
 
 		$this->compiler_file = 'CMS_Compiler.class.php';
 		$this->compiler_class = 'CMS_Compiler';
 
-		//use_sub_dirs doesn't work in safe mode
-		//if (ini_get("safe_mode") != "1")
-		//	$this->use_sub_dirs = true;
-		//$this->caching = false;
-		//$this->compile_check = true;
 		$this->assign('app_name','CMS');
-		//$this->debugging = false;
-		//$this->force_compile = false;
-		$this->cache_plugins = false;
+
+		//$this->cache_plugins = true;
+		//$this->caching = 1; // output caching disabled because output could come from databases, and can't strictly depend on the time of the template.
+		//$this->force_compile = true;
 
 		if ($config["debug"] == true)
 		{
@@ -279,14 +274,12 @@ class Smarty_CMS extends Smarty {
      */
 	function module_db_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
 	{
-		global $gCms;
 
-		$db = &$gCms->GetDb();
-		$config = $gCms->config;
-		if( isset($gCms->variables['module_template_cache']) &&
-		    isset($gCms->variables['module_template_cache'][$tpl_name]) )
+		$db = cmsms()->GetDb();
+		$module_template_cache = cms_utils::get_app_data('module_template_cache');
+		if( isset($module_template_cache) && isset($module_template_cache[$tpl_name]) )
 		  {
-		    $tpl_timestamp = $gCms->variables['module_template_cache'][$tpl_name];
+		    $tpl_timestamp = $module_template_cache[$tpl_name];
 		    return true;
 		  }
 		
@@ -296,18 +289,19 @@ class Smarty_CMS extends Smarty {
 
 		if( !count($results) ) return false;
 
-		if( !isset($gCms->variables['module_template_cache']) )
+		if( empty($module_template_cache) )
 		  {
-		    $gCms->variables['module_template_cache'] = array();
+		    $module_template_cache = array();
 		  }
 		foreach( $results as $row )
 		  {
 		    $key = $row['module_name'].';'.$row['template_name'];
 		    $val = $db->UnixTimeStamp($row['modified_date']);
-		    $gCms->variables['module_template_cache'][$key] = $val;
+		    $module_template_cache[$key] = $val;
 		  }
 
-		$tpl_timestamp = $gCms->variables['module_template_cache'][$tpl_name];
+		$tpl_timestamp = $module_template_cache[$tpl_name];
+		cms_utils::set_app_data('module_template_cache',$module_template_cache);
 		return true;
 	}
 
@@ -382,7 +376,7 @@ class Smarty_CMS extends Smarty {
 		$oneblob = $gcbops->LoadHtmlBlobByName($tpl_name);
 		if ($oneblob)
 		{
-			$tpl_timestamp = $oneblob->modified_date;
+		  $tpl_timestamp = $oneblob->modified_date;
 			debug_buffer('end global_content_get_timestamp');
 			return true;
 		}
@@ -405,7 +399,7 @@ class Smarty_CMS extends Smarty {
 	function template_top_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 	  
 	  if (is_sitedown())
 	    {
@@ -426,9 +420,9 @@ class Smarty_CMS extends Smarty {
 		}
 	      else
 		{
-		  $pageinfo = $gCms->variables['pageinfo'];
+		  $contentobj = $gCms->variables['content_obj'];
 		  $templateops =& $gCms->GetTemplateOperations();
-		  $templateobj =& $templateops->LoadTemplateByID($pageinfo->template_id);
+		  $templateobj =& $templateops->LoadTemplateByID($contentobj->TemplateId());
 		  if (isset($templateobj) && $templateobj !== FALSE)
 		    {
 		      $tpl_source = $templateobj->content;
@@ -461,7 +455,7 @@ class Smarty_CMS extends Smarty {
 	function template_head_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 	  
 	  if (is_sitedown())
 	    {
@@ -482,9 +476,9 @@ class Smarty_CMS extends Smarty {
 		}
 	      else
 		{
-		  $pageinfo = $gCms->variables['pageinfo'];
+		  $contentobj = $gCms->variables['content_obj'];
 		  $templateops =& $gCms->GetTemplateOperations();
-		  $templateobj =& $templateops->LoadTemplateByID($pageinfo->template_id);
+		  $templateobj =& $templateops->LoadTemplateByID($contentobj->TemplateId());
 		  if (isset($templateobj) && $templateobj !== FALSE)
 		    {
 		      $tpl_source = $templateobj->content;
@@ -520,7 +514,7 @@ class Smarty_CMS extends Smarty {
 	function template_body_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 	  
 	  if (is_sitedown())
 	    {
@@ -544,9 +538,9 @@ class Smarty_CMS extends Smarty {
 		}
 	      else
 		{
-		  $pageinfo = $gCms->variables['pageinfo'];
+		  $contentobj = $gCms->variables['content_obj'];
 		  $templateops =& $gCms->GetTemplateOperations();
-		  $templateobj =& $templateops->LoadTemplateByID($pageinfo->template_id);
+		  $templateobj =& $templateops->LoadTemplateByID($contentobj->TemplateId());
 		  if (isset($templateobj) && $templateobj !== FALSE)
 		    {
 		      $tpl_source = $templateobj->content;
@@ -583,7 +577,7 @@ class Smarty_CMS extends Smarty {
 	function template_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 		global $gCms;
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		if (is_sitedown())
 		{
@@ -592,8 +586,6 @@ class Smarty_CMS extends Smarty {
 		}
 		else
 		{
-			$pageinfo = $gCms->variables['pageinfo'];
-
 			if ($tpl_name == 'notemplate')
 			{
 				$tpl_source = '{content}';
@@ -633,8 +625,6 @@ class Smarty_CMS extends Smarty {
 			}
 			if( isset($_SESSION['cms_preview']) )
 			  {
-			    return 'DEBUG: IN PREVIEW<br/>';
-
 			    // get serialized data filename
 			    $tpl_name = trim($_SESSION['cms_preview']);
 			    unset($_SESSION['cms_preview']);
@@ -660,14 +650,14 @@ class Smarty_CMS extends Smarty {
 			    unlink($fname);
 	
 			    $tpl_source = $data["template"];
-
 			    return true;
 			  }
 			else
 			{
 				global $gCms;
+				$contentobj = $gCms->variables['content_obj'];
 				$templateops =& $gCms->GetTemplateOperations();
-				$templateobj =& $templateops->LoadTemplateByID($pageinfo->template_id);
+				$templateobj =& $templateops->LoadTemplateByID($contentobj->TemplateId());
 				if (isset($templateobj) && $templateobj !== FALSE)
 				{
 					$tpl_source = $templateobj->content;
@@ -679,8 +669,6 @@ class Smarty_CMS extends Smarty {
 						$tpl_source = preg_replace("/\{\/?php\}/", "", $tpl_source);
 					}
 					
-					//do_cross_reference($pageinfo->template_id, 'template', $tpl_source);
-
 					return true;
 				}
 			}
@@ -719,10 +707,14 @@ class Smarty_CMS extends Smarty {
 		}
 		else
 		{
-			$pageinfo = &$gCms->variables['pageinfo'];
-
-			$tpl_timestamp = $pageinfo->template_modified_date;
-			return true;
+		  $contentobj = $gCms->variables['content_obj'];
+		  $templateops =& $gCms->GetTemplateOperations();
+		  $templateobj =& $templateops->LoadTemplateByID($contentobj->TemplateId());
+		  if (isset($templateobj) && $templateobj !== FALSE)
+		    {
+		      $tpl_timestamp = $templateobj->modified_date;
+		      return true;
+		    }
 		}
 	}
 
@@ -743,10 +735,10 @@ class Smarty_CMS extends Smarty {
 	function content_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 		global $gCms;
-		$config =& $gCms->GetConfig();
-		$pageinfo = &$gCms->variables['pageinfo'];
+		$config = $gCms->GetConfig();
+		$contentobj = $gCms->variables['content_obj'];
 
-		if (isset($pageinfo) && $pageinfo->content_id == -1)
+		if (!is_object($contentobj))
 		{
 			#We've a custom error message...  return it here
 			header("HTTP/1.0 404 Not Found");
@@ -757,7 +749,7 @@ class Smarty_CMS extends Smarty {
 				$tpl_source = '';
 			return true;
 		}
-		else if( isset($_SESSION['cms_preview_data']) && $pageinfo->content_id == '__CMS_PREVIEW_PAGE__' )
+		else if( isset($_SESSION['cms_preview_data']) && $contentobj->Id() == '__CMS_PREVIEW_PAGE__' )
 	        {
 		  if( !isset($_SESSION['cms_preview_data']['content_obj']) )
 		    {
@@ -779,10 +771,6 @@ class Smarty_CMS extends Smarty {
 		}
 		else
 		{
-			$manager =& $gCms->GetHierarchyManager();
-			$node =& $manager->sureGetNodeById($pageinfo->content_id);
-			$contentobj =& $node->GetContent();
-
 			if (isset($contentobj) && $contentobj !== FALSE)
 			{
 
@@ -817,18 +805,23 @@ class Smarty_CMS extends Smarty {
 	{
 		global $gCms;
 
-		$pageinfo =& $gCms->variables['pageinfo'];
+		$contentobj = $gCms->variables['content_obj'];
 
-		if (isset($pageinfo) && $pageinfo->content_id == -1)
+		if (!is_object($contentobj))
 		{
 			#We've a custom error message...  set a current timestamp
 			$tpl_timestamp = time();
 		}
+		else if( isset($_SESSION['cms_preview_data']) && $contentobj->Id() == '__CMS_PREVIEW_PAGE__' )
+		{
+		       $tpl_timestamp = time();
+		}
 		else
 		{
-			if ($pageinfo->cachable)
+		  if ($contentobj->Cachable())
 			{
-				$tpl_timestamp = $pageinfo->content_modified_date;
+			  $db = $gCms->GetDb();
+			  $tpl_timestamp = $contentobj->GetModifiedDate();
 			}
 			else
 			{
@@ -854,7 +847,7 @@ class Smarty_CMS extends Smarty {
 	function module_get_template ($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 		global $gCms;
-		$pageinfo =& $gCms->variables['pageinfo'];
+		$contentobj = $gCms->variables['content_obj'];
 		$config = $gCms->config;
 
 		#Run the execute_user function and replace {content} with it's output 
@@ -863,14 +856,14 @@ class Smarty_CMS extends Smarty {
 			@ob_start();
 
 			$id = $smarty_obj->id;
-			$returnid = isset($pageinfo)?$pageinfo->content_id:'';
+			$returnid = is_object($contentobj)?$contentobj->Id():'';
 			$params = GetModuleParameters($id);
 			$action = 'default';
 			if (isset($params['action']))
 			{
 				$action = $params['action'];
 			}
-			echo $gCms->modules[$tpl_name]['object']->DoActionBase($action, $id, $params, isset($pageinfo)?$pageinfo->content_id:'');
+			echo $gCms->modules[$tpl_name]['object']->DoActionBase($action, $id, $params, is_object($contentobj)?$$contentobj->Id():'');
 			$modoutput = @ob_get_contents();
 			@ob_end_clean();
 
@@ -973,7 +966,7 @@ function load_plugins(&$smarty)
 				$userplugins[$result->fields['userplugin_name']] = $result->fields['userplugin_id'];
 				$functionname = "cms_tmp_".$result->fields['userplugin_name']."_userplugin_function";
 				//Only register valid code
-				if (!(@eval('function '.$functionname.'($params, &$smarty) {'.$result->fields['code'].'}') === FALSE))
+				if (!(@eval('function '.$functionname.'($params, &$smarty) {'.$result->fields['code']."\n}") === FALSE))
 				{
 					$smarty->register_function($result->fields['userplugin_name'], $functionname, false);
 
@@ -1204,10 +1197,18 @@ function global_content_regex_callback($matches)
 function is_sitedown()
 {
   if( get_site_preference('enablesitedownmessage') !== '1' ) return FALSE;
-  $excludes = get_site_preference('sitedownexcludes','');
+
+  if( get_site_preference('sitedownexcludeadmins') )
+    {
+      $uid = get_userid(FALSE);
+      if( $uid ) return FALSE;
+    }
+
   if( !isset($_SERVER['REMOTE_ADDR']) ) return TRUE;
+  $excludes = get_site_preference('sitedownexcludes','');
   if( empty($excludes) ) return TRUE;
-  
+ 
+  $tmp = explode(',',$excludes);
   $ret = cms_ipmatches($_SERVER['REMOTE_ADDR'],$excludes);
   if( $ret ) return FALSE;
   return TRUE;
