@@ -2,7 +2,7 @@
 /**
  * Image Manager configuration file.
  * @author $Author: Wei Zhuo $
- * @version $Id: config.inc.php 6192 2010-04-08 18:35:26Z calguy1000 $
+ * @version $Id: config.inc.php 6629 2010-09-25 17:30:11Z calguy1000 $
  * @package ImageManager
  *
  * Updated by Thijs (thijs@contemplated) to work with CMS made easy
@@ -10,7 +10,7 @@
  */
 
 global $gCms;
-$config =& $gCms->GetConfig();
+$config = $gCms->GetConfig();
 
 /* 
  File system path to the directory you want to manage the images
