@@ -2,7 +2,7 @@
 /**
  * Show a list of images in a long horizontal table.
  * @author $Author: Wei Zhuo $
- * @version $Id: images.php 6037 2009-10-03 17:16:59Z calguy1000 $
+ * @version $Id: images.php 6907 2011-02-21 18:11:12Z calguy1000 $
  * @package ImageManager
  */
 //LOCAL: lib/filemanager/ImageManager/images.php
@@ -191,14 +191,23 @@ function drawErrorBase(&$manager)
 <?php
 }
 
+// absolutely disable caching.
+header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
+header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
+header("Cache-Control: no-store, no-cache, must-revalidate");
+header("Cache-Control: post-check=0, pre-check=0", false);
+header("Pragma: no-cache");
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 
 <html>
 <head>
         <title>Image List</title>
-  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-        <link href="assets/imagelist.css" rel="stylesheet" type="text/css" />
+<meta http-Equiv="Cache-Control" Content="no-cache">
+<meta http-Equiv="Pragma" Content="no-cache">
+<meta http-Equiv="Expires" Content="0">
+<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+<link href="assets/imagelist.css" rel="stylesheet" type="text/css" />
 <script type="text/javascript" src="assets/dialog.js"></script>
 <script type="text/javascript">
 
