@@ -304,7 +304,7 @@ function cms_html_entity_decode($text_to_convert) {
 	);
 	$return_text = strtr($text_to_convert, $htmlentities_table);
 	$return_text = preg_replace('~&#x([0-9a-f]+);~ei', 'code_to_utf8(hexdec("\\1"))', $return_text);
-	$return_text = preg_replace('~&#([0-9]+);~e', 'code_to_utf8(\\1)', $return_text);
+	$return_text = preg_replace('~&#([0-9]+);~e', 'code_to_utf8("\\1")', $return_text);
 	return $return_text;
 }
 
