@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: misc.functions.php 6444 2010-07-02 04:53:23Z calguy1000 $
+#$Id: misc.functions.php 6856 2011-01-16 20:27:59Z calguy1000 $
 
 /**
  * Misc functions
@@ -39,7 +39,7 @@ function redirect($to, $noappend=false)
 
     global $gCms;
 	if (isset($gCms))
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 	else
 		$config = array();
 
@@ -123,7 +123,7 @@ function redirect($to, $noappend=false)
 			  {
 				echo "<div>".$sql_queries."</div>\n";
 			  }
-			foreach ($gCms->errors as $error)
+			foreach (cmsms()->get_errors() as $error)
 			{
 				echo $error;
 			}
@@ -149,9 +149,9 @@ function redirect($to, $noappend=false)
 function redirect_to_alias($alias)
 {
 	global $gCms;
-	$manager =& $gCms->GetHierarchyManager();
-	$node =& $manager->sureGetNodeByAlias($alias);
-	$content =& $node->GetContent();
+	$manager = $gCms->GetHierarchyManager();
+	$node = $manager->sureGetNodeByAlias($alias);
+	$content = $node->GetContent();
 	if (isset($content))
 	{
 		if ($content->GetURL() != '')
@@ -324,7 +324,7 @@ function cms_cleanfile($filename)
 	// This ensures that the file specified is somewhere
 	// underneath the cms root path
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 	if( strpos($realpath, $config['root_path']) !== 0 ) {
 		return CLEANED_FILENAME;
 	}
@@ -344,7 +344,7 @@ function cms_calculate_url()
 	$result = '';
 
     global $gCms;
-    $config =& $gCms->GetConfig();
+    $config = $gCms->GetConfig();
 
 	//Apache
 	/*
@@ -619,9 +619,15 @@ function debug_display($var, $title="", $echo_to_screen = true, $use_html = true
 
 	if (function_exists('memory_get_usage'))
 	{
-		$titleText .= ' - ('.memory_get_usage().')';
+		$titleText .= ' - (usage: '.memory_get_usage().')';
 	}
 
+	$memory_peak = (function_exists('memory_get_peak_usage')?memory_get_peak_usage():'');
+	if( $memory_peak )
+	  {
+	    $titleText .= ' - (peak: '.$memory_peak.')';
+	  }
+
 	ob_start();
 	if ($use_html)
 		echo "<div><b>$titleText</b>\n";
@@ -728,13 +734,13 @@ function debug_buffer($var, $title="")
 	global $gCms;
 	if ($gCms)
 	{
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		//debug_to_log($var, $title='');
 
 		if($config["debug"] == true)
 		{
-			$gCms->errors[] = debug_display($var, $title, false, true);
+		  cmsms()->add_error(debug_display($var, $title, false, true));
 		}
 	}
 }
@@ -752,11 +758,11 @@ function debug_sql($str, $newline = false)
 	global $gCms;
 	if ($gCms)
 	{
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 		if($config["debug"] == true)
 		{
-			$gCms->errors[] = debug_display($str, '', false, true);
+		  cmsms()->add_error(debug_display($str, '', false, true));
 		}
 	}
 }
@@ -1341,9 +1347,10 @@ function showmem($string = '')
  * @internal
  * @param string String to convert
  * @param boolean indicates whether output string should be converted to lower case
+ * @param boolean indicates wether slashes should be allowed in the input.
  * @return string
  */
-function munge_string_to_url($alias, $tolower = false)
+function munge_string_to_url($alias, $tolower = false, $withslash = false)
 {
 	// replacement.php is encoded utf-8 and must be the first modification of alias
 	include(dirname(__FILE__) . '/replacement.php');
@@ -1355,7 +1362,12 @@ function munge_string_to_url($alias, $tolower = false)
 		$alias = strtolower($alias);
 	}
 
-	$alias = preg_replace('/[^a-z0-9-_]+/i','-',$alias);
+	$expr = '/[^a-z0-9-_]+/i';
+	if( $withslash )
+	  {
+	    $expr = '/[^a-z0-9-_\/]+/i';
+	  }
+	$alias = preg_replace($expr,'-',$alias);
 	//$alias = preg_replace("/[^\w-]+/", "-", $alias);
 	$alias = trim($alias, '-');
 
@@ -1391,22 +1403,20 @@ if(!function_exists("file_get_contents"))
 }
 
 
-if(!function_exists("readfile"))
+function cms_readfile($filename)
 {
-    function readfile($filename)
-    {
-      @ob_start();
-      echo file_get_contents($filename);
-      $result = @ob_get_contents();
-      @ob_end_clean();
-      if( !empty($result) ) {
-	echo $result;
-        return TRUE;
-      }
-      return FALSE;
-    }
+  @ob_start();
+  echo file_get_contents($filename);
+  $result = @ob_get_contents();
+  @ob_end_clean();
+  if( !empty($result) ) {
+    echo $result;
+    return TRUE;
+  }
+  return FALSE;
 }
 
+
 // create the array_walk_recursive function in PHP4
 // from http://www.php.net/manual/en/function.array-walk-recursive.php
 if (!function_exists('array_walk_recursive'))
@@ -1882,7 +1892,7 @@ function stack_trace()
 function cms_move_uploaded_file( $tmpfile, $destination )
 {
    global $gCms;
-   $config =& $gCms->GetConfig();
+   $config = $gCms->GetConfig();
 
    if( !@move_uploaded_file( $tmpfile, $destination ) )
    {
@@ -1985,7 +1995,8 @@ function cms_ipmatches($ip,$checklist)
     // Does not match:
     // xxx.xxx.xxx.xx[yyy-zzz]  (range, partial octets not supported)
 
-    if (ereg("([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)/([0-9]+)",$range,$regs)) {
+    $regs = array();
+    if (preg_match("/([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\/([0-9]+)/",$range,$regs)) {
       // perform a mask match
       $ipl = ip2long($ip);
       $rangel = ip2long($regs[1] . "." . $regs[2] . "." . $regs[3] . "." . $regs[4]);
@@ -2005,12 +2016,17 @@ function cms_ipmatches($ip,$checklist)
       }
     } else {
       // range based
-      $maskocts = split("\.",$range);
-      $ipocts = split("\.",$ip);
+      $maskocts = explode('.',$range);
+      $ipocts = explode('.',$ip);
+
+      if( count($maskocts) != count($ipocts) && count($maskocts) != 4 )
+	{
+	  return 0;
+	}
 
       // perform a range match
       for ($i=0; $i<4; $i++) {
-	if (ereg("\[([0-9]+)\-([0-9]+)\]",$maskocts[$i],$regs)) {
+	if (preg_match("/\[([0-9]+)\-([0-9]+)\]/",$maskocts[$i],$regs)) {
 	  if ( ($ipocts[$i] > $regs[2]) || ($ipocts[$i] < $regs[1])) {
 	    $result = 0;
 	  }
