@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: module.functions.php 6428 2010-07-01 17:56:45Z calguy1000 $
+#$Id: module.functions.php 6801 2010-11-18 22:16:48Z ajprog $
 
 /**
  * Extend smarty for moduleinterface.php
@@ -37,13 +37,14 @@
  */
 function cms_module_plugin($params,&$smarty)
 {
-	global $gCms;
-	$cmsmodules = &$gCms->modules;
+	$gCms = cmsms();
+	$cmsmodules = $gCms->modules;
 
 	//$id = 'm' . ++$gCms->variables["modulenum"];
-	if( !isset($gCms->variables['mid_cache']) )
+	$mid_cache = cms_utils::get_app_data('mid_cache');
+	if( empty($mid_cache) )
 	  {
-	    $gCms->variables['mid_cache'] = array();
+	    $mid_cache = array();
 	  }
 	for( $i = 0; $i < 10; $i++ )
 	{
@@ -51,19 +52,21 @@ function cms_module_plugin($params,&$smarty)
 	  foreach($params as $key=>$value)
 	    $tmp .= $key.'='.$value;
 	  $id = 'm'.substr(md5($tmp),0,5);
-	  if( !isset($gCms->variables['mid_cache'][$id]) )
+	  if( !isset($mid_cache[$id]) )
 	    {
-	      $gCms->variables['mid_cache'][$id] = $id;
+	      $mid_cache[$id] = $id;
 	      break;
 	    }
 	}
+	cms_utils::set_app_data('mid_cache',$mid_cache);
 
 	$returnid = '';
-	if (isset($gCms->variables['pageinfo']) && isset($gCms->variables['pageinfo']->content_id))
+	$content_obj = cmsms()->get_variable('content_obj');
+	if (isset($content_obj) && $content_obj->Id())
 	  {
-	    $returnid = $gCms->variables['pageinfo']->content_id;
+	    $returnid = $content_obj->Id();
 	  }
-	$params = array_merge($params, GetModuleParameters($id));
+	//$params = array_merge($params, GetModuleParameters($id));
 
 	$modulename = '';
 	$action = 'default';
@@ -108,6 +111,7 @@ function cms_module_plugin($params,&$smarty)
 		  // and we're inline (the results are supposed to replace
 		  // the tag, not {content}
 		  $action = $mactaction;
+	      $params = array_merge($params, GetModuleParameters($id));
 		}
 	    }
 	}
