@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: page.functions.php 6428 2010-07-01 17:56:45Z calguy1000 $
+#$Id: page.functions.php 6771 2010-11-09 19:40:05Z calguy1000 $
 
 /**
  * Page related functions.  Generally these are functions not necessarily
@@ -37,7 +37,7 @@
 function check_login($no_redirect = false)
 {
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 
 	//Handle a current login if one is in queue in the SESSION
 	if (isset($_SESSION['login_user_id']))
@@ -172,7 +172,7 @@ function check_passhash($userid, $checksum)
 
 	global $gCms;
 	$db =& $gCms->GetDb();
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 
 	$userops =& $gCms->GetUserOperations();
 	$oneuser =& $userops->LoadUserByID($userid);
@@ -201,7 +201,7 @@ function generate_user_object($userid)
 {
 	global $gCms;
 	$db =& $gCms->GetDb();
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 
 	$userops =& $gCms->GetUserOperations();
 	$oneuser =& $userops->LoadUserByID($userid);
@@ -228,7 +228,7 @@ function generate_user_object($userid)
 function send_recovery_email($username)
 {
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 	$userops =& $gCms->GetUserOperations();
 	$user = $userops->LoadUserByUsername($username);
 	
@@ -246,7 +246,7 @@ function send_recovery_email($username)
 		return false;
 	}
 	
-	$obj->AddAddress($user->email, $firstname . ' ' . $lastname);
+	$obj->AddAddress($user->email, $user->firstname . ' ' . $user->lastname);
 	$obj->SetSubject(lang('lostpwemailsubject',$gCms->siteprefs['sitename']));
 	
 	$url = $config['root_url'] . '/' . $config['admin_dir'] . '/login.php?recoverme=' . md5(md5($config['root_path'] . '--' . $user->username . md5($user->password)));
@@ -268,7 +268,7 @@ function send_recovery_email($username)
 function find_recovery_user($hash)
 {
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 	$userops =& $gCms->GetUserOperations();
 	
 	foreach ($userops->LoadUsers() as $user)
@@ -372,17 +372,18 @@ function check_ownership($userid, $contentid = '', $strict = false)
 		$db =& $gCms->GetDb();
 
 		$variables = &$gCms->variables;
-		$variables['ownerpages'] = array();
+		$tmpa = array();
 
 		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE owner_id = ?";
 		$result = &$db->Execute($query, array($userid));
 
 		while ($result && !$result->EOF)
 		{
-			$variables['ownerpages'][] =& $result->fields['content_id'];
+			$tmpa[] = $result->fields['content_id'];
 			$result->MoveNext();
 		}
-		
+		$gCms->variables['ownerpages'] = $tmpa;
+
 		if ($result) $result->Close();
 	}
 
@@ -445,45 +446,32 @@ function author_pages($userid)
         $variables = &$gCms->variables;
 	if (!isset($variables['authorpages']))
 	{
-		$db = &$gCms->GetDb();
-		$variables['authorpages'] = array();
-		
 		// Get all of the pages this user owns
 		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE owner_id = ?";
-		$result =& $db->Execute($query, array($userid));
-		
-		while ($result && !$result->EOF)
-		{
-			$variables['authorpages'][] =& $result->fields['content_id'];
-			$result->MoveNext();
-		}
-		
-		if ($result) $result->Close();
+		$data = $db->GetCol($query, array($userid));
 
 		// Get all of the pages this user has access to.
 		$query = "SELECT user_id,content_id FROM ".cms_db_prefix()."additional_users";
-		$result = &$db->Execute($query);
-
-		while ($result && !$result->EOF)
+		$result = $db->GetArray($query);
+		foreach( $result as $row )
 		{
-		  $uid = $result->fields['user_id'];
-		  $content_id = $result->fields['content_id'];
+		  $uid = $row['user_id'];
+		  $content_id = $row['content_id'];
 		  if( $uid == $userid )
 		    {
-		      $variables['authorpages'][] = $content_id;
+		      $data[] = $content_id;
 		    }
 		  else if( $uid < 0 )
 		    {
 		      $gid = $uid * -1;
 		      if( $userops->UserInGroup($userid,$gid) )
 			{
-			  $variables['authorpages'][] = $content_id;
+			  $data[] = $content_id;
 			}
 		    }
-		  $result->MoveNext();
 		}
-		
-		if ($result) $result->Close();
+
+		$variables['authorpages'] = $data;
 	}
 
 	return $variables['authorpages'];
@@ -1189,7 +1177,7 @@ function textarea_highlight($use_javasyntax, $text, $name, $class_name="syntaxHi
  */
 function cms_db_prefix() {
   global $gCms;
-  $config =& $gCms->GetConfig();
+  $config = $gCms->GetConfig();
   return $config["db_prefix"];
 }
 
@@ -1276,23 +1264,24 @@ function get_pageid_or_alias_from_url()
   $page = '';
   if (isset($smarty->id) && isset($params[$smarty->id . 'returnid']))
     {
-      // old?
+      // get page from returnid parameter in module action
       $page = $params[$smarty->id . 'returnid'];
     }
   else if (isset($config["query_var"]) && $config["query_var"] != '' && isset($_GET[$config["query_var"]]))
     {
+      // using non friendly urls... get the page alias/id from the query var.
       $page = $_GET[$config["query_var"]];    
     }
   else
     {
-      // either we're using internal urls
+      // either we're using pretty urls
       // or this is the default page.
       if (isset($_SERVER["REQUEST_URI"]) && !endswith($_SERVER['REQUEST_URI'], 'index.php'))
 	{
 	  $matches = array();
 	  if (preg_match('/.*index\.php\/(.*?)$/', $_SERVER['REQUEST_URI'], $matches))
 	    {
-	      // internal pretty urls.
+	      // pretty urls... grab all the stuff after the index.php
 	      $page = $matches[1];
 	    }
 	}
@@ -1306,9 +1295,14 @@ function get_pageid_or_alias_from_url()
       $page = $contentops->GetDefaultContent();
     }
 
-  // by here page should be a string.
-  if( is_numeric($page) ) return $page;
+  // by here, if we're not assuming pretty urls of any sort
+  // and we have a value... we're done.
+  if( $config['url_rewriting'] == 'none' )
+    {
+      return $page;
+    }
 
+  // some kind of a pretty url.
   // strip off GET params.
   if( ($tmp = strpos($page,'?')) !== FALSE )
     {
@@ -1324,126 +1318,109 @@ function get_pageid_or_alias_from_url()
   // trim trailing /
   $page = rtrim($page, '/');
 
-  // match routes
+  // see if there's a route that matches.
   $matched = false;
-  if (strpos($page, '/') !== FALSE)
+  $route = cms_route_manager::find_match($page);
+  if( is_object($route) )
     {
-      $routes =& $gCms->variables['routes'];
-      foreach ($routes as $route)
+      $matched = true;
+      if( $route->is_content() )
 	{
-	  $matches = array();
-	  if (preg_match($route->regex, $page, $matches))
+	  // a route to a page.
+	  $page = $route->get_content();
+	}
+      else
+	{
+	  $matches = $route->get_results();
+
+	  // it's a module route
+	  //Now setup some assumptions
+	  if (!isset($matches['id']))
+	    $matches['id'] = 'cntnt01';
+	  if (!isset($matches['action']))
+	    $matches['action'] = 'defaulturl';
+	  if (!isset($matches['inline']))
+	    $matches['inline'] = 0;
+	  if (!isset($matches['returnid']))
+	    $matches['returnid'] = ''; #Look for default page
+	  if (!isset($matches['module']))
+	    $matches['module'] = $route->get_dest();
+
+	  //Get rid of numeric matches
+	  foreach ($matches as $key=>$val)
 	    {
-	      //Now setup some assumptions
-	      if (!isset($matches['id']))
-		$matches['id'] = 'cntnt01';
-	      if (!isset($matches['action']))
-		$matches['action'] = 'defaulturl';
-	      if (!isset($matches['inline']))
-		$matches['inline'] = 0;
-	      if (!isset($matches['returnid']))
-		$matches['returnid'] = ''; #Look for default page
-	      if (!isset($matches['module']))
-		$matches['module'] = $route->module;
-
-	      //Get rid of numeric matches
-	      foreach ($matches as $key=>$val)
+	      if (is_int($key))
 		{
-		  if (is_int($key))
-		    {
-		      unset($matches[$key]);
-		    }
-		  else
-		    {
-		      if ($key != 'id')
-			$_REQUEST[$matches['id'] . $key] = $val;
-		    }
+		  unset($matches[$key]);
 		}
-
-	      //Now set any defaults that might not have been in the url
-	      if (isset($route->defaults) && count($route->defaults) > 0)
+	      else
 		{
-		  foreach ($route->defaults as $key=>$val)
-		    {
-		      $_REQUEST[$matches['id'] . $key] = $val;
-		      if (array_key_exists($key, $matches))
-			{ 
-			  $matches[$key] = $val;
-			}
-		    }
+		  if ($key != 'id')
+		    $_REQUEST[$matches['id'] . $key] = $val;
 		}
-
-	      //Get a decent returnid
-	      if ($matches['returnid'] == '') {
-		$matches['returnid'] = $contentops->GetDefaultPageID();
-	      }
-
-	      $_REQUEST['mact'] = $matches['module'] . ',' . $matches['id'] . ',' . $matches['action'] . ',' . $matches['inline'];
-
-	      $page = $matches['returnid'];
-	      $smarty->id = $matches['id'];
-
-	      $matched = true;
-	      break;
 	    }
+
+	  //Now set any defaults that might not have been in the url
+	  $tmp = $route->get_defaults();
+	  if (is_array($tmp) && count($tmp) > 0)
+	    {
+	      foreach ($tmp as $key=>$val)
+		{
+		  $_REQUEST[$matches['id'] . $key] = $val;
+		  if (array_key_exists($key, $matches))
+		    { 
+		      $matches[$key] = $val;
+		    }
+		}
+	    }
+
+	  //Get a decent returnid
+	  if ($matches['returnid'] == '') {
+	    $matches['returnid'] = $contentops->GetDefaultPageID();
+	  }
+
+	  // Put the resulting mact into the request so that the subsequent smarty plugins
+	  // can grab it...
+	  $_REQUEST['mact'] = $matches['module'] . ',' . $matches['id'] . ',' . $matches['action'] . ',' . $matches['inline'];
+
+	  $page = $matches['returnid'];
+	  $smarty->id = $matches['id'];
 	}
     }
 
-  if( !$matched )
-    {
-      // call modules to see if they can match the URL
-      foreach( $gCms->modules as $key => &$data )
-	{
-	  if( !isset($data['installed']) || $data['installed'] == FALSE ) continue;
-
-	  $module =& $data['object'];
-	  $res = $module->IsValidRoute($page);
-	  if( !is_array($res) ) continue;
-
-	  $tmp = array('id'=>'cntnt01','action'=>'defaulturl',
-		       'inline'=>0,'returnid'=>'','module'=>$key);
-	  $tmp = array_merge($tmp,$res);
-
-	  foreach( $tmp as $key => $value )
-	    {
-	      switch( $key )
-		{
-		case 'returnid':
-		case 'module':
-		case 'id':
-		case 'inline':
-		  // do nothing.
-		  break;
-
-		case 'action':
-		  $_REQUEST['mact'] = $tmp['module'] . ',' . $tmp['id'] . ',' . $tmp['action'] . ',' . $tmp['inline'];
-		  break;
-
-		default:
-		  $_REQUEST[$tmp['id'].$key] = $value;
-		}
-	    }
-	  
-	  $page = $tmp['returnid'];
-	  $smarty->id = $tmp['id'];
-	  $matched = true;
-	}
-    }
-
-  // if noroute matched... grab the alias from the last /
+  // if no route matched... grab the alias from the last /
   if( ($pos = strrpos($page,'/')) !== FALSE && $matched == false )
     {
       $page = substr($page, $pos + 1);
     }
 
-  // at this point we MUST have a valid page
+  // if there's nothing use the default content.
   if( empty($page) )
     {
       // maybe it's the home page.
       $page = $contentops->GetDefaultContent();
     }
-  
+
   return $page;
 }
+
+
+/**
+ * Function to return the current page id.
+ * 
+ * Will return FALSE if in an admin action.
+ *
+ * @return integer pageid indicating the current page, or FALSE.
+ */
+function cms_get_current_pageid()
+{
+  global $gCms;
+
+  if( isset($gCms->variables['page_id']) )
+    {
+      return (int)$gCms->variables['page_id'];
+    }
+  return FALSE;
+}
 # vim:ts=4 sw=4 noet
 ?>
