@@ -25,6 +25,13 @@
  * @ignore
  */
 
+$lang_fn = 'lang';
+global $CMS_INSTALL_PAGE;
+if( isset($CMS_INSTALL_PAGE) )
+	{
+		$lang_fn = 'ilang';
+	}
+
 /**
  * A class for working with tests
  * 
@@ -145,22 +152,23 @@ function extension_loaded_or( $test )
 */
 function getTestReturn( &$test, $required, $message = '', $error_fragment = '', $error = '' )
 {
+	global $lang_fn;
 	switch($test->res)
 	{
 		case 'green':
 			list($test->continueon, $test->special_failed) = testGlobal('');
-			$test->res_text = lang('success');
+			$test->res_text = $lang_fn('success');
 			break;
 		case 'yellow':
 		case 'red':
 			list($test->continueon, $test->special_failed) = testGlobal($required);
 			if($test->res == 'yellow')
 			{
-				$test->res_text = lang('caution');
+				$test->res_text = $lang_fn('caution');
 			}
 			elseif($test->res == 'red')
 			{
-				$test->res_text = lang('failure');
+				$test->res_text = $lang_fn('failure');
 			}
 
 			if(trim($message) != '')
@@ -190,6 +198,8 @@ function getTestReturn( &$test, $required, $message = '', $error_fragment = '',
 */
 function & testSupportedDatabase( $required, $title, $db = false, $message = '' )
 {
+	global $lang_fn;
+	
 	$drivers = getSupportedDBDriver();
 
 //TODO?
@@ -259,7 +269,7 @@ function & testSupportedDatabase( $required, $title, $db = false, $message = ''
 	else
 	{
 		$test->res = 'red';
-		getTestReturn($test, $required, $message, 'DB_driver_missing', lang('no_db_driver'));
+		getTestReturn($test, $required, $message, 'DB_driver_missing', $lang_fn('no_db_driver'));
 	}
 
 	return $test;
@@ -507,6 +517,7 @@ function & testIntegerMask($required,$title,$var,$mask,$message = '',$ini = true
 */
 function & testInteger( $required, $title, $var, $message = '', $ini = true, $empty_is_ok = true, $error_fragment = '' )
 {
+	global $lang_fn;
 	$test = new CmsInstallTest();
 	$test->title = $title;
 
@@ -521,7 +532,7 @@ function & testInteger( $required, $title, $var, $message = '', $ini = true, $em
 
 	if($test->ini_val === '')
 	{
-		if($empty_is_ok) $test->value = lang('on');
+		if($empty_is_ok) $test->value = $lang_fn('on');
 		else $test->value = 0;
 	}
 	else
@@ -601,6 +612,7 @@ function & testString( $required, $title, $var, $message = '', $ini = true, $cod
 */
 function & testBoolean( $required, $title, $var, $message = '', $ini = true, $negative_test = false, $error_fragment = '' )
 {
+	global $lang_fn;
 	$test = new CmsInstallTest();
 	$test->title = $title;
 
@@ -616,8 +628,8 @@ function & testBoolean( $required, $title, $var, $message = '', $ini = true, $ne
 
 	if($test->ini_val == false)
 	{
-		$test->value = $negative_test ? lang('on') : lang('off');
-		$test->secondvalue = $negative_test ? lang('true') : lang('false');
+		$test->value = $negative_test ? $lang_fn('on') : $lang_fn('off');
+		$test->secondvalue = $negative_test ? $lang_fn('true') : $lang_fn('false');
 		if($required)
 		{
 			$test->res = 'red';
@@ -629,8 +641,8 @@ function & testBoolean( $required, $title, $var, $message = '', $ini = true, $ne
 	}
 	else
 	{
-		$test->value = $negative_test ? lang('off') : lang('on');
-		$test->secondvalue = $negative_test ? lang('false') : lang('true');
+		$test->value = $negative_test ? $lang_fn('off') : $lang_fn('on');
+		$test->secondvalue = $negative_test ? $lang_fn('false') : $lang_fn('true');
 		$test->res = 'green';
 	}
 
@@ -673,7 +685,7 @@ function & testVersionRange( $required, $title, $var, $message = '', $minimum, $
 
 	if( (! is_null($unlimited)) && ($test->ini_val == (string) $unlimited) )
 	{
-		$test->value = lang('unlimited');
+		$test->value = $lang_fn('unlimited');
 		$test->res = 'green';
 		getTestReturn($test, $required);
 	}
@@ -713,6 +725,8 @@ function & testRange( $required, $title, $var, $message = '', $minimum, $recomme
 {
 	$test = new CmsInstallTest();
 	$test->title = $title;
+	
+	global $lang_fn;
 
 	if($ini)
 	{
@@ -738,7 +752,7 @@ function & testRange( $required, $title, $var, $message = '', $minimum, $recomme
 
 	if( (! is_null($unlimited)) && ((int) $test->ini_val == (int) $unlimited) )
 	{
-		$test->value = lang('unlimited');
+		$test->value = $lang_fn('unlimited');
 		$test->res = 'green';
 		getTestReturn($test, $required);
 	}
@@ -800,6 +814,8 @@ function & testUmask( $required, $title, $umask, $message = '', $debug = false,
 {
 	$test = new CmsInstallTest();
 	$test->title = $title;
+	
+	global $lang_fn;
 
 	if(empty($dir))
 	{
@@ -820,7 +836,7 @@ function & testUmask( $required, $title, $umask, $message = '', $debug = false,
 	if(! $_test)
 	{
 		$test->res = 'red';
-		getTestReturn($test, $required, $message, 'Directory_not_writable', lang('errordirectorynotwritable').' ('.$dir .')');
+		getTestReturn($test, $required, $message, 'Directory_not_writable', $lang_fn('errordirectorynotwritable').' ('.$dir .')');
 		return $test;
 	}
 	$_test = true;
@@ -861,7 +877,7 @@ function & testUmask( $required, $title, $umask, $message = '', $debug = false,
 			{
 				$test->res = 'yellow';
 			}
-			getTestReturn($test, $required, $message, 'Can.27t_create_file', lang('errorcantcreatefile').' ('.$test_file.')');
+			getTestReturn($test, $required, $message, 'Can.27t_create_file', $lang_fn('errorcantcreatefile').' ('.$test_file.')');
 			return $test;
 		}
 
@@ -878,7 +894,7 @@ function & testUmask( $required, $title, $umask, $message = '', $debug = false,
 	}
 
 	$test->res = 'red';
-	getTestReturn($test, $required, $message, 'Can.27t_create_file', lang('errorcantcreatefile').' ('.$test_file.')');
+	getTestReturn($test, $required, $message, 'Can.27t_create_file', $lang_fn('errorcantcreatefile').' ('.$test_file.')');
 	return $test;
 }
 
@@ -891,6 +907,7 @@ function & testUmask( $required, $title, $umask, $message = '', $debug = false,
  */
 function permission_stat( $file, $debug = false )
 {
+	global $lang_fn;
 	$opt = array();
 	clearstatcache();
 	$filestat = stat($file);
@@ -919,13 +936,13 @@ function permission_stat( $file, $debug = false )
 			$userinfo = @posix_getpwuid($filestat[4]);
 			$groupinfo = @posix_getgrgid($filestat[5]);
 		}
-		$opt['username'] = isset($userinfo['name']) ? $userinfo['name'] : lang('unknown');
-		$opt['usergroup'] = isset($groupinfo['name']) ? $groupinfo['name'] : lang('unknown');
+		$opt['username'] = isset($userinfo['name']) ? $userinfo['name'] : $lang_fn('unknown');
+		$opt['usergroup'] = isset($groupinfo['name']) ? $groupinfo['name'] : $lang_fn('unknown');
 	}
 	else
 	{
-		$opt['username'] = lang('unknown');
-		$opt['usergroup'] = lang('unknown');
+		$opt['username'] = $lang_fn('unknown');
+		$opt['usergroup'] = $lang_fn('unknown');
 	}
 
 	return $opt;
@@ -997,14 +1014,16 @@ function & testCreateDirAndFile( $required, $title, $message = '', $debug = fals
 	$test->title = $title;
 	$dir = cms_join_path(TMP_CACHE_LOCATION, $dir);
 	$file = cms_join_path($dir, $file);
+	
+	global $lang_fn;
 
 	if($debug)
 	{
 		if(file_exists($file)) unlink($file);
 		if( (is_dir($dir)) && (false !== strpos($dir, dirname(dirname(__FILE__)))) ) rmdir($dir);
 
-		if(! mkdir($dir)) $test->error = lang('errordirectorynotwritable') .' ('. $dir . ')';
-		if(! touch($file)) $test->error = lang('errorcantcreatefile') .' ('. $file . ')';
+		if(! mkdir($dir)) $test->error = $lang_fn('errordirectorynotwritable') .' ('. $dir . ')';
+		if(! touch($file)) $test->error = $lang_fn('errorcantcreatefile') .' ('. $file . ')';
 		$_test = file_exists($file);
 	}
 	else
@@ -1107,7 +1126,8 @@ function & testDirWrite( $required, $title, $dir, $message = '', $quick = 0, $de
 	}
 
 	$test->res = 'red';
-	getTestReturn($test, $required, $message, 'Directory_not_writable', lang('errordirectorynotwritable').' ('.$dir.')');
+	global $lang_fn;
+	getTestReturn($test, $required, $message, 'Directory_not_writable', $lang_fn('errordirectorynotwritable').' ('.$dir.')');
 	return $test;
 }
 
@@ -1123,10 +1143,12 @@ function & testFileWritable( $required, $title, $file, $message = '', $debug = f
 {
 	$test = new CmsInstallTest();
 	$test->title = $title;
+	
+	global $lang_fn;
 
 	if(empty($file))
 	{
-		$test->error = lang('errorfilenot');
+		$test->error = $lang_fn('errorfilenot');
 		return $test;
 	}
 
@@ -1162,7 +1184,7 @@ function & testFileWritable( $required, $title, $file, $message = '', $debug = f
 	}
 
 	$test->res = 'red';
-	getTestReturn($test, $required, $message, 'File_not_writable', lang('errorfilenotwritable').' ('.$file.')');
+	getTestReturn($test, $required, $message, 'File_not_writable', $lang_fn('errorfilenotwritable').' ('.$file.')');
 	return $test;
 }
 
@@ -1178,6 +1200,7 @@ function & testFileWritable( $required, $title, $file, $message = '', $debug = f
 */
 function & testRemoteFile( $required, $title, $url = '', $message = '', $debug = false, $timeout = 10, $search = 'cmsmadesimple' )
 {
+	global $lang_fn;
 	if(empty($url))
 	{
 		$url = 'http://dev.cmsmadesimple.org/latest_version.php';
@@ -1191,200 +1214,211 @@ function & testRemoteFile( $required, $title, $url = '', $message = '', $debug =
 	{
 		// Relative or invalid URL?
 		$test->res = 'red';
-		getTestReturn($test, $required, '', '', lang('invalid_test'));
+		getTestReturn($test, $required, '', '', $lang_fn('invalid_test'));
 		return $test;
 	}
 
-	switch($url_info['scheme'])
-	{
-		case 'https':
-			$scheme = 'ssl://';
-			$port = (isset($url_info['port'])) ? $url_info['port'] : 443;
-			break;
-		case 'http':
-		default:
-			$scheme = '';
-			$port = (isset($url_info['port'])) ? $url_info['port'] : 80;
-	}
-	$complete_url  = (isset($url_info['path'])) ? $url_info['path'] : '/';
-	$complete_url .= (isset($url_info['query'])) ? '?'.$url_info['query'] : '';
-
-
-	// TEST FSOCKOPEN
-	if($debug) $handle = fsockopen($scheme . $url_info['host'], $port, $errno, $errstr, $timeout);
-	else       $handle = @fsockopen($scheme . $url_info['host'], $port, $errno, $errstr, $timeout);
-	if($handle)
-	{
-		$out  = "GET " . $complete_url . " HTTP/1.1\r\n";
-		$out .= "Host: " . $url_info['host'] . "\r\n";
-		$out .= "Connection: Close\r\n\r\n";
-		if($debug)
-		{
-			fwrite($handle, $out);
-			stream_set_blocking($handle, 1);
-			stream_set_timeout($handle, $timeout);
-			$_info = stream_get_meta_data($handle);
-		}
-		else
-		{
-			@fwrite($handle, $out);
-			@stream_set_blocking($handle, 1);
-			@stream_set_timeout($handle, $timeout);
-			$_info = @stream_get_meta_data($handle);
-		}
-
-		$content_fsockopen = '';
-		while( (! feof($handle)) && (! $_info['timed_out']) )
-		{
-			if($debug) $content_fsockopen .= fgets($handle, 128);
-			else       $content_fsockopen .= @fgets($handle, 128);
-			$_info = stream_get_meta_data($handle);
-		}
-		@fclose($handle);
-
-		if($_info['timed_out'])
-		{
-			$test->opt['fsockopen']['ok'] = 1;
-			$test->opt['fsockopen']['res'] = 'yellow';
-			$test->opt['fsockopen']['res_text'] = lang('caution');
-			$test->opt['fsockopen']['message'] = lang('remote_connection_timeout');
-		}
-		else
-		{
-			$test->opt['fsockopen']['ok'] = 0;
-		}
-	}
-	else
+	if( !isset($url_info['scheme']) || !isset($url_info['host']) )
 	{
 		$test->res = 'red';
-		getTestReturn($test, $required, '', '', lang('connection_error'));
+		getTestReturn($test, $required, '', '', $lang_fn('invalid_url'));
 		return $test;
 	}
-
-	if($test->opt['fsockopen']['ok'] < 1)
-	{
-		if( (! empty($search)) && (false !== strpos($content_fsockopen, $search)) )
-		{
-			$test->opt['fsockopen']['res'] = 'green';
-			$test->opt['fsockopen']['res_text'] = lang('success');
-			$test->opt['fsockopen']['message'] = lang('search_string_find');
-		}
-		elseif(false !== strpos($content_fsockopen, '200 OK'))
-		{
-			$test->opt['fsockopen']['ok'] = 1;
-			$test->opt['fsockopen']['res'] = 'yellow';
-			$test->opt['fsockopen']['res_text'] = lang('caution');
-			$test->opt['fsockopen']['message'] = lang('remote_response_ok');
-		}
-		elseif(false !== strpos($content_fsockopen, '404 Not Found'))
-		{
-			$test->opt['fsockopen']['ok'] = 1;
-			$test->opt['fsockopen']['res'] = 'yellow';
-			$test->opt['fsockopen']['res_text'] = lang('caution');
-			$test->opt['fsockopen']['message'] = lang('remote_response_404');
-		}
-		else
-		{
-			$test->opt['fsockopen']['ok'] = 2;
-			$test->opt['fsockopen']['res'] = 'red';
-			$test->opt['fsockopen']['res_text'] = lang('failure');
-			$test->opt['fsockopen']['message'] = lang('remote_response_error');
-		}
-	}
-
-
-	// TEST FOPEN
-	$test->opt['fopen']['ok'] = 2;
-	$result = testBoolean('', '', 'allow_url_fopen', '', true, false);
-	if($result->res == 'green')
-	{
-		if($debug) $handle = fopen($url, 'rb');
-		else       $handle = @fopen($url, 'rb');
-		if(false == $handle)
-		{
-			$test->opt['fopen']['ok'] = 2;
-			$test->opt['fopen']['res'] = 'red';
-			$test->opt['fopen']['res_text'] = lang('failure');
-			$test->opt['fopen']['message'] = lang('connection_failed');
-		}
-		else
-		{
-			if($debug)
-			{
-				stream_set_blocking($handle, 1);
-				stream_set_timeout($handle, $timeout);
-				$_info = stream_get_meta_data($handle);
-			}
-			else
-			{
-				@stream_set_blocking($handle, 1);
-				@stream_set_timeout($handle, $timeout);
-				$_info = @stream_get_meta_data($handle);
-			}
-
-			$content_fopen = '';
-			while( (! feof($handle)) && (! $_info['timed_out']) )
-			{
-				if($debug) $content_fopen .= fgets($handle, 128);
-				else       $content_fopen .= @fgets($handle, 128);
-				$_info = stream_get_meta_data($handle);
-			}
-			@fclose($handle);
-
-			if($_info['timed_out'])
-			{
-				$test->opt['fopen']['ok'] = 1;
-				$test->opt['fopen']['res'] = 'yellow';
-				$test->opt['fopen']['res_text'] = lang('caution');
-				$test->opt['fopen']['message'] = lang('remote_connection_timeout');
-			}
-			else
-			{
-				$test->opt['fopen']['ok'] = 0;
-			}
-		}
-	}
 	else
 	{
-		$test->opt['fopen']['res'] = 'red';
-		$test->opt['fopen']['res_text'] = lang('failure');
-		$test->opt['fopen']['message'] = lang('test_allow_url_fopen_failed');
-	}
+		switch($url_info['scheme'])
+			{
+			case 'https':
+				$scheme = 'ssl://';
+				$port = (isset($url_info['port'])) ? $url_info['port'] : 443;
+				break;
+			case 'http':
+			default:
+				$scheme = '';
+				$port = (isset($url_info['port'])) ? $url_info['port'] : 80;
+			}
+		$complete_url  = (isset($url_info['path'])) ? $url_info['path'] : '/';
+		$complete_url .= (isset($url_info['query'])) ? '?'.$url_info['query'] : '';
 
 
-	if($test->opt['fopen']['ok'] < 1)
-	{
-		if( (! empty($search)) && (false !== strpos($content_fopen, $search)) )
-		{
-			$test->opt['fopen']['res'] = 'green';
-			$test->opt['fopen']['res_text'] = lang('success');
-			$test->opt['fopen']['message'] = lang('search_string_find');
-		}
-		elseif(false !== strpos($content_fopen, '200 OK'))
-		{
-			$test->opt['fopen']['ok'] = 1;
-			$test->opt['fopen']['res'] = 'yellow';
-			$test->opt['fopen']['res_text'] = lang('caution');
-			$test->opt['fopen']['message'] = lang('remote_response_ok');
-		}
-		elseif(false !== strpos($content_fopen, '404 Not Found'))
-		{
-			$test->opt['fopen']['ok'] = 1;
-			$test->opt['fopen']['res'] = 'yellow';
-			$test->opt['fopen']['res_text'] = lang('caution');
-			$test->opt['fopen']['message'] = lang('remote_response_404');
-		}
+		// TEST FSOCKOPEN
+		if($debug) $handle = fsockopen($scheme . $url_info['host'], $port, $errno, $errstr, $timeout);
+		else       $handle = @fsockopen($scheme . $url_info['host'], $port, $errno, $errstr, $timeout);
+		if($handle)
+			{
+				$out  = "GET " . $complete_url . " HTTP/1.1\r\n";
+				$out .= "Host: " . $url_info['host'] . "\r\n";
+				$out .= "Connection: Close\r\n\r\n";
+				if($debug)
+					{
+						fwrite($handle, $out);
+						stream_set_blocking($handle, 1);
+						stream_set_timeout($handle, $timeout);
+						$_info = stream_get_meta_data($handle);
+					}
+				else
+					{
+						@fwrite($handle, $out);
+						@stream_set_blocking($handle, 1);
+						@stream_set_timeout($handle, $timeout);
+						$_info = @stream_get_meta_data($handle);
+					}
+
+				$content_fsockopen = '';
+				while( (! feof($handle)) && (! $_info['timed_out']) )
+					{
+						if($debug) $content_fsockopen .= fgets($handle, 128);
+						else       $content_fsockopen .= @fgets($handle, 128);
+						$_info = stream_get_meta_data($handle);
+					}
+				@fclose($handle);
+
+				if($_info['timed_out'])
+					{
+						$test->opt['fsockopen']['ok'] = 1;
+						$test->opt['fsockopen']['res'] = 'yellow';
+						$test->opt['fsockopen']['res_text'] = $lang_fn('caution');
+						$test->opt['fsockopen']['message'] = $lang_fn('remote_connection_timeout');
+					}
+				else
+					{
+						$test->opt['fsockopen']['ok'] = 0;
+					}
+			}
 		else
-		{
-			$test->opt['fopen']['ok'] = 2;
-			$test->opt['fopen']['res'] = 'red';
-			$test->opt['fopen']['res_text'] = lang('failure');
-			$test->opt['fopen']['message'] = lang('remote_response_error');
-		}
+			{
+				$test->res = 'red';
+				getTestReturn($test, $required, '', '', $lang_fn('connection_error'));
+				$test->continueon = 0;
+				return $test;
+			}
+
+		if($test->opt['fsockopen']['ok'] < 1)
+			{
+				if( (! empty($search)) && (false !== strpos($content_fsockopen, $search)) )
+					{
+						$test->opt['fsockopen']['res'] = 'green';
+						$test->opt['fsockopen']['res_text'] = $lang_fn('success');
+						$test->opt['fsockopen']['message'] = $lang_fn('search_string_find');
+					}
+				elseif(false !== strpos($content_fsockopen, '200 OK'))
+					{
+						$test->opt['fsockopen']['ok'] = 1;
+						$test->opt['fsockopen']['res'] = 'yellow';
+						$test->opt['fsockopen']['res_text'] = $lang_fn('caution');
+						$test->opt['fsockopen']['message'] = $lang_fn('remote_response_ok');
+					}
+				elseif(false !== strpos($content_fsockopen, '404 Not Found'))
+					{
+						$test->opt['fsockopen']['ok'] = 1;
+						$test->opt['fsockopen']['res'] = 'yellow';
+						$test->opt['fsockopen']['res_text'] = $lang_fn('caution');
+						$test->opt['fsockopen']['message'] = $lang_fn('remote_response_404');
+					}
+				else
+					{
+						$test->opt['fsockopen']['ok'] = 2;
+						$test->opt['fsockopen']['res'] = 'red';
+						$test->opt['fsockopen']['res_text'] = $lang_fn('failure');
+						$test->opt['fsockopen']['message'] = $lang_fn('remote_response_error');
+					}
+			}
+
+
+		// TEST FOPEN
+		$test->opt['fopen']['ok'] = 2;
+		$result = testBoolean('', '', 'allow_url_fopen', '', true, false);
+		if($result->res == 'green')
+			{
+				if($debug) $handle = fopen($url, 'rb');
+				else       $handle = @fopen($url, 'rb');
+				if(false == $handle)
+					{
+						$test->opt['fopen']['ok'] = 2;
+						$test->opt['fopen']['res'] = 'red';
+						$test->opt['fopen']['res_text'] = $lang_fn('failure');
+						$test->opt['fopen']['message'] = $lang_fn('connection_failed');
+					}
+				else
+					{
+						if($debug)
+							{
+								stream_set_blocking($handle, 1);
+								stream_set_timeout($handle, $timeout);
+								$_info = stream_get_meta_data($handle);
+							}
+						else
+							{
+								@stream_set_blocking($handle, 1);
+								@stream_set_timeout($handle, $timeout);
+								$_info = @stream_get_meta_data($handle);
+							}
+
+						$content_fopen = '';
+						while( (! feof($handle)) && (! $_info['timed_out']) )
+							{
+								if($debug) $content_fopen .= fgets($handle, 128);
+								else       $content_fopen .= @fgets($handle, 128);
+								$_info = stream_get_meta_data($handle);
+							}
+						@fclose($handle);
+
+						if($_info['timed_out'])
+							{
+								$test->opt['fopen']['ok'] = 1;
+								$test->opt['fopen']['res'] = 'yellow';
+								$test->opt['fopen']['res_text'] = $lang_fn('caution');
+								$test->opt['fopen']['message'] = $lang_fn('remote_connection_timeout');
+							}
+						else
+							{
+								$test->opt['fopen']['ok'] = 0;
+							}
+					}
+			}
+		else
+			{
+				$test->opt['fopen']['res'] = 'red';
+				$test->opt['fopen']['res_text'] = $lang_fn('failure');
+				$test->opt['fopen']['message'] = $lang_fn('test_allow_url_fopen_failed');
+			}
+
+
+		if($test->opt['fopen']['ok'] < 1)
+			{
+				if( (! empty($search)) && (false !== strpos($content_fopen, $search)) )
+					{
+						$test->opt['fopen']['res'] = 'green';
+						$test->opt['fopen']['res_text'] = $lang_fn('success');
+						$test->opt['fopen']['message'] = $lang_fn('search_string_find');
+					}
+				elseif(false !== strpos($content_fopen, '200 OK'))
+					{
+						$test->opt['fopen']['ok'] = 1;
+						$test->opt['fopen']['res'] = 'yellow';
+						$test->opt['fopen']['res_text'] = $lang_fn('caution');
+						$test->opt['fopen']['message'] = $lang_fn('remote_response_ok');
+					}
+				elseif(false !== strpos($content_fopen, '404 Not Found'))
+					{
+						$test->opt['fopen']['ok'] = 1;
+						$test->opt['fopen']['res'] = 'yellow';
+						$test->opt['fopen']['res_text'] = $lang_fn('caution');
+						$test->opt['fopen']['message'] = $lang_fn('remote_response_404');
+					}
+				else
+					{
+						$test->opt['fopen']['ok'] = 2;
+						$test->opt['fopen']['res'] = 'red';
+						$test->opt['fopen']['res_text'] = $lang_fn('failure');
+						$test->opt['fopen']['message'] = $lang_fn('remote_response_error');
+					}
+			}
+
+
+		$result = $test->opt['fsockopen']['ok'] + $test->opt['fopen']['ok'];
 	}
 
-
-	$result = $test->opt['fsockopen']['ok'] + $test->opt['fopen']['ok'];
 	switch($result)
 	{
 		case 0:
@@ -1421,20 +1455,22 @@ function & testFileChecksum( $required, $title, $file, $checksum, $message = '',
 	$test = new CmsInstallTest();
 	$test->title = $title;
 	$test->value = $file;
+	
+	global $lang_fn;
 
 	if(is_dir($file))
 	{
-		$test->secondvalue = lang('is_directory');
+		$test->secondvalue = $lang_fn('is_directory');
 		$test->res = 'yellow';
-		getTestReturn($test, '', '', '', lang('is_directory').' ('.$file.')');
+		getTestReturn($test, '', '', '', $lang_fn('is_directory').' ('.$file.')');
 		return $test;
 	}
 
 	if(! file_exists($file))
 	{
-		$test->secondvalue = lang('nofiles');
+		$test->secondvalue = $lang_fn('nofiles');
 		$test->res = 'red';
-		getTestReturn($test, '', $message, '', lang('nofiles').' ('.$file.')');
+		getTestReturn($test, '', $message, '', $lang_fn('nofiles').' ('.$file.')');
 		return $test;
 	}
 
@@ -1442,9 +1478,9 @@ function & testFileChecksum( $required, $title, $file, $checksum, $message = '',
 	else       $_test = @is_readable($file);
 	if(! $_test)
 	{
-		$test->secondvalue = lang('is_readable_false');
+		$test->secondvalue = $lang_fn('is_readable_false');
 		$test->res = 'yellow';
-		getTestReturn($test, '', '', '', lang('is_readable_false').' ('.$file.')');
+		getTestReturn($test, '', '', '', $lang_fn('is_readable_false').' ('.$file.')');
 		return $test;
 	}
 
@@ -1452,15 +1488,15 @@ function & testFileChecksum( $required, $title, $file, $checksum, $message = '',
 	else       $file_checksum = @md5_file($file);
 	if(false == $file_checksum)
 	{
-		$test->secondvalue = lang('not_checksum');
+		$test->secondvalue = $lang_fn('not_checksum');
 		$test->res = 'yellow';
-		getTestReturn($test, '', '', '', lang('not_checksum').' ('.$file.')');
+		getTestReturn($test, '', '', '', $lang_fn('not_checksum').' ('.$file.')');
 		return $test;
 	}
 
 	if($file_checksum == $checksum)
 	{
-		$test->secondvalue = lang('checksum_match');
+		$test->secondvalue = $lang_fn('checksum_match');
 		$test->res = 'green';
 		getTestReturn($test, $required);
 		return $test;
@@ -1470,9 +1506,9 @@ function & testFileChecksum( $required, $title, $file, $checksum, $message = '',
 	else       $test->opt['file_timestamp'] = @filemtime($file);
 	$test->opt['format_timestamp'] = $formattime;
 
-	$test->secondvalue = lang('checksum_not_match');
+	$test->secondvalue = $lang_fn('checksum_not_match');
 	$test->res = 'red';
-	getTestReturn($test, $required, $message, '', lang('checksum_not_match'));
+	getTestReturn($test, $required, $message, '', $lang_fn('checksum_not_match'));
 	return $test;
 }
 
@@ -1529,14 +1565,16 @@ function testSessionSavePath( $sess_path )
 */
 function & testFileUploads( $inputname )
 {
+	global $lang_fn;
+	
 	$_errors = array(
-		UPLOAD_ERR_INI_SIZE => lang('upload_err_ini_size'),
-		UPLOAD_ERR_FORM_SIZE => lang('upload_err_form_size'),
-		UPLOAD_ERR_PARTIAL => lang('upload_err_partial'),
-		UPLOAD_ERR_NO_FILE => lang('upload_err_no_file'),
-		UPLOAD_ERR_NO_TMP_DIR => lang('upload_err_no_tmp_dir'), //at least PHP 4.3.10 or PHP 5.0.3
-		UPLOAD_ERR_CANT_WRITE => lang('upload_err_cant_write'), //at least PHP 5.1.0
-		UPLOAD_ERR_EXTENSION => lang('upload_err_extension'), //at least PHP 5.2.0
+		UPLOAD_ERR_INI_SIZE => $lang_fn('upload_err_ini_size'),
+		UPLOAD_ERR_FORM_SIZE => $lang_fn('upload_err_form_size'),
+		UPLOAD_ERR_PARTIAL => $lang_fn('upload_err_partial'),
+		UPLOAD_ERR_NO_FILE => $lang_fn('upload_err_no_file'),
+		UPLOAD_ERR_NO_TMP_DIR => $lang_fn('upload_err_no_tmp_dir'), //at least PHP 4.3.10 or PHP 5.0.3
+		UPLOAD_ERR_CANT_WRITE => $lang_fn('upload_err_cant_write'), //at least PHP 5.1.0
+		UPLOAD_ERR_EXTENSION => $lang_fn('upload_err_extension'), //at least PHP 5.2.0
 	);
 
 	function orderFiles(&$file_upl)
@@ -1559,14 +1597,14 @@ function & testFileUploads( $inputname )
 	if($result->res != 'green')
 	{
 		$test->res = 'red';
-		getTestReturn($test, '', '', 'Function_file_uploads_disabled', lang('function_file_uploads_off'));
+		getTestReturn($test, '', '', 'Function_file_uploads_disabled', $lang_fn('function_file_uploads_off'));
 		return $test;
 	}
 
 	if(! isset($_FILES["$inputname"]))
 	{
 		$test->res = 'red';
-		getTestReturn($test, '', '', '', lang('error_nofileuploaded'));
+		getTestReturn($test, '', '', '', $lang_fn('error_nofileuploaded'));
 		return $test;
 	}
 
@@ -1586,15 +1624,15 @@ function & testFileUploads( $inputname )
 			}
 			elseif($_file['size'] == 0)
 			{
-				$_data['error_string'] = lang('upload_err_empty');
+				$_data['error_string'] = $lang_fn('upload_err_empty');
 			}
 			elseif(! is_readable($_file['tmp_name']))
 			{
-				$_data['error_string'] = lang('upload_file_no_readable');
+				$_data['error_string'] = $lang_fn('upload_file_no_readable');
             }
 			else
 			{
-				$_data['error_string'] = lang('upload_err_unknown');
+				$_data['error_string'] = $lang_fn('upload_err_unknown');
 			}
 		}
 
@@ -1667,5 +1705,6 @@ function GDVersion()
 
 	return $gd_version_number;
 }
+
 # vim:ts=4 sw=4 noet
 ?>
