@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: translation.functions.php 6525 2010-07-29 11:07:08Z wishy $
+#$Id: translation.functions.php 6809 2010-11-20 20:23:05Z wishy $
 
 /**
  * Translation functions/classes
@@ -24,6 +24,78 @@
  * @package CMS
  */
 
+/**
+ * A function to attempt to find a language given browser settings
+ *
+ * @internal
+ * @return string
+ */
+function cms_detect_browser_lang()
+{
+  global $gCms;
+  $nls =& $gCms->nls;
+  $curlang = '';
+
+  # take a stab at figuring out the default language...
+  # Figure out default language and set it if it exists
+  if (isset($_SERVER["HTTP_ACCEPT_LANGUAGE"])) 
+    {
+      $alllang = $_SERVER["HTTP_ACCEPT_LANGUAGE"];
+      if (strpos($alllang, ";") !== FALSE)
+	$alllang = substr($alllang,0,strpos($alllang, ";"));
+      $langs = explode(",", $alllang);
+	  
+      foreach ($langs as $onelang)
+	{
+	  // Check to see if lang exists...
+	  if (isset($nls['language'][$onelang]))
+	    {
+	      $curlang = $onelang;
+	      break;
+	    }
+#Check to see if alias exists...
+	  if (isset($nls['alias'][$onelang]))
+	    {
+	      $alias = $nls['alias'][$onelang];
+	      if (isset($nls['language'][$alias]))
+		{
+		  $curlang = $alias;
+		  break;
+		}
+	    }
+	}
+    }
+
+  return $curlang;
+}
+
+/** 
+ * A function to initialize the nls array
+ *
+ * @internal
+ * @return void
+ */
+function cms_initialize_nls()
+{
+	#Read in all current languages...
+	global $gCms;
+	$nls =& $gCms->nls;
+
+	if( !is_array($nls) || count($nls) == 0 )
+	{
+		$nls = array();
+		$dir = cms_join_path($gCms->config['root_path'],$gCms->config['admin_dir'],'/lang');
+		$handle = opendir($dir);
+		while ($handle && false !== ($file = readdir($handle))) {
+			if (is_file("$dir/$file") && strpos($file, "nls.php") != 0) {
+				include("$dir/$file");
+			}
+		}
+		closedir($handle);
+	}
+}
+
+
 /**
  * A function to return the current admin language
  *
@@ -33,112 +105,72 @@
 function cms_admin_current_language()
 {
   global $gCms;
-  global $nls;
-  $nls = array();
+  $nls =& $gCms->nls;
   $lang = array();
   $current_language = '';
 
-  #Read in all current languages...
-  if( !count($nls) )
-    {
-      $dir = cms_join_path($gCms->config['root_path'],$gCms->config['admin_dir'],'/lang');
-      
-      $handle = opendir($dir);
-      while (false!==($file = readdir($handle))) {
-	if (is_file("$dir/$file") && strpos($file, "nls.php") != 0) {
-	  include("$dir/$file");
-	}
-      }
-      closedir($handle);
-    }
+  cms_initialize_nls();
 
-  #Check to see if there is already a language in use...
-  if (isset($_POST["default_cms_lang"]) )
+  $uid = get_userid(false);
+  if( $uid )
     {
-      $tmp = basename($_POST['default_cms_lang']);
-      if( isset($nls['language'][$tmp]) ||
-	  isset($nls['alias'][$tmp]) )
+      // user is logged in (this is after the admin login)
+      // get his preference.
+      $current_language = get_preference(get_userid(false),'default_cms_language');
+      if( $current_language == '' || 
+	  (!isset($nls['language'][$current_language]) && !isset($nls['alias'][$current_language])) )
 	{
-	  $current_language = $tmp;
-	  if ($current_language == '')
-	    {
-	      setcookie("cms_language", '', time() - 3600);
-	    }
-	  else if (isset($_POST["change_cms_lang"]))
-	    {
-	      setcookie("cms_language", basename($_POST["change_cms_lang"]));
-	    }
+	  // preferred lang doesn't exist
+	  $current_language = '';
 	}
     }
-  else if (isset($_SESSION['login_cms_language']))
-    {
-      debug_buffer('Setting language to: ' . $_SESSION['login_cms_language']);
-      $current_language = $_SESSION['login_cms_language'];
-      setcookie('cms_language', $_SESSION['login_cms_language']);
-      unset($_SESSION['login_cms_language']);
-    }
-  else if (isset($_COOKIE["cms_language"]))
-    {
-      $tmp = trim(basename($_COOKIE["cms_language"]));
-      $file = dirname(__FILE__) . "/lang/" . $tmp . "/admin.inc.php";
-      if( !file_exists($file) )
-	{
-	  $file = dirname(__FILE__) . "/lang/ext/" . $tmp . "/admin.inc.php";
-	  if( !file_exists($file) )
-	    {
-	      $$tmp = '';
-	    }
-	}
-      $current_language = $tmp;
-    }
 
   if ($current_language == '')
     {
-      if (isset($gCms->config['locale']) && $gCms->config['locale'] != '')
-	{
-	  $current_language = $gCms->config['locale'];
-	}
-      else
-	{
-		
-#No, take a stab at figuring out the default language...
-#Figure out default language and set it if it exists
-	  if (isset($_SERVER["HTTP_ACCEPT_LANGUAGE"])) 
-	    {
-	      $alllang = $_SERVER["HTTP_ACCEPT_LANGUAGE"];
-	      if (strpos($alllang, ";") !== FALSE)
-		$alllang = substr($alllang,0,strpos($alllang, ";"));
-	      $langs = explode(",", $alllang);
+      // still nothing, see if we can get something from the browser.
+      $current_language = cms_detect_browser_lang();
+    }
 
-	      foreach ($langs as $onelang)
-		{
-#Check to see if lang exists...
-		  if (isset($nls['language'][$onelang]))
-		    {
-		      $current_language = $onelang;
-		      setcookie("cms_language", $onelang);
-		      break;
-		    }
-#Check to see if alias exists...
-		  if (isset($nls['alias'][$onelang]))
-		    {
-		      $alias = $nls['alias'][$onelang];
-		      if (isset($nls['language'][$alias]))
-			{
-			  $current_language = $alias;
-			  setcookie("cms_language", $alias);
-			  break;
-			}
-		    }
-		}
-	    }
+  if (isset($_POST['change_cms_lang']) && isset($_POST['default_cms_lang']) )
+    {
+      // a hack to handle the editpref case of the user changing his language
+      // this is needed because the lang stuff is included before the preference may
+      // actually be set.
+      $a1 = basename(trim($_POST['change_cms_lang']));
+      $a2 = basename(trim($_POST['default_cms_lang']));
+      if( $a1 == $a2 && 
+	  (isset($nls['language'][$a1]) || isset($nls['alias'][$a1])) )
+	{
+	  $current_language = $a1;
 	}
     }
 
+  // if it's still not set, this will use the 
+  // current locale.. maybe we should hardcode to en_US ??
   return $current_language;
 }
 
 
+/**
+ * Temporarily override the current frontend language
+ *
+ * @string lang, the language to set.  If empty, the system will be restored to the default frontend language.
+ */
+function cms_set_frontend_language($lang = '')
+{
+  global $gCms;
+  if( empty($lang) )
+    {
+      unset($gCms->variables['cms_frontend_cur_language']);
+    }
+  else if( isset($gCms->nls['language'][$lang]) || isset($gCms->nls['alias'][$lang]) )
+    {
+      // todo: check here if the language exists.
+      $gCms->variables['cms_frontend_cur_language'] = $lang;
+    }
+}
+
+
 /**
  * A function to return the current frontend language
  *
@@ -147,11 +179,15 @@ function cms_admin_current_language()
  */
 function cms_frontend_current_language()
 {
+  cms_initialize_nls();
+
   global $gCms;
+  if( isset($gCms->variables['cms_frontend_cur_language']) )
+    {
+      return $gCms->variables['cms_frontend_cur_language'];
+    }
+
   $curlang = get_site_preference('frontendlang','');
-  if (isset($gCms->config['locale']) && $gCms->config['locale'] != '') {
-    $curlang = $gCms->config['locale'];
-  }
   if( $curlang == '' ) {
     $curlang = 'en_US';
   }
@@ -180,6 +216,7 @@ function cms_current_language()
 }
 
 
+
 /**
  * Load a lang file for a specific realm.
  *
@@ -189,9 +226,10 @@ function cms_current_language()
  * @param string An optional base directory
  * @param boolean Indicates that the language is indicated by the directory name
  * @param boolean Indicates that the lang file has a sub array for the realm.
+ * @param string  The alternate language to load.  If not specified the current language will be used.
  * @return void
  */
-function cms_load_lang_realm($realm,$basedir = '',$filename = '',$lang_is_dir = 0,$has_realm = 0)
+function cms_load_lang_realm($realm,$basedir = '',$filename = '',$lang_is_dir = 0,$has_realm = 0, $is_custom = 0, $cur_lang = '')
 {
 	global $gCms;
 	global $lang;
@@ -206,7 +244,10 @@ function cms_load_lang_realm($realm,$basedir = '',$filename = '',$lang_is_dir =
 		$filename = 'en_US.php';
 	}
 
-	$cur_lang = cms_current_language();
+	if( empty($cur_lang) )
+	  {
+	    $cur_lang = cms_current_language();
+	  }
 
 	// load the default (en_US) file first.
 	$fn = cms_join_path($basedir,$filename);
@@ -214,7 +255,7 @@ function cms_load_lang_realm($realm,$basedir = '',$filename = '',$lang_is_dir =
 	{
 		$fn = cms_join_path($basedir,'en_US',$filename);
 	}
-	if (!isset($lang[$realm]))
+	if (!isset($lang[$realm]) || $is_custom)
 	{
 		if( @file_exists($fn) )
 		{
@@ -239,13 +280,17 @@ function cms_load_lang_realm($realm,$basedir = '',$filename = '',$lang_is_dir =
 		// now load the lang file itself.
 		if( $cur_lang != 'en_US' )
 		{
-      		        $cur_lang = basename($cur_lang);
-			$fn = cms_join_path($basedir,'ext',$cur_lang.'.php');
-			if( $lang_is_dir )
-			{
-				$fn = cms_join_path($basedir,'ext',$cur_lang,$filename);
-			}
-			if( @file_exists($fn) )
+		  $cur_lang = basename($cur_lang);
+		  $fn = cms_join_path($basedir,'ext',$cur_lang.'.php');
+		  if( $lang_is_dir && ! $is_custom)
+		    {
+		      $fn = cms_join_path($basedir,'ext',$cur_lang,$filename);
+		    }
+		  else if ($lang_is_dir && $is_custom)
+		    {
+		      $fn = cms_join_path($basedir,$cur_lang,$filename);
+		    }
+		  if( @file_exists($fn) )
 			{
 				if( !$has_realm )
 				{
@@ -368,13 +413,15 @@ function lang()
   // uses the default admin realm.
 	global $gCms;
 	global $lang;
-	global $nls;
+	$nls =& $gCms->nls;
 
 	$dir = cms_join_path($gCms->config['root_path'],$gCms->config['admin_dir'],'lang');
+	$customdir = cms_join_path($gCms->config['root_path'],$gCms->config['admin_dir'],'custom','lang');
 
 	if( !isset($lang['admin']) )
 	  {
 	    cms_load_lang_realm('admin',$dir,'admin.inc.php',1,1);
+	    cms_load_lang_realm('admin',$customdir,'admin.inc.php',1,1,1);			
 	  }
 	$name = '';
 	$params = array();
@@ -404,7 +451,6 @@ function lang()
 
 	if (!isset($CMS_ADMIN_PAGE) && !isset($CMS_STYLESHEET) && !isset($CMS_INSTALL_PAGE))
 	  {
-  stack_trace(); die();
 	    trigger_error('Attempt to load admin realm from non admin action');
 	    return '';
 	  }
@@ -415,11 +461,11 @@ function lang()
 
 function get_encoding($charset='', $defaultoverrides=true)
 {
-	global $nls;
 	global $current_language;
 	global $gCms;
 	$variables =& $gCms->variables;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
+	$nls =& $gCms->nls;
 
 	if ($charset != '')
 	{
@@ -487,5 +533,35 @@ function is_utf8($string)
    
 } // function is_utf8
 
+
+function get_language_list($allow_none = true)
+{
+  $tmp = array();
+  if( $allow_none )
+    {
+      $tmp = array(''=>lang('nodefault'));
+    }
+
+  global $gCms;
+  $config = $gCms->GetConfig();
+  $nls = $gCms->nls;
+  asort($nls["language"]);
+  foreach( $nls['language'] as $key=>$value )
+    {
+      if( is_dir($config['root_path'].'/'.$config['admin_dir'].'/lang/ext/'.$key) ||
+	  is_dir($config['root_path'].'/'.$config['admin_dir'].'/lang/'.$key) ||
+	  file_exists($config['root_path'].'/'.$config['admin_dir'].'/lang/'.$key.'/admin.inc.php') )
+	{
+	  if( isset($nls['englishlang'][$key]) )
+	    {
+	      $value .= ' ('.$nls['englishlang'][$key].')';
+	    }
+	  $tmp[$key] = $value;
+	}
+    }
+
+  return $tmp;
+}
+
 # vim:ts=4 sw=4 noet
 ?>
