@@ -24,6 +24,7 @@
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
 #
 #-------------------------------------------------------------------------
+if( !isset($gCms) ) exit;
 
 
 #-------------------------------------------------------------------------
@@ -33,21 +34,13 @@
 */ 
 class CMSMailer extends CMSModule
 {
-  var $the_mailer;
+  var $the_mailer = null;
 
-  /*---------------------------------------------------------
-   CMSMailer()
-   constructor
-   ---------------------------------------------------------
-  function CMSMailer()
+  function __construct()
   {
-    // call the parent class' constructor
-    parent::CMSModule();
-
-    // now do our stuff
-    $this->the_mailer = NULL;
+    parent::__construct();
+    
   }
-  
 
 
   /*---------------------------------------------------------
@@ -73,7 +66,16 @@ class CMSMailer extends CMSModule
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.73.14';
+    return '2.0.1';
+  }
+
+
+  /*---------------------------------------------------------
+   MinimumCMSVersion()
+   ---------------------------------------------------------*/
+  function MinimumCMSVersion()
+  {
+    return '1.7';
   }
 
 
@@ -181,6 +183,7 @@ class CMSMailer extends CMSModule
     $this->SetPreference('smtpauth',0);
     $this->SetPreference('username','');
     $this->SetPreference('password','');
+    $this->SetPreference('secure','');
   }
 
 
@@ -226,6 +229,7 @@ class CMSMailer extends CMSModule
     $this->RemovePreference('smtpauth',0);
     $this->RemovePreference('username');
     $this->RemovePreference('password');
+    $this->RemovePreference('secure');
   }
 
 
@@ -298,6 +302,7 @@ class CMSMailer extends CMSModule
     $this->the_mailer->ClearBCCs();
     $this->the_mailer->ClearCCs();
     $this->the_mailer->ClearReplyTos();
+    $this->the_mailer->SMTPSecure = $this->GetPreference('secure');
     $charset = $this->GetPreference('charset');
     if( !empty($charset) ) {
       $this->SetCharSet($charset);
@@ -326,6 +331,11 @@ class CMSMailer extends CMSModule
 	$this->SetPreference('host',$params['input_host']);
       }
 
+    if( isset( $params['input_secure'] ) )
+      {
+	$this->SetPreference('secure',$params['input_secure']);
+      }
+
     if( isset( $params['input_port'] ) )
       {
 	$this->SetPreference('port',$params['input_port']);
@@ -860,6 +870,22 @@ class CMSMailer extends CMSModule
     return $this->the_mailer->SmtpClose();
   }
 
+  function GetSecure()
+  {
+    $this->_load();
+    return $this->the_mailer->SMTPSecure;
+  }
+
+  function SetSecure($value)
+  {
+    $value = strtolower($value);
+    if( $value == '' || $value == 'ssl' || $value == 'tls' )
+      {
+	$this->_load();
+	$this->the_mailer->SMTPSecure = $value;
+      }
+  }
+
 } // class CMSMailer
 
 ?>
