@@ -24,6 +24,7 @@
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
 #
 #-------------------------------------------------------------------------
+if( !isset($gCms) ) exit;
 
     if( !$this->CheckPermission('Modify Site Preferences') )
       return;
@@ -137,9 +138,6 @@
 			  $this->CreateInputSubmit( $id, 'submit', 
 						    $this->Lang('submit'), '', '',
 						    $this->Lang('settingsconfirm')));
-    $this->smarty->assign('cancel',
-			  $this->CreateInputSubmit( $id, 'cancel', 
-						    $this->Lang('cancel')));
 
     echo $this->ProcessTemplate('prefs.tpl');
 ?>
\ No newline at end of file
