@@ -16,7 +16,7 @@ $lang['mailer'] = 'Meilimismeetod';
 $lang['host'] = 'SMTP hosti nimi<br/><i>(v&otilde;i IP aaddress)</i>';
 $lang['port'] = 'SMTP serveri port';
 $lang['from'] = 'Aadressilt';
-$lang['fromuser'] = 'Kasutajanimelt';
+$lang['fromuser'] = 'Kelle nimel';
 $lang['sendmail'] = 'Sendmail&#039;i asukoht';
 $lang['timeout'] = 'SMTP taimaut';
 $lang['submit'] = 'Saada';
@@ -316,9 +316,9 @@ of the license for the full disclaimer.</p>
 <p>Copyright &amp;copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;>&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>
 ';
-$lang['utma'] = '156861353.3215545266732019000.1241091787.1253831573.1253864083.129';
-$lang['utmz'] = '156861353.1253816342.127.26.utmccn=(referral)|utmcsr=klaarpuhastus.ee|utmcct=/admin/moduleinterface.php|utmcmd=referral';
+$lang['utma'] = '156861353.3215545266732019000.1241091787.1255008902.1255072702.158';
+$lang['utmz'] = '156861353.1254469083.145.28.utmccn=(organic)|utmcsr=google|utmctr=cmsms requirements|utmcmd=organic';
 $lang['qca'] = '1240683615-58409973-79915303';
-$lang['utmb'] = '156861353.2.10.1253864083';
+$lang['utmb'] = '156861353.1.10.1255072702';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
