@@ -61,6 +61,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.73.9. Janvier 2006. Ajout&eacute; la possibilit&eacute; du test email, et une confirmation &agrave; chaque bouton (sauf Annuler)</li>
 <li>Version 1.73.10. Ao&ucirc;t 2006. Modifi&eacute; pour l&#039;utilisation du &quot;lazy loading&quot; pour minimiser les besoins m&eacute;moire lorsque CMSMailer n&#039;est pas utilis&eacute;.</li>
 <li>Version 1.73.13. Janvier 2008.  Ajout de plus de v&eacute;rifications de permissions.</li>
+<li>Version 2.0.0 - 19 avril 2010 - R&eacute;vision 29, 2010-04-19.</li>
+<li>Version 2.0.1 - janvier 2011 - Suppression du bouton Annuler.</li>
 </ul>';
 $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
 <p>Ce module n&#039;apporte pas de fonctionnalit&eacute; pour l&#039;utilisateur final.  Il a &eacute;t&eacute; &eacute;crit pour &ecirc;tre int&eacute;gr&eacute; dans d&#039;autres modules et fournir des possibilit&eacute;s d&#039;envoi de courriels.  Voil&agrave;, rien de plus.</p>
@@ -320,8 +322,8 @@ $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
 <p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com">calguy1000@hotmail.com</a>. Tous droits r&eacute;serv&eacute;s.</p>
 <p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL" target="_blank">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>
 ';
-$lang['qca'] = 'P0-1624099198-1262715852421';
-$lang['utma'] = '156861353.1881430788.1271753518.1271753518.1271753518.1';
+$lang['utma'] = '156861353.2043127742.1295277213.1295277213.1295277213.1';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1271753518.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1295277213.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
