@@ -1,4 +1,9 @@
 <?php
+$lang['none'] = 'Ingen';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = 'TLS ';
+$lang['secure'] = 'Tilkoblingssikkerhet';
+$lang['info_secure'] = 'Kun gyldig for SMTP mailer metoden, hvor denne parameteren tillater &aring; spesifisere en annen sikkerhetsmekanisme for tilkoblingen';
 $lang['info_cmsmailer'] = 'Denne modulen benyttes av utallige andre moduler for &aring; muliggj&oslash;re sending av epost. Denne m&aring; v&aelig;re korrekt satt opp i forhold til din nettstedsvert sine krav. Vennligst bruk informasjonen oppgitt av din vert for &aring; tilpasse disse innstillingene. Om du likevel ikke f&aring;r test eposten til &aring; sende korrekt - b&oslash;r du kanskje kontakte din server vert for &aring; f&aring; hjelp til dette.';
 $lang['charset'] = 'Tegnkoding';
 $lang['sendtestmailconfirm'] = 'Dette vil sende en test epost til adressen oppgitt. (Om du mottar den eposten s&aring; er oppsettet i orden.) Vil du fortsette?';
@@ -25,16 +30,16 @@ $lang['info_mailer'] = 'Mail metode &aring; benytte (sendmail, smtp, mail).  Smt
 $lang['info_host'] = 'SMTP vertsnavn (kun gyldig for smtp mailer metoden)';
 $lang['info_port'] = 'SMTP portnummer (vanligvis 25) (kun gyldig for smtp mailer metoden)';
 $lang['info_from'] = 'Adresse brukt som avsender p&aring; alle eposter.
-<br/><strong>Merk</strong>, denne epostadressen m&aring; settes korrekt i for din vert ellers vil du f&aring;r problemer med &aring; sende epost.<br/>Om du ikke kjenner en korrekt verdi for denne innstillingen, b&oslash;r du kontakte din vert.';
+<br/><strong>Merk</strong>, denne e-postadressen m&aring; settes korrekt i for din vert ellers vil du f&aring;r problemer med &aring; sende epost.<br/>Om du ikke kjenner en korrekt verdi for denne innstillingen, b&oslash;r du kontakte din vert.';
 $lang['info_fromuser'] = 'Friendly navn brukt for &aring; sende alle emailer';
-$lang['info_sendmail'] = 'Full sti til din sendmail programfil (kun gyldig for smtp mailer metoden)';
+$lang['info_sendmail'] = 'Full sti til din sendmail programfil (kun gyldig for sendmail mailer metoden)';
 $lang['info_timeout'] = 'Antall sekunder i en SMTP samtale f&oslash;r feil meldes (gyldig for smtp mailer metoden)';
 $lang['info_smtpauth'] = 'Krever din smtp vert autentisering (kun gyldig for smtp mailer metoden)';
 $lang['info_username'] = 'SMTP autentisering brukernavn (kun gyldig for smtp mailer metoden, n&aring;r smtp aut. er valgt)';
 $lang['info_password'] = 'SMTP autentisering passord (kun gyldig for smtp mailer metoden, n&aring;r smtp autentisering er valgt)';
 $lang['friendlyname'] = 'CMSMailer ';
 $lang['postinstall'] = 'CMSMailer modulen har blitt installert';
-$lang['postuninstall'] = 'CMSMailer modulen avinstallert... trist &aring; se deg g&aring;...';
+$lang['postuninstall'] = 'CMSMailer modulen er avinstallert';
 $lang['uninstalled'] = 'Modul avinstallert';
 $lang['installed'] = 'Modul versjon %s installert.';
 $lang['accessdenied'] = 'Adgang nektet. Vennligst sjekk dine rettigheter.';
@@ -316,8 +321,9 @@ of the license for the full disclaimer.</p>
 <h3>Copyright and License</h3>
 <p>Copyright &amp;copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;>&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>';
-$lang['utmz'] = '156861353.1240436806.1213.30.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/projects/phpbbx';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1241312411.1241358721.1257';
+$lang['utmz'] = '156861353.1272675501.2656.57.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1272720219.1272726637.2660';
+$lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1241358721';
+$lang['utmb'] = '156861353.1.10.1272726637';
 ?>
\ No newline at end of file
