@@ -1,4 +1,9 @@
 <?php
+$lang['none'] = 'Nimic';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = ' TLS ';
+$lang['secure'] = 'Mecanism Criptare';
+$lang['info_secure'] = 'Aplicabil numai metodei SMTP, aceasta optiune permite specificarea unui anume mecanism de criptare pentru conexiune.';
 $lang['info_cmsmailer'] = 'Acest modul este folosit de numeroase alte module pentru a trimite e-mailuri. El trebuie sa fie configurat corect conform cu cerintele hostingului dumneavoastra. Folositi informatiile oferite de host pentru a ajusta aceste setari. Daca totusi nu reusiti sa trimiteti corect e-mailul de test, e posibil sa trebuiasca sa contactati pe cei care va ofera hostingul pentru asistenta.';
 $lang['charset'] = 'Set Caractere';
 $lang['sendtestmailconfirm'] = 'Acesta va trimite un mesaj de test la adresa specificata. Daca procesul de expediere se incheie cu succes, veti fi redirectionat la aceasta pagina. Doriti sa continuati?';
@@ -315,9 +320,9 @@ of the license for the full disclaimer.</p>
 <p>Copyright &copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>
 ';
-$lang['utma'] = '156861353.3573843717708992500.1250056267.1250056267.1250056267.1';
+$lang['utma'] = '156861353.1477009656.1272913798.1272913798.1274603745.2';
+$lang['utmz'] = '156861353.1274603746.2.3.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms ms';
+$lang['qca'] = 'P0-1739349973-1272913798681';
+$lang['utmb'] = '156861353.2.10.1274603745';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1250056267.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = '1249980835-92593492-79567608';
-$lang['qcb'] = '1912438266';
 ?>
\ No newline at end of file
