@@ -1,4 +1,9 @@
 <?php
+$lang['none'] = 'Нет';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = 'ТLS';
+$lang['secure'] = 'Механизм шифрования';
+$lang['info_secure'] = 'Применяется только к методу SMTP, эта опция позволяет задать различные механизмы шифрования';
 $lang['info_cmsmailer'] = 'Этот модуль используется множеством других модулей для облегчения отправки писем. Он должен быть правильно настроен в соответсвие с требованиями почтового хостинга. Пожалуйста, используйте информацию хостинга для настройки этих параметров. Если вы все еще не можете получить тестовое сообщение отправленное должным образом, вы можете обратиться к вашему почтовому хостинг провайдеру за помощью';
 $lang['charset'] = 'Кодировка';
 $lang['sendtestmailconfirm'] = 'Это отправит тестовое сообщение по заданному адресу. Если процесс будет успешно завершен, Вы будете возвращены к этой странице. Вы хотите продолжить?';
@@ -314,9 +319,9 @@ $lang['help'] = '<h3>Каково назначение данного элеме
 <h3>Авторские права и лицензия</h3>
 <p> Авторские права © 2005, Robert Campbell <a href=\'mailto:calguy1000@hotmail.com\'><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href=\'http://www.gnu.org/licenses/licenses.html#GPL\'>GNU Public License</a>. Вы должны согласиться с данной лицензией до того, как начнете использовать модуль.</p>';
-$lang['utmz'] = '156861353.1249691644.74.46.utmccn=(referral)|utmcsr=localhost|utmcct=/msnew/install/index.php|utmcmd=referral';
-$lang['utma'] = '156861353.1512485689.1236874721.1249691644.1250401334.75';
+$lang['qca'] = 'P0-1938388883-1277855813144';
+$lang['utma'] = '156861353.429593658.1277855813.1288916189.1288921409.32';
+$lang['utmz'] = '156861353.1286799193.22.13.utmccn=(organic)|utmcsr=google|utmctr=cmsmadesimple translation center|utmcmd=organic';
 $lang['utmc'] = '156861353';
-$lang['qca'] = 'P0-738804097-1250401341499';
-$lang['utmb'] = '156861353.1.10.1250401334';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
