@@ -1,7 +1,7 @@
 <?php
 $lang['none'] = 'Nie je ';
-$lang['ssl'] = 'SSL';
-$lang['tls'] = 'TLS';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = 'TLS ';
 $lang['secure'] = '&Scaron;ifrovac&iacute; mechanizmus';
 $lang['info_secure'] = 'Použiteľn&eacute; iba pri nastaven&iacute; SMTP met&oacute;dy, povoľuje nastavenia in&eacute;ho &scaron;ifrovacie mechanizmu';
 $lang['info_cmsmailer'] = 'Modul, ktor&yacute; využ&iacute;vaj&uacute; ostatn&eacute; moduly na odosielanie e-mailov. Nastavte hodnoty, podľa možnost&iacute; v&aacute;&scaron;ho poskytovateľa web priestoru. V pr&iacute;pade, že sa v&aacute;m niž&scaron;ie nepodar&iacute; odoslať testovaciu spr&aacute;vu, sk&uacute;ste kontaktovať v&aacute;&scaron;ho administr&aacute;tora.';
@@ -60,119 +60,7 @@ $lang['changelog'] = '<ul>
 <li>Version 1.73.7. January, 2006. Increased field lengths in most fields</li>
 <li>Version 1.73.8. January, 2006. Changed the preferences panel to be a bit more descriptive.</li>
 </ul>';
-$lang['help'] = 'CMS Made Simple Translation Center
-
-Log out
-
-Back to modules
-CMS Mailer
-Natural Language
-Slovak/Slovenčina
-This module is used by numerous other modules to facilitate sending emails.  It must be properly configured to your hosts requirements.  Please use the information provided by your host to adjust these settings.  If you still cannot get the test message to send properly, you may have to contact your host for assistance.
- 
-Character Set
- 
-This will send a test message to the address specified. If the send process suceeded, you will be returned to this page.  Do you want to continue?
- 
-Write current values to CMSMailer settings?
- 
-CMSMailer Test Message
- 
-This message is intended only to verify the validity of the settings in the CMSMailer module.
-If you received it, everything is working fine.
- 
-Error: Test address not specified
- 
-Test Email Address
- 
-Send Test Message
- 
-Password
- 
-Username
- 
-SMTP Authentication
- 
-Mailer method
- 
-SMTP host name<br/><i>(or IP address)</i>
- 
-Port of SMTP server
- 
-From address
- 
-From Username
- 
-Sendmail location
- 
-SMTP timeout
- 
-Submit
- 
-Cancel
- 
-Mail method to use (sendmail, smtp, mail).  Usually smtp is the most reliable.
- 
-SMTP hostname (only valid for the smtp mailer method)
- 
-SMTP port number (usually 25) (only valid for the smtp mailer method)
- 
-Address used as the sender in all emails. <br/><strong>Note</strong>, this email address must be set correctly for your host or you will have difficulty sending emails.<br/>If you do not know the proper value for this setting, you may need to contact your host.
- 
-Friendly name used for sending all emails
- 
-The complete path to your sendmail executable (only valid for the sendmail mailer method)
- 
-The number of seconds in an SMTP conversation before an error occurs (valid for the smtp mailer method)
- 
-Does your smtp host require authentication (valid only for the smtp mailer method)
- 
-SMTP authentication username (valid only for smtp mailer method, when smtp auth is selected)
- 
-SMTP authentication password (valid only for smtp mailer method, when smtp auth is selected)
- 
-CMSMailer
- 
-CMSMailer module has been successfully installed
- 
-CMSMailer module uninstalled... sorry to see you leave
- 
-Module Uninstalled.
- 
-Module version %s installed.
- 
-Access Denied. Please check your permissions.
- 
-Error!
- 
-Module upgraded to version %s.
- 
-Module Preferences
- 
-Module Admin Panel
- 
-CMSMailer Module
- 
-This is a simple wrapper around PHPMailer, it has an equivalent API (function for function) and a simple interface for some defaults.
- 
-<p>Welcome to the CMSMailer module admin section
- 
-
-<ul>
-<li>Version 1.73.1. October, 2005. Initial Release.</li>
-<li>Version 1.73.2. October, 2005. Minor bug fix with the admin panel.  The dropdown was not representing the current value from the preferences database</li>
-<li>Version 1.73.3. October, 2005. Minor bug fix with sending html email</li>
-<li>Version 1.73.4. November, 2005. Form fields in preferences are larger, fixed a problem with the fromuser, and called reset within the constructor</li>
-<li>Version 1.73.5. November, 2005. Added the form fields and functionality for SMTP authentication.</li>
-<li>Version 1.73.6. December, 2005. Default mailer method is SMTP on install, and improved documentation, and now I clear all the attachments, and addresses, etc. on reset.</li>
-<li>Version 1.73.7. January, 2006. Increased field lengths in most fields</li>
-<li>Version 1.73.8. January, 2006. Changed the preferences panel to be a bit more descriptive.</li>
-<li>Version 1.73.9. January, 2006. Added test email capability, and confirmation on each button (except cancel)</li>
-<li>Version 1.73.10. August, 2006. Modified to use lazy loading to minimize memory footprint when CMSMailer is not being used.</li>
-<li>Version 1.73.13. January, 2008.  Added more permissions checks.</li>
-</ul>
- 
-<h3>What Does This Do?</h3>
+$lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module provides no end user functionality.  It is designed to be integrated into other modules to provide email capabilities.  Thats it, nothing more.</p>
 <h3>How Do I Use It</h3>
 <p>This module provides a simple wrapper around all of the methods and variables of phpmailer.  It is designed for use by other module developers, below is an example, and a brief API reference.  Please read the PHPMailer documentation included for more information.</p>
@@ -430,13 +318,10 @@ of the license for the full disclaimer.</p>
 <h3>Copyright and License</h3>
 <p>Copyright &amp;copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;>&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>
- 
-
-﻿';
-$lang['qca'] = 'P0-1608926040-1271144175783';
-$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
-$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
-$lang['chartbeat2'] = '87v0u4nbwegh3lki';
-$lang['utmb'] = '156861353';
+';
+$lang['utma'] = '156861353.1423109725.1280259016.1283883395.1284147995.32';
+$lang['utmz'] = '156861353.1284147995.32.30.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/873';
+$lang['qca'] = 'P0-748439131-1280259017524';
+$lang['utmb'] = '156861353.2.10.1284147995';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
