@@ -3,7 +3,7 @@ $lang['none'] = 'Ingen';
 $lang['ssl'] = 'SSL - kryptering';
 $lang['tls'] = 'TLS - kryptering';
 $lang['secure'] = 'Krypteringsmekanism';
-$lang['info_secure'] = 'Applicable only to the SMTP mailer method, this option allows specifying different encryption mechanisms for the connection';
+$lang['info_secure'] = 'G&auml;ller endast f&ouml;r SMTP-mailer metoden. Detta alternativ till&aring;ter olika krypterings mekanismer f&ouml;r anslutningen.';
 $lang['info_cmsmailer'] = 'Den h&auml;r modulen anv&auml;nds av flera andra moduler f&ouml;r att g&ouml;ra det m&ouml;jligt att skicka e-postmeddelanden. Den m&aring;ste konfigureras beroende p&aring; ditt webbhotell. V&auml;nligen anv&auml;nd informationen fr&aring;n ditt webbhotell f&ouml;r att korrigera de h&auml;r inst&auml;llningarna. Om testmeddelandet &auml;nd&aring; inte skickas som det ska, kan du beh&ouml;va kontakta ditt webbhotell f&ouml;r hj&auml;lp.';
 $lang['charset'] = 'Teckenupps&auml;ttning';
 $lang['sendtestmailconfirm'] = 'Ett meddelande kommer att skickas till den adress du angav. Om leveransen lyckas kommer du att &aring;terv&auml;nda till denna sida. Vill du forts&auml;tta?';
@@ -320,9 +320,9 @@ of the license for the full disclaimer.</p>
 <h3>Copyright and License</h3>
 <p>Copyright &amp;copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;>&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>';
-$lang['utma'] = '156861353.906052642.1267835734.1280855260.1280862441.163';
-$lang['utmz'] = '156861353.1280548859.155.12.utmcsr=wiki.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/User_Handbook/Admin_Panel/Content/Global_Content_Blocks';
-$lang['qca'] = 'P0-1605183070-1267835733865';
+$lang['utma'] = '156861353.622613290.1282068801.1284058470.1284061448.13';
+$lang['utmz'] = '156861353.1284058470.12.3.utmccn=(referral)|utmcsr=cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['qca'] = 'P0-1267218368-1282068801788';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1280862441';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
