@@ -50,7 +50,7 @@ class FileManager extends CMSModule {
 	}
 
 	function GetVersion() {
-		return '1.0.2';
+		return '1.1.0';
 	}
 
 	function GetHelp() {
@@ -86,7 +86,7 @@ class FileManager extends CMSModule {
 	}
 
 	function MinimumCMSVersion() {
-		return "1.5.4";
+		return "1.8.0";
 	}
 
 	function VisibleToAdminUser() {
@@ -106,7 +106,7 @@ class FileManager extends CMSModule {
 	}
 
 	function GetActionIcon($action) {
-	  $config =$this->cms->GetConfig();
+	  $config = $this->cms->GetConfig();
 		//$iconsize=$this->GetPreference("iconsize","32px");
 		//if (file_exists($config["root_path"].
 		//$iconsize="16px";
@@ -118,7 +118,7 @@ class FileManager extends CMSModule {
 	function GetFileIcon($extension,$isdir=false) {
 	  if (empty($extension)) $extension = '---'; // hardcode extension to something.
 	  if ($extension[0]==".") $extension=substr($extension,1);    
-	  $config =$this->cms->GetConfig();
+	  $config = $this->cms->GetConfig();
 	  $iconsize=$this->GetPreference("iconsize","32px");
 		///for valid xhtml
 	    $iconsizeHeight=str_replace("px","",$iconsize);
@@ -294,7 +294,7 @@ class FileManager extends CMSModule {
 
 	function upDir() {
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 		//static $udir="";
 		//if ($udir!="") return $udir;
 		$udir=substr($config["uploads_path"],strlen($config["root_path"]));
@@ -305,7 +305,7 @@ class FileManager extends CMSModule {
 
 	function SetMode($mode,$path,$file="") {
 	  
-	  $config =$this->cms->GetConfig();
+	  $config = $this->cms->GetConfig();
 	  $realfile="";
 	  if ($file!="") {
 		  //$realpath=$this->Slash($config["root_path"],$path);
@@ -351,21 +351,21 @@ class FileManager extends CMSModule {
 	}
 
 	function GetPermissions($path,$file) {
-	  $config =&$this->cms->GetConfig();
+	  $config = $this->cms->GetConfig();
 		$realpath=$this->Slash($config["root_path"],$path);
 		$statinfo=stat($this->Slash($realpath,$file));
 		return $statinfo["mode"];
 	}
 
 	function GetMode($path,$file) {	  
-	  $config =&$this->cms->GetConfig();
+	  $config = $this->cms->GetConfig();
 		$realpath=$this->Slash($config["root_path"],$path);
 		$statinfo=stat($this->Slash($realpath,$file));
 		return $this->FormatPermissions($statinfo["mode"]);
 	}
 	
   function GetModeWin($path,$file) {	  
-	  $config =&$this->cms->GetConfig();
+	  $config = $this->cms->GetConfig();
 		$realpath=$this->Slash($config["root_path"],$path);
 		$realpath=$this->Slash($realpath,$file);
 		if (is_writable($realpath)) {
@@ -435,7 +435,7 @@ class FileManager extends CMSModule {
 	  global $gCms;
 	  
 	  if ($advancedmode=="check") $advancedmode=$this->AdvancedAccessAllowed();
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 	  
 	  $path=$this->Slash($config["root_path"],$path);
 
@@ -452,7 +452,7 @@ class FileManager extends CMSModule {
 		$showhiddenfiles=$this->GetPreference("showhiddenfiles","1");
 		$result=array();
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 		$realpath=$this->Slash($config["root_path"],$path);
 		if ($this->IntruderCheck($realpath,$advancedmode)) {
 			$realpath=$config["uploads_path"];
@@ -520,7 +520,7 @@ class FileManager extends CMSModule {
 					$info["permissions"]="R";
 				}
 			}
-			$info["writable"]=is_writable($this->Slash($realpath,$file));
+			
 			$result[]=$info;
 		}
 		$result=$this->columnSort($result);
@@ -540,7 +540,7 @@ class FileManager extends CMSModule {
 	
 	function GetThumbnailLink($file,$path) {
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 		$filepath=$config["root_path"].$path;
 		$url=$config["root_url"].$path;
 		//echo $url;
