@@ -3,6 +3,28 @@
 if (!isset($gCms)) exit;
 if (!$this->AccessAllowed() && !$this->AdvancedAccessAllowed()) exit;
 
+
+if (file_exists(dirname(__FILE__)."/postlet")) {
+  echo $this->ShowErrors($this->Lang("postletexists"));
+}
+
+if (isset($params["fmmessage"]) && $params["fmmessage"]!="") {
+  $count="";
+  if (isset($params["fmmessagecount"]) && $params["fmmessagecount"]!="") {
+    $count=$params["fmmessagecount"];
+  }
+
+  echo $this->ShowMessage($this->Lang($params["fmmessage"],$count));
+}
+
+if (isset($params["fmerror"]) && $params["fmerror"]!="") {
+  $count="";
+  if (isset($params["fmerrorcount"]) && $params["fmerrorcount"]!="") {
+    $count=$params["fmerrorcount"];
+  }
+  echo $this->ShowErrors($this->Lang($params["fmerror"],$count));
+}
+
 $advancedmode=$this->GetPreference("advancedmode",0);
 if (!$this->AdvancedAccessAllowed()) $advancedmode=0;
 $showhiddenfiles=$this->GetPreference("showhiddenfiles",0);
