@@ -7,7 +7,7 @@ if(!isset($params["filename"]) || !isset($params["path"])) {
 }
 
 if ($this->IntruderCheck($params["path"])) {
-	$this->Redirect($id, 'defaultadmin',$returnid,array("module_error"=>$this->Lang("fileoutsideuploads")));
+	$this->Redirect($id, 'defaultadmin',$returnid,array("fmerror"=>"fileoutsideuploads"));
 }
 $config =& $gCms->GetConfig();
 $fullname=$this->Slash($params["path"],$params["filename"]);
@@ -15,8 +15,11 @@ $fullname=$this->Slash($config["root_path"],$fullname);
 
 $message=""; $error="";
 
-if (@unlink($fullname)) $message=$this->Lang("singlefiledeletesuccess"); else $error=$this->Lang("singlefiledeletefail");
+if (@unlink($fullname)) 
+  $message="singlefiledeletesuccess";
+else
+  $error="singlefiledeletefail";
 
-$this->Redirect($id,"defaultadmin",$returnid,array("path"=>$params["path"],"module_message"=>$message,"module_error"=>$error));
+$this->Redirect($id,"defaultadmin",$returnid,array("path"=>$params["path"],"fmmessage"=>$message,"fmerror"=>$error));
 
 ?>
\ No newline at end of file
