@@ -7,13 +7,13 @@ if(!isset($params["newdirname"]) || !isset($params["path"])) {
 }
 
 if ($this->IntruderCheck($params["path"])) {
-	$this->Redirect($id, 'defaultadmin',$returnid,array("module_error"=>$this->Lang("fileoutsideuploads")));
+	$this->Redirect($id, 'defaultadmin',$returnid,array("fmerror"=>"fileoutsideuploads"));
 }
 
 if (strpos($params["newdirname"],"/")!==false ||
     strpos($params["newdirname"],"\\")!==false ||
     strpos($params["newdirname"],"..")!==false) {
-  $this->Redirect($id, 'defaultadmin',$returnid,array("module_error"=>$this->Lang("invalidnewdir")));
+  $this->Redirect($id, 'defaultadmin',$returnid,array("fmerror"=>"invalidnewdir"));
 }
 
 $config =& $gCms->GetConfig();
@@ -21,13 +21,18 @@ $newdir=$this->Slash($params["path"],$params["newdirname"]);
 $newdir=$this->Slash($config["root_path"],$newdir);
 
 //echo $newdir; die();
-$message=""; $error="";
-if (mkdir($newdir)) {
-  $message=$this->Lang("newdirsuccess");
-} else {
-  $error=$this->Lang("newdirfail");
+
+if (is_dir($newdir)) {
+	$this->Redirect($id, 'defaultadmin',$returnid,array("fmerror"=>"direxists"));
 }
 
-$this->Redirect($id,"defaultadmin",$returnid,array("path"=>$params["path"],"module_message"=>$message,"module_error"=>$error))
+$message=""; $error="";
+if (mkdir($newdir)) {
+  $message="newdirsuccess";
+} else {
+  $error="newdirfail";
+}
+
+$this->Redirect($id,"defaultadmin",$returnid,array("path"=>$params["path"],"fmmessage"=>$message,"fmerror"=>$error))
 
 ?>
