@@ -96,6 +96,7 @@ $lang['unpacksuccess'] = 'Soubor byl &uacute;&scaron;pě&scaron;ně rozbalen';
 $lang['unpackfail'] = 'Nastaly chyby během rozbalov&aacute;n&iacute; souboru:';
 $lang['packfileopenfail'] = 'Nemohu rozbalit soubor (nepodporovan&yacute; form&aacute;t?)';
 $lang['packfilewritefail'] = 'Nemohu otevř&iacute;t soubor &amp;s pro z&aacute;pis';
+$lang['containsillegalchars'] = 'Jm&eacute;no souboru obsahuje jeden nebo v&iacute;ce chybn&yacute;ch znaků (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['currentpath'] = 'Aktu&aacute;ln&iacute; adres&aacute;ř:';
 $lang['newdirname'] = 'Vytvořit nov&yacute; adres&aacute;ř:';
 $lang['newdirsuccess'] = 'Adres&aacute;ř byl &uacute;spě&scaron;ně vytvořen';
@@ -127,8 +128,9 @@ $lang['help'] = '		<h3>Co děl&aacute; tento modul?</h3>
 		<p>Tento modul poskytuje funkce spr&aacute;vy souborů</p>
 		<h3>Jak se použ&iacute;v&aacute;?</h3>
 		<p>Vyberte tento modul z menu v administraci.</p>';
-$lang['utma'] = '156861353.503654010.1232181160.1240228642.1241432088.28';
-$lang['utmz'] = '156861353.1239794723.26.6.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/users/peca/edit';
-$lang['utmb'] = '156861353.1.10.1241432088';
+$lang['utma'] = '156861353.3769824904990279700.1249913289.1261996808.1263200482.16';
+$lang['utmz'] = '156861353.1249913289.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = '1229762881-19854751-99654968';
+$lang['utmb'] = '156861353.1.10.1263200482';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
