@@ -12,6 +12,7 @@ $lang['fileview'] = 'Fil-visning';
 $lang['switchtofileview'] = 'Skift til fil-visning';
 $lang['settings'] = 'Indstillinger';
 $lang['savesettings'] = 'Gem indstillinger';
+$lang['postletexists'] = 'Advarsel! Fjern venligst folderen modules/FileManager/postlet helt, da denne ikke ikke har burdet v&aelig;re der i mange versioner.';
 $lang['filename'] = 'Filnavn';
 $lang['fileinfo'] = 'Fil-info';
 $lang['fileowner'] = 'Ejer';
@@ -21,7 +22,7 @@ $lang['filedate'] = 'Dato';
 $lang['actions'] = 'Handlinger';
 $lang['delete'] = 'Slet';
 $lang['notwritable'] = 'Skrivebeskyttet';
-$lang['filetoobig'] = 'er for stor. Upload blev afbrudt.';
+$lang['afileistoobig'] = 'En fil er for stor. Upload blev afbrudt.';
 $lang['unknown'] = 'Ukendt';
 $lang['fileoutsideuploads'] = 'Du m&aring; ikke &aelig;ndre i filer udenfor uploads-mappen! (Dette kr&aelig;ver avanceret fil-h&aring;ndterings tilladelsen)';
 $lang['writable'] = 'Skrivbar';
@@ -60,6 +61,8 @@ $lang['movedto'] = 'flyttet til';
 $lang['copiedto'] = 'kopieret til';
 $lang['couldnotmove'] = 'kunne ikke flyttes';
 $lang['couldnotcopy'] = 'kunne ikke kopieres';
+$lang['filesdeletedsuccessfully'] = '%s fil(er) blev slettet';
+$lang['filesdeletedfiled'] = '%s fil(er) blev ikke slettet pga en fejl';
 $lang['rename'] = 'Omd&oslash;b';
 $lang['newname'] = 'Nyt navn:';
 $lang['renamesuccess'] = 'Filen blev omd&oslash;bt';
@@ -79,6 +82,8 @@ $lang['chmodselected'] = 'Skift tilladelser p&aring; valgte filer';
 $lang['chmodsuccess'] = 'Filen fik nye tilladelser';
 $lang['chmodfailure'] = '&AElig;ndring af filens tilladelser fejlede';
 $lang['chmodcancelled'] = '&AElig;ndring af tilladelser blev afbrudt';
+$lang['newuploadfailed'] = '%s fil(er) fejlede ved upload (eller udpakning)';
+$lang['newuploadsuccess'] = '%s fil(er) blev korrekt uploadet (og udpakket, hvis dette var valgt)';
 $lang['dirchmodfailmulti'] = 'Det skete en fejl ved &aelig;ndring af tilladelser for mappen, dele af den indhold kan dog ha f&aring;et nye tilladelser';
 $lang['dirchmodsuccessmulti'] = 'Changing permissions on the directory and it&#039;s content was successful';
 $lang['dirchmodsuccess'] = 'Mappen fik nye tilladelser';
@@ -96,11 +101,12 @@ $lang['unpacksuccess'] = 'blev korrekt udpakket';
 $lang['unpackfail'] = 'blev ikke korrekt udpakket pga.:';
 $lang['packfileopenfail'] = 'Kunne ikke udpakke filen (ikke-underst&oslash;ttet format?)';
 $lang['packfilewritefail'] = 'Kunne ikke f&aring; lov til at skrive til filen &amp;s';
-$lang['containsillegalchars'] = 'Filnavnet indeholder et eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$)';
+$lang['afilecontainsillegalchars'] = 'Et filnavn indeholder ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$). Upload blev afbrudt.';
 $lang['currentpath'] = 'Nuv&aelig;rende sti:';
 $lang['newdirname'] = 'Opret ny mappe:';
 $lang['newdirsuccess'] = 'Mappen blev oprettet';
 $lang['newdirfail'] = 'Det skete en fejl ved oprettelse af mappen';
+$lang['direxists'] = 'Mappen eksisterer allerede';
 $lang['invalidnewdir'] = 'Navnet p&aring; den nye mappe kan ikke indholde tegn som /, \ og &#039;..&#039; ';
 $lang['filedateformat'] = 'd/m/Y H:m:s';
 $lang['iconsize'] = 'Ikon st&oslash;rrelse';
@@ -115,7 +121,7 @@ $lang['uploadfilesto'] = 'Upload&#039;er filer til:';
 $lang['uploadview'] = 'Upload filer';
 $lang['uploadboxes'] = 'Antal upload-bokse';
 $lang['nothinguploaded'] = 'Intet blev upload&#039;et';
-$lang['unsupportedarchive'] = 'Ikke-underst&oslash;ttet arkiv-format';
+$lang['newunsupportedarchive'] = '%s er ikke et underst&oslash;ttet pakke-format.';
 $lang['uploadmethod'] = 'Upload metode';
 $lang['uploaderstandard'] = 'Standard html input-metode (tillader udpakning)';
 $lang['enableadvanced'] = 'Sl&aring; avanceret modus til? (hvis tilladt)';
@@ -128,9 +134,9 @@ $lang['help'] = '		<h3>Hvad g&oslash;r dette modul?</h3>
 		<p>Dette modul giver adgang til basale funktioner til filh&aring;ndtering</p>
 		<h3>Hvordan bruger jeg det?</h3>
 		<p>V&aelig;lg det fra indholds-menuen</p>';
-$lang['utma'] = '156861353.2039886585.1231713618.1267662159.1267896976.103';
-$lang['utmz'] = '156861353.1266781206.98.17.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,41427.0.html';
 $lang['qca'] = '1229601790-85243197-43260713';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.150641055.1290514235.1294607935.1294612513.12';
+$lang['utmz'] = '156861353.1292168301.8.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
