@@ -12,6 +12,7 @@ $lang['fileview'] = 'Dateiansicht';
 $lang['switchtofileview'] = 'Zur Datei-Anzeige wechseln';
 $lang['settings'] = 'Einstellungen';
 $lang['savesettings'] = 'Einstellungen speichern';
+$lang['postletexists'] = 'Warnung! Bitte entfernen Sie aus Sicherheitsgr&uuml;nden das Verzeichnis /modules/FileManager/postlet vollst&auml;ndig - es wird schon seit einigen Versionen nicht mehr ben&ouml;tigt.';
 $lang['filename'] = 'Dateiname';
 $lang['fileinfo'] = 'Datei-Info';
 $lang['fileowner'] = 'Datei-Eigent&uuml;mer';
@@ -21,7 +22,7 @@ $lang['filedate'] = 'Datum';
 $lang['actions'] = 'Aktionen';
 $lang['delete'] = 'L&ouml;schen';
 $lang['notwritable'] = 'Nicht beschreibbar';
-$lang['filetoobig'] = 'ist zu gro&szlig;. Das Hochladen wurde abgebrochen.';
+$lang['afileistoobig'] = 'Die Datei ist zu gro&szlig;. Das Hochladen wurde abgebrochen.';
 $lang['unknown'] = 'Unbekannt';
 $lang['fileoutsideuploads'] = 'Sie sind nicht berechtigt, Dateien au&szlig;erhalb des uploads-Verzeichnisses zu ver&auml;ndern! (Daf&uuml;r ist die Berechtigung zur erweiterten Dateiverwaltung erforderlich)';
 $lang['writable'] = 'Beschreibbar';
@@ -60,11 +61,18 @@ $lang['movedto'] = 'verschoben nach';
 $lang['copiedto'] = 'kopiert nach';
 $lang['couldnotmove'] = 'konnte nicht verschoben werden';
 $lang['couldnotcopy'] = 'konnte nicht kopiert werden';
+$lang['filesdeletedsuccessfully'] = '%s Datei(en) wurde(n) gel&ouml;scht';
+$lang['filesdeletedfiled'] = 'Bei %s Datei(en) ist das L&ouml;schen fehlgeschlagen';
+$lang['filesmovedsuccessfully'] = '%s Datei(en) wurde(n) verschoben';
+$lang['filesmovedfailed'] = 'Bei %s Datei(en) ist das Verschieben fehlgeschlagen';
+$lang['filescopiedsuccessfully'] = '%s Datei(en) wurde(n) kopiert';
+$lang['filescopiedfailed'] = 'Bei %s Datei(en) ist das Kopieren fehlgeschlagen';
+$lang['internalerror'] = 'Interner Fehler (das bedeutet, irgend etwas macht keinen Sinn - bitte melden Sie uns m&ouml;glichst genau, was Sie getan haben)';
 $lang['rename'] = 'Umbenennen';
 $lang['newname'] = 'Neuer Name:';
 $lang['renamesuccess'] = 'Die Datei wurde umbenannt';
-$lang['renamefailure'] = 'Die Umbenennung der Datei ist fehlgeschlagen';
-$lang['renamecancelled'] = 'Die Umbenennung der Datei wurde abgebrochen';
+$lang['renamefailure'] = 'Das Umbenennen der Datei ist fehlgeschlagen';
+$lang['renamecancelled'] = 'Das Umbenennen der Datei wurde abgebrochen';
 $lang['owner'] = 'Eigent&uuml;mer';
 $lang['group'] = 'Gruppe';
 $lang['others'] = 'Andere';
@@ -75,13 +83,15 @@ $lang['rwxstyle'] = 'rwx';
 $lang['755style'] = '755';
 $lang['quickmode'] = 'Schneller chmod (z. Bsp. 777)';
 $lang['chmod'] = 'Berechtigungen &auml;ndern';
-$lang['chmodselected'] = 'Die Berechtigungen der ausgew&auml;hlten Dateien &auml;ndern';
+$lang['chmodselected'] = 'Berechtigungen der ausgew&auml;hlten Dateien &auml;ndern';
 $lang['chmodsuccess'] = 'Die Vergabe der neuen Berechtigungen war erfolgreich';
-$lang['chmodfailure'] = 'Die &Auml;nderung der Berechtigung ist fehlgeschlagen';
-$lang['chmodcancelled'] = 'Die &Auml;nderung der Berechtigung wurde abgebrochen';
-$lang['dirchmodfailmulti'] = 'Das &Auml;ndern der Berechtigungen f&uuml;r das Verzeichnis ist gescheitert. Es ist jedoch m&ouml;glich, dass f&uuml;r einige Inhalte des Verzeichnisses trotzdem neue Berechtigungen gesetzt wurden.';
-$lang['dirchmodsuccessmulti'] = 'Das &Auml;ndern der Berechtigungen f&uuml;r das Verzeichnis und dessen Inhalte war erfolgreich';
-$lang['dirchmodsuccess'] = 'Dem Verzeichnis wurden die neuen Berechtigungen erfolgreich zugewiesen';
+$lang['chmodfailure'] = 'Das &Auml;ndern der Berechtigung ist fehlgeschlagen';
+$lang['chmodcancelled'] = 'Das &Auml;ndern der Berechtigung wurde abgebrochen';
+$lang['newuploadfailed'] = 'Bei %s Datei(en) ist das hochladen oder m&ouml;glicherweise nur das Entpacken fehlgeschlagen';
+$lang['newuploadsuccess'] = '%s Datei(en) wurde(n) hochgeladen und entpackt (falls ausgew&auml;hlt)';
+$lang['dirchmodfailmulti'] = 'Das &Auml;ndern der Berechtigungen f&uuml;r das Verzeichnis ist fehlgeschlagen. Es ist jedoch m&ouml;glich, dass f&uuml;r einige Inhalte des Verzeichnisses trotzdem neue Berechtigungen gesetzt wurden.';
+$lang['dirchmodsuccessmulti'] = 'Die Berechtigungen f&uuml;r das Verzeichnis und dessen Inhalte wurden ge&auml;ndert';
+$lang['dirchmodsuccess'] = 'Dem Verzeichnis wurden die neuen Berechtigungen zugewiesen';
 $lang['dirchmodfailure'] = 'Beim &Auml;ndern der Berechtigungen des Verzeichnisses ist ein Fehler aufgetreten';
 $lang['dirnotemptyconfirm'] = 'Dieses Verzeichnis ist nicht leer. Wollen Sie es wirklich l&ouml;schen (einschlie&szlig;lich s&auml;mtlicher Inhalte und Unterverzeichnisse) ?';
 $lang['dirtreedeletecancelled'] = 'Das L&ouml;schen des Verzeichnisses wurde abgebrochen';
@@ -90,17 +100,18 @@ $lang['cancel'] = 'Abbrechen';
 $lang['ok'] = 'Ok';
 $lang['uploadnewfile'] = 'Neue Datei(en) hochladen:';
 $lang['unpackafterupload'] = 'Nach dem Hochladen die Datei entpacken (nur tgz und zip-Dateien)?';
-$lang['uploadsuccess'] = 'wurde erfolgreich hochgeladen';
+$lang['uploadsuccess'] = 'wurde hochgeladen';
 $lang['uploadfail'] = 'wurde nicht hochgeladen';
-$lang['unpacksuccess'] = 'wurde erfolgreich entpackt';
+$lang['unpacksuccess'] = 'wurde entpackt';
 $lang['unpackfail'] = 'wurde mit dem Fehler abgebrochen:';
 $lang['packfileopenfail'] = 'Die gepackte Datei konnte nicht ge&ouml;ffnet werden (nicht unterst&uuml;tztes Format?)';
 $lang['packfilewritefail'] = 'Die Datei %s konnte nicht geschrieben werden.';
-$lang['containsillegalchars'] = 'Der Dateiname enth&auml;lt ein oder mehrere nicht erlaubte Zeichen (&#039;,&quot;,+,*,\,/,&amp;,$)';
+$lang['afilecontainsillegalchars'] = 'Der Dateiname enth&auml;lt einen oder mehrere unzul&auml;ssige Zeichen (&#039;,&quot;,+,*,\,/,&amp;,$). Das Hochladen wurde abgebrochen.';
 $lang['currentpath'] = 'Aktueller Pfad:';
 $lang['newdirname'] = 'Neues Verzeichnis erstellen:';
-$lang['newdirsuccess'] = 'Das Verzeichnis wurde erfolgreich erstellt.';
+$lang['newdirsuccess'] = 'Das Verzeichnis wurde erstellt.';
 $lang['newdirfail'] = 'Beim Erstellen des Verzeichnisses ist ein Fehler aufgetreten.';
+$lang['direxists'] = 'Ein Verzeichnis mit diesem Namen existiert bereits';
 $lang['invalidnewdir'] = 'Der Name des neuen Verzeichnisses darf keine Zeichen wie /, \ und &#039;..&#039; enthalten.';
 $lang['filedateformat'] = 'd.m.Y H:m:s';
 $lang['iconsize'] = 'Gr&ouml;&szlig;e der Icons';
@@ -115,11 +126,11 @@ $lang['uploadfilesto'] = 'Dateien hochladen in:';
 $lang['uploadview'] = 'Hochzuladende Dateien';
 $lang['uploadboxes'] = 'Anzahl der Felder f&uuml;r hochzuladende Dateien';
 $lang['nothinguploaded'] = 'Nichts hochgeladen';
-$lang['unsupportedarchive'] = 'Nicht unterst&uuml;tzte Archiv-Formate';
+$lang['newunsupportedarchive'] = '%s ist ein nicht unterst&uuml;tztes Archiv-Format';
 $lang['uploadmethod'] = 'Methode zum Hochladen';
 $lang['uploaderstandard'] = 'Standard-HTML-Eingabemethode (erlaubt das Entpacken)';
-$lang['enableadvanced'] = 'Erweiterten Modus aktivieren? (falls erlaubt)';
-$lang['advancedhelp'] = 'Damit erhalten Sie Zugriff auf ALLE CMSms-Dateien (nicht nur auf das /uploads-Verzeichnis)';
+$lang['enableadvanced'] = 'Erweiterten Modus aktivieren?';
+$lang['advancedhelp'] = 'Damit erhalten Sie Zugriff auf ALLE CMSms-Dateien, nicht nur auf das /uploads-Verzeichnis (falls erlaubt)';
 $lang['showhiddenfileshelp'] = 'Ist nur bei Aktivierung des erweiterten Modus sinnvoll';
 $lang['showhiddenfiles'] = 'Verborgene Dateien anzeigen';
 $lang['settingsconfirmsingledelete'] = 'Das L&ouml;schen einzelner Datei best&auml;tigen?';
@@ -128,9 +139,8 @@ $lang['help'] = '		<h3>Was macht das Modul?</h3>
 		<p>Dieses Modul bietet verschiedene Funktionen zur Dateiverwaltung.</p>
 		<h3>Wie wird es eingesetzt?</h3>
 		<p>W&auml;hlen Sie das Modul in der Administration im Men&uuml; &quot;Inhalte&quot; aus.</p>';
-$lang['qca'] = 'P0-180715755-1255429031955';
-$lang['utma'] = '156861353.631674314.1255431066.1255431066.1255431066.1';
+$lang['utma'] = '156861353.1653174585.1296045220.1296045220.1296045220.1';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1255431066.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,38144.new.html|utmcmd=referral';
+$lang['utmz'] = '156861353.1296045220.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
