@@ -12,6 +12,7 @@ $lang['fileview'] = 'Ver archivo';
 $lang['switchtofileview'] = 'Cambiar a vista de archivo';
 $lang['settings'] = 'Configuraciones';
 $lang['savesettings'] = 'Guardar configuraciones';
+$lang['postletexists'] = '&iexcl;Advertencia! por favor remueva las carpeta modules/FileManager/postlet completamente, &eacute;sta es obsoleta desde muchas versiones anteriores.';
 $lang['filename'] = 'Nombre de Archivo';
 $lang['fileinfo'] = 'Info de archivo';
 $lang['fileowner'] = 'Due&ntilde;o de archivo';
@@ -21,7 +22,7 @@ $lang['filedate'] = 'Fecha';
 $lang['actions'] = 'Acciones';
 $lang['delete'] = 'Eliminar';
 $lang['notwritable'] = 'No se pude escribir';
-$lang['filetoobig'] = 'es demasiado grande. En envio se ha cancelado.';
+$lang['afileistoobig'] = 'Un archivo es demasiado grande. Se cancel&oacute; la carga.';
 $lang['unknown'] = 'Desconocido';
 $lang['fileoutsideuploads'] = 'No tiene permiso de modificar archivos fuera del directorio &#039;uploads&#039; (Esto requiere el que se active el permiso de Administraci&oacute;n Avanzada de Archivos)';
 $lang['writable'] = 'De escritura';
@@ -60,6 +61,13 @@ $lang['movedto'] = 'movido a';
 $lang['copiedto'] = 'copiado a';
 $lang['couldnotmove'] = 'no se pudo mover';
 $lang['couldnotcopy'] = 'no se pudo copiar';
+$lang['filesdeletedsuccessfully'] = '%s archivo(s) fueron borrados';
+$lang['filesdeletedfiled'] = '%s archivo(s) no se borraron';
+$lang['filesmovedsuccessfully'] = '%s archivo(s) me movieron con exito';
+$lang['filesmovedfailed'] = '%s archivo(s) no se pudieron mover';
+$lang['filescopiedsuccessfully'] = '%s archivo(s) fueron copiados';
+$lang['filescopiedfailed'] = '%s archivo(s) no se pudieron copiar';
+$lang['internalerror'] = 'Error interno, por favor reporte dicho error.';
 $lang['rename'] = 'Renombrar';
 $lang['newname'] = 'Nuevo nombre:';
 $lang['renamesuccess'] = 'Archivo renombrado con &eacute;xito';
@@ -79,6 +87,8 @@ $lang['chmodselected'] = 'Cambiar permisos de archivos seleccionados';
 $lang['chmodsuccess'] = 'El archivo obtuvo nuevos permisos exitosamente';
 $lang['chmodfailure'] = 'Fall&oacute; el cambio de permisos del archivo';
 $lang['chmodcancelled'] = 'Se cancel&oacute; el cambio de permisos';
+$lang['newuploadfailed'] = '%s archivo(s) no se pudieron cargar (o desempacar)';
+$lang['newuploadsuccess'] = '%s archivo(s) fuero subidos (y desempacados si asi se solicit&oacute;)';
 $lang['dirchmodfailmulti'] = 'No se pudo hacer el cambio de los permisos del directorio, pero algo en su contenido puede que haya recibido los nuevos permisos.';
 $lang['dirchmodsuccessmulti'] = 'Se cambiaron los permisos y el contenido exitosamente ';
 $lang['dirchmodsuccess'] = 'El directorio recibi&oacute; los nuevos permisos exitosamente';
@@ -96,11 +106,12 @@ $lang['unpacksuccess'] = 'fue descomprimido con &eacute;xito';
 $lang['unpackfail'] = 'fall&oacute; con el siguiente error: ';
 $lang['packfileopenfail'] = 'No se pudo abrir el archivo para descomprimir (&iquest;quiz&aacute; un formato no soportado?)';
 $lang['packfilewritefail'] = 'No se pudo abrir el archivo &amp;s para escribir';
-$lang['containsillegalchars'] = 'El nombre de archivo contiene caracteres inv&aacute;lidos (&#039;,&quot;,+,*,\,/,&amp;,$)';
+$lang['afilecontainsillegalchars'] = 'Un nombre de archivo contiene uno o mas caracteres invalidos (&#039;,&quot;,+,*,\,/,&amp;,$). Carga cancelada.';
 $lang['currentpath'] = 'Paso actual:';
 $lang['newdirname'] = 'Crear nuevo directorio:';
 $lang['newdirsuccess'] = 'El directorio se creo con &eacute;xito';
 $lang['newdirfail'] = 'Ha ocurrido un error tratando de crear el directorio';
+$lang['direxists'] = 'La carpeta ya existe';
 $lang['invalidnewdir'] = 'Nombre del nuevo directorio no puede contener caracteres como /, \ y &#039;..&#039; ';
 $lang['filedateformat'] = 'm/d/Y H:m:s ';
 $lang['iconsize'] = 'Tama&ntilde;o de icono';
@@ -115,7 +126,7 @@ $lang['uploadfilesto'] = 'Subiendo archivos a:';
 $lang['uploadview'] = 'Subir archivos';
 $lang['uploadboxes'] = 'Cantidad de rampas p/subir';
 $lang['nothinguploaded'] = 'Nada subido';
-$lang['unsupportedarchive'] = 'Formato de archivo no soportado';
+$lang['newunsupportedarchive'] = '%s es un archivo con formato inaceptable';
 $lang['uploadmethod'] = 'M&eacute;todo de subida';
 $lang['uploaderstandard'] = 'M&eacute;todo de carga html standard (permite descomprimir)';
 $lang['enableadvanced'] = '&iquest;Habilitamos modo avanzado?';
@@ -128,9 +139,9 @@ $lang['help'] = '		<h3>&iquest;Qu&eacute; hace esto?</h3>
 		<p>Este m&oacute;dulo provee funciones de manejo de archivos, eventualmente y con expectativas de reemplazar al ya viejo sistema de manejo de archivos</p>
 		<h3>&iquest;C&oacute;mo se usa?</h3>
 		<p>Seleccione al mismo en el men&uacute; de contenido del &aacute;rea de administraci&oacute;n. Seguramente el viejo sistema de archivos est&aacute; a&uacute;n all&iacute;, elija el que est&aacute; m&aacute;s abajo dentro del men&uacute;.</p>';
-$lang['utma'] = '156861353.1791238199.1256157318.1256620466.1256855476.6';
-$lang['utmz'] = '156861353.1256620490.5.5.utmccn=(organic)|utmcsr=google|utmctr=cms made simple pretty urls|utmcmd=organic';
-$lang['qca'] = 'P0-1140984805-1256189057107';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-672577724-1291068511180';
+$lang['utmz'] = '156861353.1291068584.1.2.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['utma'] = '156861353.761306410.1291068511.1297984934.1298856162.17';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
