@@ -12,6 +12,7 @@ $lang['fileview'] = 'Bestandsweergave';
 $lang['switchtofileview'] = 'Schakel naar bestandsweergave';
 $lang['settings'] = 'Instellingen';
 $lang['savesettings'] = 'Bewaar instellingen';
+$lang['postletexists'] = 'Waarschuwing! Verwijder de servermap modules/FileManager/postlet in zijn geheel. De map en inhoud wordt al geruime tijd niet meer gebruikt en onderhouden.';
 $lang['filename'] = 'Bestandsnaam';
 $lang['fileinfo'] = 'Bestandsinformatie';
 $lang['fileowner'] = 'Bestandseigenaar';
@@ -21,7 +22,7 @@ $lang['filedate'] = 'Datum';
 $lang['actions'] = 'Acties';
 $lang['delete'] = 'Verwijder';
 $lang['notwritable'] = 'Niet schrijfbaar';
-$lang['filetoobig'] = 'is te groot. Upload is afgebroken.';
+$lang['afileistoobig'] = 'Een bestand is te groot. Upload is geannuleerd.';
 $lang['unknown'] = 'Onbekend';
 $lang['fileoutsideuploads'] = 'U heef geen autorisatie om bestanden buiten de uploads-folder aan te passen! (Daarvoor is Advanced File Management permissie nodig)';
 $lang['writable'] = 'Schrijfbaar';
@@ -60,6 +61,13 @@ $lang['movedto'] = 'verplaatst naar';
 $lang['copiedto'] = 'gekopieerd naar';
 $lang['couldnotmove'] = 'kon niet worden verplaatst';
 $lang['couldnotcopy'] = 'kon niet worden gekopieerd';
+$lang['filesdeletedsuccessfully'] = '%s bestand(en) is/zijn verwijderd';
+$lang['filesdeletedfiled'] = '%s bestand(en) is/zijn NIET verwijderd';
+$lang['filesmovedsuccessfully'] = '%s bestand(en) is/zijn verplaatst';
+$lang['filesmovedfailed'] = '%s bestand(en) is/zijn NIET verplaatst';
+$lang['filescopiedsuccessfully'] = '%s bestand(en) is/zijn gekopieerd';
+$lang['filescopiedfailed'] = '%s bestand(en) is/zijn NIET gekopieerd';
+$lang['internalerror'] = 'Interne Fout (Geeft u ons alstublieft in een bugreport door welke stappen u heeft ondernomen dat leidde tot deze melding...)';
 $lang['rename'] = 'Naam wijzigen';
 $lang['newname'] = 'Nieuwe naam:';
 $lang['renamesuccess'] = 'Bestandsnaam gewijzigd';
@@ -79,6 +87,8 @@ $lang['chmodselected'] = 'Wijzig permissies op geselecteerde bestanden';
 $lang['chmodsuccess'] = 'Permissies gewijzigd';
 $lang['chmodfailure'] = 'Permissies wijzigen mislukt';
 $lang['chmodcancelled'] = 'Permissies wijzigen geannuleerd';
+$lang['newuploadfailed'] = '%s bestand(en) is/zijn NIET ge&uuml;pload (of wellicht niet uitgepakt)';
+$lang['newuploadsuccess'] = '%s bestand(en) is/zijn ge&uuml;pload (en indien aangevinkt ook uitgepakt)';
 $lang['dirchmodfailmulti'] = 'Permissie wijzigen van deze map is mislukt, het kan echter wel zijn dat bepaalde bestanden wel gewijzigde rechten hebben gekregen.';
 $lang['dirchmodsuccessmulti'] = 'Permissies wijzigen van de map en de inhoud is geslaagd';
 $lang['dirchmodsuccess'] = 'Map permissies gewijzigd';
@@ -96,11 +106,12 @@ $lang['unpacksuccess'] = 'is uitgepakt';
 $lang['unpackfail'] = 'afgebroken met deze fout:';
 $lang['packfileopenfail'] = 'Kon het ingepakte bestand niet openen om uit te pakken (niet-ondersteund formaat?)';
 $lang['packfilewritefail'] = 'Kan het bestand %s niet openen om naar te schrijven';
-$lang['containsillegalchars'] = 'De bestandsnaam bevat &eacute;&eacute;n of meer niet-toegestane karakters (&#039;,&quot;,+,*,\,/,&amp;,$)';
+$lang['afilecontainsillegalchars'] = 'Een bestandsnaam bevat niet toegestane karakters (&#039;,&quot;,+,*,\,/,&amp;,$). Upload is geannuleerd.';
 $lang['currentpath'] = 'Huidig pad:';
 $lang['newdirname'] = 'Maak nieuwe map aan:';
 $lang['newdirsuccess'] = 'De map is aangemaakt';
 $lang['newdirfail'] = 'Er is een fout opgetreden bij het aanmaken van de map';
+$lang['direxists'] = 'De mapnaam bestaat al';
 $lang['invalidnewdir'] = 'Naam van de nieuwe map geen karakters zoals /, \ en &#039;..&#039; bevatten';
 $lang['filedateformat'] = 'm/d/J U:m:s';
 $lang['iconsize'] = 'Pictogramgrootte';
@@ -115,7 +126,7 @@ $lang['uploadfilesto'] = 'Upload bestanden naar: ';
 $lang['uploadview'] = 'Upload bestanden';
 $lang['uploadboxes'] = 'Aantal uploadvelden';
 $lang['nothinguploaded'] = 'Niets ge&uuml;pload';
-$lang['unsupportedarchive'] = 'Niet-ondersteund archiefformaat';
+$lang['newunsupportedarchive'] = '%s heeft een niet ondersteund archief formaat';
 $lang['uploadmethod'] = 'Upload-methode';
 $lang['uploaderstandard'] = 'Standaard html invoermethode (staat uitpakken toe)';
 $lang['enableadvanced'] = 'Sta gevorderdenmodus toe?';
@@ -128,9 +139,9 @@ $lang['help'] = '		<h3>Wat doet het?</h3>
 		<p>Deze module verzorgt een bestandsbeheer functionaliteit</p>
 		<h3>Hoe gebruikt u het</h3>
 		<p>Selecteer Bestandsbeheer in het Inhoudsmenu.</p>';
-$lang['utma'] = '156861353.1269027775.1259416186.1267015852.1267019956.409';
-$lang['utmz'] = '156861353.1266930309.404.68.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=tjassens rolf';
-$lang['qca'] = 'P0-431297011-1259416186230';
-$lang['utmb'] = '156861353.12.10.1267019956';
+$lang['utma'] = '156861353.1335698708.1284586217.1294649577.1294650161.782';
+$lang['utmz'] = '156861353.1294432973.744.60.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/bug/list/133';
+$lang['qca'] = 'P0-1551306179-1284586216711';
+$lang['utmb'] = '156861353.1.10.1294650161';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
