@@ -17,6 +17,7 @@
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #$Id: News.module.php 2114 2005-11-04 21:51:13Z wishy $
+if( !isset($gCms) ) exit;
 
 class MenuManager extends CMSModule
 {
@@ -49,16 +50,20 @@ class MenuManager extends CMSModule
   {
     // remove the permissions
     $this->RemovePermission('Manage Menu');
+    $this->RemovePreference();
+    $this->RemoveEventHandler('Core','ContentEditPost');
+    $this->RemoveEventHandler('Core','ContentDeletePost');
+    $this->DeleteTemplate();
   }
 
   function GetVersion()
   {
-    return '1.6.5';
+    return '1.7.6';
   }
 
   function MinimumCMSVersion()
   {
-    return '1.6.7';
+    return '1.9.1';
   }
 
   function GetAdminDescription()
@@ -112,6 +117,9 @@ class MenuManager extends CMSModule
 
     $this->CreateParameter('childrenof','',$this->Lang('help_childrenof'));
     $this->SetParameterType('childrenof',CLEAN_STRING);
+
+    $this->CreateParameter('nocache','',$this->Lang('help_nocache'));
+    $this->SetParameterType('nocache',CLEAN_INT);
   }
 
   /**
@@ -138,6 +146,8 @@ class MenuManager extends CMSModule
       {
 	$show_all = 0;
       }
+
+    $nadded = 0;
     if (isset($parentnode))
       {
 	$children =& $parentnode->getChildren($deep);
@@ -191,26 +201,39 @@ class MenuManager extends CMSModule
 		    ($content->ShowInMenu() || ($show_all == 1  && !$content->IsSystemPage())))
 		  {
 		    $newnode =& $this->FillNode($content, $onechild, $nodelist, 
-						$gCms, $count, $prevdepth, $origdepth, $deep);
+						$gCms, $count, $prevdepth, $origdepth, $deep, $params);
+		    $nadded++;
+
 		    //Ok, this one is nasty...
 		    //First part checks to see if number_of_levels is set and whether the current depth is deeper than the set number_of_levels depth (opposite logic, actually)
 		    //Second part checks to see if showparents is set...  if so, then it checks to see if this hierarchy position is one of them
 		    //If either of these things occurs, then try to show the children of this node
-		    if (!(isset($params['number_of_levels']) && 
-			  $newnode->depth > ($params['number_of_levels']) - ($origdepth)) && 
-			(count($showparents) == 0 || (count($showparents) > 0 && 
-						      in_array($content->Hierarchy() . '.', $showparents))))
+		    $n = (int)($newnode->depth);
+		    $limit_levels = isset($params['number_of_levels']);
+		    $have_depth = $limit_levels && ($n < (int)$params['number_of_levels']);
+		    $collapsing = count($showparents) > 0;
+		    $in_collapse_path = $collapsing && in_array($content->Hierarchy().'.',$showparents);
+		    if( ($limit_levels && $have_depth && !$collapsing) || ($in_collapse_path && ($have_depth || !$limit_levels)) || (!$limit_levels && !$collapsing) )
 		      {
-			$this->GetChildNodes($onechild, $nodelist, $gCms, $prevdepth, $count, $params, $origdepth, $showparents, $deep);
+			$tmp = $this->GetChildNodes($onechild, $nodelist, $gCms, $prevdepth, $count, $params, $origdepth, $showparents, $deep);
+			if( $tmp )
+			  {
+			    $nadded += $tmp;
+			    $newnode->haschildren = true;
+			  }
 		      }
 		  }
 	      }
 	  }
       }
+      return $nadded;
   }
 
-  function & FillNode(&$content, &$node, &$nodelist, &$gCms, &$count, &$prevdepth, $origdepth, $deep = false)
+  function & FillNode(&$content, &$node, &$nodelist, &$gCms, &$count, &$prevdepth, $origdepth, $deep = false, $params = array())
     {
+      global $gCms;
+      $config = $gCms->GetConfig();
+
       $onenode = new stdClass();
       $onenode->id = $content->Id();
       $onenode->pagetitle = $content->Name();
@@ -221,15 +244,33 @@ class MenuManager extends CMSModule
       $onenode->titleattribute = $content->TitleAttribute();
       $onenode->modified = $content->GetModifiedDate();
       $onenode->created = $content->GetCreationDate();
-
       $onenode->hierarchy = $content->Hierarchy();
       $onenode->depth = count(explode('.', $content->Hierarchy())) - ($origdepth - 1);
       $onenode->prevdepth = $prevdepth - ($origdepth - 1);
       if ($onenode->prevdepth == 0)
 	$onenode->prevdepth = 1;
+      $onenode->children_exist = false;
+      if ($node->has_children())
+	{
+	  $children = $node->get_children();
+	  if( $children )
+	    {
+	      for( $i = 0; $i < count($children); $i++ )
+		{
+		  $tmpc = $children[$i]->getContent();
+		  if( $tmpc->Active() && $tmpc->ShowInMenu() )
+		    {
+		      $onenode->children_exist = true;
+		      break;
+		    }
+		}
+	    }
+	}
+//       if( is_object($node) )
+// 	{
+// 	  $onenode->children_exist = $node->hasChildren();
+// 	}
       $onenode->haschildren = false;
-      if (isset($node))
-	$onenode->haschildren = $node->HasChildren(true);
       $prevdepth = $onenode->depth + ($origdepth - 1);
       $onenode->menutext = my_htmlentities($content->MenuText());
       $onenode->raw_menutext = $content->MenuText();
@@ -247,12 +288,18 @@ class MenuManager extends CMSModule
 	  $tmp = $content->GetPropertyValue('image');
 	  if( !empty($tmp) && $tmp != -1 )
 	    {
-	      $onenode->image = $tmp;
+	      $url = get_site_preference('content_imagefield_path').'/'.$tmp;
+	      if( !startswith($url,'/') ) $url = '/'.$url;
+	      $url = $config['image_uploads_url'].$url;
+	      $onenode->image = $url;
 	    }
 	  $tmp = $content->GetPropertyValue('thumbnail');
 	  if( !empty($tmp) && $tmp != -1 )
 	    {
-	      $onenode->thumbnail = $tmp;
+	      $url = get_site_preference('content_thumbnailfield_path').'/'.$tmp;
+	      if( !startswith($url,'/') ) $url = '/'.$url;
+	      $url = $config['image_uploads_url'].$url;
+	      $onenode->thumbnail = $url;
 	    }
 	  if ($content->HasProperty('target'))
 	    $onenode->target = $content->GetPropertyValue('target');
@@ -260,16 +307,32 @@ class MenuManager extends CMSModule
 	  
 
       if (isset($gCms->variables['content_id']) && $onenode->id == $gCms->variables['content_id'])
-	$onenode->current = true;
+	{
+	  $onenode->current = true;
+	}
       else
 	{
 	  $onenode->current = false;
 	  //So, it's not current.  Lets check to see if it's a direct parent
 	  if (isset($gCms->variables["friendly_position"]))
 	    {
-	      if (strstr($gCms->variables["friendly_position"] . '.', $content->Hierarchy() . '.') == $gCms->variables["friendly_position"] . '.')
+	      if( startswith($gCms->variables['friendly_position'].'.',$content->Hierarchy().'.') ) 
 		{
 		  $onenode->parent = true;
+// 		  // content is a parent of the current page.
+// 		  if( is_array($params) && isset($params['number_of_levels']) )
+// 		    {
+// 		      $a = count(explode('.',$gCms->variables['friendly_position']));
+// 		      $nl = (int)$params['number_of_levels'];
+// 		      if( $nl - $onenode->depth >= $a )
+// 			{
+// 			  $onenode->parent = true;
+// 			}
+// 		    }
+// 		  else
+// 		    {
+// 		      $onenode->parent = true;
+// 		    }
 		}
 	    }
 	}
@@ -359,6 +422,19 @@ class MenuManager extends CMSModule
     $this->SetTemplate( $tpl_name, $content );
     return true;
   }
+
+  function clear_cache()
+  {
+    $fs = cms_join_path(TMP_CACHE_LOCATION,'menu.*.cache');
+    $files = glob($fs);
+    if( is_array( $files ) )
+      {
+	foreach( $files as $one )
+	  {
+	    @unlink($one);
+	  }
+      }
+  }
 } // End of class
 
 # vim:ts=4 sw=4 noet
