@@ -27,10 +27,7 @@ else if (isset($params['submit']))
 	{
 		if ($this->GetTemplate($newtemplate) == '')
 		{
-			@ob_start();
-			@readfile(dirname(__FILE__) . '/templates/' . $params['tplname']);
-			$contents = @ob_get_contents();
-			@ob_clean();
+			$contents = file_get_contents(dirname(__FILE__) . '/templates/' . $params['tplname']);
 			$this->SetTemplate($newtemplate, $contents);
 			$this->Redirect($id, 'defaultadmin', $returnid);
 		}
