@@ -1,4 +1,8 @@
 <?php
+$lang['set_cachable'] = 'Aseta t&auml;m&auml; sivupohja v&auml;limuistiin lis&auml;tt&auml;v&auml;ksi';
+$lang['help_nocache'] = 'Disable any caching of this call to the menu.  This parameter, if set to any positive value will override any settings in the content object and the menu template.';
+$lang['cachable'] = 'V&auml;limuistissa';
+$lang['help_childrenof'] = 'T&auml;m&auml; asetus n&auml;ytt&auml;&auml; valikossa ainoastaan kohteet, jotka ovat alasivuja valitulle sivulle tai aliakselle, esimerkiksi  <code>{menu childrenof=$page_alias}</code> n&auml;ytt&auml;&auml; ainoastaan nykyisen sivun alasivut.';
 $lang['usage'] = 'K&auml;ytt&ouml;';
 $lang['help_loadprops'] = 'K&auml;yt&auml; parametria, kun k&auml;yt&auml;t monipuolisempia asetuksia valikonhallintamalleissa. T&auml;m&auml; parametri pakottaa kaikkien sis&auml;lt&ouml;asetusten lataamisen jokaiselle tietosolmulle (kuten extra1, image, thumbnail jne.) ja lis&auml;&auml; dramaattisesti kyselyjen m&auml;&auml;r&auml;&auml; jokaisen valikon luomiseksi ja lis&auml;&auml; my&ouml;s muistivaatimuksia, mutta sallii monimutkaisempien valikoiden luomisen.';
 $lang['readonly'] = 'vain luku';
@@ -83,9 +87,9 @@ $lang['notemplatefiles'] = 'Ei tiedostomalleja kohteessa %s';
 $lang['notemplatename'] = 'Mallin nime&auml; ei annettu';
 $lang['templatecontent'] = 'Mallin sis&auml;lt&ouml;';
 $lang['templatenameexists'] = 'Samalla nimell&auml; on jo malli';
-$lang['utma'] = '156861353.572491444.1274267548.1274281846.1274285048.5';
+$lang['qca'] = 'P0-143593381-1287469720325';
+$lang['utmz'] = '156861353.1289907526.70.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,48780.0.html';
+$lang['utma'] = '156861353.386609350.1282051258.1289907526.1289915269.71';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1274270099.2.2.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
-$lang['qca'] = 'P0-1477326709-1274267548700';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1289915269';
 ?>
\ No newline at end of file
