@@ -1,4 +1,7 @@
 <?php
+$lang['set_cachable'] = 'Fissa questo template come cachable';
+$lang['help_nocache'] = 'Disabilita il caching di questa chiamata al menu. Questo parametro, se fissato a valori positivi sovrascrive qualsiasi impostazione nell&#039;oggetto content e menu template.';
+$lang['cachable'] = 'Cachable ';
 $lang['help_childrenof'] = 'Questa opzione visualizzer&agrave; il menu solo con i discendenti della pagina ID o alias. p.e: <code>{menu childrenof=$page_alias}</code> visualizzer&agrave; solo i figli della pagina corrente.';
 $lang['usage'] = 'Uso';
 $lang['help_loadprops'] = 'Usa questo parametro quando stai usando le propriet&agrave; avanzate nel Vostro MenuManager template. Questo parametro forzer&agrave; il caricamento di tutte le propriet&agrave; di ciascun nodo (come extra1, image, thumbnail, etc) e quindi permetter&agrave; la costruzione di menu molto pi&ugrave; avanzati ma aumenter&agrave; considerevolmente il numero di query richieste per costruire un menu e quindi l&#039;ammontare di memoria richiesta';
@@ -11,6 +14,7 @@ $lang['templates'] = 'Modelli';
 $lang['addtemplate'] = 'Aggiungere Modello';
 $lang['areyousure'] = 'Sei sicuri di volerlo eliminare?';
 $lang['changelog'] = '	<ul>
+<li>1.7 - Adds the possibility to cache menumanager output to a cache file, this will remove a bunch of queries from mostly static sites. Fixes to childrenof parameter.</li>
 <li>1.6.3 - Adds usage column.</li>
 <li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
 <li>1.6.1 - Add created and modified entries on each node.</li>
@@ -84,7 +88,11 @@ $lang['help'] = '	<h3>Che cosa fa?</h3>
 			<li>$node->index -- Contatore di questo nodo nell&#039;intero menu</li>
 			<li>$node->parent -- True (vero) se questo nodo &egrave; un parent (genitore) della pagina correntemente selezionata</li>
 		</ul>
-	</p>';
+	</p>
+        <h3>Caching</h3>
+        <p>This module has the capability to cache its output into static files to reduce memory requirements and sql queries, and to improve frontend performance.  This provides all the advantages of static menus without the inconvenience involved when creating or editing pages.</p>
+        <p>Each menu template can be marked as &amp;quot;Cachable&amp;quot;. When a cachable menu template is used on a content page that is cachable, any cached menu output that is available for thsi page will be used.  The nocache parameter on the menu tag can be used to completely disable caching.</p>
+        <p>All cached menu files are erased when a content item is added, edited, or deleted... and also when a menu template is added/edited or deleted.</p>';
 $lang['importtemplate'] = 'Importa Modello nel database';
 $lang['menumanager'] = 'Gestore menu';
 $lang['newtemplate'] = 'Nuovo nome di Modello';
@@ -93,9 +101,8 @@ $lang['notemplatefiles'] = 'Nessun modello per file in %s';
 $lang['notemplatename'] = 'Nessun nome di Modello fornito.';
 $lang['templatecontent'] = 'Contenuto del Modello';
 $lang['templatenameexists'] = 'Un Modello con questo nome esiste gi&agrave;';
-$lang['qca'] = 'P0-1187230324-1271659236866';
-$lang['utma'] = '156861353.976402040.1271759292.1276850904.1277118686.4';
-$lang['utmz'] = '156861353.1277118686.4.4.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.974349155.1299072468.1299072468.1299072468.1';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
