@@ -1,7 +1,10 @@
 <?php
+$lang['set_cachable'] = 'Tillat denne malen &aring; mellomlagres';
+$lang['help_nocache'] = 'Sl&aring; av all mellomlagring for dette kallet til menyen. Denne parameteren, om den er satt til en positiv verdi, vil overstyre alle innstillinger i innholdsobjektet og i malen for menyen.';
+$lang['cachable'] = 'Kan mellomlagres';
 $lang['help_childrenof'] = 'Dette valget vil gj&oslash;re at menyen kun viser enheter som er etterkommere av den valgte sideID eller alias. F.eks. s&aring; vil: <code>{menu childrenof=$page_alias}</code> kun vise barn av den gjeldende siden.';
 $lang['usage'] = 'Benyttes slik';
-$lang['help_loadprops'] = 'Benytt denne parameter om du benytter avanserte egenskaper i din menybehandlermal. Denne parameter vil SL&Aring; AV lasting av alle innholddsegenskaper for hver node (som extra1, image, thumbnail, osv.). Dette vil dramatisk minske antall sp&oslash;rringer krevd for &aring; bygge en meny og minsker ogs&aring; minnekravet, men dette vil fjerne muligheten for bygging av mye mer avanserte menyer';
+$lang['help_loadprops'] = 'Benytt denne parameter om du IKKE benytter avanserte egenskaper i din menybehandlermal. Denne parameter vil SL&Aring; AV lasting av alle innholddsegenskaper for hver node (som extra1, image, thumbnail, osv.). Dette vil dramatisk minske antall sp&oslash;rringer krevd for &aring; bygge en meny og minsker ogs&aring; minnekravet, men dette vil fjerne muligheten for bygging av mye mer avanserte menyer';
 $lang['readonly'] = 'skrivebeskyttet';
 $lang['error_templatename'] = 'Du kan ikke oppgi ett malnavn som ender p&aring; .tpl';
 $lang['this_is_default'] = 'Standard menymal';
@@ -11,6 +14,7 @@ $lang['templates'] = 'Maler';
 $lang['addtemplate'] = 'Legg til mal';
 $lang['areyousure'] = 'Er du sikker p&aring; at du vil slette dette?';
 $lang['changelog'] = '	<ul>
+<li>1.7 - Adds the possibility to cache menumanager output to a cache file, this will remove a bunch of queries from mostly static sites.</li>
 <li>1.6.3 - Adds usage column.</li>
 <li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
 <li>1.6.1 - Add created and modified entries on each node.</li>
@@ -31,17 +35,17 @@ $lang['deletetemplate'] = 'Slett mal';
 $lang['edittemplate'] = 'Rediger mal';
 $lang['filename'] = 'Filnavn';
 $lang['filetemplates'] = 'Fil maler';
-$lang['help_includeprefix'] = 'Inkluder kun de punktene hvor sidealias starter med den spesifiserte forstavelsen. Denne parameteren kan ikke kombineres med excludeprefix (utelatprefiks) parameteren.';
-$lang['help_excludeprefix'] = 'Utelat alle punkter (og deres underpunkter) hvor sidealias inneholder den spesifiserte forstavelsen. Denne parameter m&aring; ikke benyttes sammen med includeprefix (inkluderprefiks) parameteren.';
+$lang['help_includeprefix'] = 'Inkluder kun de punktene hvor sidealias starter med den spesifiserte forstavelsen. Denne parameteren kan ikke kombineres med excludeprefix (utelat-prefiks) parameteren.';
+$lang['help_excludeprefix'] = 'Utelat alle punkter (og deres underpunkter) hvor sidealias inneholder den spesifiserte forstavelsen. Denne parameter m&aring; ikke benyttes sammen med includeprefix (inkluder-prefiks) parameteren.';
 $lang['help_collapse'] = 'Sl&aring; p&aring; (sett til 1) for &aring; f&aring; menyen til &aring; skjule artikler som ikke er relatert til den valgte siden.';
 $lang['help_items'] = 'Bruk denne verdien for &aring; velge en liste av sider som denne menyen skal vise.  Verdien skal v&aelig;re en liste over side-alias separert med komma.';
 $lang['help_number_of_levels'] = 'Denne innstillingen vil bare tillate menyen &aring; vise et visst antall av niv&aring;er ned.';
 $lang['help_show_all'] = 'Dette valget vil gj&oslash;re at menyen vil vise alle noder selv om de eventuelt er satt til ikke &aring; vises i menyen. Men inaktive sider vil fortsatt ikke vises.';
-$lang['help_show_root_siblings'] = 'Dette valget er kun nyttig om start_element eller start_page er i bruk.  I basis vil menyen vise s&oslash;sken langs siden p&aring; den valgte start_page/element.';
+$lang['help_show_root_siblings'] = 'Dette valget er kun nyttig om start_element eller start_page er i bruk.  I basis vil menyen vise s&oslash;sken for det valgte start_page/element.';
 $lang['help_start_level'] = 'Dette valget vil f&aring; menyen til kun &aring; vise poster startende p&aring; et gitt niv&aring;.  Et enkelt eksempel vil v&aelig;re om du hadde en meny p&aring; siden med number_of_levels=&#039;1&#039;.  S&aring; som en andre meny, du kan ha start_level=&#039;2&#039;.  N&aring; vil din andre meny vise poster basert p&aring; hva som er valgt i den f&oslash;rste menyen.';
 $lang['help_start_element'] = 'Starter menyen med visning p&aring; den gitte start_element og viser kun det elementet og dets barn.  Tar en hierarki plassering (f.eks. 5.1.2).';
 $lang['help_start_page'] = 'Starter menyen med visning p&aring; en gitt start_page og viser kun det elementet og dets barn.  Tar en side alias.';
-$lang['help_template'] = 'Mal &aring; bruke for &aring; vise menyen. Maler vil komme fra databasemaler om ikke malens navn ender p&aring; .tpl - i s&aring; fall vill den komme fra en fil i MenuManager mal-mappen (standard er simple_navigation.tpl)';
+$lang['help_template'] = 'Mal &aring; bruke for &aring; vise menyen. Maler vil komme fra databasemaler om ikke malens navn ender p&aring; .tpl - i s&aring; fall vill den komme fra en fil i MenuManager templates-mappen (standard er simple_navigation.tpl)';
 $lang['help'] = '	<h3>Hva gj&oslash;r denne?</h3>
 	<p>Menu Manager er en modul for &aring; sette menyer inn i et system som er lett &aring; bruke og lett &aring; tilpasse.  Den setter visnings delen av menyer inn i smarty maler som lett kan modifiseres for &aring; passe brukerens behov. Det vil si, menu manager er kun motoren som mater malen. Ved &aring; tilpasse malene, eller lage dine egne, kan du lage omtrent enhver meny du kan tenke deg.</p>
 	<h3>Hvordan bruker jeg den?</h3>
@@ -69,6 +73,7 @@ $lang['help'] = '	<h3>Hva gj&oslash;r denne?</h3>
 			<li>$node->depth -- Dybde (niv&aring;) p&aring; denne klyngen i denne menyen</li>
 			<li>$node->prevdepth -- Dybde (niv&aring;) p&aring; klyngen som var rett f&oslash;r denne</li>
 			<li>$node->haschildren -- Returnerer sann om denne klyngen har barneklynger &aring; vise</li>
+			<li>$node->children_exist -- Returnerer sann on denne noden har barneklynger tilgjengelig i databasen som kan vises i menyen</li>
 			<li>$node->menutext -- Meny Tekst</li>
 			<li>$node->raw_menutext -- Menytekst uten konverterte html-entiteter</li>
 			<li>$node->alias -- Side alias</li>
@@ -83,7 +88,10 @@ $lang['help'] = '	<h3>Hva gj&oslash;r denne?</h3>
 			<li>$node->index -- Nummer for denne klyngen i hele menyen</li>
 			<li>$node->parent -- Sann om denne klyngen ar foreldre til den n&aring; valgte side</li>
 		</ul>
-	</p>';
+	</p>
+<p> Denne modulen har funksjoner for &aring; mellomlagre sine utdata inn i statiske filer for &aring; redusere krav til minne og sql sp&oslash;rringer, og for &aring; forbedre frontend-ytelsen. Dette gir alle fordelene med statiske menyer uten det tunge involvert n&aring;r du oppretter eller redigerer sider. </p>
+        <p> Hver menymal kan v&aelig;re merket som &quot;Kan mellomlagres&quot;. N&aring;r en mellomlagret menymal brukes p&aring; en innholdsside som kan mellomlagres, vil mellomlagrede menyvisninger som er tilgjengelig for denne siden vil bli brukt. Den ikke mellomlagres parameteren p&aring; menytaggen kan brukes til helt &aring; deaktivere hurtigbufring. </p>
+        <p>Alle mellomlagrede menyfiler slettes n&aring;r et innholdselement er lagt til, redigert eller slettet ... og ogs&aring; n&aring;r en menymal blir lagt til/ redigert eller slettet. </p>';
 $lang['importtemplate'] = 'Importer mal til databasen';
 $lang['menumanager'] = 'Meny behandler';
 $lang['newtemplate'] = 'Nytt malnavn';
@@ -92,9 +100,9 @@ $lang['notemplatefiles'] = 'Ingen fil maler i %s';
 $lang['notemplatename'] = 'Ingen malnavn oppgitt.';
 $lang['templatecontent'] = 'Mal innhold';
 $lang['templatenameexists'] = 'En mal med dette navnet eksisterer allerede';
-$lang['utmz'] = '156861353.1274726983.2794.62.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/bug/view/4955';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1275076743.1275081270.2812';
-$lang['qca'] = '1210971690-27308073-81952832';
+$lang['utma'] = '156861353.4516254727077762000.1214829895.1291365970.1291375132.278';
+$lang['utmz'] = '156861353.1290182173.274.25.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = '1214401694-66536492-18746566';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1275081270';
+$lang['utmb'] = '156861353.1.10.1291375132';
 ?>
\ No newline at end of file
