@@ -1,4 +1,8 @@
 <?php
+$lang['set_cachable'] = 'Setare acest şablon ca disponibil pentru cache';
+$lang['help_nocache'] = 'Disable any caching of this call to the menu.  This parameter, if set to any positive value will override any settings in the content object and the menu template.';
+$lang['cachable'] = 'Cachable';
+$lang['help_childrenof'] = 'Aceasta optiune face ca meniul sa afiseze numai obiecte care sunt descendenti ai id-ului sau aliasului de pagina selectat.  Ex: <code>{menu childrenof=$page_alias}</code> va afisa numai descendentii paginii curente.';
 $lang['usage'] = 'Folosire';
 $lang['help_loadprops'] = 'Folositi acest parametru cand utilizati proprietati avansate in template-ul dumneavoastra de manager meniu. Acest parametru va forta incarcarea tuturor proprietatilor continutului fiecarui nod (cum ar fi extra1, imagine, trhumbnail, etc.) si va creste dramatic numarul de interogari necesare pentru construirea unui meniu, si o crestere a cerintelor de memorie, dar permite meniuri mult mai avansate.';
 $lang['readonly'] = 'numai citire';
@@ -89,9 +93,9 @@ $lang['notemplatefiles'] = 'Nici un fisier template in %s';
 $lang['notemplatename'] = 'Nu ati dat nume de template.';
 $lang['templatecontent'] = 'Continut template';
 $lang['templatenameexists'] = 'Un template cu acest nume exista deja';
-$lang['utma'] = '156861353.1477009656.1272913798.1272913798.1274603745.2';
-$lang['utmz'] = '156861353.1274603746.2.3.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms ms';
-$lang['qca'] = 'P0-1739349973-1272913798681';
-$lang['utmb'] = '156861353.2.10.1274603745';
+$lang['utma'] = '156861353.1023816423.1296940428.1298058074.1298887031.3';
+$lang['utmz'] = '156861353.1298058074.2.2.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['qca'] = 'P0-1623500024-1296940428329';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
