@@ -1,4 +1,9 @@
 <?php
+$lang['set_cachable'] = 'Nastavi to predlogo kot predpomnjeno';
+$lang['help_nocache'] = 'Onemogoči vse predpomnjenje tega razpisa v meni. Ta parameter, če je nastavljen za vsako pozitivno vrednost prepi&scaron;e vse nastavitve v vsebini predmeta in meni predlogi.';
+$lang['cachable'] = 'Predpomnjeno';
+$lang['help_childrenof'] = 'Ta možnost bo prikazala v meniju le predmete, ki so potomci izbranih id stran ali psevdonimov.  Na primer: S <code>{menu childrenof=$page_alias}</code> bodo prikazani samo otroci trenutne strani.';
+$lang['usage'] = 'Uporaba';
 $lang['help_loadprops'] = 'Uporabite ta parameter pri uporabi naprednih možnosti v va&scaron;i predlogi menija. Parameter bo prisilil nalaganje vseh lastnosti vsebine za vse elemente (kot npr. extra1, slika, pomanj&scaron;ava, itd.) in bo zelo povečal &scaron;tevilo SQL zahtev v ozadju. To povi&scaron;a porabo spomina, vendar pa omogoča izdelavo bolj naprednih menijev.';
 $lang['readonly'] = 'samo za branje';
 $lang['error_templatename'] = 'Ne morete določiti ime predloge s končnico .tpl';
@@ -75,9 +80,9 @@ $lang['notemplatefiles'] = 'Ni datotek s predlogami v %s';
 $lang['notemplatename'] = 'Ime predloge ni podano.';
 $lang['templatecontent'] = 'Vsebina predloge';
 $lang['templatenameexists'] = 'Predloga s tem imenom že obstaja';
-$lang['utma'] = '156861353.1722464354432002000.1251370098.1258962106.1259238241.16';
-$lang['utmz'] = '156861353.1259238241.16.15.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
-$lang['qca'] = 'P0-1580489763-1251370099388';
-$lang['utmb'] = '156861353.2.10.1259238241';
+$lang['utma'] = '156861353.1305885590.1292925612.1292925612.1294042049.2';
+$lang['utmz'] = '156861353.1294042049.2.2.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['qca'] = 'P0-1418285860-1292925612468';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
