@@ -34,6 +34,7 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
+if (!isset($gCms)) exit;
 
 define('MINIMUM_REPOSITORY_VERSION','1.3');
 
@@ -73,7 +74,7 @@ class ModuleManager extends CMSModule
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.4';
+    return '1.4.1';
   }
 
 
@@ -475,7 +476,7 @@ class ModuleManager extends CMSModule
     else if (isset($_SESSION['mm_curletter']))
       {
 	  $curletter = $_SESSION['mm_curletter'];
-	  }
+      }
 
     // get the modules available in the repository
     $repmodules = '';
@@ -1241,7 +1242,7 @@ class ModuleManager extends CMSModule
 			return $this->DoAction('defaultadmin', $id, $params, $returnid);
 			}
 		
-		set_time_limit(0);
+		@set_time_limit(999);
 		$installs = array_reverse(unserialize(base64_decode($params['modlist'])));
 	    $url = $this->GetPreference('module_repository');
 	    if( $url == '' )
