@@ -34,6 +34,7 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
+if( !isset($gCms) ) exit;
 {
   echo '<div class="pagewarning">'."\n";
   echo '<h3>'.$this->Lang('notice')."</h3>\n";
@@ -58,6 +59,8 @@
     {
       echo $this->SetTabHeader('newversions',$this->Lang('newversions'),
 			  $active_tab == 'newversions' );
+      echo $this->SetTabHeader('search',$this->Lang('search'),
+			       $active_tab == 'search');
       echo $this->SetTabHeader('modules',$this->Lang('availmodules'),
 			  $active_tab == 'modules' );
     }
@@ -75,6 +78,10 @@
       include(dirname(__FILE__).'/function.newversionstab.php');
       echo $this->EndTab();
 
+      echo $this->StartTab('search');
+      include(dirname(__FILE__).'/function.search.php');
+      echo $this->EndTab();
+
       echo $this->StartTab('modules');
       $this->_DisplayAdminModulesTab( $id, $params, $returnid );
       echo $this->EndTab();
