@@ -34,6 +34,7 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
+if( !isset($gCms) ) exit;
 
 global $CMS_VERSION;
 $caninstall = true;
@@ -155,9 +156,11 @@ else
                 $onerow->status = $this->CreateLink( $id, 'upgrademodule', $returnid,
                              $this->Lang('upgrade'), 
                              array('name' => $row['name'],
-                             'version' => $row['version'],
-                             'filename' => $row['filename'],
-                             'size' => $row['size']));
+				   'version' => $row['version'],
+				   'filename' => $row['filename'],
+				   'size' => $row['size'],
+				   'reset_prefs'=1));
+));
               }
           }
           else
