@@ -1,4 +1,13 @@
 <?php
+$lang['error_searchterm'] = 'You have entered an invalid search term.  The term must consist of ascii characters and be three or more characters long';
+$lang['search_noresults'] = 'Search succeeded but no results matched the expresssion';
+$lang['advancedsearch_help'] = 'Specify words to include or exclude from the search using a + or -, surround exact phrases with quotes.  i.e:  +red -apple +"some text"';
+$lang['search_results'] = 'Search Results';
+$lang['prompt_advancedsearch'] = 'Advanced Search';
+$lang['search_input'] = 'Search Input';
+$lang['searchterm'] = 'Search Term';
+$lang['search'] = 'Search';
+$lang['error_searchterm']='Please specify something valid to search for';
 $lang['available_updates'] = 'Modules Available for Update; Before upgrading, please read the releasenotes in the Forge and create a backup of the website.';
 $lang['all_modules_up_to_date'] = 'There are no newer modules available in the repository';
 $lang['error_module_object'] = 'Error: could not get an instance of the %s module';
@@ -52,7 +61,7 @@ $lang['preferencessaved'] = 'Preferences saved';
 $lang['repositorycount'] = 'Modules found in the repository';
 $lang['instcount'] = 'Modules currently installed';
 $lang['availablemodules'] = 'The current status of modules available from the current repository';
-$lang['time_warning'] = 'The installation list has more than one or two modules. Be aware that the install could take a few minutes. Please be patient!';
+$lang['time_warning'] = 'The installation list has two or more modules. Be aware that the install could take a few minutes. Please be patient!';
 $lang['helptxt'] = 'Help';
 $lang['abouttxt'] = 'About';
 $lang['xmltext'] = 'XML File';
