@@ -1,12 +1,20 @@
 <?php
-$lang['available_updates'] = 'Zur Aktualisierung bereitstehende Module; Bevor Sie die Module aktualisieren, lesen Sie die Versionsinformationen Im Forge und erstellen eine Sicherungskopie (Datenbank + Dateien) Ihrer Webseite.';
+$lang['error_searchterm'] = 'Bitte geben Sie einen g&uuml;ltigen Begriff ein, nach dem gesucht werden soll';
+$lang['search_noresults'] = 'Die Suche wurde erfolgreich abgeschlossen, es wurde jedoch keine &Uuml;bereinstimmung mit Ihrer Abfrage gefunden.';
+$lang['advancedsearch_help'] = 'Bitte verwenden Sie die Zeichen + oder - und f&uuml;r bestimmte Wortgruppen Anf&uuml;hrungszeichen, um bestimmte Worte/Wortgruppen in Ihre Suche ein- bzw. auszuschlie&szlig;en, zum Beispiel:  +rot -Apfel +&quot;irgendein Text&quot;';
+$lang['search_results'] = 'Suchergebnisse';
+$lang['prompt_advancedsearch'] = 'Erweiterte Suche';
+$lang['search_input'] = 'Sucheingabe';
+$lang['searchterm'] = 'Suchbegriff';
+$lang['search'] = 'Suche';
+$lang['available_updates'] = 'Zur Aktualisierung bereitstehende Module; Bevor Sie die Module aktualisieren, lesen Sie die Versionsinformationen im Forge und erstellen eine Sicherungskopie Ihrer Webseite (Datenbank + Dateien).';
 $lang['all_modules_up_to_date'] = 'Es sind keine neueren Module im Moduldepot verf&uuml;gbar';
 $lang['error_module_object'] = 'Fehler: konnte keine Instanz des %s-Moduls finden';
 $lang['error_nomatchingmodules'] = 'Fehler: konnte keine &uuml;bereinstimmenden Module im Moduldepot finden';
 $lang['error_nomodules'] = 'Fehler: konnte die Liste der installierten Module nicht abfragen';
 $lang['upgrade_available'] = 'Neuere Version verf&uuml;gbar (%s), Sie verwenden (%s)';
 $lang['newversions'] = 'Verf&uuml;gbare Aktualisierungen';
-$lang['notice_depends'] = '%s ist von den folgenden Aktionen abh&auml;ngig. Klicken Sie zum Weitermachen auf &quot;Installieren&quot;.';
+$lang['notice_depends'] = '%s ist von den weiteren Aktionen abh&auml;ngig. Klicken Sie zum Weitermachen auf &quot;Installieren&quot;.';
 $lang['install_submit'] = 'Installieren';
 $lang['depend_upgrade'] = 'Das Modul %s muss auf Version %s aktualisiert werden.';
 $lang['depend_install'] = 'Das Modul %s (Version %s oder h&ouml;her) muss installiert werden.';
@@ -17,26 +25,26 @@ $lang['action_upgraded'] = 'Das Modul %s wurde aktualisiert';
 $lang['title_installation_complete'] = 'Die Installation wurde vollst&auml;ndig abgeschlossen!';
 $lang['install_with_deps'] = 'Alle Abh&auml;ngigkeiten pr&uuml;fen und installieren';
 $lang['msg_nodependencies'] = 'Dieses Modul hat keine Abh&auml;ngigkeiten von anderen Modulen.';
-$lang['error_upgrade'] = 'Die Aktualisierung des Moduls %s ist felgeschlagen!';
-$lang['error_skipping'] = 'Aufgrund von Fehlern in den Einstellungen der Abh&auml;ngigkeiten wurde die Installation/Aktualisierung von %s &uuml;bersprungen. Bitte schauen Sie sich die unten stehenden Hinweise an und versuchen es dann noch einmal.';
+$lang['error_upgrade'] = 'Die Aktualisierung des Moduls %s ist fehlgeschlagen!';
+$lang['error_skipping'] = 'Aufgrund von Fehlern in den Einstellungen der Abh&auml;ngigkeiten wurde die Installation/Aktualisierung von %s &uuml;bersprungen. Bitte schauen Sie sich die nachfolgenden Hinweise an und versuchen es dann noch einmal.';
 $lang['dependstxt'] = 'Abh&auml;ngigkeiten';
 $lang['use_at_your_own_risk'] = 'Verwendung auf eigene Gefahr';
 $lang['compatibility_disclaimer'] = 'Die hier angezeigten Module wurden sowohl von CMSms-Entwicklern als auch Drittanbietern erstellt. Wir k&ouml;nnen nicht garantieren, dass jedes hier angebotene Modul mit Ihrem System funktionsf&auml;hig, getestet oder kompatibel ist. Vor der Installation sollten Sie daher die Modulhilfe und die Informationen/Postings im Forum lesen.';
 $lang['notice'] = 'Hinweis';
-$lang['general_notice'] = 'Die hier angezeigte Version repr&auml;sentiert die jeweils letzte, im ausgew&auml;hlten Moduldepot (wahrscheinlich das CMS %s) als XML-Datei vorhandene Modulversion. Diese Version kann die letzte/aktuellste sein, muss aber nicht. Um dies zu pr&uuml;fen, k&ouml;nnen Sie sich die verf&uuml;gbaren Dateien im gew&auml;hlten Moduldepot anschauen. Wenn Sie das voreingestellte Moduldepot verwenden, k&ouml;nnen Sie im Suchfeld von <a href="http://dev.cmsmadesimple.org">forge</a> den Namen des Moduls eingeben und dann auf &quot;Files&quot; klicken.';
+$lang['general_notice'] = 'Die hier angezeigte Version repr&auml;sentiert die jeweils letzte, im ausgew&auml;hlten Moduldepot (wahrscheinlich das CMS %s) als XML-Datei vorhandene Modulversion. Diese Version kann die letzte/aktuellste sein, muss aber nicht. Um dies zu pr&uuml;fen, k&ouml;nnen Sie sich die verf&uuml;gbaren Dateien im gew&auml;hlten Moduldepot anschauen. Wenn Sie das voreingestellte Moduldepot verwenden, k&ouml;nnen Sie im Suchfeld von <a href="http://dev.cmsmadesimple.org">forge</a> den Namen des Moduls eingeben und dann bei Erfolg dann auf die Registerkarte &quot;Files&quot; klicken.';
 $lang['incompatible'] = 'Inkompatibel';
 $lang['prompt_settings'] = 'Einstellungen';
 $lang['prompt_otheroptions'] = 'Weitere Optionen';
 $lang['reset'] = 'Zur&uuml;cksetzen';
-$lang['error_permissions'] = '<strong><em>WARNUNG:</em></strong> Die Berechtigungen des Verzeichnisses sind f&uuml;r die Installation von Modulen nicht ausreichend. Eventuell k&ouml;nnten auch Probleme mit dem Safe-Modus Ihres Servers auftreten. Bitte stellen Sie sicher, dass der Safe-Modus Ihres Servers deaktiviert ist und die Dateiberechtigungen ausreichend sind.';
-$lang['error_minimumrepository'] = 'Die Moduldepot-Version ist mit diesem ModulManager nicht kompatibel';
-$lang['prompt_reseturl'] = 'Die URL auf den Standard zur&uuml;cksetzen';
+$lang['error_permissions'] = '<strong><em>WARNUNG:</em></strong> Die Berechtigungen des Verzeichnisses sind f&uuml;r die Installation von Modulen nicht ausreichend. Eventuell k&ouml;nnten auch Probleme mit dem PHP-Safe-Modus Ihres Servers auftreten. Bitte stellen Sie sicher, dass der Safe-Modus Ihres Servers deaktiviert ist und die Dateiberechtigungen ausreichend sind.';
+$lang['error_minimumrepository'] = 'Die ModulRepository-Version ist mit diesem ModulManager nicht kompatibel';
+$lang['prompt_reseturl'] = 'Die URL auf die programmseitige Voreinstellung zur&uuml;cksetzen';
 $lang['prompt_resetcache'] = 'Den lokalen Zwischenspeicher der Moduldepot-Daten l&ouml;schen';
 $lang['prompt_dl_chunksize'] = 'Maximale Teil-Gr&ouml;&szlig;e (Kb)';
 $lang['text_dl_chunksize'] = 'Der Maximalwert der an einem St&uuml;ck vom Server herunter zu ladenden Daten (beim Installieren eines Moduls)';
 $lang['error_nofilesize'] = 'Der Parameter Dateigr&ouml;&szlig;e wurde nicht angegeben';
 $lang['error_nofilename'] = 'Der Parameter Dateiname wurde nicht angegeben';
-$lang['error_unsatisfiable_dependency'] = 'Konnte das erforderliche Modul &quot;%s&quot; (Version %s oder h&ouml;her) nicht im Moduldepot finden. Es wird direkt von %s ben&ouml;tigt; dies k&ouml;nnte auf ein Problem mit der im Moduldepot vorhandenen Version des Moduls hinweisen. Bitte kontaktieren Sie den Autor des Moduls. Vorgang abgebrochen.';
+$lang['error_unsatisfiable_dependency'] = 'Konnte das erforderliche Modul &quot;%s&quot; (Version %s oder h&ouml;her) im Moduldepot nicht finden. Es wird von %s ben&ouml;tigt; dies k&ouml;nnte auf ein Problem mit der im Moduldepot vorhandenen Version des Moduls hinweisen. Bitte kontaktieren Sie den Autor des Moduls. Vorgang abgebrochen.';
 $lang['error_checksum'] = 'Pr&uuml;fsummen-Fehler. Dieser Fehler deutet auf eine besch&auml;digte Datei hin. Die Datei kann entweder beim Hochladen in das Moduldepot oder bei der &Uuml;bertragung auf Ihr System besch&auml;digt worden sein. (erwartet %s, zur&uuml;ckgegeben wurde %s)';
 $lang['cantdownload'] = 'Konnte nichts herunterladen';
 $lang['download'] = 'Herunterladen und Installieren';
@@ -52,7 +60,7 @@ $lang['preferencessaved'] = 'Voreinstellungen gespeichert';
 $lang['repositorycount'] = 'Module im Moduldepot gefunden';
 $lang['instcount'] = 'Module aktuell installiert';
 $lang['availablemodules'] = 'Aktueller Status der im Moduldepot verf&uuml;gbaren Module';
-$lang['time_warning'] = 'Wenn die Installationsliste mehr als zwei Module enth&auml;lt, kann die Installation ein paar Minuten in Anspruch nehmen. Bitte haben Sie erwas Geduld!';
+$lang['time_warning'] = 'Wenn die Installationsliste mehr als zwei Module enth&auml;lt, kann die Installation ein paar Minuten in Anspruch nehmen. Bitte haben Sie etwas Geduld!';
 $lang['helptxt'] = 'Hilfe';
 $lang['abouttxt'] = '&Uuml;ber';
 $lang['xmltext'] = 'XML-Datei';
@@ -74,11 +82,11 @@ $lang['error_norepositoryurl'] = 'Die URL f&uuml;r das Moduldepot wurde nicht fe
 $lang['friendlyname'] = 'ModulManager';
 $lang['postinstall'] = 'Der ModulManager wurde erfolgreich installiert.';
 $lang['postuninstall'] = 'Der ModulManager wurde deinstalliert. Es k&ouml;nnen keine Module mehr direkt aus dem Moduldepot installiert werden. Es ist jedoch noch die Installation von XML-Dateien m&ouml;glich, die zuvor hochgeladen werden m&uuml;ssen.';
-$lang['really_uninstall'] = 'Wollen Sie wirklich dieses Modul deinstallieren? Sie werden diese tolle Funktion vermissen.';
+$lang['really_uninstall'] = 'Wollen Sie wirklich dieses Modul deinstallieren? Sie werden diese Funktion vermissen.';
 $lang['uninstalled'] = 'Modul deinstalliert.';
 $lang['installed'] = 'Modulversion %s installiert.';
 $lang['upgraded'] = 'Modul auf Version %s aktualisiert.';
-$lang['moddescription'] = 'Ein Client f&uuml;r das Modul &quot;ModuleRepository&quot;. Dieses Modul erlaubt die Vorschau und die Modul-Installation von Remote-Seiten aus, ohne dass diese &uuml;ber FTP auf den Server geladen oder entpackt werden m&uuml;ssen. Die XML-Modul-Dateien werden &uuml;ber die SOAP-Technologie herunter geladen, auf Integrit&auml;t &uuml;berpr&uuml;ft und automatisch entpackt.';
+$lang['moddescription'] = 'Ein Client f&uuml;r das Modul &quot;ModulRepository&quot;. Dieses Modul erlaubt die Vorschau und die Modul-Installation von Remote-Seiten aus, ohne dass diese &uuml;ber FTP auf den Server geladen oder entpackt werden m&uuml;ssen. Die XML-Moduldateien werden &uuml;ber die SOAP-Technologie herunter geladen, auf Integrit&auml;t &uuml;berpr&uuml;ft und automatisch entpackt.';
 $lang['back_to_module_manager'] = '&laquo; Zur&uuml;ck zum ModulManager';
 $lang['error'] = 'Fehler!';
 $lang['admindescription'] = 'Ein Werkzeug zum Auffinden und Installieren von Modulen in Moduldepots.';
@@ -133,17 +141,17 @@ Added dependency checking.
 </li>
 </ul>';
 $lang['help'] = '<h3>Was macht dieses Modul?</h3>
-<p>Ein Client f&uuml;r das Modul &quot;ModuleRepository&quot;. Dieses Modul erlaubt die Vorschau und die Modul-Installation von Remote-Seiten aus, ohne dass diese per FTP auf den Server geladen oder entpackt werden m&uuml;ssen. Die XML-Modul-Dateien werden &uuml;ber die SOAP-Technologie herunter geladen, auf Integrit&auml;t &uuml;berpr&uuml;ft und automatisch entpackt.</p>
+<p>Ein Client f&uuml;r das Modul &quot;ModulRepository&quot;. Dieses Modul erlaubt die Vorschau und die Modul-Installation von Remote-Seiten aus, ohne dass diese per FTP auf den Server geladen oder entpackt werden m&uuml;ssen. Die XML-Modul-Dateien werden &uuml;ber die SOAP-Technologie herunter geladen, auf Integrit&auml;t &uuml;berpr&uuml;ft und automatisch entpackt.</p>
 <h3>Wie wird es eingesetzt ?</h3>
-<p>Zur Verwendung dieses Moduls ben&ouml;tigen Sie die Berechtigung &#039;Modify Modules&#039; und die URL einer &#039;ModuleRepository&#039;-Installation. Diese URL k&ouml;nnen Sie auf der Seite &#039;Erweiterungen > ModulManager > Einstellungen&#039; festlegen.</p><br />
+<p>Zur Verwendung dieses Moduls ben&ouml;tigen Sie die Berechtigung &#039;Modify Modules&#039; und die URL einer &#039;ModulRepository&#039;-Installation. Diese URL k&ouml;nnen Sie auf der Seite &#039;Erweiterungen > ModulManager > Einstellungen&#039; festlegen.</p>
 <p>Die Administration dieses Moduls finden Sie im Men&uuml; &#039;Erweiterungen&#039;. Bei Auswahl dieses Moduls wird automatisch eine Liste der verf&uuml;gbaren XML-Module abgefragt.  Diese Liste wird auf die Liste der aktuell installierten Module referenziert und eine Zusammenfassung angezeigt. Sie k&ouml;nnen sich die Beschreibung und die Hilfe der zu Module anzeigen lassen, ohne diese installieren zu m&uuml;ssen. Von hier aus k&ouml;nnen die Module dann auch installiert oder aktualisiert werden.</p>
 <h3>Support</h3>
 <p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>
 <h3>Copyright und Lizenz</h3>
 <p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. Alle Rechte vorbehalten.</p>
 <p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>';
-$lang['utma'] = '156861353.448336968.1277008087.1277008087.1277008087.1';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.178890951.1298889837.1299177721.1299280219.6';
+$lang['utmz'] = '156861353.1298889837.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1277008087.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
