@@ -1,4 +1,12 @@
 <?php
+$lang['error_searchterm'] = 'Voer een zoekterm in';
+$lang['search_noresults'] = 'Zoekopdracht is uitgevoerd, maar er zijn geen resultaten gevonden';
+$lang['advancedsearch_help'] = 'Gebruik een + of - om bepaalde woorden in de zoekopdracht te negeren of juist wel mee te nemen. Omvat een zoekopdracht van meerdere woorden in haakjes. Bijv.  &quot;+rood -appel +&quot;een tekst&quot;';
+$lang['search_results'] = 'Zoek Resultaten';
+$lang['prompt_advancedsearch'] = 'Uitgebreid Zoeken';
+$lang['search_input'] = 'Zoek Invoer';
+$lang['searchterm'] = 'Zoek Term';
+$lang['search'] = 'Zoek';
 $lang['available_updates'] = 'Voor onderstaande modules zijn updates beschikbaar. Lees eerst de release notes in de Forge en maak een back-up van de website!';
 $lang['all_modules_up_to_date'] = 'Er zijn geen nieuwe module versies beschikbaar.';
 $lang['error_module_object'] = 'Fout: kan geen gegevens vinden van de %s module';
@@ -30,25 +38,25 @@ $lang['prompt_otheroptions'] = 'Andere opties';
 $lang['reset'] = 'Opnieuw instellen';
 $lang['error_permissions'] = '<strong><em>WAARSCHUWING:</em></strong> Onvoldoende rechten op de map om modules te installeren. Het probleem kan ook zijn dat PHP Safe mode op de server aan staat. Controleer of PHP Safe mode uit staat en of u voldoende rechten heeft op de map.';
 $lang['error_minimumrepository'] = 'De softwarebronversie is niet compatibel met deze Module Manager';
-$lang['prompt_reseturl'] = 'Standaard URL instellen';
-$lang['prompt_resetcache'] = 'Lokale softwarebron-cache vernieuwen';
+$lang['prompt_reseturl'] = 'Standaard Url herstellen';
+$lang['prompt_resetcache'] = 'Softwarebron buffer legen';
 $lang['prompt_dl_chunksize'] = 'Download blokgrootte (Kb)';
 $lang['text_dl_chunksize'] = 'De maximale hoeveelheid data die in &eacute;&eacute;n keer wordt gedownload (bij een module installatie)';
 $lang['error_nofilesize'] = 'Geen &quot;filesize&quot; parameter opgegeven';
 $lang['error_nofilename'] = 'Geen &quot;filename&quot; parameter opgegeven';
 $lang['error_unsatisfiable_dependency'] = 'Kan de benodigde module &quot;%s&quot; (versie %s of hoger) niet in de repository vinden. Deze is echter wel nodig voor %s. Dit kan een teken zijn van een versie probleem van de module in de repository. Neemt u alstublieft contact op met de module developer. Deze bewerking wordt nu gestopt...';
 $lang['error_checksum'] = 'Checksum fout. Dit wijst waarschijnlijk op een beschadigd bestand. Dit kan gebeurt zijn tijdens het uploaden door de developer naar de repository, of tijdens uw download.';
-$lang['cantdownload'] = 'Kan niet downloaden';
+$lang['cantdownload'] = 'Downloaden niet mogelijk...';
 $lang['download'] = 'Downloaden &amp; Installeren';
-$lang['error_moduleinstallfailed'] = 'Moduleinstallatie mislukt';
+$lang['error_moduleinstallfailed'] = 'Module Installatie Mislukt';
 $lang['error_connectnomodules'] = 'Ondanks dat er met succes een verbinding met de aangegeven module-softwarebron is gemaakt, lijkt het erop dat deze softwarebron nog geen modules bevat.';
 $lang['submit'] = 'Verstuur';
 $lang['text_repository_url'] = 'De URL moet het formaat hebben http://www.mijnsite.nl/path/soap.php?module=ModuleRepository';
 $lang['prompt_repository_url'] = 'Modulebron URL:';
 $lang['title_installation'] = 'Installatie';
 $lang['availmodules'] = 'Beschikbare modules';
-$lang['preferences'] = 'Voorkeuren';
-$lang['preferencessaved'] = 'Voorkeuren opgeslagen';
+$lang['preferences'] = 'Instellingen';
+$lang['preferencessaved'] = 'Instellingen opgeslagen';
 $lang['repositorycount'] = 'Modules gevonden in de softwarebron';
 $lang['instcount'] = 'Ge&iuml;nstalleerde modules';
 $lang['availablemodules'] = 'De huidige modulestatus beschikbaar uit de huidige softwarebron';
@@ -64,7 +72,7 @@ $lang['sizetext'] = 'Grootte (Kilobytes)';
 $lang['statustext'] = 'Status/bewerking';
 $lang['uptodate'] = 'Ge&iuml;nstalleerd';
 $lang['install'] = 'installeer';
-$lang['newerversion'] = 'Nieuwere versie ge&iuml;nstalleerd';
+$lang['newerversion'] = 'Nieuwere versie is ge&iuml;nstalleerd';
 $lang['onlynewesttext'] = 'Toon alleen de nieuwste versie';
 $lang['upgrade'] = 'Bijwerken';
 $lang['error_nosoapconnect'] = 'Kon geen verbinding met de SOAP server tot stand brengen';
@@ -72,14 +80,14 @@ $lang['error_soaperror'] = 'SOAP probleem';
 $lang['soaperror'] = 'SOAP probeem: %s';
 $lang['error_norepositoryurl'] = 'De URL voor de module-bron is niet opgegeven';
 $lang['friendlyname'] = 'Module Manager ';
-$lang['postinstall'] = 'Module Manager is ge&iuml;nstalleerd';
+$lang['postinstall'] = 'De Module Manager is ge&iuml;nstalleerd';
 $lang['postuninstall'] = 'De Module Manager is gede&iuml;nstalleerd. Gebruikers hebben niet langer de mogelijkheid om modules te installeren vanuit een externe softwarebron. Lokale installatie is nog wel mogelijk.';
-$lang['really_uninstall'] = 'De Module Manager de&iuml;nstalleren? Hiermee verliest u de functionaliteit die deze module u biedt.';
+$lang['really_uninstall'] = 'Wilt u de Module Manager de&iuml;nstalleren? Hiermee verliest u de functionaliteit die deze module u biedt.';
 $lang['uninstalled'] = 'Module gede&iuml;nstalleerd.';
 $lang['installed'] = 'Moduleversie %s ge&iuml;nstalleerd.';
 $lang['upgraded'] = 'Module bijgewerkt naar versie %s.';
-$lang['moddescription'] = 'Een client voor de ModuleRepository. Deze module maakt het mogelijk modules te installeren zonder de noodzaak van ftp-en en uitpakken van bestanden. Module XML-bestanden worden gedownload met gebruik van SOAP, de integriteit wordt getest en het uitpakken gebeurt automatisch.';
-$lang['back_to_module_manager'] = '&laquo; Terug naar Module Manager';
+$lang['moddescription'] = 'Een cli&euml;nt voor de ModuleRepository. Deze module maakt het mogelijk modules te installeren zonder de noodzaak van ftp-en en uitpakken van bestanden. Module XML-bestanden worden gedownload met gebruik van SOAP, de integriteit wordt getest en het uitpakken gebeurt automatisch.';
+$lang['back_to_module_manager'] = '&laquo; Terug naar de Module Manager';
 $lang['error'] = 'Fout!';
 $lang['admindescription'] = 'Een module, om andere modules vanaf andere servers op te halen en te installeren.';
 $lang['accessdenied'] = 'Toegang geweigerd. Controleer uw rechten.';
@@ -143,9 +151,9 @@ $lang['help'] = '<h3>Wat doet het?</h3>
 <h3>Copyright and License</h3>
 <p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
-$lang['utma'] = '156861353.509382990.1276370458.1276712311.1276778984.27';
-$lang['utmz'] = '156861353.1276631266.24.6.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=shop made simple pretty url';
-$lang['qca'] = 'P0-26515958-1276370458481';
-$lang['utmb'] = '156861353.3.10.1276778984';
+$lang['utma'] = '156861353.1335698708.1284586217.1288728143.1288778289.272';
+$lang['utmz'] = '156861353.1288551918.260.31.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['qca'] = 'P0-1551306179-1284586216711';
+$lang['utmb'] = '156861353.2.10.1288778289';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
