@@ -1,4 +1,12 @@
 <?php
+$lang['search_noresults'] = 'Din s&ouml;kning lyckades men inga resultat matchade';
+$lang['advancedsearch_help'] = 'Ange ord att inkludera eller utesluta fr&aring;n s&ouml;kningen med ett + eller -, exakta fraser med citationstecken. I.E: &quot;+ r&ouml;da -&auml;pple +&quot; n&aring;gon text &quot;';
+$lang['search_results'] = 'S&ouml;kresultat';
+$lang['prompt_advancedsearch'] = 'Avancerad s&ouml;kning';
+$lang['search_input'] = 'S&ouml;kinmatning';
+$lang['searchterm'] = 'S&ouml;kterm';
+$lang['search'] = 'S&ouml;k';
+$lang['error_searchterm'] = 'V&auml;nligen ange n&aring;got giltigt f&ouml;r att s&ouml;ka';
 $lang['available_updates'] = 'Moduler tillg&auml;ngliga f&ouml;r uppdatering';
 $lang['all_modules_up_to_date'] = 'Det finns inga nyare moduler tillg&auml;ngliga som finns i arkivet';
 $lang['error_module_object'] = 'Fel: kunde inte f&aring; en instans av %s modulen';
@@ -6,8 +14,19 @@ $lang['error_nomatchingmodules'] = 'Fel: Kunde inte hitta n&aring;gra matchande
 $lang['error_nomodules'] = 'Fel: Kunde inte h&auml;mta lista med installerade moduler';
 $lang['upgrade_available'] = 'Nyare verson tillg&auml;nglig (%s), du har (%s)';
 $lang['newversions'] = 'Installerade moduler';
-$lang['error_depends'] = 'Ett eller flera beroenden &auml;r inte installerade. Du borde installera beroendena f&ouml;rst';
+$lang['notice_depends'] = '%s depends on the following actions. Click &quot;Install&quot; to go ahead.';
+$lang['install_submit'] = 'Installera';
+$lang['depend_upgrade'] = 'Modulen %s beh&ouml;ver uppgraderas till version %s.';
+$lang['depend_install'] = 'Modul %s (version %s eller senare) m&aring;ste installeras.';
+$lang['depend_activate'] = 'Modulen %s m&aring;ste aktiveras.';
+$lang['action_activated'] = 'Modulen %s &auml;r nu aktiverad.';
+$lang['action_installed'] = 'Modulen %s har installerats med f&ouml;ljande meddelande(n): %s';
+$lang['action_upgraded'] = 'Modulen %s &auml;r nu uppgraderad';
+$lang['title_installation_complete'] = 'Installationen &auml;r f&auml;rdig!';
+$lang['install_with_deps'] = 'Utv&auml;rdera alla beroenden och installera';
 $lang['msg_nodependencies'] = 'Filen har inte listat n&aring;gra beroenden';
+$lang['error_upgrade'] = 'Uppgraderingen av modulen %s misslyckades!';
+$lang['error_skipping'] = 'Hoppar &ouml;ver installation/uppgradering av %s p&aring; grund av fel med beroenden. Se meddelande ovan, och f&ouml;rs&ouml;k igen.';
 $lang['dependstxt'] = 'Beroenden';
 $lang['use_at_your_own_risk'] = 'Anv&auml;nd p&aring; egen risk';
 $lang['compatibility_disclaimer'] = 'Modulerna som visas h&auml;r har bidragits av b&aring;de CMSMS-utvecklarna och oberoende tredjepartsutvecklare. Vi kan inte garantera att modulerna som finns tillg&auml;ngliga h&auml;r fungerar, &auml;r testade eller &auml;r kompatibla med ditt system. L&auml;s g&auml;rna informationen som finns i hj&auml;lpen och om-l&auml;nkarna f&ouml;r varje modul innan du installerar n&aring;got.';
@@ -25,6 +44,7 @@ $lang['prompt_dl_chunksize'] = 'Storlek p&aring; nedladdningsstycke (Kb)';
 $lang['text_dl_chunksize'] = 'Maximal storlek p&aring; data att ladda ner fr&aring;n servern i ett stycke (n&auml;r en modul installeras)';
 $lang['error_nofilesize'] = 'Inga filstorleksparametrar angivna';
 $lang['error_nofilename'] = 'Inga filnamnsparametrar angivna';
+$lang['error_unsatisfiable_dependency'] = 'Cannot find the required module &quot;%s&quot; (version %s or later) in the repository. It is directly required by %s; this could indicate a problem with the version of this module in the repository. Please contact the module&#039;s author. Aborting.';
 $lang['error_checksum'] = 'Checksum-fel. Detta inneb&auml;r troligen att det &auml;r fel p&aring; filen, antingen n&auml;r den laddades upp till lagringsplatsen eller ett problem vid &ouml;verf&ouml;ringen till din dator.';
 $lang['cantdownload'] = 'Kan inte ladda ner';
 $lang['download'] = 'Ladda ner &amp; installera';
@@ -33,16 +53,20 @@ $lang['error_connectnomodules'] = '&Auml;ven om en anslutning till den angivna l
 $lang['submit'] = 'Skicka';
 $lang['text_repository_url'] = 'URL-adressen ska vara i formen http://www.mincmssida.com/s&ouml;kv&auml;g/soap.php?module=ModuleRepository';
 $lang['prompt_repository_url'] = 'URL-adress f&ouml;r modul-lagringsplats';
+$lang['title_installation'] = 'Installation.';
 $lang['availmodules'] = 'Tillg&auml;ngliga moduler';
 $lang['preferences'] = 'Inst&auml;llningar';
 $lang['preferencessaved'] = 'Inst&auml;llningar sparade';
 $lang['repositorycount'] = 'Moduler som hittades p&aring; lagringsplatsen';
 $lang['instcount'] = 'Moduler som &auml;r installerade';
 $lang['availablemodules'] = 'Nuvarande status f&ouml;r moduler som &auml;r tillg&auml;ngliga fr&aring;n den nuvarande lagringsplatsen';
+$lang['time_warning'] = 'Installationslistan har tv&aring; eller fler moduler. Installationen kan ta ett par minuter. Ha t&aring;lamod!';
 $lang['helptxt'] = 'Hj&auml;lp';
 $lang['abouttxt'] = 'Om';
 $lang['xmltext'] = 'XML-fil';
 $lang['nametext'] = 'Modulnamn';
+$lang['mod_name_ver'] = '%s Version %s';
+$lang['unknown'] = 'Ok&auml;nd';
 $lang['vertext'] = 'version ';
 $lang['sizetext'] = 'Storlek (kilobyte)';
 $lang['statustext'] = 'Status/&Aring;tg&auml;rd';
@@ -53,6 +77,7 @@ $lang['onlynewesttext'] = 'Visa bara senaste versionen';
 $lang['upgrade'] = 'Uppgradera';
 $lang['error_nosoapconnect'] = 'Kunde inte ansluta till SOAP-servern';
 $lang['error_soaperror'] = 'SOAP-problem';
+$lang['soaperror'] = 'SOAP fel: %s';
 $lang['error_norepositoryurl'] = 'URL-adressen f&ouml;r modul-lagringsplatsen har inte angetts';
 $lang['friendlyname'] = 'Modulhanterare';
 $lang['postinstall'] = 'Modulehanteraren har installerats.';
@@ -62,6 +87,7 @@ $lang['uninstalled'] = 'Modul avinstallerad.';
 $lang['installed'] = 'Modul med versionsnummer %s &auml;r installerad.';
 $lang['upgraded'] = 'Modul uppgraderad till version %s.';
 $lang['moddescription'] = 'Den h&auml;r modulen &auml;r en klient till modulen ModuleRepository (modul-lagringsplats). Du kan med denna modul f&ouml;rhandsgranska och installera moduler fr&aring;n externa sajter utan att beh&ouml;va anv&auml;nda FTP eller packa upp arkivfiler. XML-filer laddas ner med hj&auml;lp av SOAP, integritetsverifierade, och packas sedan upp automatiskt.';
+$lang['back_to_module_manager'] = '&laquo; Return to Module Manager';
 $lang['error'] = 'Fel!';
 $lang['admindescription'] = 'Ett verktyg f&ouml;r att ladda ner och installera moduler fr&aring;n externa servrar.';
 $lang['accessdenied'] = '&Aring;tkomst nekad. Var god kontrollera dina r&auml;ttigheter.';
@@ -109,8 +135,9 @@ $lang['help'] = '<h3>Vad g&ouml;r den h&auml;r modulen?</h3>
 <h3>Copyright och licens</h3>
 <p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. Alla R&auml;ttigheter Reserverade.</p>
 <p>Den h&auml;r modulen har sl&auml;ppts under <a href="http://www.gnu.org/licenses/licenses.html#GPL">den allm&auml;nna GNU-licensen</a>. Du m&aring;ste godk&auml;nna den licensen innan du anv&auml;nder modulen.</p>';
-$lang['utma'] = '156861353.950238273729472100.1237140425.1241729623.1241793776.144';
-$lang['utmz'] = '156861353.1241501270.132.12.utmccn=(referral)|utmcsr=coldman.dyndns.org|utmcct=/coldman/1.6/install/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.397033920.1281357884.1288022505.1288031696.42';
+$lang['utmz'] = '156861353.1288031696.42.3.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/14';
+$lang['qca'] = 'P0-1852641632-1281357886006';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.3.10.1241793776';
+$lang['utmb'] = '156861353.1.10.1288031696';
 ?>
\ No newline at end of file
