@@ -17,6 +17,7 @@
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #$Id: News.module.php 2114 2005-11-04 21:51:13Z wishy $
+if( !isset($gCms) ) exit;
 
 class News extends CMSModule
 {
@@ -42,12 +43,12 @@ class News extends CMSModule
 
 	function GetVersion()
 	{
-		return '2.10.6';
+		return '2.11.2';
 	}
 
 	function MinimumCMSVersion()
 	{
-		return '1.8-beta1';
+		return '1.9.1';
 	}
 
 	function GetAdminDescription()
@@ -62,8 +63,31 @@ class News extends CMSModule
 
 	function SetParameters()
 	{
-		$test = $this->GetPreference('test','');
-
+	  global $gCms;
+	  $db = $gCms->GetDb();
+	  $query = 'SELECT news_id,news_url FROM '.cms_db_prefix().'module_news
+                           WHERE status = ? AND news_url != ? AND '
+	    . '('.$db->ifNull('start_time',$db->DbTimeStamp(1)).' < NOW()) AND '
+	    . '(('.$db->IfNull('end_time',$db->DbTimeStamp(1)).' = '.$db->DbTimeStamp(1).') OR (end_time > NOW()))';
+	  $query .= ' ORDER BY news_date DESC';
+	  $tmp = $db->GetArray($query,array('published',''));
+	  if( is_array($tmp) )
+	    {
+	      $detailpage = $this->GetPreference('detail_returnid',-1);
+	      if( $detailpage == -1 )
+		{
+		  $contentops = $gCms->GetContentOperations();
+		  $detailpage = $contentops->GetDefaultContent();
+		}
+	      foreach( $tmp as $one )
+		{
+		  $parms = array('action'=>'detail','returnid'=>$detailpage,
+				 'articleid'=>$one['news_id']);
+		  $route = new CmsRoute($one['news_url'],$this->GetName(),$parms,TRUE);
+		  cms_route_manager::register($route);
+		}
+	    }
+	      
 		$this->RestrictUnknownParams();
 		$this->RegisterRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)\/d,(?P<detailtemplate>.*?)$/');
 		$this->RegisterRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/');
@@ -298,7 +322,7 @@ class News extends CMSModule
 	  $db =& $this->GetDb();
 	  $now = $db->DbTimeStamp(time());
 	  $zerotime = $db->DbTimeStamp(1);
-	  $q = "SELECT news_title FROM ".cms_db_prefix()."module_news WHERE
+	  $q = "SELECT news_title,news_url FROM ".cms_db_prefix()."module_news WHERE
 		       news_id = ?";
 	  if( $this->GetPreference('expired_searchable',1) == 0 )
 	    {
@@ -318,9 +342,12 @@ class News extends CMSModule
 	      $result[1] = $row['news_title'];
 
 	      //2 position is the URL to the title.
-	      
-	      $aliased_title = munge_string_to_url($row['news_title']);
-	      $prettyurl = 'news/' . $articleid.'/'.$returnid."/$aliased_title";
+	      $pretty_url = $row['news_url'];
+	      if( $pretty_url == '' )
+		{
+		  $aliased_title = munge_string_to_url($row['news_title']);
+		  $prettyurl = 'news/' . $articleid.'/'.$returnid."/$aliased_title";
+		}
 	      $result[2] = $this->CreateLink('cntnt01', 'detail', $returnid, '', array('articleid' => $articleid) ,'', true, false, '', true, $prettyurl);
 	    }
 	}
@@ -646,7 +673,7 @@ class News extends CMSModule
   function handle_upload($itemid, $fieldname, &$error)
   {
 	  global $gCms;
-	  $config =& $gCms->GetConfig();
+	  $config = $gCms->GetConfig();
 	  
 	  $p = cms_join_path($config['uploads_path'],'news');
 	  if (!is_dir($p)) {
@@ -714,7 +741,7 @@ class News extends CMSModule
   function image_transform($srcSpec, $destSpec, $size)
   {
 	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
     require_once(dirname(__FILE__).'/../../lib/filemanager/ImageManager/Classes/Transform.php');
      
     $it = new Image_Transform;
