@@ -1,29 +1,6 @@
 <?php
 	if (!isset($gCms)) exit;
 
-	$detailpage = '';
-	if (isset($params['detailpage']))
-	{
-		$manager =& $gCms->GetHierarchyManager();
-		$node =& $manager->sureGetNodeByAlias($params['detailpage']);
-		if (isset($node))
-		{
-			$content =& $node->GetContent();
-			if (isset($content))
-			{
-				$detailpage = $content->Id();
-			}
-		}
-		else
-		{
-			$node =& $manager->sureGetNodeById($params['detailpage']);
-			if (isset($node))
-			{
-				$detailpage = $params['detailpage'];
-			}
-		}
-	}
-
 	if (!$this->CheckPermission('Modify News'))
 	{
 		echo $this->ShowErrors($this->Lang('needpermission', array('Modify News')));
