@@ -1,6 +1,6 @@
 <?php
 		if (!isset($gCms)) exit;
-		$config =& $gCms->GetConfig();
+		$config = $gCms->GetConfig();
 
 if( !isset($params['articleid']) )
   {
@@ -72,11 +72,15 @@ else
 			$onerow->extra = $row['news_extra'];
 
 			// handle canonical URL
-			$aliased_title = munge_string_to_url($row['news_title']);
-			$prettyurl = 'news/'.$row['news_id']."/$returnid/$aliased_title";
-			if (isset($sendtodetail['detailtemplate']))
+			$prettyurl = $row['news_url'];
+			if( $prettyurl == '' )
 			  {
-			    $prettyurl .= '/d,' . $sendtodetail['detailtemplate'];
+			    $aliased_title = munge_string_to_url($row['news_title']);
+			    $prettyurl = 'news/'.$row['news_id']."/$returnid/$aliased_title";
+			    if (isset($sendtodetail['detailtemplate']))
+			      {
+				$prettyurl .= '/d,' . $sendtodetail['detailtemplate'];
+			      }
 			  }
 			$onerow->canonical = $this->CreateLink($id, 'detail', $returnid, 
 							     '', $params, '', true, false, '', true, $prettyurl);
