@@ -1,4 +1,5 @@
 <?php
+if( !isset($gCms) ) exit;
 
 $smarty->assign('formstart',$this->CreateFormStart($id,'defaultadmin'));  
 	
@@ -276,7 +277,7 @@ $smarty->assign('categorytext', $this->Lang('category'));
 
 global $gCms;
 $theme =& $gCms->variables['admintheme'];
-$config =& $this->GetConfig();
+$config = $this->GetConfig();
 $themedir = $config['root_url'].'/'.$config['admin_dir'].'/themes/'.$theme->themeName.'/images/icons/system';
 
 $smarty->assign('iconurl',$themedir);
