@@ -1,4 +1,5 @@
 <?php
+if( !isset($gCms) ) exit;
 
   // CreateFormStart sets up a proper form tag that will cause the submit to
   // return control to this module for processing.
@@ -67,6 +68,18 @@ $smarty->assign('input_fesubmit_redirect',
 		$this->CreateInputText($id,'fesubmit_redirect',
 				       $this->GetPreference('fesubmit_redirect',''),20,20));
 
+$contentops = $gCms->GetContentOperations();
+$smarty->assign('title_detail_returnid',$this->Lang('title_detail_returnid'));
+$smarty->assign('input_detail_returnid',
+		$contentops->CreateHierarchyDropdown('',$this->GetPreference('detail_returnid',-1),
+						     $id.'detail_returnid'));
+$smarty->assign('info_detail_returnid',$this->Lang('info_detail_returnid'));
+
+$smarty->assign('title_submission_settings',$this->Lang('title_submission_settings'));
+$smarty->assign('title_fesubmit_settings',$this->Lang('title_fesubmit_settings'));
+$smarty->assign('title_notification_settings',$this->Lang('title_notification_settings'));
+$smarty->assign('title_detail_settings',$this->Lang('title_detail_settings'));
+
 // Display the populated template
 echo $this->ProcessTemplate ('adminprefs.tpl');
 
