@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'Mit diesen Einstellungen kann eine Seite festgelegt werden (und damit auch ein Template), die f&uuml;r die Anzeige der Detailansicht verwendet werden soll. Die individuellen News-Detail-URLs werden jedoch nicht funktionieren, wenn dieser Parameter keine g&uuml;ltige Seite enth&auml;lt. Wird diese Einstellung aktiviert und im news-Tag der Parameter detailpage nicht angegeben, wird dieser Wert f&uuml;r Detail-Links verwendet.';
+$lang['title_detail_returnid'] = 'Voreingestellte Seite, die f&uuml;r die Detailansicht verwendet werden soll';
+$lang['title_submission_settings'] = 'Einstellungen f&uuml;r die News-&Uuml;bertragung';
+$lang['title_fesubmit_settings'] = 'Einstellungen f&uuml;r den Versand &uuml;ber die Webseite';
+$lang['title_notification_settings'] = 'Benachrichtigungseinstellungen';
+$lang['title_detail_settings'] = 'Einstellungen f&uuml;r die Detailansicht';
+$lang['error_invalidurl'] = 'Ung&uuml;ltige URL <em>(eventuell wird diese bereits verwendet oder sie enth&auml;lt ung&uuml;ltige Zeichen)</em>';
+$lang['url'] = 'URL ';
 $lang['expired_searchable'] = 'Artikel, deren Anzeigedauer &uuml;berschritten ist, d&uuml;rfen in den Suchergebnissen erscheinen';
 $lang['helpshowall'] = 'Alle Artikel anzeigen (unabh&auml;ngig von deren Anzeigedauer)';
 $lang['error_invaliddates'] = 'Ein oder mehrere der eingegebenen Daten sind ung&uuml;ltig';
@@ -10,9 +18,9 @@ $lang['anonymous'] = 'Anonym';
 $lang['unknown'] = 'Unbekannt';
 $lang['fesubmit_redirect'] = 'Die Seiten-ID oder der Seiten-Alias der Seite, auf die der Einsender eines Artikels &uuml;ber die fesubmit-Aktion weitergeleitet werden soll';
 $lang['allow_summary_wysiwyg'] = 'Den WYSIWYG-Editor f&uuml;r das Zusammenfassungsfeld verwenden';
-$lang['title_browsecat_template'] = 'Vorlageneditor f&uuml;r die Kategorien-Anzeige';
+$lang['title_browsecat_template'] = 'Template-Editor f&uuml;r die Kategorien-Anzeige';
 $lang['title_browsecat_sysdefault'] = 'Voreingestelltes Template f&uuml;r die Kategorien-Anzeige';
-$lang['browsecattemplate'] = 'Vorlagen f&uuml;r die Kategorien-Anzeige';
+$lang['browsecattemplate'] = 'Templates f&uuml;r die Kategorien-Anzeige';
 $lang['error_filesize'] = 'Die hochgeladene Datei &uuml;berschreitet die maximal erlaubte Gr&ouml;&szlig;e';
 $lang['post_date_desc'] = 'nach Erstellungsdatum absteigend';
 $lang['post_date_asc'] = 'nach Erstellungsdatum aufsteigend';
@@ -53,7 +61,7 @@ $lang['fielddefdeleted'] = 'Extra-Feld gel&ouml;scht';
 $lang['nameexists'] = 'Ein Extra-Feld mit diesem Namen existiert bereits';
 $lang['notanumber'] = 'Die maximale L&auml;nge ist keine Zahl';
 $lang['fielddef'] = 'Extra-Feld';
-$lang['fielddefadded'] = 'Das Extra-Feld wurde erfolgreich hinzugef&uuml;gt';
+$lang['fielddefadded'] = 'Das Extra-Feld wurde hinzugef&uuml;gt';
 $lang['public'] = '&Ouml;ffentlich';
 $lang['type'] = 'Typ';
 $lang['info_maxlength'] = 'Die maximale L&auml;nge hat nur Auswirkungen auf einzeilige Textfelder.';
@@ -100,13 +108,13 @@ $lang['author'] = 'Autor';
 $lang['sysdefaults'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
 $lang['restoretodefaultsmsg'] = 'Diese Funktion setzt die Templates auf die programmseitigen Voreinstellung zur&uuml;ck. Wollen Sie das wirklich?';
 $lang['addarticle'] = 'Artikel hinzuf&uuml;gen';
-$lang['articleadded'] = 'Der Artikel wurde erfolgreich hinzugef&uuml;gt.';
-$lang['articleupdated'] = 'Der Artikel wurde erfolgreich aktualisiert.';
-$lang['articledeleted'] = 'Der Artikel wurde erfolgreich gel&ouml;scht.';
+$lang['articleadded'] = 'Der Artikel wurde hinzugef&uuml;gt.';
+$lang['articleupdated'] = 'Der Artikel wurde aktualisiert.';
+$lang['articledeleted'] = 'Der Artikel wurde gel&ouml;scht.';
 $lang['addcategory'] = 'Kategorie hinzuf&uuml;gen';
-$lang['categoryadded'] = 'Die Kategorie wurde erfolgreich hinzugef&uuml;gt.';
-$lang['categoryupdated'] = 'Die Kategorie wurde erfolgreich aktualisiert.';
-$lang['categorydeleted'] = 'Die Kategorie wurde erfolgreich gel&ouml;scht.';
+$lang['categoryadded'] = 'Die Kategorie wurde hinzugef&uuml;gt.';
+$lang['categoryupdated'] = 'Die Kategorie wurde aktualisiert.';
+$lang['categorydeleted'] = 'Die Kategorie wurde gel&ouml;scht.';
 $lang['addnewsitem'] = 'News-Eintrag hinzuf&uuml;gen';
 $lang['allcategories'] = 'Alle Kategorien';
 $lang['allentries'] = 'Alle Eintr&auml;ge';
@@ -143,12 +151,12 @@ $lang['newcategory'] = 'Neue Kategorie';
 $lang['needpermission'] = 'Sie ben&ouml;tigen die Berechtigung &bdquo;%s&ldquo;, um diese Funktion nutzen zu k&ouml;nnen.';
 $lang['nocategorygiven'] = 'Keine Kategorie vorhanden';
 $lang['startdatetoolate'] = 'FEHLER: Der Startzeitpunkt muss VOR dem Endzeitpunkt liegen';
-$lang['nocontentgiven'] = 'Kein Inhalt vorhanden';
+$lang['nocontentgiven'] = 'Fehler: Es wurde kein Inhalt eingegeben';
 $lang['noitemsfound'] = '<strong>Keine</strong> Eintr&auml;ge in der Kategorie %s gefunden ';
-$lang['nopostdategiven'] = 'Fehler: Kein Erstellungsdatum vorhanden';
+$lang['nopostdategiven'] = 'Fehler: Es wurde kein Erstellungsdatum eingestellt';
 $lang['note'] = '<em>Hinweis:</em> Datum/Zeit muss im Format &bdquo;JJJJ-MM-TT hh:mm:ss&ldquo; angegeben werden.';
-$lang['notitlegiven'] = 'FEHLER: Kein Titel eingegeben';
-$lang['nonamegiven'] = 'FEHLER: Kein Name eingegeben';
+$lang['notitlegiven'] = 'FEHLER: Es wurde kein Titel eingegeben';
+$lang['nonamegiven'] = 'FEHLER: Es wurde kein Name eingegeben';
 $lang['numbertodisplay'] = 'Anzuzeigende Anzahl (ohne Eintrag werden alle Datens&auml;tze angezeigt)';
 $lang['print'] = 'Drucken';
 $lang['postdate'] = 'Erstellt am';
@@ -157,12 +165,12 @@ $lang['selectcategory'] = 'Kategorie ausw&auml;hlen';
 $lang['showchildcategories'] = 'Unterkategorien anzeigen';
 $lang['sortascending'] = 'aufsteigend sortieren';
 $lang['startdate'] = 'Startzeitpunkt';
-$lang['startoffset'] = 'Beginnt mit der Anzeige ab dem <span style=&quot;font-style: italic;&quot;>n</span>-ten Eintrag';
+$lang['startoffset'] = 'Beginnt mit der Anzeige ab dem <em>n</em>-ten Eintrag';
 $lang['startrequiresend'] = 'Die Eingabe eines Startzeitpunktes erfordert auch die Eingabe eines Endzeitpunktes.';
 $lang['submit'] = 'Speichern';
 $lang['summary'] = 'Zusammenfassung';
 $lang['summarytemplate'] = 'Zusammenfassungs-Templates';
-$lang['summarytemplateupdated'] = 'Das aktualisierte Zusammenfassungs-Template wurde in der Datenbank gespeichert.';
+$lang['summarytemplateupdated'] = 'Das Zusammenfassungs-Template wurde aktualisiert.';
 $lang['title'] = 'Titel';
 $lang['options'] = 'Optionen';
 $lang['optionsupdated'] = 'Die Einstellungen wurden gespeichert.';
@@ -279,9 +287,8 @@ $lang['help'] = '<h3>Wichtiger Hinweis</h3>
 </ul>
 <p>Auch die Variablen der Extra-Felder k&ouml;nnen in den Templates separat verwendet werden. So l&auml;sst sich zum Beispiel das Extrafeld mit dem Namen &quot;musterfeld&quot; &uuml;ber die Variable entry->musterfeld abfragen.</p>
 <p><strong>ACHTUNG:</strong> Leerzeichen m&uuml;ssen dabei durch den Unterstrich (&quot;_&quot;) ersetzt werden.</p> ';
-$lang['qca'] = 'P0-75091478-1268421814072';
-$lang['utmz'] = '156861353.1272379137.12.8.utmcsr=cmsmadesimple.de|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '156861353.728989452.1268567475.1271758833.1272379137.12';
+$lang['utma'] = '156861353.178890951.1298889837.1299177721.1299280219.6';
+$lang['utmz'] = '156861353.1298889837.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1272379137';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
