@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'Esta preferencia se usa para determinar una pagina (y por ende una plantilla) para usar para la vista detallada. URLs Individualizadas para detalles de Noticias no funcionara si este parametro no est&aacute; establecido a una pagina valida. Adicionalmente, si esta preferencia est&aacute; establecida, y no se proporciona el parametro &#039;detailpage&#039; en la etiqueta de noticias, entonces este valor ser&aacute; utilizado para los enlaces de detalle.';
+$lang['title_detail_returnid'] = 'Pagina por defecto para usar para las vistas detalladas';
+$lang['title_submission_settings'] = 'Ajustes de envio de Noticias';
+$lang['title_fesubmit_settings'] = 'Ajustes de envio a traves de la pagina frontal';
+$lang['title_notification_settings'] = 'Ajustes de notificaci&oacute;n';
+$lang['title_detail_settings'] = 'Ajustes de vista detallada';
+$lang['error_invalidurl'] = 'URL Inv&aacute;lida <em>(puede que est&eacute; en uso, o contiene caracteres inv&aacute;lidos)</em>';
+$lang['url'] = 'URL ';
 $lang['expired_searchable'] = 'Articulos expirados pueden aparecer en resultados de busquedas';
 $lang['helpshowall'] = 'Mostrar todos los articulos, sin importar la fecha en que finalizan';
 $lang['error_invaliddates'] = 'Una o mas de las fechas ingresadas son invalidas';
@@ -20,6 +28,8 @@ $lang['expiry_date_desc'] = 'Fecha Vence Descendente';
 $lang['expiry_date_asc'] = 'Fecha Vence Ascendente';
 $lang['title_desc'] = 'T&iacute;tulo Descendente';
 $lang['title_asc'] = 'T&iacute;tulo Ascendente';
+$lang['status_desc'] = 'Status Descendiente';
+$lang['status_asc'] = 'Status Ascendiente';
 $lang['fesubmit_status'] = 'El estado de art&iacute;culos de noticias enviados v&iacute;a el portal';
 $lang['error_invalidfiletype'] = 'No se puede subir este tipo de archivo';
 $lang['error_upload'] = 'Ha ocurrido un problema subiendo un archivo';
@@ -263,8 +273,9 @@ $lang['help'] = '<h3>Notas Importantes</h3>
 <li>Hacer Click en Enviar</li>
 </ul>
 Al seguir estos pasos se deber&iacute;an solucionar todos aquellos problemas de plantillas de noticias que no son encontradas y otros errores de smarty similares que aparecen cuando usted actualiza su versi&oacute;n de CMS MS a una que tiene el m&oacute;dulo News 2.3 o mayor.</p>';
-$lang['utma'] = '156861353.661434885.1227567621.1241502996.1241545688.65';
-$lang['utmz'] = '156861353.1241473702.63.28.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/board,30.0.html|utmcmd=referral';
+$lang['qca'] = 'P0-672577724-1291068511180';
+$lang['utmz'] = '156861353.1291068584.1.2.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['utma'] = '156861353.761306410.1291068511.1297984934.1298856162.17';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
