@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'T&auml;t&auml; asetusta k&auml;ytet&auml;&auml;n m&auml;&auml;rittelem&auml;&auml;n sivu (ja sivupohja), jota k&auml;ytet&auml;&auml;n lis&auml;tietojen n&auml;ytt&auml;miseksi. Yksil&ouml;lliset uutisten URL-osoitteet eiv&auml;t toimi, jos t&auml;t&auml; asetusta ei ole asetettu toimivaksi sivuksi. Lis&auml;ksi, jos t&auml;m&auml; asetus on m&auml;&auml;ritelty, eik&auml; detailpage-parametria ole annettu uutistagissa, t&auml;t&auml; asetusta k&auml;ytet&auml;&auml;n lis&auml;tietolinkiss&auml;.';
+$lang['title_detail_returnid'] = 'Oletus sivu detail n&auml;kym&auml;lle';
+$lang['title_submission_settings'] = 'Uutisten L&auml;hetys Asetukset';
+$lang['title_fesubmit_settings'] = 'Frontend L&auml;hetys Asetukset';
+$lang['title_notification_settings'] = 'Huomautus Asetukset';
+$lang['title_detail_settings'] = 'Detail N&auml;kym&auml;n Asetukset';
+$lang['error_invalidurl'] = 'Virheellinen URL <em>(Mahdollisesti k&auml;yt&ouml;ss&auml;, tai sis&auml;lt&auml;&auml; virheellisi&auml; merkkej&auml;)</em>';
+$lang['url'] = 'URL-osoite';
 $lang['expired_searchable'] = 'Vanhentuneet artikkelit voivat esiinty&auml; hakutuloksissa';
 $lang['helpshowall'] = 'N&auml;yt&auml; kaikki artikkelit, riippumatta p&auml;&auml;ttymisp&auml;iv&auml;m&auml;&auml;r&auml;st&auml;';
 $lang['error_invaliddates'] = 'Yksi tai useampi annettu p&auml;iv&auml;m&auml;&auml;r&auml; oli virheellinen';
@@ -274,8 +282,9 @@ $lang['help'] = '<h3>T&auml;rkeit&auml; muistiinpanoja</h3>
 <li>Paina L&auml;het&auml;</li>
 </ul>
 <p>N&auml;iden ohjeiden seuraamisen pit&auml;isi ratkaista ongelmat uutispohjien l&ouml;ytymisen ja muiden smarty-virheiden kanssa, kun p&auml;ivitet&auml;t uudempaan versioon CMS-j&auml;rjestelm&auml;&auml;.</p>';
-$lang['utma'] = '156861353.572491444.1274267548.1274275175.1274281846.4';
+$lang['qca'] = 'P0-143593381-1287469720325';
+$lang['utmz'] = '156861353.1289907526.70.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,48780.0.html';
+$lang['utma'] = '156861353.386609350.1282051258.1289907526.1289915269.71';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1274270099.2.2.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
-$lang['qca'] = 'P0-1477326709-1274267548700';
+$lang['utmb'] = '156861353.1.10.1289915269';
 ?>
\ No newline at end of file
