@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'Questa preferenza &egrave; usata per determinare una pagina (e quindi un template) da usare per visualizzare le pagine di dettaglio. URL Dettaglio News individuali non funzionano se questo parametro non &egrave; settato ad una pagina valida. In aggiunta, se questo parametro &egrave; settato, e nessun parametro detailpage &egrave; aggiunto sul tag news, allora questo valore sar&agrave; usato per i link dei dettagli';
+$lang['title_detail_returnid'] = 'pagina preefinita da usare per le visualizzazioni di dettaglio';
+$lang['title_submission_settings'] = 'Configurazioni inserimento News';
+$lang['title_fesubmit_settings'] = 'Configurazioni inserimento dal frontend';
+$lang['title_notification_settings'] = 'Configurazioni di notifica';
+$lang['title_detail_settings'] = 'Configurazioni visualizzazione dettaglo';
+$lang['error_invalidurl'] = 'URL invalido <em>(forse &egrave; gi&agrave; usato, o ci sono dei caratteri non validi)</em>';
+$lang['url'] = 'URL ';
 $lang['expired_searchable'] = 'Articoli spirati possono apparire nei risultati della ricerca';
 $lang['helpshowall'] = 'Mostra tutti gli articoli, senza considerare la data di termine visualizzazione';
 $lang['error_invaliddates'] = 'Una o pi&ugrave; date inserite non sono valide';
@@ -273,9 +281,8 @@ $lang['help'] = '<h3>Note Importanti</h3>
 <li>Premere Invio</li>
 </ul>
 Seguendo questi passi si dovrebbe risolvere il problema dei nuovi modelli non trovati e altri errori similari di smarty quando aggiorni ad una versione di CMS che contiene News 2.3 o maggiore.</p>';
-$lang['qca'] = 'P0-1187230324-1271659236866';
-$lang['utma'] = '156861353.976402040.1271759292.1276850904.1277118686.4';
-$lang['utmz'] = '156861353.1277118686.4.4.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.974349155.1299072468.1299072468.1299072468.1';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
