@@ -1,21 +1,35 @@
 <?php
-$lang['unlimited'] = 'Unlimited';
+$lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
+$lang['title_detail_returnid'] = 'Default page to use for detail views';
+$lang['title_submission_settings'] = 'News Submission Settings';
+$lang['title_fesubmit_settings'] = 'Frontend Submit Settings';
+$lang['title_notification_settings'] = '通知設定';
+$lang['title_detail_settings'] = '詳細表示設定';
+$lang['error_invalidurl'] = 'Invalid URL <em>(maybe it is already used, or there are invalid characters)</em>';
+$lang['url'] = 'URL';
+$lang['expired_searchable'] = 'Expired articles can appear in search results';
+$lang['helpshowall'] = 'Show all articles, irrespective of end date';
+$lang['error_invaliddates'] = 'One or more of the dates entered were invalid';
+$lang['notify_n_draft_items_sub'] = '%d News article(s)';
+$lang['notify_n_draft_items'] = 'You have %s that is/are not published';
+$lang['unlimited'] = '上限値なし';
 $lang['none'] = 'なし';
-$lang['rss_destinationpage'] = 'The id or page alias of the landing page for news articles from the rss feed';
 $lang['anonymous'] = 'Anonymous';
-$lang['unknown'] = 'Unknown';
+$lang['unknown'] = '知らない。';
 $lang['fesubmit_redirect'] = 'PageID or alias to redirect to after a news article has been submitted via the fesubmit action';
 $lang['allow_summary_wysiwyg'] = 'Allow using a WYSIWYG editor on the summary field';
 $lang['title_browsecat_template'] = 'Browse Category Template Editor';
 $lang['title_browsecat_sysdefault'] = 'Default Browse category Template';
-$lang['browsecattemplate'] = 'Browse Category Templates';
+$lang['browsecattemplate'] = 'カテゴリ・テンプレートを見る。';
 $lang['error_filesize'] = 'An uploaded file exceeded the maximum allowed size';
 $lang['post_date_desc'] = 'Post Date Descending';
 $lang['post_date_asc'] = 'Post Date Ascending';
 $lang['expiry_date_desc'] = 'Expiry Date Descending';
 $lang['expiry_date_asc'] = 'Expiry Date Ascending';
-$lang['title_desc'] = 'Title Descending';
-$lang['title_asc'] = 'Title Ascending';
+$lang['title_desc'] = 'タイトル降順';
+$lang['title_asc'] = 'タイトル昇順';
+$lang['status_desc'] = 'ステータス降順';
+$lang['status_asc'] = 'ステータス昇順';
 $lang['fesubmit_status'] = 'The status of news articles submitted via the frontend';
 $lang['error_invalidfiletype'] = 'Cannot upload this type of file';
 $lang['error_upload'] = 'Problem occurred uploading a file';
@@ -110,53 +124,6 @@ $lang['cancel'] = 'キャンセル';
 $lang['category'] = 'カテゴリ';
 $lang['categories'] = 'カテゴリ';
 $lang['default_category'] = 'デフォルトカテゴリ';
-$lang['changelog'] = '<ul>
-<li>
-<p>Version: 1.0</p>
-<p>This module is a hacked and extended version of <em>Ted Kulp\'s</em> News module.  I simply added another field to the database, and some more code to make that field worl.... I also re-cleaned the code a bit, so it was a little easier to read, other than that, it\'s Ted\'s code.</p>
-</li> 
-<li> 
-<p>Version: 1.1</p> 
-<p>Added the ability to set an automatic expiry date from a pulldown, moved the category selection, and on the main page you now filter the entries you want to see.</p> 
-</li> 
-<li> 
-<p>Version: 1.2</p> 
-<p>Added summary, no_anchor and length parameters.  In summary mode links are made to the real articles, tags are stripped, and links are insreted to the news page and the specific news item.</p> 
-</li> 
-<li> 
-<p>Version: 1.3</p> 
-<p>Minor cosmetic changes</p> 
-</li> 
-<li> 
-<p>Version 1.5</p> 
-<p>Merged into the trunk News module</p> 
-</li> 
-<li> 
-<p>Version 1.6</p> 
-<p>Added pagination, and moved the add button to the top (calguy)</p>
-</li>
-<li>
-<p>Version 2.0</p>
-<p>Re-written to use smarty templates, and several other significant improvements</p>
-</li>
-<li>
-<p>Version 2.0.1</p>
-<p>Minor tweaks to the RSS output to allow it to work correctly on different browsers, and to support non alpha numeric characters in the description.</p> 
-</li> 
-<li>
-<p>Version 2.0.2</p>
-<p>- Add a "start" parameter to specify a start offset for news items</p>
-<p>- The template tabs now have a "reset to default" button on them</p>
-<p>- Start menu item is now required, but end date is optional when useexpirydate is on, 
-<p>- Change the permissions model significantly, The "Modify News" permission is only for articles and categories. "Modify Templates" permission is required to edit the templates, and "Modify Site Preferences" is required to edit the options.</p> 
-<p>- Put the rss feed titile into the lang entries</p>
-</li> 
-<p>Version 2.0.3</p>
-<p>- Added the ability to track the original author of an article</p>
-<li>
-</ul>
-</ul> 
-';
 $lang['content'] = 'コンテンツ';
 $lang['dateformat'] = '%sは有効なフォーマットではありません。「yyyy-mm-dd hh:mm:ss」の必要があります。';
 $lang['delete'] = '削除';
@@ -194,8 +161,6 @@ $lang['numbertodisplay'] = '表示数(空欄の場合は全てのレコードが
 $lang['print'] = '印刷';
 $lang['postdate'] = '投稿日';
 $lang['postinstall'] = 'ニュース項目を管理するユーザーには"ニュースを修正"パーミッションを設定する必要があります。';
-$lang['rssfeedtitle'] = 'CMS Made Simple RSSフィード';
-$lang['rsstemplate'] = 'RSSテンプレート';
 $lang['selectcategory'] = 'カテゴリの選択';
 $lang['showchildcategories'] = '子カテゴリを表示';
 $lang['sortascending'] = '昇順並び替え';
@@ -210,8 +175,6 @@ $lang['title'] = 'タイトル';
 $lang['options'] = 'オプション';
 $lang['optionsupdated'] = 'オプションは正常に更新されました。';
 $lang['useexpiration'] = '期限切れ日付を使用';
-$lang['showautodiscovery'] = 'RSSフィードAuto-Discoveryリンクを表示';
-$lang['autodiscoverylink'] = 'RSSフィードAuto-Discovery URL (デフォルトは空欄)';
 $lang['eventdesc-NewsArticleAdded'] = '記事の追加時に送信';
 $lang['eventhelp-NewsArticleAdded'] = '<p>記事の追加時に送信</p>
 <h4>パラメーター</h4>
@@ -270,9 +233,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>カテゴリの削除時に送信</
 <li>\\"category_id\\" - ニュースのID</li>
 </ul>
 ';
+$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article.';
 $lang['helpnumber'] = '表示できる項目の最大数の値 -- 空欄の場合は全項目を表示';
 $lang['helpstart'] = '○番目の項目からスタート -- 空欄の場合は最初からスタート';
-$lang['helpmakerssbutton'] = 'ニュース項目のRSSフィードへのリンクボタンを作成';
 $lang['helpcategory'] = '該当カテゴリとその子カテゴリの項目だけを表示。空欄の場合は全カテゴリを表示。';
 $lang['helpmoretext'] = '要約のサイズを超えている場合に、ニュース項目を最後まで表示します。デフォルトは"さらに表示..."。';
 $lang['helpsummarytemplate'] = '要約記事の表示に別のテンプレートを利用。 ファイルはmodules/News/templatesに置く必要があります。';
@@ -282,7 +245,6 @@ $lang['helpdetailtemplate'] = '記事詳細の表示に別のテンプレート
 $lang['helpsortby'] = '並び替えの優先項目。項目は: "news_date"、"summary"、"news_data"、"news_category"、"news_title"。デフォルトは"news_date"。';
 $lang['helpsortasc'] = 'ニュース項目を昇順に並べ替え。';
 $lang['helpdetailpage'] = 'ニュース詳細を表示するページ。ページのエイリアスまたはIDを使用できます。記事概要と異なるテンプレートで表示させる場合に使います。';
-$lang['helpdateformat'] = '記事の投稿日の日付フォーマット。これはPHPの<a href="http://php.net/strftime" target="_blank">strftime</a>関数によるもので、テンプレート内で$entry->formatpostdateという風に呼び出せます。';
 $lang['helpshowarchive'] = 'Show only expired news articles.';
 $lang['helpbrowsecat'] = 'Shows a browseable category list.';
 $lang['helpaction'] = 'Override the default action.  Possible values are \'default\' to display the summary view, and \'fesubmit\' to display the frontend form for allowing users to submit news articles on the front end.';
@@ -292,8 +254,9 @@ $lang['help'] = '	<h3>何ができるのでしょうか?</h3>
 	<p>利用ユーザーは、入力や編集等の作業を行う為に、必ず\'ニュースの修正\'パーミッションを持ったグループに所属する必要があります。</p>
 	<h3>使用方法</h3>
 	<p>もっとも簡単な利用方法はcms_moduleタグと合わて使うことです。この方法はモジュールをテンプレートやページのどこかニュース項目を表示したい場所に挿入することです。コードの形式は以下のようになります： <code>{cms_module module="news" number="5" category="beer"}</code></p>';
-$lang['utma'] = '156861353.1193756969.1199698276.1213318721.1213322938.6';
-$lang['utmz'] = '156861353.1213322938.6.4.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1025915730.1283783986.1283783986.1283783986.1';
+$lang['utmb'] = '156861353.1.10.1283783986';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1283783986.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-494958194-1283783986906';
 ?>
\ No newline at end of file
