@@ -1,11 +1,11 @@
 <?php
+$lang['expired_searchable'] = 'Expired articles can appear in search results';
+$lang['helpshowall'] = 'Show all articles, irrespective of end date';
 $lang['error_invaliddates'] = 'One or more of the dates entered were invalid';
 $lang['notify_n_draft_items_sub'] = 'Naujienų straipsnių: %d ';
 $lang['notify_n_draft_items'] = 'You have %s that is/are not published';
-$lang['helprsscategory'] = 'For use with the makerssbutton parameter, this parameter allows specyfing a single category for use in the rss feed';
 $lang['unlimited'] = 'Neribojama';
 $lang['none'] = 'Nei vienas';
-$lang['rss_destinationpage'] = 'Id ar puslapio trumpinys rss tiekimo paskirties puslapiui';
 $lang['anonymous'] = 'Anoniminis';
 $lang['unknown'] = 'Nežinomas';
 $lang['fesubmit_redirect'] = 'ID ar puslapio trumpinys kur bus nukreiptas po naujienos pateikimo naudojant fesubmint veiksmą';
@@ -99,7 +99,7 @@ $lang['author'] = 'Autorius';
 $lang['sysdefaults'] = 'Atstayti įprastus nustatymus';
 $lang['restoretodefaultsmsg'] = '&Scaron;is veiksmas atstatys turinio &scaron;abloną į sistemos įprasta.  Ar tikrai norite tęsti?';
 $lang['addarticle'] = 'Įdėti Straipsnį';
-$lang['articleadded'] = 'Naujas staripsnis sėkmingai įdėtas.';
+$lang['articleadded'] = 'Naujas straipsnis sėkmingai įdėtas.';
 $lang['articleupdated'] = 'Straipsnis sėkmingai atnaujintas.';
 $lang['articledeleted'] = 'Straipsnis sėkmingai i&scaron;trintas.';
 $lang['addcategory'] = 'Įdėti Kategoriją';
@@ -152,8 +152,6 @@ $lang['numbertodisplay'] = 'Rodomas Skaičius (palikus tu&scaron;čią, rodomi v
 $lang['print'] = 'Spausdinti';
 $lang['postdate'] = 'Įra&scaron;o data';
 $lang['postinstall'] = 'Nustatykite &quot;Redaguoti Naujienas (Modify News)&quot; prieigą tiems vartotojams, kurie administruos naujienas.';
-$lang['rssfeedtitle'] = 'RSS Feedas';
-$lang['rsstemplate'] = 'RSS &Scaron;ablonas';
 $lang['selectcategory'] = 'Pasirinkite Kategoriją';
 $lang['showchildcategories'] = 'Rodyti subkategorijas';
 $lang['sortascending'] = 'Rū&scaron;iuoti Didėjančiai';
@@ -168,8 +166,6 @@ $lang['title'] = 'Pavadinimas';
 $lang['options'] = 'Nustatymai';
 $lang['optionsupdated'] = 'Nustaymai atnaujinti.';
 $lang['useexpiration'] = 'Naudoti galiojimo datą';
-$lang['showautodiscovery'] = 'Rodyti Feed Auto-Discovery nuorodą';
-$lang['autodiscoverylink'] = 'Feed Auto-Discovery URL (tu&scaron;čias įprasta reik&scaron;mė)';
 $lang['eventdesc-NewsArticleAdded'] = 'Nusiųsti kai straipsnis įdėtas.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <h4>Parameters</h4>
@@ -232,9 +228,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p
 <li>\&quot;name\&quot; - Name of the deleted category</li>
 </ul>
 ';
+$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article.';
 $lang['helpnumber'] = 'Maximalus rodomų elementų skaičius =- palikite tu&scaron;čia, rodys visus.';
 $lang['helpstart'] = 'Pradėti nth elementu -- palikite tu&scaron;čia, pradės nuo pirmos.';
-$lang['helpmakerssbutton'] = 'Padaryti mygtuką nurodantį į RSS naujienų tiekimą.';
 $lang['helpcategory'] = 'Rodo straipsnius tik i&scaron; nurodytos kategorijos. <b>Naudoti * po kategorijos jei rodyti subkategorijas.</b>  Daugiau kategorijų galima rodyti jei pavadinimai atskirti kableliais. Palikite tu&scaron;čia rodysite visas kategorijas. &Scaron;is parametras taip pat veikia su prie&scaron;akiniu pateikimo forma. bet palaiko tik vieną kategoriją.';
 $lang['helpmoretext'] = 'Tekstas rodomas santraukos pabaigoje, nuoroda į straipsnio turinį. Įprastai &quot;more...&quot;';
 $lang['helpsummarytemplate'] = 'Use a separate database template for displaying the article summary.  This template must exist and be visible in the summary template tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
@@ -266,8 +262,9 @@ $lang['help'] = '	<h3>Ką jis daro?</h3>
 	<li><em>(optional)</em> sortasc=&quot;true&quot; - Rū&scaron;iuoti naujienas didėjančia tvarka.</li>
 	</ul>
 	</p>';
-$lang['utma'] = '156861353.3301155305762579000.1220345070.1228902847.1228986351.20';
-$lang['utmz'] = '156861353.1228986351.20.15.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,28219.0.html|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1259353230.1259355475.2152';
+$lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353.2.10.1259355475';
 ?>
\ No newline at end of file
