@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'Denne innstillingen brukes til &aring; fastsl&aring; en side (og derfor en mal) &aring; bruke til &aring; vise detaljsider. Individuelle Nyhetsdetalj nettadresser vil ikke fungere hvis denne parameteren ikke er satt til en gyldig side. I tillegg, hvis denne innstillingen er satt, og ingen detaljside-parameter er gitt p&aring; nyhetstaggen, s&aring; vil denne verdien bli brukt for detaljlenker';
+$lang['title_detail_returnid'] = 'Standardside &aring; benytte for detaljvisninger';
+$lang['title_submission_settings'] = 'Nyhetsinnleverings innstillinger';
+$lang['title_fesubmit_settings'] = 'Frontend-innsendings innstillinger';
+$lang['title_notification_settings'] = 'Varslingsinnstillinger';
+$lang['title_detail_settings'] = 'Detaljvisnings innstillinger';
+$lang['error_invalidurl'] = 'Ugyldig URL <em>(mulig den allerede er benyttet, eller at det er ugyldige bokstaver)</em>';
+$lang['url'] = 'URL ';
 $lang['expired_searchable'] = 'Utl&oslash;pte artikler f&aring;r vises i s&oslash;keresultat';
 $lang['helpshowall'] = 'Vis alle artikler, uten &aring; ta hensyn til utl&oslash;psdato';
 $lang['error_invaliddates'] = 'En eller flere av datoene som er oppgitt er ugyldige';
@@ -27,9 +35,9 @@ $lang['error_invalidfiletype'] = 'Kan ikke laste opp denne filtypen';
 $lang['error_upload'] = 'Et problem oppstod under opplasting av fil';
 $lang['error_movefile'] = 'Kunne ikke opprette fil: %s';
 $lang['error_mkdir'] = 'Kunne ikke opprette katalog: %s';
-$lang['expiry_interval'] = 'Antall dager (standard) f&oslash;r en artikkel skal utl&oslash;pe (om utl&oslash;per er valgt)';
+$lang['expiry_interval'] = 'Antall dager (standard) f&oslash;r en artikkel skal utl&oslash;pe (om utl&oslash;p er valgt)';
 $lang['removed'] = 'Fjernet';
-$lang['msg_contenttype_removed'] = 'Nyhet innholdstypen har blitt fjernet. Vennligst plasser {news} tagger med passende parametere i din mal eller inne i sideinnholdet for &aring; gjenskape denne funksjonaliteten.';
+$lang['msg_contenttype_removed'] = 'Nyhet-innholdstypen har blitt fjernet. Vennligst plasser {news} tagger med passende parametere i din mal eller inne i sideinnholdet for &aring; gjenskape denne funksjonaliteten.';
 $lang['delete_selected'] = 'Slett de valgte artiklene';
 $lang['areyousure_deletemultiple'] = 'Er du sikker p&aring; du vil slette alle de valgte nyhetsartiklene?\nDette kan ikke angres!';
 $lang['error_templatenamexists'] = 'En mal med det navnet eksisterer allerede';
@@ -77,7 +85,7 @@ $lang['prompt_template'] = 'Mal kildekode';
 $lang['title_form_sysdefault'] = 'Standard Skjemamal';
 $lang['title_summary_sysdefault'] = 'Standard Sammendragsmal';
 $lang['title_detail_sysdefault'] = 'Standard Detaljmal';
-$lang['info_sysdefault2'] = '<strong>Merk:</strong> Denne fliken inneholder tekstomr&aring;der som tillater deg &aring; redigere de malene som vises n&aring;r du oppretter et &#039;nytt&#039; sammendrag, detalj, eller skjema mal. &Aring; endre innhold i denne fliken og klikke &#039;utf&oslash;r&#039; vil <strong>ikke ha effekt p&aring; n&aring;v&aelig;rende visninger</strong>.';
+$lang['info_sysdefault2'] = '<strong>Merk:</strong> Denne fanen inneholder tekstomr&aring;der som tillater deg &aring; redigere de malene som vises n&aring;r du oppretter et &#039;nytt&#039; sammendrag, detalj, eller skjema mal. &Aring; endre innhold i denne fanen og klikke &#039;utf&oslash;r&#039; vil <strong>ikke ha effekt p&aring; n&aring;v&aelig;rende visninger</strong>.';
 $lang['info_sysdefault'] = '<em>(malen som er benyttet som standard n&aring;r en ny mal velges)</em>';
 $lang['template'] = 'Mal';
 $lang['prompt_name'] = 'Navn';
@@ -232,11 +240,11 @@ $lang['help_articleid'] = 'Denne parameter er kun gyldig i detaljvisning. Den ti
 $lang['helpnumber'] = 'Maksimalt antall elementer som skal vises (per side) (ingen verdi vil medf&oslash;re at alle elementer vises). Denne er synonym for pagelimit parameteren.';
 $lang['helpstart'] = 'Start med artikkel n-- dersom ingen parameter er gitt vil visningen starte fra f&oslash;rste artikkel.';
 $lang['helpcategory'] = 'Benyttet i sammendragsvisning for kun &aring; vise elementer fra den spesifiserte kategorien. <b>Bruk * etter navnet for &aring; vise underelementer.</b>  Flere kategorier kan bli brukt dersom disse er separert med komma. Om ingen verdi oppgis vil det resultere i at alle kategorier vises. Denne parameter virker ogs&aring; p&aring; frontend submit handlingen, men st&oslash;tter kun et kategori navn.';
-$lang['helpmoretext'] = 'Tekst som skal vises p&aring; slutten av nyhetssaken dersom innlegget er lengre enn sammendragslengden. Standard verdi er &quot;more...&quot;';
-$lang['helpsummarytemplate'] = 'Bruk en separat mal for &aring; vise artikkelsammendrag. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Sammendrag mal fliken i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
-$lang['helpformtemplate'] = 'Bruk en database mal for &aring; vise artikkel innsending skjemaet. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Skjema mal fliken i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
-$lang['helpbrowsecattemplate'] = 'Benytt en database-mal for &aring; vise kategoris&oslash;ket. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i S&oslash;k-Kategori maler fliken i Nyhetsadministrasjonen, men den trenger ikke &aring; v&aelig;re satt som standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
-$lang['helpdetailtemplate'] = 'Bruk en separat database mal for visning av artikkel detaljene. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Detalj mal fliken i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
+$lang['helpmoretext'] = 'Tekst som skal vises p&aring; slutten av nyhetssaken dersom innlegget er lengre enn sammendragslengden. Standard verdi er &quot;Mer&quot;';
+$lang['helpsummarytemplate'] = 'Bruk en separat mal for &aring; vise artikkelsammendrag. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Sammendrag malfanen i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
+$lang['helpformtemplate'] = 'Bruk en database mal for &aring; vise artikkel innsending skjemaet. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Skjema malfanen i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
+$lang['helpbrowsecattemplate'] = 'Benytt en database-mal for &aring; vise kategoris&oslash;ket. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i S&oslash;k-Kategori malfanen i Nyhetsadministrasjonen, men den trenger ikke &aring; v&aelig;re satt som standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
+$lang['helpdetailtemplate'] = 'Bruk en separat database mal for visning av artikkel detaljene. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Detalj malfanen i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
 $lang['helpsortby'] = 'Felt &aring; sortere etter.  Alternativene er &#039;news_date&#039;, &#039;summary&#039;, &#039;news_data&#039;, &#039;news_category&#039;, &#039;news_title&#039;, &#039;news_extra&#039;, &#039;end_time&#039;, &#039;start_time&#039;, &#039;random&#039;.  Standardsetting er &#039;news_date&#039;. Om tilfeldig(random) er valgt vil sortasc parameteren bli ignorert.';
 $lang['helpsortasc'] = 'Sorter nyhetselementer i stigende rekkef&oslash;lge i stedet for synkende.';
 $lang['helpdetailpage'] = 'Side hvor nyhetsdetaljer skal vises. Dette kan enten v&aelig;re et sidealias eller en id. Benyttes for &aring; tillate visning av detaljer i en annen mal enn sammendragsmalen.';
@@ -254,40 +262,38 @@ $lang['help'] = '<h3>Viktige merknader</h3>
 
 <h3>Hva gj&oslash;r denne modulen?</h3>
 <p>News er en modul for visning av nyhetsartikler p&aring; din side. Den ligner en blogg, men har flere muligheter!.  
-N&aring;r modulen er installert, blir det lagt til en administrasjonsside for Nyheter i administrasjonsmenyen, som vil tillate deg &aring; velg og  legge til nyhetskategori.  
-	N&aring;r en nyhetskategori er opprettet eller valgt, vil det vises en liste med nyhetsartikler for den kategorien.  
+N&aring;r modulen er installert, blir det lagt til en administrasjonsside for Nyheter i administrasjonsmenyen, som vil tillate deg &aring; velge og  legge til nyhetskategori. N&aring;r en nyhetskategori er opprettet eller valgt, vil det vises en liste med nyhetsartikler for den kategorien.  
 Herfra kan du legge til, redigere eller slette nyheter for kategorien.</p>
         <h4>Mange visningsm&aring;ter</h4>
 	<p>Parameterne som er st&oslash;ttet av nyhets modulen, og st&oslash;tte for mange maler p&aring; en gang vil si at dine muligheter for &aring; vise nyhetsartikler er ubegrenset.</p>
         <h4>Egendefinerte felter</h4>
-	<p>Nyhetsmodulen tillater definering av mange egendefinerte felter (inkludert filer og bilder) som vil tillate deg &aring; koble pdf filer eller flere bilders til dine artikler.</p>
+	<p>Nyhetsmodulen tillater definering av mange egendefinerte felter (inkludert filer og bilder) som vil tillate deg &aring; koble pdf filer eller flere bilder til dine artikler.</p>
         <h4>Kategorier</h4>
-	<p>Nyheter st&oslash;tter en hierarktisk kategori mekanisme for &aring; organisere dine artikler. En hyhetsartikkel kan kun tilh&oslash;re en posisjon i hierarkiet.</p>
+	<p>Nyheter st&oslash;tter en hierarkisk kategori mekanisme for &aring; organisere dine artikler. En nyhetsartikkel kan kun tilh&oslash;re en posisjon i hierarkiet.</p>
 	<h4>Utl&oslash;psdato og Status</h4>
 	<p>Hver nyhetsartikkel kan ha en utl&oslash;psdato(valgfritt) og n&aring;r denne utl&oslash;per vil artikkelen ikke vises p&aring; din nettside. I tillegg kan artikler ogs&aring; merkes som <em>kladd</em> for &aring; sette dem til &aring; ikke vises p&aring; din nettside.</p>
 	<h3>Sikkerhet</h3>
-	<p>Brukeren m&aring; tilh&oslash;re en gruppe med &#039;Modify News&#039; tillatelse for &aring; kunne legge til, redigere elle slette Nyhetsartikler.</p>
+	<p>Brukeren m&aring; tilh&oslash;re en gruppe med &#039;Modify News&#039; tillatelse for &aring; kunne legge til, redigere eller slette nyhetsartikler.</p>
         <p>Og for &aring; slette nyhetsartikler m&aring; brukeren tilh&oslash;re en gruppe men &#039;Delete News Articles&#039; tillatelse.</p>
 <p>For &aring; endre layout malene, m&aring; brukeren tilh&oslash;re en gruppe med &#039;Modify Templates&#039; tillatelse.</p>
 <p>For &aring; redigere globale nyhets preferanser, m&aring; brukeren tilh&oslash;re en gruppe med &#039;Modify Site Preferences&#039; tillatelse.</p>
 <p>Og for &aring; godkjenne nyheter for forsidevisning m&aring; brukeren i tillegg tilh&oslash;re en gruppe med &#039;Approve News&#039; tillatelse.</p>
 
 <h3>Hvordan bruker jeg modulen?</h3>
-<p>Den enkleste m&aring;ten &aring; bruke den er med en {news} omslagstagg (lukker inn modulen i en tagg, for &aring; forenkle syntaksen).  
-Dette vil sette inn modulen i din mal eller side hvor du m&aring;tte &oslash;nske, og vise nyhetsartikler.  Koden vil se ut noe slikt som: <code>{news number=&#039;5&#039;}</code></p>
+<p>Den enkleste m&aring;ten &aring; bruke den er med en {news} omslagstagg (lukker inn modulen i en tagg, for &aring; forenkle syntaksen). Dette vil sette inn modulen i din mal eller side hvor du m&aring;tte &oslash;nske, og vise nyhetsartikler.  Koden vil se ut noe slikt som: <code>{news number=&#039;5&#039;}</code></p>
 
 <h3>Maler</h3>
 <p>Fra og med versjon 2.3 st&oslash;tter News flere database maler, og st&oslash;tter ikke lenger filmaler. Brukere som brukte det gamle filmal systemet kan f&oslash;lge disse trinnene (for hver filmal):
 <ul>
 <li>Kopier filmalen til utklippstavla</li>
-<li>Opprett en ny databasemal <em>(enten sammendrag eller detalj som trengs)</em>.  Gi den nye malen samme navn (inkludert .tpl endelse) som den gamle filmalen, og lim inn innholdet.</li>
+<li>Opprett en ny databasemal <em>(enten sammendrag eller detalj)</em>.  Gi den nye malen samme navn (inkludert .tpl endelse) som den gamle filmalen, og lim inn innholdet.</li>
 <li>Trykk Oppdater</li>
 </ul>
 
-<p>Dersom du f&oslash;lger disse trinnene skulle det l&oslash;se problemet med at dine nyhetsamaler ikke blir funnet og lignende smarty feil, n&aring;r du oppgraderer til en versjon av CMS som har News 2.3 eller h&oslash;yere.</p>';
-$lang['utmz'] = '156861353.1272675501.2656.57.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1272720219.1272726637.2660';
+<p>Dersom du f&oslash;lger disse trinnene skulle det l&oslash;se problemet med at dine nyhetsmaler ikke blir funnet og tilsvarende smarty feil, n&aring;r du oppgraderer til en versjon av CMS som har News 2.3 eller h&oslash;yere.</p>';
+$lang['utmz'] = '156861353.1288991067.3364.78.utmccn=(referral)|utmcsr=cmsmadesimple.org|utmcct=/about-link/special-fans-listing/|utmcmd=referral';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1290337505.1290347334.3406';
 $lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1272726637';
+$lang['utmb'] = '156861353.2.10.1290347334';
 ?>
\ No newline at end of file
