@@ -1,4 +1,13 @@
 <?php
+$lang['info_detail_returnid'] = 'Deze instelling wordt gebruikt om een pagina (en dus een sjabloon) te bepalen om te gebruiken om het detail artikel te tonen. Ge&iuml;ndividualiseerde Nieuws Detail URL&#039;s zullen niet werken als deze parameter niet is ingesteld op een geldige pagina.<br />
+Bovendien, als deze voorkeur is ingesteld en de News tag is niet voorzien van de detailpage parameter, dan zal deze waarde worden gebruikt voor de detail links';
+$lang['title_detail_returnid'] = 'Standaard pagina voor detail vertoningen';
+$lang['title_submission_settings'] = 'Nieuws Aanmelding Instellingen';
+$lang['title_fesubmit_settings'] = 'Frontend Aanmelding Instellingen';
+$lang['title_notification_settings'] = 'Berichtgeving Instellingen';
+$lang['title_detail_settings'] = 'Detail vertoning Instellingen';
+$lang['error_invalidurl'] = 'Verkeerde Url <em>(kan zijn dat deze al in gebruik is, of dat er verkeerde tekens in staan)</em>';
+$lang['url'] = 'Url';
 $lang['expired_searchable'] = 'Verlopen artikelen kunnen verschijnen in de zoekresultaten';
 $lang['helpshowall'] = 'Geef alle artikelen weer, ongeacht de einddatum';
 $lang['error_invaliddates'] = 'Een of meerdere ingegeven datums zijn incorrect';
@@ -279,9 +288,9 @@ $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 <li>Klik Versturen</li>
 </ul>
 Het uitvoeren van bovenstaande stappen moet het probleem oplossen van verdwenen nieuwssjablonen en vergelijkbare smarty-fouten als u upgrade naar een versie van CMSMS die de News-module versie 2.3 of nieuwer heeft.</p>';
-$lang['utma'] = '156861353.1269027775.1259416186.1273854185.1273860758.784';
-$lang['utmz'] = '156861353.1273667738.769.136.utmccn=(referral)|utmcsr=lgsbv.oke-webdesign.nl|utmcct=/admin/moduleinterface.php|utmcmd=referral';
-$lang['qca'] = 'P0-431297011-1259416186230';
+$lang['utma'] = '156861353.1335698708.1284586217.1286127363.1286137388.108';
+$lang['utmz'] = '156861353.1286137388.108.14.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-1551306179-1284586216711';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.9.10.1273860758';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
