@@ -1,11 +1,11 @@
 <?php
+$lang['expired_searchable'] = 'Artigos expirados podem aparecer nos resultados da pesquisa';
+$lang['helpshowall'] = 'Mostrar todos os artigos independentemente da data de vencimento';
 $lang['error_invaliddates'] = 'Uma ou mais das datas enviadas est&atilde;o inv&aacute;lidas';
 $lang['notify_n_draft_items_sub'] = '%d Artigo(s) de not&iacute;cia';
 $lang['notify_n_draft_items'] = 'You have %s that is/are not published';
-$lang['helprsscategory'] = 'For use with the makerssbutton parameter, this parameter allows specyfing a single category for use in the rss feed';
 $lang['unlimited'] = 'Ilimitado';
 $lang['none'] = 'Nenhum';
-$lang['rss_destinationpage'] = 'The id or page alias of the landing page for news articles from the rss feed';
 $lang['anonymous'] = 'An&ocirc;nimo';
 $lang['unknown'] = 'Desconhecido';
 $lang['fesubmit_redirect'] = 'PageID or alias to redirect to after a news article has been submitted via the fesubmit action';
@@ -151,8 +151,6 @@ $lang['numbertodisplay'] = 'N&uacute;mero &aacute; exibir (em branco mostra todo
 $lang['print'] = 'Imprimir';
 $lang['postdate'] = 'Data de Postagem';
 $lang['postinstall'] = 'Tenha certeza de especificar a permiss&atilde;o de &quot;Modificar Not&iacute;cias&quot; aos usu&aacute;rios que ir&atilde;o administrar os itens de Not&iacute;cias.';
-$lang['rssfeedtitle'] = 'Feed RSS do CMS Made Simple';
-$lang['rsstemplate'] = 'Template RSS';
 $lang['selectcategory'] = 'Selecione a Categoria';
 $lang['showchildcategories'] = 'Exibir sub-categorias';
 $lang['sortascending'] = 'Ordena&ccedil;&atilde;o Ascendente';
@@ -167,8 +165,6 @@ $lang['title'] = 'T&iacute;tulo';
 $lang['options'] = 'Op&ccedil;&otilde;es';
 $lang['optionsupdated'] = 'As op&ccedil;&otilde;es foram atualizadas com sucesso.';
 $lang['useexpiration'] = 'Usar data de expira&ccedil;&atilde;o';
-$lang['showautodiscovery'] = 'Exibir Link do Feed Auto-Discovery';
-$lang['autodiscoverylink'] = 'URL do Feed Auto-Discovery (padr&atilde;o em branco)';
 $lang['eventdesc-NewsArticleAdded'] = 'Enviado quando o artigo &eacute; adicionado.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <h4>Parameters</h4>
@@ -231,9 +227,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p
 <li>\&quot;name\&quot; - Name of the deleted category</li>
 </ul>
 ';
+$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article.';
 $lang['helpnumber'] = 'N&uacute;mero m&aacute;ximo de itens a exibir =- deixar em branco mostrar&aacute; todos os itens.';
 $lang['helpstart'] = 'Iniciar no en&eacute;simo item -- deixar em branco iniciar&aacute; no primeiro item';
-$lang['helpmakerssbutton'] = 'Criar um bot&atilde;o com o link para um feed RSS das not&iacute;cias.';
 $lang['helpcategory'] = 'S&oacute; mostrar itens para aquela categoria. Use * ap&oacute;s o nome para exibir as subcategorias. Muitas categiras pode ser usadas se separadas por v&iacute;rgula. Deixar em branco, ir&aacute; mostrar todas as categorias.';
 $lang['helpmoretext'] = 'Texto para exibir no final de uma not&iacute;cia se ela passar do tamanho m&aacute;ximo do resumo. O Padr&atilde; &eacute; &quot;mais...&quot;';
 $lang['helpsummarytemplate'] = 'Usa um modelo visual diferente para exibir o resumo do artigo. Ele deve estar no diret&oacute;rio modules/News/templates.';
@@ -262,8 +258,8 @@ $lang['help'] = '	<h3>O que isto faz?</h3>
 <h3>Informa&ccedil;&atilde;o de Tradu&ccedil;&atilde;o</h3>
 <p>Traduzido por Jos&eacute; Diogenes Silva</br>D&uacute;vidas e sugest&otilde;es: diogenescmsms@gmail.com</p>
 ';
-$lang['utmz'] = '156861353.1228186412.3.3.utmccn=(referral)|utmcsr=localhost|utmcct=/alccm/admin/moduleinterface.php|utmcmd=referral';
-$lang['utma'] = '156861353.1141998637.1228091253.1228186412.1229058939.4';
+$lang['utma'] = '156861353.3961599676465751000.1236885004.1236889412.1237485500.3';
+$lang['utmz'] = '156861353.1237485500.3.3.utmcsr=ruimedeiros.com|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utmb'] = '156861353.1.10.1237485500';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.4.10.1229058939';
 ?>
\ No newline at end of file
