@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'Data de Expira&ccedil;&atilde;o Descendente';
 $lang['expiry_date_asc'] = 'Data de Expira&ccedil;&atilde;o Ascendente';
 $lang['title_desc'] = 'Titulo Descendente';
 $lang['title_asc'] = 'Titulo Ascendente';
+$lang['status_desc'] = 'Estado Descendente';
+$lang['status_asc'] = 'Estado Ascendente';
 $lang['fesubmit_status'] = 'O Estado das not&iacute;cias submetidas via frontend';
 $lang['error_invalidfiletype'] = 'N&atilde;o &eacute; poss&iacute;vel carregar esse tipo de arquivo';
 $lang['error_upload'] = 'Ocorreu um problema no carregamento de um arquivo';
@@ -276,8 +278,9 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.2407387738755988500.1245288249.1245774815.1245778069.14';
-$lang['utmz'] = '156861353.1245774815.13.6.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,34889.msg164654.html';
-$lang['utmc'] = '156861353';
+$lang['qca'] = 'P0-1091236660-1271519106143';
+$lang['utma'] = '156861353.1066088901.1271528668.1271873862.1272120553.10';
+$lang['utmz'] = '156861353.1271618958.6.4.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,43343.0.html';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
