@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'Этот параметр используется для назначания страницы (и соотвествнно шаблона), в которой будет показываться полный текст новости. Альтернативные ссылки на новостт не будут работать, если этот параметр не установлен. Также, если этот параметр установлен и тег {news} используется без параметра detailpage, то это значение будет использовано по умолчанию.';
+$lang['title_detail_returnid'] = 'Страница по умолчанию для полного текста новости';
+$lang['title_submission_settings'] = 'Настройки добавления новостей';
+$lang['title_fesubmit_settings'] = 'Настройки добавления новостей пользователями';
+$lang['title_notification_settings'] = 'Настройки уведомлений';
+$lang['title_detail_settings'] = 'Настройки показа полного текста новости';
+$lang['error_invalidurl'] = 'Неверная ссылка <em>(возможно, уже используется или содержит запрещенные символы)</em>';
+$lang['url'] = 'Ссылка';
 $lang['expired_searchable'] = 'Новости могут появляться в результатах поиска, независимо от даты окончания';
 $lang['helpshowall'] = 'Показать все новости, независимо от даты окончания';
 $lang['error_invaliddates'] = 'Одна или несколько дат введены неверно';
@@ -111,7 +119,7 @@ $lang['addnewsitem'] = 'Добавить статью';
 $lang['allcategories'] = 'Все категории';
 $lang['allentries'] = 'Все новости';
 $lang['areyousure'] = 'Вы действительно хотите это удалить?';
-$lang['articles'] = 'Статьи';
+$lang['articles'] = 'Новости';
 $lang['cancel'] = 'Отмена';
 $lang['category'] = 'Категория';
 $lang['categories'] = 'Категории';
@@ -274,5 +282,9 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['qca'] = 'P0-137572696-1265912509436';
+$lang['qca'] = 'P0-1938388883-1277855813144';
+$lang['utma'] = '156861353.429593658.1277855813.1286806205.1286814378.25';
+$lang['utmz'] = '156861353.1286799193.22.13.utmccn=(organic)|utmcsr=google|utmctr=cmsmadesimple translation center|utmcmd=organic';
+$lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
