@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
+$lang['title_detail_returnid'] = 'Prednastaven&eacute; str&aacute;nka rpe detail';
+$lang['title_submission_settings'] = 'Nastavenie odoslania noviniek ';
+$lang['title_fesubmit_settings'] = 'Nastavenie odoslania cez web';
+$lang['title_notification_settings'] = 'Nastavenia notifik&aacute;cie';
+$lang['title_detail_settings'] = 'Nastavenie detailu';
+$lang['error_invalidurl'] = 'Neplatn&aacute; URL <em>(buď už existuje, alebo obsahuje neplatn&eacute; znaky)</em>';
+$lang['url'] = 'URL adresa';
 $lang['expired_searchable'] = 'Vypr&scaron;an&eacute; čl&aacute;nky sa m&ocirc;žu objaviť vo v&yacute;sledkoch vyhľad&aacute;vania';
 $lang['helpshowall'] = 'Zobraziť v&scaron;etky čl&aacute;nky, bez ohľadu na d&aacute;tum konca';
 $lang['error_invaliddates'] = 'D&aacute;tumy boli vložen&eacute; nespr&aacute;vne';
@@ -280,10 +288,9 @@ $lang['help'] = '<h3>D&ocirc;ležit&eacute; upozornenie</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['qca'] = 'P0-1608926040-1271144175783';
-$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
-$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
-$lang['chartbeat2'] = '87v0u4nbwegh3lki';
-$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
+$lang['qca'] = 'P0-1608926040-1271144175783';
+$lang['utma'] = '156861353.786385904.1271157997.1297103637.1297162122.164';
+$lang['utmz'] = '156861353.1297162122.164.149.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['utmb'] = '156861353.1.10.1297162122';
 ?>
\ No newline at end of file
