@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'Ta nastavitev se uporablja za določanje strani (in zato predlogo) za uporabo v podrobnem ogledu strani. Posebni URL-ji za podroben ogled novic ne bodo delovali, če ta parameter ni nastavljen na veljavno stran. Poleg tega, če je ta nastavljen, in noben detailpage parameter ni dodeljen v news tagu, nato bo ta vrednost uporabljena za linke do ogleda podrobnosti';
+$lang['title_detail_returnid'] = 'Predstavljena stran, za uporabo podrobnega ogleda novic';
+$lang['title_submission_settings'] = 'Nastavitve za predložitev novic';
+$lang['title_fesubmit_settings'] = 'Nastavitve za Frontend predložitev';
+$lang['title_notification_settings'] = 'Nastavitve za obvestilo';
+$lang['title_detail_settings'] = 'Nastavitve za ogled podrobnosti';
+$lang['error_invalidurl'] = 'Neveljaven URL <em>(Mogoče je že v uporabi, ali pa obstajajo neveljavni znaki)</em>';
+$lang['url'] = 'URL';
 $lang['expired_searchable'] = 'Potekli članki se lahko prikažejo v rezultatih iskanja';
 $lang['helpshowall'] = 'Prikaži vse članke, ne glede na datum zaključka objave';
 $lang['error_invaliddates'] = 'Eden ali več datumov je bilo narobe vne&scaron;enih';
@@ -20,6 +28,8 @@ $lang['expiry_date_desc'] = 'Datum zapada padajoče';
 $lang['expiry_date_asc'] = 'Datum zapada nara&scaron;čajoče';
 $lang['title_desc'] = 'Naziv padajoče';
 $lang['title_asc'] = 'Naziv nara&scaron;čajoče';
+$lang['status_desc'] = 'Status padajoč';
+$lang['status_asc'] = 'Status nara&scaron;čajoč';
 $lang['fesubmit_status'] = 'Status člankov, objavljenih preko front-end strani';
 $lang['error_invalidfiletype'] = 'Ne morem naložiti datoteke tega tipa';
 $lang['error_upload'] = 'Pri&scaron;lo je do napake pri nalaganju datoteke';
@@ -272,9 +282,9 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.1722464354432002000.1251370098.1258962106.1259238241.16';
-$lang['utmz'] = '156861353.1259238241.16.15.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
-$lang['qca'] = 'P0-1580489763-1251370099388';
-$lang['utmb'] = '156861353.2.10.1259238241';
+$lang['qca'] = 'P0-1458450664-1284573084918';
+$lang['utmz'] = '156861353.1286352801.131.17.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms api docu';
+$lang['utma'] = '156861353.1164361908.1285153768.1286732521.1286738424.162';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
