@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
+$lang['title_detail_returnid'] = 'Ayrıntılı g&ouml;r&uuml;n&uuml;m i&ccedil;in varsayılan sayfa';
+$lang['title_submission_settings'] = 'Haber Giriş Ayarları';
+$lang['title_fesubmit_settings'] = 'Frontend Submit Settings';
+$lang['title_notification_settings'] = 'Bilgilendirme Ayarları';
+$lang['title_detail_settings'] = 'Ayrıntılı G&ouml;r&uuml;n&uuml;m Ayarları';
+$lang['error_invalidurl'] = 'Invalid URL <em>(maybe it is already used, or there are invalid characters)</em>';
+$lang['url'] = 'URL';
 $lang['expired_searchable'] = 'S&uuml;resi bitmiş haberler arama sonu&ccedil;larında &ccedil;ıkabilsin';
 $lang['helpshowall'] = 'Bitiş tarihine bakılmaksızın t&uuml;m haberleri g&ouml;ster';
 $lang['error_invaliddates'] = 'Bir yada daha fazla tarih yanlış girirldi';
@@ -21,7 +29,7 @@ $lang['expiry_date_asc'] = 'Ger&ccedil;erlilik Tarihi Artan';
 $lang['title_desc'] = 'Başlığa G&ouml;re Azalan';
 $lang['title_asc'] = 'Başlığa G&ouml;re Artan';
 $lang['status_desc'] = 'Duruma G&ouml;re Azalan';
-$lang['status_asc'] = 'Durum G&ouml;re Azalan';
+$lang['status_asc'] = 'Duruma G&ouml;re Azalan';
 $lang['fesubmit_status'] = 'The status of news articles submitted via the frontend';
 $lang['error_invalidfiletype'] = 'Bu dosya tipini y&uuml;kleyemezsiniz';
 $lang['error_upload'] = 'Dosya y&uuml;kleme hatası oluştu';
@@ -257,9 +265,9 @@ $lang['help'] = '	<h3>What does this do?</h3>
 	<p>In order to edit the global news preferences, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>
 	<h3>How do I use it?</h3>
 	<p>The easiest way to use it is with the {news} wrapper tag (wraps the module in a tag, to simplify the syntax).  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{news number=&#039;5&#039;}</code></p>';
-$lang['utma'] = '156861353.1664897565.1272759163.1277761254.1277765691.32';
-$lang['utmz'] = '156861353.1277765691.32.5.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/250|utmcmd=referral';
-$lang['qca'] = 'P0-1960756361-1272759163370';
+$lang['utma'] = '156861353.1249837180.1276218286.1297348508.1297351199.9';
+$lang['utmz'] = '156861353.1297348590.8.3.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-1332436756-1295403130439';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
