@@ -18,7 +18,8 @@ $flds = "
 	create_date " . CMS_ADODB_DT . ",
 	modified_date " . CMS_ADODB_DT . ",
 	author_id I,
-    news_extra C(255)
+        news_extra C(255),
+        news_url C(255)
 ";
 
 $taboptarray = array('mysql' => 'TYPE=MyISAM');
