@@ -24,6 +24,8 @@ $db->DropSequence( cms_db_prefix()."module_news_seq" );
 $db->DropSequence( cms_db_prefix()."module_news_categories_seq" );
 
 $this->RemovePermission('Modify News');
+$this->RemovePermission('Approve News');
+$this->RemovePermission('Delete News');
 
 // Remove all preferences for this module
 $this->RemovePreference();
