@@ -36,11 +36,11 @@ class Printing extends CMSModule {
 	}
 
 	function GetVersion() {
-		return '1.1.0';
+		return '1.1.2';
 	}
 
 	function MinimumCMSVersion() {
-		return '1.8-beta1';
+		return '1.8';
 	}
 
 	function GetAdminDescription() {
