@@ -2,14 +2,12 @@
 $lang['friendlyname'] = 'Impression';
 $lang['description'] = 'Ce module permet de personnaliser l&#039;affichage de pages pour impression pour CMSMS.  
 Alternativement, des fichiers (simple) PDF du contenu principal peuvent &ecirc;tre cr&eacute;&eacute;s &agrave; la vol&eacute;e.';
-$lang['postinstall'] = 'Le module a &eacute;t&eacute; intall&eacute; avec succ&egrave;s';
+$lang['postinstall'] = 'Le module a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
 $lang['confirmuninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir d&eacute;sinstaller le module ?';
 $lang['postuninstall'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute; avec succ&egrave;s';
 $lang['linktemplate'] = 'Gabarit de lien';
 $lang['printtemplate'] = 'Gabarit d&#039;impression';
 $lang['pdftemplate'] = 'Gabarit PDF';
-$lang['pdfengine'] = 'Moteur PDF';
-$lang['internal'] = 'Interne (tcpdf)';
 $lang['templatesaved'] = 'Le gabarit a &eacute;t&eacute; mis &agrave; jour avec succ&egrave;s';
 $lang['templatereset'] = 'Le gabarit a &eacute;t&eacute; r&eacute;initialis&eacute; avec succ&egrave;s';
 $lang['confirmresettemplate'] = '&Ecirc;tes-vous s&ucirc;r de vouloir r&eacute;initialiser le gabarit &agrave; son contenu par d&eacute;faut ?';
@@ -22,8 +20,8 @@ $lang['pdfsettings'] = 'Param&egrave;tres PDF';
 $lang['pdfsettingssaved'] = 'Les param&egrave;tres PDF on &eacute;t&eacute; sauvegard&eacute;s avec succ&egrave;s';
 $lang['pdfheader'] = 'En-t&ecirc;te du PDF';
 $lang['pdfenable'] = 'Activer la g&eacute;n&eacute;ration de PDF';
-$lang['pdfenablehelp'] = 'Vous devriez savoir que la g&eacute;n&eacute;ration de PDF est tr&egrave;s rudimentaire, uniquement le tansfert du contenu basic. 
-Utilisez &agrave; volont&eacute;, mais merci de ne pas se plaindre de la qualit&eacute; du r&eacute;sultat.';
+$lang['pdfenablehelp'] = 'Vous devez savoir que la g&eacute;n&eacute;ration de PDF est tr&egrave;s rudimentaire et correspond uniquement au transfert basique du contenu des pages. 
+Utilisez-la &agrave; volont&eacute;, mais merci de ne pas vous plaindre de la qualit&eacute; du r&eacute;sultat.';
 $lang['headerfontsize'] = 'Taille du texte de l&#039;en-t&ecirc;te';
 $lang['contentfontsize'] = 'Taille du texte du contenu';
 $lang['fonttypetext'] = 'Type de fontes';
@@ -36,7 +34,7 @@ $lang['pdffooter'] = ' ';
 $lang['pdffooterhelp'] = ' ';
 $lang['template'] = 'Gabarit&nbsp;';
 $lang['notemplatecontent'] = 'Aucun contenu dans le nouveau gabarit...';
-$lang['defaultlinktext'] = ' Imprimer cette page';
+$lang['defaultlinktext'] = 'Imprimer cette page';
 $lang['defaultpdflinktext'] = 'G&eacute;n&eacute;rer un PDF';
 $lang['backbuttontext'] = 'Retour';
 $lang['overridestylereset'] = 'La feuille de style de remplacement a &eacute;t&eacute; r&eacute;initialis&eacute;e avec succ&egrave;s';
@@ -59,7 +57,7 @@ $lang['help'] = '<b>Que fait ce module ?</b>
 <br/>
 Il permet d&#039;ins&eacute;rer un lien dans votre page ou votre gabarit pour afficher une page imprimable. Plusieurs param&egrave;tres peuvent &ecirc;tre utilis&eacute;s pour le lien afin de rendre l&#039;impression telle que vous la d&eacute;sirez. Un param&egrave;tre permet de g&eacute;n&eacute;rer la page en PDF &agrave; la vol&eacute;e.
 <br/>
-Noter que, &agrave; moins que le param&egrave;tre <i>includetemplate = true</i> soit utilis&eacute;, le module permet l&#039;impression uniquement du contenu des pages du site.
+Noter que, &agrave; moins que le param&egrave;tre <i>includetemplate = true</i> soit utilis&eacute;, le module permet l&#039;impression uniquement du contenu des pages du site. Et que le fichier PDF en sortie peut ne pas avoir beaucoup de ressemblance avec votre page, mais donne le contenu.
 
 <br/><br/>
 <b>Comment l&#039;utiliser ?</b>
@@ -76,8 +74,8 @@ ou simplement,
 </pre>
 pour utiliser le plugin d&#039;impression.
 <br/>';
-$lang['utma'] = '156861353.2081279316.1241510515.1241510515.1241510515.1';
+$lang['utma'] = '156861353.1357645550.1277887498.1277887498.1277887498.1';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1241510515.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1277887498.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
