@@ -7,8 +7,6 @@ $lang['postuninstall'] = 'Modul har avinstallerats';
 $lang['linktemplate'] = 'L&auml;nkmall';
 $lang['printtemplate'] = 'Utskriftsmall';
 $lang['pdftemplate'] = 'PDF-mall';
-$lang['pdfengine'] = 'PDF-engine';
-$lang['internal'] = 'Internal-engine (tcpdf)';
 $lang['templatesaved'] = 'Mallen sparades';
 $lang['templatereset'] = 'Mallen har &aring;terst&auml;llts till standardinst&auml;llningen';
 $lang['confirmresettemplate'] = '&Auml;r du s&auml;ker p&aring; att mallen ska &aring;terst&auml;llas till standardinst&auml;llningen?';
@@ -21,8 +19,7 @@ $lang['pdfsettings'] = 'PDF inst&auml;llningar';
 $lang['pdfsettingssaved'] = 'PDF inst&auml;llningarna sparade';
 $lang['pdfheader'] = 'PDF-rubrik';
 $lang['pdfenable'] = 'Aktivera PDF-generering';
-$lang['pdfenablehelp'] = 'You should know that PDF-generation is very rudimentary only outputting the most basic of content.
-Use at will, but please don&#039;t complain about the quality of the result.';
+$lang['pdfenablehelp'] = 'Du ska veta att PDF-generationen &auml;r mycket rudiment&auml;r som bara matar fram de mest grundl&auml;ggande av allt inneh&aring;ll. Anv&auml;nd som du vill, men ska du inte klaga p&aring; kvaliteten.';
 $lang['headerfontsize'] = 'Teckenstorlek f&ouml;r rubrik';
 $lang['contentfontsize'] = 'Teckenstorlek f&ouml;r inneh&aring;ll';
 $lang['fonttypetext'] = 'Teckensnittstyp';
@@ -74,8 +71,9 @@ I sidans inneh&aring;ll eller i mallen l&auml;gger till till n&aring;got i stil
 och en l&auml;nk ska synas p&aring; dina sidor.
 <br/>
 ';
-$lang['utma'] = '156861353.433275480279966850.1241641285.1241641285.1241641285.1';
-$lang['utmb'] = '156861353.1.10.1241641285';
+$lang['utma'] = '156861353.622613290.1282068801.1286133816.1286141542.24';
+$lang['utmz'] = '156861353.1284652314.14.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-1267218368-1282068801788';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1241641285.1.1.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['utmb'] = '156861353.1.10.1286141542';
 ?>
\ No newline at end of file
