@@ -1,4 +1,5 @@
 <?php
+$lang['use_or'] = 'L&ouml;yd&auml; tulokset mitk&auml; t&auml;sm&auml;&auml;v&auml;t MIHIN TAHANSA sanaan';
 $lang['param_detailpage'] = 'K&auml;ytet&auml;&auml;n ainoastaan tulosten etsimiseen moduuleista, t&auml;m&auml; parametri sallii sallii erillisen tulossivun m&auml;&auml;rittelemisen. T&auml;m&auml; on k&auml;yt&auml;nn&ouml;llist&auml;, jos esimerkiksi n&auml;yt&auml;t aina tulokset erillisell&auml; sivupohjalla.  <em>(<strong>Huom:</strong> moduulit voivat ohittaa t&auml;m&auml;n parametrin.)</em>';
 $lang['prompt_resultpage'] = 'Sivu erillisille moduulien tuloksille <em>(Huomaa, ett&auml; moduulit voivat halutessaan ohittaa t&auml;m&auml;n)</em>';
 $lang['search_method'] = 'Siev&auml;t url-osoitteet, jotka ovat yhteensopivia POST-metodin kanssa, oletusarvo on aina GET. T&auml;m&auml;n toimintaan saamiseksi lis&auml;&auml; {search search_method=&quot;post&quot;} ';
@@ -86,9 +87,9 @@ $lang['help'] = '	<h3>Mit&auml; t&auml;m&auml; moduuli tekee?</h3>
 <h4>Kuinka tietyn sis&auml;ll&ouml;n indeksointi estet&auml;&auml;n?</h4>
 <p>Search-moduuli ei hae &quot;ep&auml;aktiivisilta&quot; sivuilta. Esimerkiksi CustomContent-moduulia tai muuta smarty-logiikkaa k&auml;ytett&auml;ess&auml; siihen, ett&auml; eri sis&auml;lt&ouml;&auml; n&auml;ytet&auml;&auml;n eri k&auml;ytt&auml;jille, voi olla hyv&auml; est&auml;&auml; koko sivun indeksointi, vaikka sivu olisikin aktiivinen. T&auml;m&auml; tehd&auml;&auml;n lis&auml;&auml;m&auml;ll&auml; mihin tahansa sivulle seuraava tagi: <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> Kun hakumoduuli n&auml;kee t&auml;m&auml;n tagin sivulla, se ei indeksoi mit&auml;&auml;n sivun sis&auml;lt&ouml;&auml;.</p>
 <p><em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> -tagin voi laittaa my&ouml;s sivupohjaan. Jos n&auml;in tehd&auml;&auml;n, mit&auml;&auml;n tuohon pohjaan liitetty&auml; sivua ei indeksoida. Jos tagi poistetaan, sivut on ideksoitava uudelleen.</p>';
-$lang['utmz'] = '156861353.1269853138.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-418055388-1269853137911';
-$lang['utma'] = '156861353.2121864343.1269853138.1274266042.1274341684.17';
+$lang['utma'] = '156861353.144823811.1251375439.1288623556.1288630766.361';
+$lang['utmz'] = '156861353.1285804076.330.37.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-1379893105-1252067779694';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1274341684';
+$lang['utmb'] = '156861353.1.10.1288630766';
 ?>
\ No newline at end of file
