@@ -1,4 +1,7 @@
 <?php
+$lang['use_or'] = 'Toon resultaten die voldoen aan tenminste &eacute;&eacute;n woord';
+$lang['param_detailpage'] = 'Alleen gebruikt voor gevonden resultaten van modules, met deze parameter kunt u een andere detail pagina benoemen voor deze zoekresultaten. Deze toepassing is nuttig bij bijvoorbeeld het tonen van de resultaten in een pagina met een ander sjabloon.  <em>(<strong>Opm.:</strong> Modules kunnen deze parameter mogelijk negeren.)</em>';
+$lang['prompt_resultpage'] = 'Pagina voor individuele module resultaten <em>(Opm. modules kunnen dit mogelijk negeren)</em>';
 $lang['search_method'] = 'Pretty URLs Compatibiliteit via de POST methode, standaard waarde is GET. Om dit te laten werken moet je {search search_method=&quot;post&quot;} in het sjabloon plaatsen.';
 $lang['export_to_csv'] = 'Exporteer naar CSV';
 $lang['prompt_savephrases'] = 'Track Zoek Termen, geen Individuele Woorden';
@@ -75,7 +78,7 @@ $lang['eventhelp-SearchAllItemsDeleted'] = '<p>Verzonden als alle item zijn verw
 
 <h4>Parameters</h4>
 <ul>
-<li>Niets</li>
+<li>Geen</li>
 </ul>
 ';
 $lang['help'] = '<h3>Wat doet het?</h3>
@@ -83,12 +86,12 @@ $lang['help'] = '<h3>Wat doet het?</h3>
 <h3>Hoe gebruikt u het?</h3>
 <p>De makkelijkste manier om het te gebruiken is de {search} tag in een sjabloon of pagina te plaatsen, waarna het zoekformulier wordt getoond. De code kan eruit zien als: <code>{search}</code></p>
 <h4>Hoe voorkomt u dat bepaalde inhoud ge&iuml;ndexeerd wordt?</h4>
-<p>De zoekmodule zal geen &quot;inactieve&quot; pagina&#039;s doorzoeken. Echter, als u gebruik maakt van de CustomContent module of van een andere smarty logica om bepaalde inhoud aan bepaalde gebruikersgroepen te tonen, of dit juiste te blokkeren, dan kan het de voorkeur hebben om te voorkomen dat volledige pagina&#039;s ge&iuml;ndexeerd worden. Om dit te bereiken kunt u de volgende tag willekeurig op de pagina plaatsen: <em><!-- pageAttribute: NotSearchable --></em> (let op: deze string moet letterlijk overgenomen worden, inclusief de drie losse spaties). Als de zoekmodule deze tag op een pagina tegenkomt zal het de inhoud niet indexeren.</p>
-<p>De <em><!-- pageAttribute: NotSearchable --></em> tag kan ook in een sjabloon worden geplaatst.  In dit geval zullen geen van de pagina&#039;s die met deze sjabloon gekoppeld zijn worden ge&iuml;ndexeerd.  Deze pagina&#039;s worden opnieuw ge&iuml;ndexeerd als de tag verwijderd is.</p>
+<p>De zoekmodule zal geen &quot;inactieve&quot; pagina&#039;s doorzoeken. Echter, als u gebruik maakt van de CustomContent module of van een andere smarty logica om bepaalde inhoud aan bepaalde gebruikersgroepen te tonen, of dit juiste te blokkeren, dan kan het de voorkeur hebben om te voorkomen dat volledige pagina&#039;s ge&iuml;ndexeerd worden. Om dit te bereiken kunt u de volgende tag willekeurig op de pagina plaatsen: <code><! -- pageAttribute: NotSearchable -- ></code> (let op: deze string moet letterlijk overgenomen worden, inclusief de drie losse spaties). Als de zoekmodule deze tag op een pagina tegenkomt zal het de inhoud niet indexeren.</p>
+<p>De <code><! -- pageAttribute: NotSearchable -- ></code> tag kan ook in een sjabloon worden geplaatst.  In dit geval zullen geen van de pagina&#039;s die met deze sjabloon gekoppeld zijn worden ge&iuml;ndexeerd.  Deze pagina&#039;s worden opnieuw ge&iuml;ndexeerd als de tag verwijderd is.</p>
 ';
-$lang['qca'] = 'P0-603614347-1252681532014';
-$lang['utma'] = '156861353.36781539.1252748587.1253629210.1253734910.23';
-$lang['utmz'] = '156861353.1253629210.22.11.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,37218.new.html';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1738896039.1278840000.1280414803.1280421296.64';
+$lang['utmz'] = '156861353.1280414803.63.9.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['qca'] = 'P0-854387043-1278840000917';
+$lang['utmb'] = '156861353.23.10.1280421296';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
