@@ -1,4 +1,7 @@
 <?php
+$lang['use_or'] = 'Выдать результаты, содержащие ЛЮБОЕ из слов';
+$lang['param_detailpage'] = 'Используется только для выдачи результатов из модулей. Этот параметр позволяет указать другую страницу для выдачи найденого. Эта настройка полезна, если Вы хотите выдавать результаты на страницах с различными шаблонами. <em> (<strong> Примечание: </ strong> Модули могут перекрывать эту параметр.) </ em>';
+$lang['prompt_resultpage'] = 'Страница для выдачи результатов отдельных модулей. <em> (<strong> Примечание: </ strong> Модули могут перекрывать эту параметр.) </ em>';
 $lang['search_method'] = 'Совместимость с Pretty Urls c помощью метода POST, по умолчанию параметры передаются в GET, чтобы изменить используйте {search search_method="post"} ';
 $lang['export_to_csv'] = 'Экспорт в CSV';
 $lang['prompt_savephrases'] = 'Поисковый запрос это не отдельные слова';
@@ -91,8 +94,9 @@ $lang['help'] = '<h3>Как это работает?</h3>
 <p>Поисковый модуль не будет искать на "неактивных" страницах. Тем не менее, в случае, если используется модуль CustomContent, или какая-либо другая Smarty-логика, с целью показать различный контент для различных групп пользователей, советуем предотвратить  индексирование всей страницы, даже если она активна. Чтобы это сделать, включите следующий тег в любом месте страницы <em><!-- pageAttribute: NotSearchable --></em>. Когда модуль поиска видит такой тег в коде страницы, он полностью исключает её из индекса.</p>
 
 <p>Тег <em><!-- pageAttribute: NotSearchable --></em> также может быть помещен и в шаблон.  Если это сделать, то никакие из страниц, которые его используют не будут проидексированы. Чтобы  переиндексировать эти страницы, следует удалить этот тег.</p>';
-$lang['utma'] = '156861353.3831803396166608400.1236078336.1242483093.1242487978.79';
-$lang['utmz'] = '156861353.1242036083.77.58.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-1938388883-1277855813144';
+$lang['utma'] = '156861353.429593658.1277855813.1286864591.1286875216.27';
+$lang['utmz'] = '156861353.1286799193.22.13.utmccn=(organic)|utmcsr=google|utmctr=cmsmadesimple translation center|utmcmd=organic';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
