@@ -1,4 +1,5 @@
 <?php
+$lang['use_or'] = 'N&aacute;jsť v&yacute;sledky, ktor&eacute; zodpovedaj&uacute; ak&eacute;mukoľvek slovu';
 $lang['param_detailpage'] = 'Použitie iba v pr&iacute;pade modulov, parameter povoľuje &scaron;pecifikovať odli&scaron;n&uacute; str&aacute;nku detailu pre v&yacute;sledky.   Použiteľn&eacute; napr&iacute;klad keď zobrazujete detail na inej str&aacute;nke ako v&yacute;sledky vyhľad&aacute;vania <em>(<strong>Pozn&aacute;mka:</strong> moduly toto m&ocirc;žu prep&iacute;sať.)</em>';
 $lang['prompt_resultpage'] = 'Str&aacute;nka pre individu&aacute;lne v&yacute;sledky modulu <em>(pozn&aacute;mka: moduly m&ocirc;žu toto prep&iacute;sať)</em>';
 $lang['search_method'] = 'Kompatibilita čitateľn&yacute; adries cez met&oacute;du POST, prednastaven&aacute; hodnota je GET, pre zmenu vložte do str&aacute;nok značku {search search_method=&quot;post&quot;} ';
@@ -81,10 +82,9 @@ $lang['help'] = '<h3>Ako to funguje?</h3>
 <h4>Ako zak&aacute;zať indexovanie určit&eacute;ho obsahu?</h4>
 <p>Vyhľad&aacute;vac&iacute; modul nebude prehľad&aacute;vať &quot;neakt&iacute;vne&quot; str&aacute;nky. Napriek tomu, v pr&iacute;pade, že použ&iacute;vate modul CustomContent, alebo in&yacute; inteligentn&yacute; sp&ocirc;sob pre zobrazenie r&ocirc;zneho obsahu pre r&ocirc;zne skupiny použ&iacute;vateľov, je odpor&uacute;čan&eacute; zak&aacute;zať prehľad&aacute;vanie tak&yacute;chto živ&yacute;ch str&aacute;nok. M&ocirc;žete to spraviť použit&iacute;m tagu <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> hocikde na str&aacute;nke. Pokiaľ vyhľad&aacute;vac&iacute; modul n&aacute;jde tak&yacute;to tag na str&aacute;nke, nebude indexovať jej obsah.</p>
 <p>Tag <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> m&ocirc;že byť umiestnen&yacute; aj v &scaron;abl&oacute;ne. V takomto pr&iacute;pade, žiadna zo str&aacute;nok použ&iacute;vaj&uacute;ca dan&uacute; &scaron;abl&oacute;nu nebude indexovan&aacute;. Po odstr&aacute;nen&iacute; tagu bud&uacute; tak&eacute;to str&aacute;nky preindexovan&eacute;.</p>';
-$lang['qca'] = 'P0-1608926040-1271144175783';
-$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
-$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
-$lang['chartbeat2'] = '87v0u4nbwegh3lki';
+$lang['utma'] = '156861353.1423109725.1280259016.1283630846.1283679544.29';
+$lang['utmz'] = '156861353.1283630846.28.27.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['qca'] = 'P0-748439131-1280259017524';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
