@@ -1,4 +1,7 @@
 <?php
+$lang['use_or'] = 'Visa resultat som matchar n&aring;got ord';
+$lang['param_detailpage'] = 'Anv&auml;nds endast f&ouml;r matchande resultat fr&aring;n moduler, den h&auml;r parametern l&aring;ter specificera en annan detaljsida f&ouml;r resultaten. Det h&auml;r &auml;r anv&auml;ndbart om, exempelvis, du alltid har dina detaljvisningar p&aring; en sida med en avvikande mall. <em>(<strong>Notera:</strong> moduler har m&ouml;jligheten att &aring;sidos&auml;tta den h&auml;r parametern.)</em>';
+$lang['prompt_resultpage'] = 'Sida f&ouml;r individuella modulresultat <em>(Notera att moduler frivilligt kan &aring;sidos&auml;tta detta)</em>';
 $lang['search_method'] = 'Pretty Urls kompabilitet via POST metoden, grundinst&auml;llningen &auml;r alltid GET, f&ouml;r att f&aring; detta att fungera anv&auml;nd bara {search search_method=&quot;post&quot;} ';
 $lang['export_to_csv'] = 'Exportera till CSV';
 $lang['prompt_savephrases'] = 'Sp&aring;ra S&ouml;k fraser, inte individuella ord';
@@ -85,8 +88,9 @@ $lang['help'] = '<h3>Vad g&ouml;r den h&auml;r modulen?</h3>
 <p>S&ouml;kmodulen s&ouml;ker inte n&aring;gra &quot;inaktiva&quot; sidor. Men ibland, om du anv&auml;nder modulen CustomContent, eller annan smarty-logik f&ouml;r att visa olika inneh&aring;ll f&ouml;r olika grupper av anv&auml;ndare, rekommenderas att f&ouml;rhindra hela sidan fr&aring;n att indexeras &auml;ven n&auml;r den &auml;r aktiv. F&ouml;r att g&ouml;ra detta, l&auml;gg till f&ouml;ljande tagg var som helst p&aring; sidan: <em><!-- pageAttribute: NotSearchable --></em>. N&auml;r s&ouml;kmodulen ser den taggen p&aring; sidan kommer den inte att indexera n&aring;got inneh&aring;ll f&ouml;r den sidan.</p>
 <p>Taggen <em><!-- pageAttribute: NotSearchable --></em> kan &auml;ven anv&auml;ndas i mallen. I s&aring; fall kommer inga sidor som anv&auml;nder den mallen att indexeras. De sidorna omindexeras om taggen tas bort.</p>
 ';
-$lang['utma'] = '156861353.120607462.1233740298.1240663505.1240666920.20';
-$lang['utmz'] = '156861353.1240663505.19.15.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.397033920.1281357884.1286814578.1286820501.35';
+$lang['utmz'] = '156861353.1281357884.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-1852641632-1281357886006';
+$lang['utmb'] = '156861353.1.10.1286820501';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
