@@ -76,6 +76,11 @@ class ThemeManager extends CMSModule
     return 'ThemeManager';
   }
 
+  function &GetObject()
+  {
+    return cmsms()->modules['ThemeManager']['object'];
+  }
+
 
   /*---------------------------------------------------------
    GetFriendlyName()
@@ -91,7 +96,7 @@ class ThemeManager extends CMSModule
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.1.1';
+    return '1.1.4';
   }
 
 
@@ -100,7 +105,7 @@ class ThemeManager extends CMSModule
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.5.4";
+    return "1.9.1";
   }
 
 
