@@ -5,17 +5,17 @@ $lang['active'] = 'Akt&iacute;vny';
 $lang['default'] = 'Prednastaven&yacute;';
 $lang['prompt_themename'] = 'Exportuj t&eacute;mu ako:';
 $lang['info_themename'] = 'This field determines the output theme name, irrespective of the input theme name';
-$lang['error_editingproblem'] = 'Problem cleaning up and changing the referenced files in this theme.';
-$lang['error_problemsavingincludes'] = 'Problem saving the files encoded in the theme.';
+$lang['error_editingproblem'] = 'Problem s upratan&iacute;m a zmenou referenci&iacute; s&uacute;borov v t&eacute;me';
+$lang['error_problemsavingincludes'] = 'Problem s ukl&aacute;dan&iacute;m s&uacute;borov enk&oacute;dovan&yacute;ch v &scaron;abl&oacute;ne';
 $lang['error_nofilesuploaded'] = 'No files were uploaded. Make sure your form tag&#039;s enctype was set to multipart/form-data and that the right field is being checked for the uploaded file.';
 $lang['error_templateexists'] = 'A template with the name &quot;%s&quot; already exists';
 $lang['error_stylesheetexists'] = 'A stylesheet with the name &quot;%s&quot; already exists';
-$lang['error_nostylesheets'] = 'No stylesheets were detected in this theme';
-$lang['error_couldnotcreatetemplate'] = 'Could not create the template definition';
-$lang['error_couldnotassoccss'] = 'Problem associating stylesheets with the template';
-$lang['error_nooutput'] = 'Nothing to output';
+$lang['error_nostylesheets'] = 'Neboli n&aacute;jden&eacute; žiadne &scaron;t&yacute;ly v t&eacute;me';
+$lang['error_couldnotcreatetemplate'] = 'Nie je možn&eacute; vytvoriť defin&iacute;ciu &scaron;abl&oacute;ny';
+$lang['error_couldnotassoccss'] = 'Problem s pripojen&iacute;my &scaron;t&yacute;lmi v &scaron;abl&oacute;ne';
+$lang['error_nooutput'] = 'Nič pre v&yacute;stup';
 $lang['error_notemplate'] = 'Nemožem n&aacute;jsť &scaron;abl&oacute;nu';
-$lang['error_dtdmismatch'] = 'DTD Version mismatch, cannot import';
+$lang['error_dtdmismatch'] = 'Konflik DTD verzi&iacute;, nem&ocirc;žem importovať';
 $lang['import'] = 'Importovať';
 $lang['upload'] = 'Nahrať t&eacute;mu';
 $lang['id'] = 'ID';
@@ -54,8 +54,9 @@ of the license for the full disclaimer.</p>
 <p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
 ';
-$lang['utmz'] = '156861353.1242823757.727.119.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '156861353.4300742689275601400.1213256953.1242818813.1242823757.727';
+$lang['qca'] = 'P0-1608926040-1271144175783';
+$lang['utma'] = '156861353.786385904.1271157997.1297178147.1297240836.168';
+$lang['utmz'] = '156861353.1297240836.168.154.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1242823757';
 ?>
\ No newline at end of file
