@@ -29,6 +29,7 @@ class TinyMCE extends CMSModule {
   var $plugins_ignore;
   var $templateid;
   var $module_plugins;
+  var $module_filepickers;
 
   function TinyMCE() {
 
@@ -49,25 +50,32 @@ class TinyMCE extends CMSModule {
     return $this->Lang("friendlyname");
   }
 
+	function  GetAdminDescription() {
+		return $this->Lang("admindescription");
+	}
+
   function HasAdmin() {
     return true;
   }
 
   function GetVersion() {
-    return '2.7.2';
+    return '2.8.4';
   }
 
   function IsWYSIWYG() {
     return true;
   }
 
+  function  IsPluginModule() {
+    return true;
+  }
+
   function HandlesEvents() {
     return true;
   }
 
   function HasCapability($capability, $params=array()) {
-    if ($capability == "wysiwyg")
-      return true;
+    if ($capability == "wysiwyg") return true;
     return false;
   }
 
@@ -138,11 +146,12 @@ Insert Smarty {literal} around selection|{literal}|{/literal}");
       $this->SetPreference('forcecleanpaste', 1);
       $this->SetPreference('startenabled', 1);
       $this->SetPreference('loadcmslinker', 1);
-      $this->SetPreference('cmslinkerstyle', "a");
+      $this->SetPreference('cmslinkerstyle', "selflink");
+      $this->SetPreference('cmslinkeradds',"");
       $this->SetPreference('usestaticconfig', 0);
       $this->SetPreference('ignoremodifyfiles', 0);
 
-      $this->SetPreference('dropdownblockformats', 'p,div,h1,h2,h3,h4,h5,h6,div,blockquote,dt,dd,code,samp');
+      $this->SetPreference('dropdownblockformats', 'h1,h2,h3,h4,h5,h6,blockquote,dt,dd,code,samp');
     }
   }
 
@@ -222,29 +231,47 @@ Insert Smarty {literal} around selection|{literal}|{/literal}");
 
     //if ($frontend) echo "hi";
     //$basepath = $gCms->config["root_url"].'/modules/TinyMCE/tinymce/jscripts/tiny_mce/';
-    $output = "";
+    $output = '';
+    //$output = "<!-- TinyMCE Configuration -->";
 
     if ($this->wysiwygactive) {
-
-      $output = '<script type="text/javascript" src="' . $gCms->config['root_url'] . '/modules/TinyMCE/tinymce/jscripts/tiny_mce/tiny_mce.js"></script>';
+       $output = "<!-- TinyMCE Configuration -->";
+      $output.= '<script type="text/javascript" src="' . $gCms->config['root_url'] . '/modules/TinyMCE/tinymce/jscripts/tiny_mce/tiny_mce.js"></script>';
       if ($this->GetPreference("usestaticconfig") != "1") {
-        $front = "";
-        $parms = '';
+        //$front = "";
+        
+      //  $parms = '';
 
-        if ($frontend) {
+        /*if ($frontend) {
           $parms = '?';
           $front = "&amp;frontend=yes";
         } else {
           $parms = get_secure_param();
+        }*/
+        $params=array(
+            "templateid"=>$this->templateid,
+            "languageid"=>$languageid,
+            );
+        if ($frontend) {
+          $params["frontend"]="yes";
         }
-        $output.='<script type="text/javascript" src="' . $gCms->config['root_url'] . '/modules/TinyMCE/tinyconfig.php' . $parms . '&amp;templateid=' . $this->templateid . '&amp;languageid=' . $languageid . $front . '"></script>';
+        $contentops = $gCms->GetContentOperations();
+	$pageid = '';
+	if( $frontend ) $pageid = $contentops->GetDefaultContent();
+        $configurl=$this->CreateLink(""/*id*/, "tinyconfig", $pageid, "", $params, "", true);
+        $configurl.="&amp;showtemplate=false";
+        //$configurl=str_replace("&amp;", "&", $configurl);
+        //$output.='<script type="text/javascript" src="' . $gCms->config['root_url'] . '/modules/TinyMCE/tinyconfig.php' . $parms . '&amp;templateid=' . $this->templateid . '&amp;languageid=' . $languageid . $front . '"></script>';
+        $output.='<script type="text/javascript" src="'.$configurl.'"></script>';
       } else {
 
         $output.='<script type="text/javascript" src="' . $gCms->config['root_url'] . '/tmp/tinyconfig.js"></script>';
       }
+      $output.= "<!-- TinyMCE Configuration -->";
     } else {
-      $output = "<!-- TinyMCE Session vars empty -->";
+      //$output.= "<!-- TinyMCE Session vars empty -->";
     }
+    //
 
     return $output;
   }
@@ -279,11 +306,11 @@ Insert Smarty {literal} around selection|{literal}|{/literal}");
     } else {
       $mylang = $gCms->userprefs["default_cms_language"];
     }
-
+    $mylang=trim($mylang);
     if ($mylang == "")
       return "en"; //Lang setting "No default selected"
  $mylang = substr($mylang, 0, 2);
-
+//echo $mylang;
     switch ($mylang) {
       case "tw" : return strtolower($gCms->userprefs["default_cms_language"]);
       default : return $mylang;
@@ -307,16 +334,16 @@ Insert Smarty {literal} around selection|{literal}|{/literal}");
   }
 
   function Slashes($url) {
-
-    $result = str_replace("\\", "/", $url);
-
-    return $result;
+    $url = str_replace('://','^^^',$url);
+    $url = str_replace("\\", "/", $url);
+    $url = str_replace('//','/',$url);
+    $url = str_replace('^^^','://',$url);
+    return $url;
   }
 
   function GetCustomDropdown() {
 
-    if ($this->GetPreference("customdropdown") == "")
-      return "";
+    if ($this->GetPreference("customdropdown") == "") return;
 
     $config = $this->GetConfig();
     $result = "";
@@ -401,41 +428,27 @@ tinymce.PluginManager.add('customdropdown', tinymce.plugins.CustomDropDown);
     $menutext = str_replace("\r", "", $menutext);
     $menutext = str_replace("\t", "", $menutext);
 
-    if (strlen($menutext) > 30) {
-      $menutext = htmlspecialchars(substr($menutext, 0, 30), ENT_QUOTES) . " &#133;";
+    if (strlen(utf8_decode($menutext)) > 30) {
+      $menutext = htmlspecialchars(utf8_encode(substr(utf8_decode($menutext), 0, 30)), ENT_QUOTES, 'UTF-8') . " &#133;";
     } else {
-      $menutext = htmlspecialchars($menutext, ENT_QUOTES);
+      $menutext = htmlspecialchars($menutext, ENT_QUOTES, 'UTF-8');
     }
 
     $result.="
 					" . $menu . ".add({title : '" . $menutext . "', onclick : function() {
 						var sel=tinyMCE.activeEditor.selection.getContent();
-						if (sel=='') sel='" . htmlentities($entry->MenuText(), ENT_QUOTES) . "';";
+						if (sel=='') sel='" . htmlentities($entry->MenuText(), ENT_QUOTES, 'UTF-8') . "';";
 
-    if ($this->GetPreference("cmslinkerstyle", "a") == "a") {
-      if (($config['url_rewriting'] != 'none')) {
-        if ($config['url_rewriting'] == 'mod_rewrite') {
-          $link = $config['root_url'] . "/";
-        } else {
-          $link = $config['root_url'] . "/index.php/" . $entry->HierarchyPath() . $config['page_extension'];
-        }
-
-        if ($config['use_hierarchy']) {
-          $link.=$entry->HierarchyPath() . $config['page_extension'];
-        } else {
-          $link.=$entry->Alias() . $config['page_extension'];
-        }
-      } else {
-        //if ($tiny->GetPreference("cmslinkerstyle","selflink")=="a") {
-        $link = "index.php?" . $config['query_var'] . "=" . $entry->Alias();
-        //}
-      }
+    if ($this->GetPreference("cmslinkerstyle", "selflink") == "a") {
+      $link = $entry->GetURL();
+      $additions=$this->GetPreference("cmslinkeradds");
 
       $result.="
-						tinyMCE.activeEditor.execCommand('mceInsertContent', false, '<a href=\"" . $link . "\">'+sel+'</a>');";
+						tinyMCE.activeEditor.execCommand('mceInsertContent', false, '<a href=\"" . $link . "\" ".$additions.">'+sel+'</a>');";
     } else {
+      $additions=$this->GetPreference("cmslinkeradds");
       $result.="
-						tinyMCE.activeEditor.execCommand('mceInsertContent', false, '<a href=\"{cms_selflink href=\'" . $entry->Alias() . "\'}\">'+sel+'</a>');";
+						tinyMCE.activeEditor.execCommand('mceInsertContent', false, '<a href=\"{cms_selflink href=\'" . $entry->Alias() . "\' ".$additions."}\">'+sel+'</a>');";
     }
 
     $result.="
@@ -448,19 +461,20 @@ tinymce.PluginManager.add('customdropdown', tinymce.plugins.CustomDropDown);
 
     $menutext = $entry->Hierarchy() . " " . $entry->MenuText();
 
-    if (strlen($menutext) > 30) {
-      $menutext = htmlspecialchars(substr($menutext, 0, 30), ENT_QUOTES) . " &#133;";
+    if (strlen(utf8_decode($menutext)) > 30) {
+      $menutext = htmlspecialchars(utf8_encode(substr(utf8_decode($menutext), 0, 30)), ENT_QUOTES, 'UTF-8') . " &#133;";
     } else {
-      $menutext = htmlspecialchars($menutext, ENT_QUOTES);
+      $menutext = htmlspecialchars($menutext, ENT_QUOTES, 'UTF-8');
     }
 
     $newmenu = $menu . "m";
     $result.="					var " . $newmenu . " = " . $menu . ".addMenu({title : '" . $menutext . "'});
 ";
 
-    if ($entry->Type() != "sectionheader") {
-      $result.=$this->AddEntry($newmenu, $entry);
-      $result.="					" . $newmenu . ".addSeparator();
+    if ($entry->Type() != "sectionheader") 
+      {
+	$result.=$this->AddEntry($newmenu, $entry);
+	$result.="					" . $newmenu . ".addSeparator();
 ";
     }
 
@@ -469,11 +483,16 @@ tinymce.PluginManager.add('customdropdown', tinymce.plugins.CustomDropDown);
 
   function GetCMSLinker() {
 
-    if ($this->GetPreference("loadcmslinker", "0") != "1")
-      return "";
-    $result = "";
-    $config = $this->GetConfig();
-    $result.="
+    if ($this->GetPreference("loadcmslinker", "0") != "1") return;
+
+    global $gCms;//=cmsms();
+    $config = $this->GetConfig();	
+    $content_ops = $gCms->GetContentOperations();
+    $content_array = $content_ops->GetAllContent(true);
+
+    $level = 0;
+    $menu = "m";
+    $result = "
 		
 //Creates a new plugin class and a custom listbox
 tinymce.create('tinymce.plugins.CMSLinkerPlugin', {
@@ -488,37 +507,34 @@ tinymce.create('tinymce.plugins.CMSLinkerPlugin', {
 
 				c.onRenderMenu.add(function(c, m) {
 ";
-    global $gCms;
-    $content_ops = $gCms->GetContentOperations();
-    $content_array = $content_ops->GetAllContent();
-
-    $level = 0;
-    $menu = "m";
 
     foreach ($content_array as $one) {
 
-      if ($one->Active() != 1)
-        continue;
-      //echo $one->Type();
-      if ($one->Name() == '--------') {
-        continue;
-      }
-      //print_r($one);
-      $thislevel = substr_count($one->Hierarchy(), ".");
-      //echo $thislevel.":".$level;
+		if(is_object($one)) {
 
-      if ($thislevel < $level) {
-        $menu = substr($menu, ($level - $thislevel));
-        $level-= ( $level - $thislevel);
-      }
-      //if ($thislevel==$level) {
+			if ($one->Active()) {
 
-      if ($one->ChildCount() > 0) {
-        $menu = $this->AddSub($menu, $one, $result);
-        $level++;
-      } else {
-        $result.=$this->AddEntry($menu, $one);
-      }
+				if ($one->Name() == '--------') continue; // ???? -Stikki-
+				
+				$thislevel = substr_count($one->Hierarchy(), ".");
+
+				if ($thislevel < $level) {
+				
+					$menu = substr($menu, ($level - $thislevel));
+					$level-= ( $level - $thislevel);
+				}
+
+				if ($one->ChildCount() > 0) {
+				
+					$menu = $this->AddSub($menu, $one, $result);
+					$level++;
+					
+				} else {
+				
+					$result .= $this->AddEntry($menu, $one);
+				}
+			}
+		}
     }
 
     $result.="
@@ -539,7 +555,7 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
     return $result;
   }
 
-  function GenerateConfig($frontend=false, $templateid="", $languageid="") {
+  function GenerateConfig($id, $returnid, $frontend=false, $templateid="", $languageid="") {
 
     $result = "";
     $result.=$this->GetCustomDropDown();
@@ -564,6 +580,17 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
     if (isset($_SESSION['tiny_live_textareas']))
       $this->smarty->assign("textareas", $_SESSION["tiny_live_textareas"]);
 
+    $params=array(
+        "templateid"=>$templateid,
+        "mediatype"=>"screen"
+        );
+    global $gCms;
+    /*$contentops = $gCms->GetContentOperations();
+    $cssurl=$this->CreateLink($id, "stylesheet", $contentops->GetDefaultContent(), "", $params, "", true);
+    $cssurl.="&amp;bogus=".time()."&amp;showtemplate=false";
+    $cssurl=str_replace("&amp;","&",$cssurl);
+    //$cssurl=str_replace(",",",,",$cssurl);
+    $this->smarty->assign("css", $cssurl);*/
     $this->smarty->assign("css", $config['root_url'] . "/modules/TinyMCE/stylesheet.php?templateid=" . $templateid . "&amp;mediatype=screen&amp;bogus=" . time());
 
     $this->smarty->assign("rooturl", $config["root_url"]);
@@ -574,6 +601,8 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
 
     $this->smarty->assign("allowresizing", $this->GetPreference('allowresizing', 'none'));
 
+    $this->smarty->assign("avoidlinkconversion", $this->GetPreference('avoidlinkconversion', '0'));
+
     $plugins = $this->GetPreference('plugins', $this->plugins_default_enabled);
     if (($this->GetPreference("allow_tables", "0") == "1") || ($this->GetPreference("advanced_allow_tables", "0") == "1") || ($this->GetPreference("front_allow_tables", "0") == "1")) {
       $plugins.=",table";
@@ -688,6 +717,7 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
       $this->smarty->assign("relativeurls", "false");
     }
 
+    if ($languageid=="") $languageid=substr(get_site_preference('frontendlang'),0,2);
     $this->smarty->assign("language", $languageid);
 
     if ($this->GetPreference('source_formatting', 1) == 1) {
@@ -751,6 +781,9 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
     $this->smarty->assign("extraconfig", $extraconfig);
 
     $this->smarty->assign("filepickertitle", $this->Lang("filepickertitle"));
+    $fpurl=$this->CreateLink($id,"filepicker",$returnid,"",array(),"",true);
+    $fpurl=str_replace("&amp;","&",$fpurl);
+    $this->smarty->assign("filepickerurl", $fpurl);
     $this->smarty->assign("fpwidth", $this->GetPreference("fpwidth", "700"));
     $this->smarty->assign("fpheight", $this->GetPreference("fpheight", "500"));
 
@@ -760,27 +793,79 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
   }
 
   function GetModulePlugins() {
-
     @set_time_limit(999);
-
-    global $gCms;
-
+    global $gCms;//=cmsms();
     foreach ($gCms->modules as $key => $value) {
-
       if (!array_key_exists($key, $this->module_plugins)) {
-
         if ($gCms->modules[$key]['installed'] == true && $gCms->modules[$key]['active'] == true) {
-
           if (method_exists($gCms->modules[$key]['object'], 'RegisterTinyMCEPlugin')) {
-
             $onemodule = array();
             foreach ($gCms->modules[$key]['object']->RegisterTinyMCEPlugin() as $oneplugin) {
-
               $plugin_name = strtolower($key) . "_" . $oneplugin[0];
               $plugin_script = str_replace($oneplugin[0], $plugin_name, $oneplugin[1]);
+              $plugin_script = html_entity_decode($plugin_script, ENT_QUOTES, 'UTF-8');
               $onemodule[] = array($plugin_name, $plugin_script, $oneplugin[2]);
             }
+            $this->module_plugins[$key] = $onemodule;
+          }
+        }
+      }
+    }
 
+    return $this->module_plugins;
+  }
+
+  function MakeDropdownPlugin($pluginname, $plugintitle, $icon, $entries) {
+    $plugin = "
+	tinymce.create('tinymce.plugins." . $pluginname . "', {
+        createControl: function(n, cm) {
+            switch (n) {
+                 case 'picker':
+                    var c = cm.createMenuButton('picker', {
+                        title : '" . $plugintitle . "',
+                        image : '" . $icon . "',
+                        icons : false
+                        });
+
+                        c.onRenderMenu.add(function(c, m) {
+                ";
+
+    foreach ($entries as $entry) {
+      $plugin .= "
+            m.add({title : '" . $entry['name'] . "', onclick : function() {
+                tinyMCE.activeEditor.execCommand('mceInsertContent', false, '" . $entry["code"] . "');
+                }
+            });
+            ";
+    }
+
+    $plugin .= "
+                });              
+              return c;
+            }
+
+          return null;
+       }
+});
+";
+
+    return array(array($pluginname, $plugin, $plugintitle));
+  }
+
+  function GetModuleFilepickers() {
+    @set_time_limit(999);
+    global $gCms;//=cmsms();
+    foreach ($gCms->modules as $key => $value) {
+      if (!array_key_exists($key, $this->module_plugins)) {
+        if ($gCms->modules[$key]['installed'] == true && $gCms->modules[$key]['active'] == true) {
+          if (method_exists($gCms->modules[$key]['object'], 'RegisterTinyMCEFilePicker')) {
+            $onemodule = array();
+            foreach ($gCms->modules[$key]['object']->RegisterTinyMCEFilePicker() as $oneplugin) {
+              $plugin_name = strtolower($key) . "_" . $oneplugin[0];
+              $plugin_script = str_replace($oneplugin[0], $plugin_name, $oneplugin[1]);
+              $plugin_script = html_entity_decode($plugin_script, ENT_QUOTES, 'UTF-8');
+              $onemodule[] = array($plugin_name, $plugin_script, $oneplugin[2]);
+            }
             $this->module_plugins[$key] = $onemodule;
           }
         }
@@ -793,8 +878,7 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
   function IsTempWritable() {
     $config = $this->GetConfig();
     $filename = $this->Slashes($config["root_path"] . "/tmp/tinyconfig.js");
-    if (!@touch($filename))
-      return false;
+    if (!@touch($filename)) return false;
     return true;
   }
 
@@ -819,8 +903,14 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
   }
 
   function SaveStaticConfig($frontend=false, $templateid="", $languageid="") {
+    $id = 'm1_'; $returnid = '';
+    if( $frontend )
+      {
+        $contentops = cmsms()->GetContentOperations();
+	$id = 'cntnt01'; $returnid = $contentops->GetDefaultContent();
+      }
     $config = $this->config;
-    $configcontent = $this->GenerateConfig($frontend, $templateid, $languageid);
+    $configcontent = $this->GenerateConfig($id, $returnid, $frontend, $templateid, $languageid);
     $filename = $this->Slashes($config["root_path"] . "/tmp/tinyconfig.js");
     return file_put_contents($filename, $configcontent);
   }
@@ -928,7 +1018,6 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
   }
 
   function Slash($str, $str2="", $str3="") {
-
     if ($str == "")
       return $str2;
     if ($str2 == "")
@@ -950,5 +1039,6 @@ tinymce.PluginManager.add('cmslinker', tinymce.plugins.CMSLinkerPlugin);
     return "Error in Slash-function. Please report";
   }
 
+
 }
 ?>
