@@ -32,6 +32,7 @@ echo $this->SetTabHeader("profiles",$this->Lang("profiles_tab"), ($params["tab"]
 echo $this->SetTabHeader("plugins",$this->Lang("plugins_tab"), ($params["tab"] == "plugins")?true:false);
 echo $this->SetTabHeader("styles",$this->Lang("styles_tab"), ($params["tab"] == "styles")?true:false);
 echo $this->SetTabHeader("advanced",$this->Lang("advanced_tab"), ($params["tab"] == "advanced")?true:false);
+echo $this->SetTabHeader("testarea",$this->Lang("testarea_tab"), ($params["tab"] == "testarea")?true:false);
 echo $this->EndTabHeaders();
 
 echo $this->StartTabContent();
@@ -56,12 +57,14 @@ echo $this->EndTab();
 echo $this->StartTab("advanced");
 include(dirname(__FILE__).'/function.admin_advanced.php');
 echo $this->EndTab();
+
+
+echo $this->StartTab("testarea");
+include(dirname(__FILE__).'/function.admin_testarea.php');
+echo $this->EndTab();
+
 echo $this->EndTabContent();
 //echo$this->CreateInputSubmit($id, "resetall", $this->Lang("resetall"),"","",$this->Lang("confirmresetall")));
-echo "\n<div class=\"pageoverflow\" style=\"margin-top: 1em;\">\n";
-echo $this->CreateFormStart($id);
-echo $this->CreateTextArea(true,$id,$this->Lang("testareatext"),"testarea","","","","",80,15,"TinyMCE");
-echo $this->CreateFormEnd();
-echo "</div>\n";
+
 
 ?>
\ No newline at end of file
