@@ -27,7 +27,10 @@ $extrastyles = $this->GetPreference('extrastyles', "li {\n  margin-left : 16px;\
 $startenabled = $this->GetPreference('startenabled',1);
 $loadcmslinker = $this->GetPreference('loadcmslinker',1);
 $loadstylesheet = $this->GetPreference('loadstylesheet',1);
-$cmslinkerstyle = $this->GetPreference('cmslinkerstyle',"a");
+$cmslinkerstyle = $this->GetPreference('cmslinkerstyle',"selflink");
+$cmslinkeradds = $this->GetPreference('cmslinkeradds',"");
+
+$avoidlinkconversion = $this->GetPreference("avoidlinkconversion","0");
 
 //echo "here:".$this->GetPreference("cmslinkerstyle","selflink");
 //$dropdownblockformats = $this->GetPreference('dropdownblockformats',$this->defaultblockformats);
@@ -71,8 +74,16 @@ $this->smarty->assign('loadcmslinker_help', $this->Lang('loadcmslinkerhelp'));
 $this->smarty->assign('loadcmslinker_input', $this->CreateInputCheckbox($id, 'loadcmslinker', 1, $loadcmslinker ));
 
 $this->smarty->assign('cmslinkerstyle_text', $this->Lang('cmslinkerstyletext'));
-$this->smarty->assign('cmslinkerstyle_input',$this->CreateInputDropdown($id,"cmslinkerstyle",array($this->Lang("ahrefstyle")=>"a",$this->Lang("cmsselflinkstyle")=>"selflink"),-1,$cmslinkerstyle));
+$this->smarty->assign('cmslinkerstyle_input',$this->CreateInputDropdown($id,"cmslinkerstyle",
+									array($this->Lang("cmsselflinkstyle")=>"selflink",$this->Lang("ahrefstyle")=>"a"),
+									-1,$cmslinkerstyle));
+$this->smarty->assign('cmslinkeradds_input', $this->CreateInputText($id, 'cmslinkeradds',$cmslinkeradds, 20));
+$this->smarty->assign('cmslinkeradds_text', $this->Lang('cmslinkeraddstext'));
+$this->smarty->assign('cmslinkeradds_help', $this->Lang('cmslinkeraddshelp'));
 
+$this->smarty->assign('avoidlinkconversion_input', $this->CreateInputCheckbox($id, 'avoidlinkconversion', "1", $avoidlinkconversion));
+$this->smarty->assign('avoidlinkconversion_text', $this->Lang('avoidlinkconversiontext'));
+$this->smarty->assign('avoidlinkconversion_help', $this->Lang('avoidlinkconversionhelp'));
 
 $this->smarty->assign('relativeurlstext', $this->Lang('relativeurlstext'));
 $this->smarty->assign('relativeurlsinput', $this->CreateInputCheckbox($id, 'relativeurls', "1", $relativeurls ));
