@@ -1,5 +1,6 @@
 <?php
 $lang['friendlyname'] = 'TinyMCE';
+$lang['admindescription'] = 'Mit diesem Modul k&ouml;nnen haupts&auml;chlich Inhalte, aber auch alle anderen Arten von Daten &uuml;ber den WYSIWYG-Editor des TinyMCE-Projekts bearbeitet werden.';
 $lang['uninstalled'] = 'Das Modul wurde deinstalliert.';
 $lang['installed'] = 'Das Modul wurde in der Version %s installiert.';
 $lang['stripbackgroundtags'] = 'CSS-Stile f&uuml;r den Hintergrund entfernen';
@@ -11,7 +12,7 @@ $lang['newlinestyle_text'] = 'Neue Zeilen erstellen mit';
 $lang['pstyle'] = 'Absatz (via p)';
 $lang['brstyle'] = 'Zeilenumbruch (via br)';
 $lang['usecompressiontext'] = 'GZIP-Kompression verwenden';
-$lang['usecompressionhelp'] = 'Dies kann das Laden von TinyMCE beschleunigen, aber unter bestimmten Umst&auml;nden auch das Laden verhindern. Sie sollten diese Funktion daher mit Bedacht einsetzen.';
+$lang['usecompressionhelp'] = 'Dies kann das Laden von TinyMCE beschleunigen, aber unter bestimmten Umst&auml;nden auch das Laden verhindern. Verwenden Sie daher diese Funktion mit Bedacht.';
 $lang['forcedrootblocktext'] = 'Absatz erzwingen';
 $lang['forcedrootblockhelp'] = 'Erzwingt, dass die Inhalte in einem Absatz ausgegeben werden (via p-Tag)';
 $lang['filepickerstyle'] = 'Stil der Dateiauswahl';
@@ -20,20 +21,20 @@ $lang['allowuploadtext'] = 'Das Hochladen und die Erstellung von Verzeichnissen
 $lang['allowscalingtext'] = 'Eine sofortige Gr&ouml;&szlig;en&auml;nderungen der hochgeladenen Bilddateien erlauben';
 $lang['scalingdimensionstext'] = 'Voreingestellte Abmessungen';
 $lang['resizeto'] = 'Gr&ouml;&szlig;e &auml;ndern auf:';
-$lang['makethumbnail'] = 'Vorschaubilder erstellen, wenn Bilder hochgeladen werden';
+$lang['makethumbnail'] = 'Automatisch Vorschaubilder erstellen, wenn Bilder hochgeladen werden';
 $lang['useadvancedprofile'] = 'Erweitertes TinyMCE-Profil verwenden';
 $lang['saveprofile'] = 'Profil speichern';
 $lang['profilesaved'] = 'Das Profil wurde gespeichert';
 $lang['profiles_tab'] = 'Profile';
-$lang['advanced_backend_toolbars'] = 'Erweiterte Profileinstellungen f&uuml;r das Backend';
+$lang['advanced_backend_toolbars'] = 'Erweiterte Profileinstellungen f&uuml;r die Administration ';
 $lang['savestyles'] = 'Styles speichern';
 $lang['allowadvancedprofile'] = 'Die Verwendung von erweiterten Profilen im TinyMCE erlauben';
 $lang['showfilemanagement'] = 'Optionen zur Dateiverwaltung anzeigen';
 $lang['showfilemanagementhelp'] = 'Optionen zur Dateiverwaltung wie Hochladen, Verzeichnis erstellen und Dateien l&ouml;schen anzeigen (falls dem Benutzer das Ausf&uuml;hren dieser Aktionen erlaubt ist)';
 $lang['restrictdirs'] = 'Benutzer-Zugriff auf Verzeichnisse beschr&auml;nken';
-$lang['restrictdirshelp'] = 'Hiermit k&ouml;nnen die M&ouml;glichkeiten eines Benutzers zur Verwaltung von Dateien auf ein Unterverzeichnis von&#039;uploads&#039; beschr&auml;nkt werden, dessen Name identisch mit dem Benutzernamen ist. Wenn dieses Unterverzeichnis nicht existiert, wird es erstellt. Bitte beachten Sie, dass dies aktuell nur mit den Standard-Verzeichnisnamen uploads/images funktioniert. Dies soll sich aber in Zukunft &auml;ndern.';
+$lang['restrictdirshelp'] = 'Hiermit k&ouml;nnen die M&ouml;glichkeiten eines Benutzers zur Verwaltung von Dateien auf ein Unterverzeichnis von &#039;/uploads&#039; beschr&auml;nkt werden, dessen Name identisch mit dem Benutzernamen ist. Wenn dieses Unterverzeichnis nicht existiert, wird es erstellt. Bitte beachten Sie, dass dies aktuell nur mit den Standard-Verzeichnisnamen uploads/images funktioniert. Dies soll sich aber in Zukunft &auml;ndern.';
 $lang['deleteconfirmation'] = 'Wollen Sie diese Datei wirklich l&ouml;schen?';
-$lang['deletefilesuccess'] = 'wurde erfolgreich gel&ouml;scht';
+$lang['deletefilesuccess'] = 'wurde gel&ouml;scht';
 $lang['deletefilefailed'] = 'konnte nicht gel&ouml;scht werden';
 $lang['deletesubdirfailed'] = 'konnte nicht gel&ouml;scht werden';
 $lang['deletesubdirsuccess'] = 'wurde gel&ouml;scht';
@@ -61,18 +62,23 @@ $lang['editor_width_text'] = 'Breite des Editor-Feldes';
 $lang['editor_height_text'] = 'H&ouml;he des Editor-Feldes';
 $lang['auto'] = 'Automatisch';
 $lang['or'] = 'oder';
+$lang['testarea_tab'] = 'Testbereich';
+$lang['showtestingoutput'] = 'Testausgabe zeigen';
+$lang['testareaeditor'] = 'Editor f&uuml;r den Testbereich';
+$lang['testareaoutput'] = 'Ausgabe des Testbereichs';
+$lang['testareaoutputsource'] = 'Quellcode des Testbereichs';
 $lang['allowresizing'] = 'Erlaubt die Gr&ouml;&szlig;en&auml;nderung von Bildern innerhalb des Editorfeldes';
-$lang['resizenone'] = 'Keine &Auml;nderungen erlauben';
-$lang['resizeboth'] = '&Auml;nderungen in beide Richtungen erlauben';
-$lang['resizeheight'] = 'Nur &Auml;nderungen der Bildh&ouml;he erlauben';
+$lang['resizenone'] = 'Keine Gr&ouml;&szlig;en&auml;nderung erlauben';
+$lang['resizeboth'] = 'Gr&ouml;&szlig;en&auml;nderung in beide Richtungen erlauben';
+$lang['resizeheight'] = 'Nur Gr&ouml;&szlig;en&auml;nderung der Bildh&ouml;he erlauben';
 $lang['datetimeformat_text'] = 'Datums-/Zeit-Format';
 $lang['timetext'] = 'Zeit';
 $lang['datetext'] = 'Datum';
-$lang['datetimeformat_help'] = 'Klicken Sie hier f&uuml;r eine Hilfe, wie Sie die Ausgabe von Datum und Zeit formatieren k&ouml;nnen';
+$lang['datetimeformat_help'] = 'Klicken Sie hier f&uuml;r Informationen, wie Sie die Ausgabe von Datum und Zeit formatieren k&ouml;nnen';
 $lang['extraconfigtext'] = 'Weitere Optionen';
 $lang['extraconfighelp2'] = 'Eine Vorgabe pro Zeile, Kommatas werden vor dem nach diesem Inhalt hinzugef&uuml;gt. F&uuml;r weitere Informationen schauen Sie ins Wiki auf der TinyMCE-Webseite.';
 $lang['customdropdowntext'] = 'Benutzerdefiniertes Listenfeld';
-$lang['customdropdownhelp'] = 'Hiermit k&ouml;nnen zuvor definierte Code- oder Text-Schnipsel &uuml;ber ein Listenfeld-Men&uuml; eingef&uuml;gt werden. Eine naheliegende Anwendung w&auml;re zum Beispiel der einfache Zugriff auf h&auml;ufig verwendete Tags usw. Das Men&uuml; wird &uuml;ber &#039;customdropdown&#039; in die Werkzeugleiste eingef&uuml;gt.';
+$lang['customdropdownhelp'] = 'Hiermit k&ouml;nnen zuvor definierte Code- oder Text-Schnipsel &uuml;ber ein Listenfeld-Men&uuml; eingef&uuml;gt werden. Eine naheliegende Anwendung w&auml;re zum Beispiel der einfache Zugriff auf h&auml;ufig verwendete Tags. Das Men&uuml; wird &uuml;ber &#039;customdropdown&#039; in die Werkzeugleiste eingef&uuml;gt.';
 $lang['startenabledtext'] = 'WYSIWYG aktiviert';
 $lang['startenabledhelp'] = 'Wenn Sie dieses Feld deaktivieren, wird TinyMCE mit deaktiviertem WYSIWYG-Editor gestartet. Mit dem Kontrollfeld &quot;WYSIWYG aktivieren/deaktivieren&quot; kann dieser dann bei Bedarf zugeschaltet werden.';
 $lang['loadcmslinkertext'] = 'Den CMS-Linker laden';
@@ -80,11 +86,15 @@ $lang['loadcmslinkerhelp'] = 'Dies generiert den erforderlichen Javascript-Code,
 $lang['cmslinkerstyletext'] = 'Stil des CMS-Linkers';
 $lang['cmsselflinkstyle'] = 'Stil des cms_selflink Tags (unterst&uuml;tzt Pretty URLs)';
 $lang['ahrefstyle'] = 'Stil des a-(Link)-Tags (unterst&uuml;tzt keine Pretty URLs)';
+$lang['cmslinkeraddstext'] = 'CMS-Linker Erg&auml;nzungen erlauben';
+$lang['cmslinkeraddshelp'] = 'Damit k&ouml;nnen Sie erlauben, dass dem <a href>-Tag oder {cms_selflink} weitere Parameter mitgegeben werden k&ouml;nnen, wenn diese durch den CMS-linker erzeugt werden.';
+$lang['avoidlinkconversiontext'] = 'Linkumwandlung deaktivieren';
+$lang['avoidlinkconversionhelp'] = 'Deaktiviert die in TinyMCE eingebaute Linkumwandlung. Damit k&ouml;nnen Smarty-Anweisungen in URLs verwendet werden.';
 $lang['relativeurlstext'] = 'Relative URLs erzeugen';
 $lang['forcecleanpastetext'] = 'Bereinigung des Quellcodes beim Einf&uuml;gen erzwingen';
 $lang['forcecleanpastehelp'] = 'Dies sollte aktiviert werden, um unsinnige Formatierungen, wie sie zum Beispiel beim Einf&uuml;gen von Text aus Word usw. auftreten, zu entfernen.';
 $lang['bodycss_text'] = 'CSS-Bodytag';
-$lang['bodycss_help'] = 'Um den CSS-Style Ihrer Seite zu verwenden, lassen Sie das Feld leer oder setzen es auf &bdquo;default&ldquo;. Hinweis: Um den Hintergrund des Editors wei&szlig; einzuf&auml;rben, m&uuml;ssen Sie hier dies eintragen: <code>background-color:white;</code>';
+$lang['bodycss_help'] = 'Um den CSS-Style Ihrer Seite zu verwenden, lassen Sie das Feld leer oder setzen es auf &bdquo;default&ldquo;. Tipp: Um den Hintergrund des Editors wei&szlig; einzuf&auml;rben, m&uuml;ssen Sie dies eintragen: <code>background-color:white;</code>';
 $lang['includeonlyscreencss_text'] = 'Nur die Bildschirm-CSS einbinden';
 $lang['includeonlyscreencss_help'] = 'Wenn Sie diese Option ausw&auml;hlen, werden in den Styles von TinyMCE nur Stylesheets des Medientyps &bdquo;Screen&ldquo; angezeigt.';
 $lang['usestaticconfigtext'] = 'Eine statische Konfigurationsdatei verwenden';
@@ -118,16 +128,16 @@ $lang['confirmreset'] = 'Wollen Sie wirklich diese Einstellungen auf die program
 $lang['confirmresetall'] = 'Wollen Sie wirklich ALLE Einstellungen auf die programmseitigen Vorgaben zur&uuml;cksetzen?';
 $lang['settingsreset'] = 'Diese Einstellungen wurden auf die programmseitigen Vorgaben zur&uuml;ckgesetzt';
 $lang['allsettingsreset'] = 'Alle Einstellungen wurden auf die programmseitigen Vorgaben zur&uuml;ckgesetzt';
-$lang['upgraded'] = 'wurde aktualisiert auf Version %s';
+$lang['upgraded'] = 'wurde auf Version %s aktualisiert';
 $lang['customdropdown'] = 'Benutzerdefiniertes Listenfeld-Men&uuml;';
 $lang['cmsmslinker'] = 'Einen Link auf eine CMSms-Seite einf&uuml;gen';
 $lang['backend_toolbars'] = 'Einstellungen f&uuml;r die Werkzeugleiste in der Administration';
 $lang['frontend_toolbars'] = 'Einstellungen f&uuml;r die Werkzeugleiste auf der Webseite';
 $lang['plugins_tab'] = 'Erweiterungen';
-$lang['plugins_help'] = 'W&auml;hlen sie hier die TinyMCE-Erweiterungen aus, die sie aktivieren m&ouml;chten. F&uuml;r weitere Informationen lesen sie bitte die <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">Dokumentation</a>.';
+$lang['plugins_help'] = 'W&auml;hlen Sie die TinyMCE-Erweiterungen aus, die aktiviert werden sollen. Weitere Informationen finden Sie in der <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">Dokumentation</a>.';
 $lang['plugins_text'] = 'Plugins ';
 $lang['saveplugins'] = 'Plugin-Auswahl speichern';
-$lang['pluginssaved'] = 'Plugin-Auswahl gespeicht';
+$lang['pluginssaved'] = 'Plugin-Auswahl gespeichert';
 $lang['plugins_module'] = 'Modul-Plugins';
 $lang['plugins_common'] = 'Andere Plugins';
 $lang['module'] = 'Modul';
@@ -141,7 +151,7 @@ $lang['uploadnewfile'] = 'Neue Datei';
 $lang['uploadfile'] = 'Hochladen';
 $lang['createnewdir'] = 'Neues Verzeichnis';
 $lang['createdir'] = 'Erstellen';
-$lang['nodirname'] = 'Kein Verzeichnisname angegeben';
+$lang['nodirname'] = 'Es wurde kein Verzeichnisname angegeben';
 $lang['direxists'] = 'Dieser Verzeichnisname existiert bereits';
 $lang['newdircreated'] = 'Das neue Verzeichnis wurde erstellt';
 $lang['newdirfailed'] = 'Bei der Erstellung des Verzeichnisses ist ein Fehler aufgetreten';
@@ -150,8 +160,9 @@ $lang['filetoobig'] = 'Die hochgeladene Datei ist zu gro&szlig;';
 $lang['containsillegalchars'] = 'Der Dateiname enth&auml;lt ein oder mehrere nicht erlaubte Zeichen (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Beim Verschieben der hochgeladenen Datei an die vorgegebene Stelle ist ein Fehler aufgetreten.';
 $lang['fileuploaded'] = 'Die Datei wurde hochgeladen';
+$lang['notanimage'] = 'Die hochgeladene Datei ist kein Bild';
 $lang['filepickertitle'] = 'CMS-Made-Simple-Dateiauswahl';
-$lang['success'] = 'Erfolgreich abgeschlossen';
+$lang['success'] = 'Erledigt';
 $lang['fileoperations'] = 'Dateioperationen';
 $lang['thousanddelimiter'] = ', ';
 $lang['size'] = 'Gr&ouml;&szlig;e';
@@ -170,11 +181,13 @@ $lang['help'] = '       <h3>Was macht dieses Modul?</h3>
 	<li>Bitte, bitte versuchen Sie, das TinyMCE-Verzeichnis nochmals in den /modules-Ordner hochzuladen. Sie w&auml;ren &uuml;berrascht, wenn Sie w&uuml;ssten, wie oft dies bereits anderen Anwendern geholfen hat.</li>
 	<li>Versuchen Sie, die Option f&uuml;r eine statische Konfigurationsdatei zu verwenden. Bitte beachten Sie, dass daf&uuml;r ihr /tmp-Verzeichnis durch den Webserver beschreibbar sein muss.</li>
 	<li>Falls Sie das Modul aktualisiert haben, versuchen Sie, s&auml;mtliche Einstellungen auf die programmseitigen Vorgaben zur&uuml;ckzusetzen. Ich wei&szlig;, dass das nicht gerade sch&ouml;n ist, wenn Sie TinyMCE bereits individuell angepasst hatten, aber mit der Umstellung des Moduls von 2.3.x auf 2.4.x sind eine Menge &Auml;nderungen erfolgt.</li>
-	<li>Versuchen Sie, in der Registerkarte &bdquo;Weitere Optionen&ldquo; die Option zur Verwendung einer statischen Konfigurationsdatei zu verwenden. Auf manchen (CGI-basierten) Systemen funktioniert dies besser.</li>
-	</ol>';
-$lang['qca'] = 'P0-75091478-1268421814072';
-$lang['utmz'] = '156861353.1276509051.33.21.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
-$lang['utma'] = '156861353.728989452.1268567475.1276509051.1276511098.34';
+	<li>Versuchen Sie, in der Registerkarte &bdquo;Weitere Optionen&ldquo; die Option zur Verwendung einer statischen Konfigurationsdatei zu verwenden. Auf manchen (CGI-basierten) Systemen funktioniert dies besser. Bitte beachten Sie, dass daf&uuml;r das Verzeichnis /tmp/ durch den Webserver beschreibbar sein muss.</li>
+	</ol>
+  <h3>Plugin-Programmierung</h3>
+  <p>Ab Version 2.7.0 des TinyMCE-Moduls kann anderen Modulen erlaubt werden, Erweiterungen f&uuml;r diese zu registrieren. Dies k&ouml;nnte zum Beispiel ein benutzerdefiniertes Ikon sein, mit dem Inhalte von anderen Module eingef&uuml;gt werden k&ouml;nnen, wie zum Beispiel eine Bildergalerie. Wenn Sie ein Modul-Programmierer sind und mehr &uuml;ber die technischen Hintergr&uuml;nde erfahren m&ouml;chten, finden Sie im Verzeichnis TinyMCE/docs weitere Informationen.
+';
+$lang['utma'] = '156861353.178890951.1298889837.1299177721.1299280219.6';
+$lang['utmz'] = '156861353.1298889837.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
