@@ -1,5 +1,6 @@
 <?php
 $lang['friendlyname'] = 'TinyMCE WYSIWYG -perusmoduuli';
+$lang['admindescription'] = 'T&auml;m&auml; moduuli sallii p&auml;&auml;asiassa sis&auml;ll&ouml;n, mutta mahdollisesti my&ouml;s muunkin datan muokkaamisen WYSIWYG editorilla.';
 $lang['uninstalled'] = 'Moduuli poistettu.';
 $lang['installed'] = 'Moduulin versio %s asennettu.';
 $lang['stripbackgroundtags'] = 'Poista taustatagit CSS:st&auml;';
@@ -61,6 +62,11 @@ $lang['editor_width_text'] = 'Editorikent&auml;n leveys';
 $lang['editor_height_text'] = 'Editorikent&auml;n korkeus';
 $lang['auto'] = 'Automaattinen';
 $lang['or'] = 'tai';
+$lang['testarea_tab'] = 'Testaus alue';
+$lang['showtestingoutput'] = 'N&auml;yt&auml; testaus tulokset';
+$lang['testareaeditor'] = 'Testaus alueen editori';
+$lang['testareaoutput'] = 'Testaus alueen tulokset';
+$lang['testareaoutputsource'] = 'Testaus alueen l&auml;hde';
 $lang['allowresizing'] = 'Salli editointikent&auml;n koon muuttaminen paikallaan';
 $lang['resizenone'] = '&Auml;l&auml; salli koon muuttamista';
 $lang['resizeboth'] = 'Salli koon muutttaminen molempiin suuntiin';
@@ -80,6 +86,10 @@ $lang['loadcmslinkerhelp'] = 'T&auml;m&auml; luo JavaScript-koodin, joka sallii
 $lang['cmslinkerstyletext'] = 'CMS-linkitt&auml;j&auml;n linkkityyli';
 $lang['cmsselflinkstyle'] = '{cms_selflink}-tyyli';
 $lang['ahrefstyle'] = '<a href>-tyyli';
+$lang['cmslinkeraddstext'] = 'CMS-linker lis&auml;ykset';
+$lang['cmslinkeraddshelp'] = 'T&auml;m&auml; mahdollistaa parametrien lis&auml;&auml;misen &amp;lt;a href&amp;gt; tai {cms_selflink} -tagiin, kun generoidaan CMS-linkerill&auml;.';
+$lang['avoidlinkconversiontext'] = 'V&auml;lt&auml; linkki muunnoksia';
+$lang['avoidlinkconversionhelp'] = 'Poistaa k&auml;yt&ouml;st&auml; TinyMCE:n oman linkki convertterin. Mahdollistaa {smarty}:n k&auml;yt&ouml;n urleissa.';
 $lang['relativeurlstext'] = 'Luo relatiiviset url-osoitteet';
 $lang['forcecleanpastetext'] = 'Pakota koodin siistiminen liitt&auml;misess&auml;';
 $lang['forcecleanpastehelp'] = 'T&auml;m&auml; tulisi olla p&auml;&auml;ll&auml;, jotta oudot muotoilut poistetaan koodista, kun liitet&auml;&auml;n teksti&auml; esimerkiksi Wordista.';
@@ -124,6 +134,7 @@ $lang['plugins_tab'] = 'Lis&auml;osat';
 $lang['plugins_help'] = 'Valitse, mitk&auml; lis&auml;osat haluat aktivoida. Dokumentaatio l&ouml;ytyy <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">t&auml;&auml;lt&auml;</a>';
 $lang['plugins_text'] = 'Lis&auml;osat';
 $lang['saveplugins'] = 'Tallenna lis&auml;osat';
+$lang['pluginssaved'] = 'Lis&auml;osat tallennettu';
 $lang['plugins_module'] = 'Moduulin lis&auml;osat';
 $lang['plugins_common'] = 'Yleiset lis&auml;osat';
 $lang['module'] = 'Moduuli';
@@ -146,6 +157,7 @@ $lang['filetoobig'] = 'L&auml;hetett&auml;v&auml; tiedosto on liian suuri';
 $lang['containsillegalchars'] = 'Tiedoston nimi sis&auml;lt&auml;&auml; yhden tai useamman kielletyn merkin (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Virhe l&auml;hetetyn tiedoston siirt&auml;misess&auml;';
 $lang['fileuploaded'] = 'Tiedosto l&auml;hetettiin onnistuneesti';
+$lang['notanimage'] = 'L&auml;hetett&auml;v&auml; tiedosto ei ole kuva';
 $lang['filepickertitle'] = 'CMSMadeSimple tiedoston valitseminen';
 $lang['success'] = 'Onnistui';
 $lang['fileoperations'] = 'Tiedostotyoiminnot';
@@ -170,9 +182,9 @@ $lang['help'] = '<h3>Mit&auml; t&auml;m&auml; tekee?</h3>
 	<br/>
   <h3>Lis&auml;osan kehitt&auml;minen</h3>
  Versiosta 2.7.0 l&auml;htien TinyMCE-moduulissa on mahdollista muiden moduulien rekister&ouml;id&auml; lis&auml;yksi&auml; siihen. Se voi esimerkiksi oma ikoni, joka sallii sis&auml;lt&ouml;jen lis&auml;&auml;misen toisesta moduulista, esimerkiksi Galleriasta. T&auml;m&auml;n tekeminen on suhteellisen teknist&auml; tietoa, mutta jos olet moduulin kehitt&auml;j&auml; ja olet kiinnostunut t&auml;st&auml;, ole hyv&auml; ja katso lis&auml;tietoa TinyMCE/docs -hakemistosta.';
-$lang['utmz'] = '156861353.1269853138.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-418055388-1269853137911';
-$lang['utma'] = '156861353.2121864343.1269853138.1274341684.1274344592.18';
+$lang['utma'] = '156861353.144823811.1251375439.1288623556.1288630766.361';
+$lang['utmz'] = '156861353.1285804076.330.37.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-1379893105-1252067779694';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1288630766';
 ?>
\ No newline at end of file
