@@ -1,5 +1,6 @@
 <?php
 $lang['friendlyname'] = 'Editeur TinyMCE WYSIWYG';
+$lang['admindescription'] = 'Ce module permet principalement de g&eacute;rer le contenu, mais il est possible d&#039;utiliser un &eacute;diteur WYSIWYG avec d&#039;autres types de donn&eacute;es, en utilisant le projet TinyMCE.';
 $lang['uninstalled'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute;.';
 $lang['installed'] = 'La version %s du module a &eacute;t&eacute; install&eacute;e.';
 $lang['stripbackgroundtags'] = 'Lors de l&#039;&eacute;dition, affiche avec le CSS, mais sans le fond&nbsp;';
@@ -25,7 +26,7 @@ $lang['useadvancedprofile'] = 'Utiliser les param&egrave;tres avanc&eacute;s du
 $lang['saveprofile'] = 'Sauvegarder le profil';
 $lang['profilesaved'] = 'Profil sauvegard&eacute;';
 $lang['profiles_tab'] = 'Profils';
-$lang['advanced_backend_toolbars'] = 'Profil param&egrave;tres avanc&eacute;s (backend)';
+$lang['advanced_backend_toolbars'] = 'Profil de barre d&#039;outils pour l&#039;administration (utilisateur Admin)';
 $lang['savestyles'] = 'Sauvegarder les styles';
 $lang['allowadvancedprofile'] = 'Autoriser l&#039;utilisation des param&egrave;tres avanc&eacute;s dans le profil de TinyMCE';
 $lang['showfilemanagement'] = 'Montrer les options sur les fichiers&nbsp;';
@@ -61,6 +62,11 @@ $lang['editor_width_text'] = 'Largeur de l&#039;&eacute;diteur&nbsp;';
 $lang['editor_height_text'] = 'Hauteur de l&#039;&eacute;diteur&nbsp;';
 $lang['auto'] = 'Auto ';
 $lang['or'] = 'ou';
+$lang['testarea_tab'] = 'Zone de test';
+$lang['showtestingoutput'] = 'Afficher le test';
+$lang['testareaeditor'] = 'Zone de test pour l&#039;&eacute;diteur TinyMCE';
+$lang['testareaoutput'] = 'Affichage du test';
+$lang['testareaoutputsource'] = 'Affichage du source du test';
 $lang['allowresizing'] = 'Redimensionnement sur pages du site du champ de l&#039;&eacute;diteur ';
 $lang['resizenone'] = 'Interdire le redimensionnement';
 $lang['resizeboth'] = 'Autoriser le redimensionnement en hauteur et en largeur';
@@ -75,11 +81,15 @@ $lang['customdropdowntext'] = 'Dropdown personnalis&eacute;&nbsp;';
 $lang['customdropdownhelp'] = 'Ins&egrave;re des fragments de code/texte personnalis&eacute;s par s&eacute;lection dans le menu d&eacute;roulant.  L&#039;utilisation des balises (tags) s&#039;en trouve facilit&eacute;e. Le menu est ins&eacute;r&eacute; dans la barre d&#039;outils en utilisant &#039;customdropdown&#039;.';
 $lang['startenabledtext'] = 'D&eacute;marrage permis&nbsp;';
 $lang['startenabledhelp'] = 'D&eacute;cocher cette case d&eacute;marre Tiny-&eacute;diteurs dans un &eacute;tat d&eacute;sactiv&eacute;. Devrait &ecirc;tre utilis&eacute;e avec la case a cocher &quot;Afficher WYSIWYG Oui/Non&quot;.';
-$lang['loadcmslinkertext'] = 'Charger le CMSmslinker&nbsp;';
+$lang['loadcmslinkertext'] = 'Charger le CMS-linker&nbsp;';
 $lang['loadcmslinkerhelp'] = 'Ceci g&eacute;n&egrave;re le code javascript pour pouvoir ajouter &#039;cmslinker&#039; &agrave; la barre d&#039;outils.';
 $lang['cmslinkerstyletext'] = 'Style pour CMS-linker&nbsp;';
 $lang['cmsselflinkstyle'] = 'Style - {cms_selflink}';
 $lang['ahrefstyle'] = 'Style - <a href>';
+$lang['cmslinkeraddstext'] = 'Addition CMS-linker&nbsp;';
+$lang['cmslinkeraddshelp'] = 'Cela vous permet d&#039;ajouter des choses soit &agrave; la balise < a href > ou &agrave; {cms_selflink}, lorsqu&#039;elle est g&eacute;n&eacute;r&eacute;e par CMS-linker.';
+$lang['avoidlinkconversiontext'] = 'Evitez les liens de conversion';
+$lang['avoidlinkconversionhelp'] = 'Annule la logique des liens de conversion int&eacute;gr&eacute;e &agrave; TinyMCE. Redonne les usages &agrave; la balise {smarty} pour les URLs.';
 $lang['relativeurlstext'] = 'G&eacute;n&eacute;rer les urls relatives&nbsp;';
 $lang['forcecleanpastetext'] = 'Forcer le nettoyage en collant&nbsp;';
 $lang['forcecleanpastehelp'] = 'Cela peut &ecirc;tre utile pour enlever un formatage &eacute;trange lors du collage avec Word etc...';
@@ -118,9 +128,9 @@ $lang['settingsreset'] = 'La configuration par d&eacute;faut est restaur&eacute;
 $lang['allsettingsreset'] = 'Toute la configuration par d&eacute;faut est restaur&eacute;e ';
 $lang['upgraded'] = 'A &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
 $lang['customdropdown'] = 'Dropdown personnalis\351';
-$lang['cmsmslinker'] = 'Ins\351rer le lien vers une page cmsms';
+$lang['cmsmslinker'] = 'Ins\351rer le lien vers une page CMSMS&trade;';
 $lang['backend_toolbars'] = 'Profil de barre d&#039;outils pour l&#039;administration';
-$lang['frontend_toolbars'] = 'Profil de barre d&#039;outils pour le site (Frontend)';
+$lang['frontend_toolbars'] = 'Profil de barre d&#039;outils pour le site WEB (Frontend)';
 $lang['plugins_tab'] = 'Plugins&nbsp;';
 $lang['plugins_help'] = 'Choisir les plugins que vous voulez activer. La documentation est <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">ici</a>';
 $lang['plugins_text'] = 'Plugins&nbsp;';
@@ -134,7 +144,7 @@ $lang['plugin'] = 'Plugin ';
 $lang['youareintext'] = 'Vous &ecirc;tes dans&nbsp;:&nbsp;';
 $lang['loadstylesheettext'] = 'Charger la feuille de style pour le contenu (recommand&eacute;)&nbsp;';
 $lang['extrastylestext'] = 'Ajouts &agrave; la feuille de style&nbsp;';
-$lang['extrastyleshelp'] = 'Le CSS entr&eacute; ici sera ajout&eacute; &agrave; la feuille de style lue par TinyMCE apr&egrave;s la r&eacute;ception des styles de CMSms ';
+$lang['extrastyleshelp'] = 'Le CSS entr&eacute; ici sera ajout&eacute; &agrave; la feuille de style lue par TinyMCE apr&egrave;s la r&eacute;ception des styles de CMSMS&trade; ';
 $lang['uploadnewfile'] = 'Nouveau fichier&nbsp;';
 $lang['uploadfile'] = 'Charger';
 $lang['createnewdir'] = 'Nouveau dossier&nbsp;';
@@ -148,6 +158,7 @@ $lang['filetoobig'] = 'Le fichier charg&eacute; est trop gros';
 $lang['containsillegalchars'] = 'Le nom du fichier contient un ou plusieurs caract&egrave;res non autoris&eacute;s (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Erreur lors du chargement du fichier';
 $lang['fileuploaded'] = 'Fichier charg&eacute; avec succ&egrave;s';
+$lang['notanimage'] = 'Le fichier upload&eacute; n&#039;est pas un fichier image !';
 $lang['filepickertitle'] = 'Fichiers CMSMadeSimple';
 $lang['success'] = 'Succ&egrave;s';
 $lang['fileoperations'] = 'Op&eacute;rations sur les fichiers&nbsp;';
@@ -175,9 +186,8 @@ $lang['help'] = '	<h3>Que fait ce module&nbsp;?</h3>
 	<br/>
 <h3> Plugin de d&eacute;veloppement </h3> 
   Depuis la version 2.7.0 du module TinyMCE  donne la possibilit&eacute; d&#039;avoir votre propre plugin TinyMCE l&#039;int&eacute;rieur de vos modules. Une ic&ocirc;ne personnalis&eacute;e vous permettra d&#039;ins&eacute;rer du contenu dans certains modules, comme Gallery etc... Pour cela c&#039;est une affaire assez technique, mais si vous &ecirc;tes un d&eacute;veloppeur int&eacute;ress&eacute; par ce plugin, regardez s&#039;il vous pla&icirc;t dans le dossier TinyMCE/docs pour d&#039;autres instructions.';
-$lang['utma'] = '156861353.2003866910.1245652859.1275308886.1276552747.149';
-$lang['utmz'] = '156861353.1276552748.149.136.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
-$lang['qca'] = '4a3d1b41-5eb36-c9570-f49ea';
-$lang['utmb'] = '156861353.1.10.1276552747';
+$lang['utma'] = '156861353.232585807.1290104021.1290104021.1290104021.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1290104021.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
