@@ -1,5 +1,6 @@
 <?php
 $lang['friendlyname'] = 'TinyMCE WYSIWYG ';
+$lang['admindescription'] = 'Denne modulen tillater hovedsaklig at innhold, men ogs&aring; andre typer data, kan redigeres ved bruk av en WYSIWYG redigerer utviklet av TinyMCE prosjektet.';
 $lang['uninstalled'] = 'Modul avinstallert.';
 $lang['installed'] = 'Modulversjon %s er installert';
 $lang['stripbackgroundtags'] = 'Fjern bakgrunnstagger fra stilark(CSS)';
@@ -31,7 +32,7 @@ $lang['allowadvancedprofile'] = 'Tillat bruk av avanserte profiler i TinyMCE';
 $lang['showfilemanagement'] = 'Vis filbehandlingsvalg';
 $lang['showfilemanagementhelp'] = 'Vis filbehandlingsvalg som opplasting, opprette katalog og sletting av fil i FilePicker, om brukeren har tillatelse til &aring; utf&oslash;re disse.';
 $lang['restrictdirs'] = 'Begrens brukers tilgang til kataloger';
-$lang['restrictdirshelp'] = 'Dette vil begrense filbehandlingsegenskapene til brukeren til kun en underkatalog av &quot;uploads&quot; som har samme navn som brukerens p&aring;loggingsnavn. Hvis underkatalogen ikke eksisterer, vil den muligens bli opprettet. V&aelig;r oppmerksom p&aring; at dette forel&oslash;pig bare fungerer med standard katalognavn, uploads / images. Dette kan endre seg i fremtiden.';
+$lang['restrictdirshelp'] = 'Dette vil begrense filbehandlingsegenskapene til brukeren til kun en underkatalog av &quot;uploads&quot; som har samme navn som brukerens p&aring;loggingsnavn. Hvis underkatalogen ikke eksisterer, vil den om mulig bli opprettet. V&aelig;r oppmerksom p&aring; at dette forel&oslash;pig bare fungerer med standard katalognavn, uploads / images. Dette kan endre seg i fremtiden.';
 $lang['deleteconfirmation'] = 'Er du sikker p&aring; at denne filen skal slettes?';
 $lang['deletefilesuccess'] = 'ble vellykket slettet';
 $lang['deletefilefailed'] = 'kunne ikke slettes';
@@ -61,6 +62,11 @@ $lang['editor_width_text'] = 'Bredde p&aring; redigeringsfelt';
 $lang['editor_height_text'] = 'H&oslash;yde p&aring; redigeringsfelt';
 $lang['auto'] = 'Auto ';
 $lang['or'] = 'eller';
+$lang['testarea_tab'] = 'Testomr&aring;de';
+$lang['showtestingoutput'] = 'Vis test utdata';
+$lang['testareaeditor'] = 'Testomr&aring;de redigerer';
+$lang['testareaoutput'] = 'Testomr&aring;de utdata';
+$lang['testareaoutputsource'] = 'Testomr&aring;de kildekode';
 $lang['allowresizing'] = 'Tillat p&aring;-stedet st&oslash;rrelessendring av redigeringsfeltet';
 $lang['resizenone'] = 'Ikke tillat st&oslash;rrelsesendring';
 $lang['resizeboth'] = 'Tillat st&oslash;rrelsesendring i begge retninger';
@@ -80,7 +86,11 @@ $lang['loadcmslinkertext'] = 'Last CMS-linker';
 $lang['loadcmslinkerhelp'] = 'Dette genererer javascript koden som trengs for &aring; tillate cmslinker &aring; bli lagt til verkt&oslash;ylinjen.';
 $lang['cmslinkerstyletext'] = 'CMS-linker lenkestil';
 $lang['cmsselflinkstyle'] = '{cms_selflink}-stil (st&oslash;tter vakre url&#039;er)';
-$lang['ahrefstyle'] = '< a href >-stil (st&oslash;tter ikke vakre url&#039;er)';
+$lang['ahrefstyle'] = '&amp;lt;a href&amp;gt;-stil (st&oslash;tter ikke vakre url&#039;er)';
+$lang['cmslinkeraddstext'] = 'CMS-lenker tillegg';
+$lang['cmslinkeraddshelp'] = 'Dette tillater deg &aring; legge til stoff til enten &amp;lt;a href&amp;gt;-taggen eller til {cms_selflink}, n&aring;r de genereres av CMS-lenker.';
+$lang['avoidlinkconversiontext'] = 'Unng&aring; lenke-konvertering';
+$lang['avoidlinkconversionhelp'] = 'Sl&aring;r den innebygde TinyMCE lenkekonverterer logikken av. Dette gj&oslash;r at {smarty}-bruk i lenker blir mulig.';
 $lang['relativeurlstext'] = 'Generer relative url&#039;er';
 $lang['forcecleanpastetext'] = 'Tving ren innliming';
 $lang['forcecleanpastehelp'] = 'Dette b&oslash;r v&aelig;re sl&aring;tt p&aring; for &aring; fjerne rare formatteringskoder n&aring;r man limer inn fra f.eks. Word.';
@@ -101,8 +111,8 @@ $lang['styles_help'] = '  Hvis du lar dette feltet tomt, vil TinyMCE tolke dine
   Hvis du bare &oslash;nsker &aring; presentere noen stiler til brukerne, kan du spesifisere dem p&aring; formen
 &quot;CustomName1=style1; CustomName2=style2&quot;,
   &quot;style1&quot; er et klasse kall i ditt stilark og du hopper over    .   
-  normalt benyttes dette for klasse kall(class calls) da dette allerede er i din CSS, det vil se slik ut <span class=&quot;style1&quot;>tekst</span>, 
- i det f&oslash;rste feltet nedenfor. ';
+  normalt benyttes dette for klasse kall(class calls) da dette allerede er i din CSS, det vil se slik ut < span class=&quot;style1&quot;>tekst< /span>, 
+ i det f&oslash;rste feltet nedenfor.';
 $lang['css_styles_text'] = 'Stiler';
 $lang['accessdenied'] = 'Ikke tilgang. Sjekk om du har rettigheter til dette.';
 $lang['error'] = 'Feil!';
@@ -140,7 +150,7 @@ $lang['plugin'] = 'Plugin ';
 $lang['youareintext'] = 'Du er i';
 $lang['loadstylesheettext'] = 'Last stilark for innhold (anbefalt)';
 $lang['extrastylestext'] = 'Tillegg til stilark';
-$lang['extrastyleshelp'] = 'CSS du setter inn her vil bli lagt til stilarket som leses av TinyMCE - etter TinyMCE mottar stilene fra CMSms';
+$lang['extrastyleshelp'] = 'CSS du setter inn her vil bli lagt til stilarket som leses av TinyMCE - etter TinyMCE mottar CMSMS-stilarkene';
 $lang['uploadnewfile'] = 'Ny fil';
 $lang['uploadfile'] = 'Last opp';
 $lang['createnewdir'] = 'Ny katalog';
@@ -154,6 +164,7 @@ $lang['filetoobig'] = 'Opplastet fil er for stor';
 $lang['containsillegalchars'] = 'Filnavnet inneholder et eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Feil ved flytting av opplastet fil til sin plassering';
 $lang['fileuploaded'] = 'Fill vellykket lastet opp';
+$lang['notanimage'] = 'Den opplastede filen er ikke et bilde';
 $lang['filepickertitle'] = 'CMSMadeSimple Fil-velger';
 $lang['success'] = 'Vellykket';
 $lang['fileoperations'] = 'Filoperasjoner';
@@ -161,10 +172,10 @@ $lang['thousanddelimiter'] = ' ';
 $lang['size'] = 'St&oslash;rrelse';
 $lang['dimensions'] = 'BxH';
 $lang['advanced_tab'] = 'Avansert';
-$lang['help'] = '	<h3>Hva gj&oslash;r denne modulen?</h3>
-	<p>Gj&oslash;r det mulig &aring; bruke TinyMCE som WYSIWYG tekstbehandler.</p>
-	<h3>Hvordan bruker jeg den?</h3>
-	<p>Installer den, g&aring; deretter til System - Brukervalg og velg TinyMCE som din WYSIWYG tekstbehandler.</p>
+$lang['help'] = '	<h3>What does this do?</h3>
+	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
+	<h3>How do I use it?</h3>
+	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
   <h3>Spellchecker</h3>
   <p>As of version 2.6.0, TinyMCE includes an online spellchecker. Please notice that SSL must be turned on in your server-configuration in order for this to work. On some setups this option is called php_openssl but that may vary</p>
 	<h3>Troubleshooting</h3>
@@ -181,9 +192,9 @@ $lang['help'] = '	<h3>Hva gj&oslash;r denne modulen?</h3>
   As of version 2.7.0 the TinyMCE-module has the ability to allow other modules to register extensions for it. Could be a custom icon allowing you to insert
   content from some module, like Gallery etc. How to do this is pretty tech stuff, but if you are a module developer and interested in checking it out
   please look in the TinyMCE/docs-dir for further instructions.';
-$lang['utmz'] = '156861353.1274726983.2794.62.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/bug/view/4955';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1276537553.1276543877.2883';
+$lang['utmz'] = '156861353.1288991067.3364.78.utmccn=(referral)|utmcsr=cmsmadesimple.org|utmcct=/about-link/special-fans-listing/|utmcmd=referral';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1290337505.1290347334.3406';
 $lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1276543877';
+$lang['utmb'] = '156861353.2.10.1290347334';
 ?>
\ No newline at end of file
