@@ -1,7 +1,7 @@
 <?php
 $lang['friendlyname'] = 'Editorul TinyMCE WYSIWYG';
-$lang['uninstalled'] = 'Modul dezinstalat.';
-$lang['installed'] = 'Modul versiunea %s instalat.';
+$lang['uninstalled'] = 'Modul a fost dezinstalat.';
+$lang['installed'] = 'Modul versiunea %s a fost instalat.';
 $lang['stripbackgroundtags'] = 'Scoatere taguri background din CSS';
 $lang['stiptags_help'] = 'Aceasta optiune incearca sa inlature setarile pentru background din stylesheet.';
 $lang['source_formatting_text'] = 'Aplicare formatare sursa la HTML output';
@@ -128,6 +128,7 @@ $lang['plugins_tab'] = 'Plugin-uri';
 $lang['plugins_help'] = 'Alegeti plugin-urile pe care doriti sa le activati. Documentatia poate fi gasita <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">aici</a>';
 $lang['plugins_text'] = 'Plugin-uri';
 $lang['saveplugins'] = 'Salvare plugin-uri';
+$lang['pluginssaved'] = 'Plugin-urile au fost salvate';
 $lang['plugins_module'] = 'Plugin-uri Modul';
 $lang['plugins_common'] = 'Plugin-uri Comune';
 $lang['module'] = 'Modul';
@@ -172,9 +173,9 @@ $lang['help'] = '	<h3>Ce face acesta?</h3>
 	<br/>
 		
 ';
-$lang['utma'] = '156861353.1477009656.1272913798.1272913798.1274603745.2';
-$lang['utmz'] = '156861353.1274603746.2.3.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms ms';
-$lang['qca'] = 'P0-1739349973-1272913798681';
-$lang['utmb'] = '156861353.2.10.1274603745';
+$lang['qca'] = 'P0-1838215043-1282807533934';
+$lang['utmz'] = '156861353.1282807972.1.2.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['utma'] = '156861353.1191873817.1282807534.1282807534.1282807534.1';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353.12.9.1282807615368';
 ?>
\ No newline at end of file
