@@ -1,37 +1,46 @@
 <?php
 $lang['friendlyname'] = 'TinyMCE Визуальный редактор';
+$lang['admindescription'] = 'Этот модуль позволяет редактировать контент или другие виды данных.';
 $lang['uninstalled'] = 'Модуль удален.';
 $lang['installed'] = 'Модуль версии %s установлен.';
 $lang['stripbackgroundtags'] = 'Удалить теги фона из CSS';
 $lang['stiptags_help'] = 'Удалить фон сайта из редактора.';
 $lang['source_formatting_text'] = 'Применить форматирование для вывода HTML';
 $lang['dropdownblockformats_text'] = 'Форматы блоков в выпадающем меню';
-$lang['allowtables'] = 'Разрешить применениу таблиц';
+$lang['allowtables'] = 'Добавить операции с таблицами';
 $lang['newlinestyle_text'] = 'Стиль для новой строки';
-$lang['pstyle'] = 'параграф (<p>)';
-$lang['brstyle'] = 'перенос (<br>)';
+$lang['pstyle'] = 'параграф (HTML тег p)';
+$lang['brstyle'] = 'перенос (HTML тег br)';
 $lang['usecompressiontext'] = 'Использовать сжатие gz';
 $lang['usecompressionhelp'] = 'Это позволяет увеличить скорость загрузки TinyMCE, НО также может помешать его загрузке на некоторых системах. Используйте с осторожностью.';
-$lang['forcedrootblocktext'] = 'Всегда добавлять';
-$lang['forcedrootblockhelp'] = 'Forces the returned content to at least be enclosed in a <p>-tag';
+$lang['forcedrootblocktext'] = 'Всегда добавлять HTML тег p, как первый и основной в контенте.';
+$lang['forcedrootblockhelp'] = 'Всегда заключать текст без тегов в HTML тег p';
 $lang['filepickerstyle'] = 'Cтиль Filepicker';
 $lang['filepickersize'] = 'Размер Filepicker';
 $lang['allowuploadtext'] = 'Разрешить загрузку файлов и создание папок через FilePicker';
 $lang['allowscalingtext'] = 'Разрешить автоматическое изменение размеров загруженных картинок';
 $lang['scalingdimensionstext'] = 'Размеры по-умолчанию';
 $lang['resizeto'] = 'Изменить разрешение на:';
+$lang['makethumbnail'] = 'Создавать эскиз во время загрузки файлов';
 $lang['useadvancedprofile'] = 'Использовать улучшенный профиль TinyMCE';
 $lang['saveprofile'] = 'Сохранить профиль';
 $lang['profilesaved'] = 'Профиль сохранен';
 $lang['profiles_tab'] = 'Профили';
-$lang['advanced_backend_toolbars'] = 'Расширенные настройки профиля Backand';
+$lang['advanced_backend_toolbars'] = 'Панель инструментов для администраторов';
 $lang['savestyles'] = 'Сохранить настройки';
 $lang['allowadvancedprofile'] = 'Разрешить использование расширенного профиля TinyMCE';
 $lang['showfilemanagement'] = 'Показать опции управления файлами';
 $lang['showfilemanagementhelp'] = 'Показать управление файлами (загрузка, создание папки и удаление файла)  в FilePicker, если пользователь обладает достаточными правами';
+$lang['restrictdirs'] = 'Ограничение доступа пользователя';
+$lang['restrictdirshelp'] = 'Эта настройка позволяет ограничить управления файлами на подкаталог в папке uploads, который имеет то же название, что и логин пользователя. Если такой подкаталог не существует, он будет создан. Пожалуйста, обратите внимание, это в настоящее время это ограничение работает только в каталоге uploads/images. Это может измениться в будущем.';
 $lang['deleteconfirmation'] = 'Вы уверены что хотите удалить этот файл? ';
 $lang['deletefilesuccess'] = 'был успешно удален';
-$lang['deletefilefila'] = 'не может быть удален';
+$lang['deletefilefailed'] = 'невозможно удалить';
+$lang['deletesubdirfailed'] = 'невозможно удалить';
+$lang['deletesubdirsuccess'] = 'успешно удалено';
+$lang['deletedirconfirmation'] = 'Вы уверены, что хотите удалить эту пустую поддиректорию?';
+$lang['deletedir'] = 'Удалить пустую поддиректорию';
+$lang['deletefile'] = 'Удалить файл';
 $lang['cannotreadconfig'] = 'Невозможно прочесть файл tinyconfig.php, возможно TinyMCE не будет работать. Проверьте права на доступ к файлу и его папке: доступен для всех на чтение и только для владельца на запись. ';
 $lang['filenameonly'] = 'Показывать имена файлов';
 $lang['thumbnailsonly'] = 'Показывать уменьшенные изображения';
@@ -39,11 +48,11 @@ $lang['showthumbnailfilestext'] = 'Показывать маленькие из
 $lang['filenameandthumbnails'] = 'Показывать как маленькие изображения файлов так и имена';
 $lang['skinstext'] = 'Скин';
 $lang['skinvariationtext'] = 'Разновидность скина';
-$lang['advancedwarning'] = '<strong>Внимание!<br/>Изменение этих параметров может привести к тому, что TinyMCE перестанет работать или генерируемый им код может производить ошибки. Редактируйте этот параметр только, если вы знаете, что вы делаете! Обратитесь к веб-сайту TinyMCE перед тем как произвести изменения. </strong>';
+$lang['advancedwarning'] = '<strong>Внимание!<br/>Изменение этих параметров может привести к тому, что TinyMCE перестанет работать или генерируемый им код будет содержать ошибки. Редактируйте эти настройки только, если Вы знаете, что Вы делаете! Читайте документацию к TinyMCE на официальном сайте, перед тем как производить изменения. </strong>';
 $lang['entityencoding_text'] = 'Кодирование символов';
 $lang['rawencoding'] = 'Как есть (быстро, работает в большинстве случаев)';
-$lang['namedencoding'] = 'Именное (пример &nbsp;)';
-$lang['numericencoding'] = 'Цифровое (пример  )';
+$lang['namedencoding'] = 'Именное (пример  nbsp;)';
+$lang['numericencoding'] = 'Цифровое (пример #160;)';
 $lang['show_path_text'] = 'Показать путь элемента в нижней части редактора.';
 $lang['toolbar_tab'] = 'Панель инструментов';
 $lang['toolbar_help'] = 'Здесь должен стоять список кнопок через запятую, которые должны быть включены в панель инструментов.';
@@ -53,33 +62,48 @@ $lang['editor_width_text'] = 'Ширина окна редактирования
 $lang['editor_height_text'] = 'Высота окна редактирования';
 $lang['auto'] = 'По умолчанию';
 $lang['or'] = 'или';
+$lang['testarea_tab'] = 'Тестовое поле';
+$lang['showtestingoutput'] = 'Показать результат теста';
+$lang['testareaeditor'] = 'Тестовое поля редактора';
+$lang['testareaoutput'] = 'Тестовое поля выдачи';
+$lang['testareaoutputsource'] = 'Тестовое поля исходного кода';
+$lang['allowresizing'] = 'Разрешить изменение размеров поля редактора';
+$lang['resizenone'] = 'Не разрешать изменять';
+$lang['resizeboth'] = 'Разрешать изменять в ширину и высоту';
+$lang['resizeheight'] = 'Разрешать изменять только в высоту';
 $lang['datetimeformat_text'] = 'Формат даты и времени';
 $lang['timetext'] = 'Время';
 $lang['datetext'] = 'Дата';
 $lang['datetimeformat_help'] = 'Нажмите сюда, чтобы получить помощь для формата даты или времени.';
 $lang['extraconfigtext'] = 'Дополнительные настройки';
-$lang['extraconfighelp'] = 'Посмотреть инструкции в TinyMCE-вики';
+$lang['extraconfighelp2'] = 'Одно значение на каждую строку, запятые будут добавлены до и после этого содержимого. Читайте инструкцию к  TinyMCE в Wiki.';
 $lang['customdropdowntext'] = 'Дополнительное выпадающее меню';
-$lang['customdropdownhelp'] = 'Пользовательское выпадающее меню.  Очевидное использование - упрощеный доступ к тегам например: "Start expand/collapse-area|{startExpandCollapse id=\\\'expand1\\\' title=\\\'This is my expandable area\\\'}
+$lang['customdropdownhelp'] = 'Пользовательское выпадающее меню.  Использование для упрощенного доступа к тегам например: "Start expand/collapse-area|{startExpandCollapse id=\\\'expand1\\\' title=\\\'This is my expandable area\\\'}
 
 ';
 $lang['startenabledtext'] = 'Стартовые настройки разрешены';
-$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
+$lang['startenabledhelp'] = 'При отключении редактор Tiny будет загружаться в отключенном состоянии. Рекомендуется только при использовании чекбокса для включения / выключения редактора.';
 $lang['loadcmslinkertext'] = 'Загрузить CMS-linker';
 $lang['loadcmslinkerhelp'] = 'Это позволяет сгенерировать ява скрипт код, необходимый для добавления \'cmslinker\'-а на панель инструментов.';
 $lang['cmslinkerstyletext'] = 'CMS-linker стиль ссылок';
 $lang['cmsselflinkstyle'] = '{cms_selflink}-стиль (с поддержкой ЧПУ)';
-$lang['ahrefstyle'] = '<a href>-стиль (без поддержки ЧПУ)';
+$lang['ahrefstyle'] = 'HTML тег A (без поддержки ЧПУ)';
+$lang['cmslinkeraddstext'] = 'CMS-linker дополнения';
+$lang['cmslinkeraddshelp'] = 'Это позволяет добавлять ссылки в виде HTML тега A или {cms_selflink}, если ссылка создается при помощи CMS-linker.';
+$lang['avoidlinkconversiontext'] = 'Избегать преобразования ссылок';
+$lang['avoidlinkconversionhelp'] = 'Выключает встроенную логику TinyMCE для преобразования ссылок. Позволяет использование тегов Smarty в URL.';
 $lang['relativeurlstext'] = 'Генерировать относительные ссылки';
 $lang['forcecleanpastetext'] = 'Принудительная чистка кода при вставке';
 $lang['forcecleanpastehelp'] = 'Это должно быть включено для удаления странных кодов форматирования при вставке из редактора  Word  и т.п.';
 $lang['bodycss_text'] = 'Тег CSS для body-элемента';
 $lang['bodycss_help'] = 'Будет добавлено к css стилю body-тэга. Подсказка: цвет фона может быть установлен в белый при использовании "background-color:white"';
 $lang['includeonlyscreencss_text'] = 'Включать только экранный CSS';
-$lang['includeonlyscreencss_help'] = 'Selecting this allows only attached stylesheets with the screen-mediatype selected to be included in the styles TinyMCE handles.';
+$lang['includeonlyscreencss_help'] = 'Выберите если хотите видеть только стили с media="screen" при работе с редактором.';
 $lang['usestaticconfigtext'] = 'Использовать статичный файл конфигурации';
-$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamiccally created javascript config file';
-$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the static config-file and will most probably render TinyMCE inoperational.';
+$lang['usestaticconfighelp'] = 'Это может заставить работать Tiny на системах, где хостинг автоматически добавляет всякую чушь к динамично к выводу, типа статистики, нарушая при этом динамически созданный конфигурационный файл JavaScript';
+$lang['usestaticconfigwarning'] = 'Внимание! У Вас включены статические файлы конфигурации, но ваш каталог tmp не доступен для записи. Это не позволит модулю сохранить статичный файл конфигурации и, скорей всего, приведет к отказу работы TinyMCE.';
+$lang['ignoremodifyfilestext'] = 'Игнорировать права "Modify Files" для FilePicker';
+$lang['ignoremodifyfileshelp'] = 'Внимание! Это позволит произвести некоторые операции по изменению файлов, даже если у группу отсуствуют права "Modify Files". Используйте для ограничения доступа к каталогам пользователей.';
 $lang['showtogglebutton_text'] = 'Показывать флажок для включения и выключения визуального редактора';
 $lang['togglewysiwyg'] = 'Включить / выключить визуальный редактор';
 $lang['styles_tab'] = 'Стили CSS';
@@ -96,7 +120,7 @@ $lang['saveadvanced'] = 'Сохранить расширенные настро
 $lang['advancedsaved'] = 'Расширенные настройки сохранены';
 $lang['toolbarsaved'] = 'Панель инструментов сохранена';
 $lang['stylessaved'] = 'Стили сохранены';
-$lang['testareatext'] = '<p>Поля для теста, вы не повредите содержанию страниц пробуя редактор в этом поле...</p>';
+$lang['testareatext'] = '<p>Поле для теста. Тест в этом поле никак не повлияет на содержание Ваших страниц и не может быть сохранен...</p>';
 $lang['reset'] = 'Сброс к значениям по умолчанию';
 $lang['resetall'] = 'Сбросить все настройки к значениям по умолчанию';
 $lang['confirmreset'] = 'Вы уверены, что хотите сбросить эти параметры к значениям по умолчанию?';
@@ -106,13 +130,18 @@ $lang['allsettingsreset'] = 'Все настройки были сброшены
 $lang['upgraded'] = 'был обновлен до версии %s';
 $lang['customdropdown'] = 'Расширенное выпадающее меню';
 $lang['cmsmslinker'] = 'Вставить линк на страницу CMSMS';
-$lang['backend_toolbars'] = 'Панель инструментов для администраторского интерфейса';
-$lang['frontend_toolbars'] = 'Панель инструментов для пользовательского интерфейса';
+$lang['backend_toolbars'] = 'Панель инструментов для редакторов';
+$lang['frontend_toolbars'] = 'Панель инструментов для пользователей сайта';
 $lang['plugins_tab'] = 'Плагины';
-$lang['plugins_help'] = 'Choose the plugins you want to activate. Documentation can be found <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">here</a>';
+$lang['plugins_help'] = 'Выберите плагины, которые Вы хотите использовать. Документация по плагинам находится <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">здесь</a>';
 $lang['plugins_text'] = 'Плагины';
 $lang['saveplugins'] = 'Загрузить плагины';
 $lang['pluginssaved'] = 'Загруженные плагины';
+$lang['plugins_module'] = 'Модульные плагины';
+$lang['plugins_common'] = 'Общие плагины';
+$lang['module'] = 'Модули';
+$lang['description'] = 'Описание';
+$lang['plugin'] = 'Плагин';
 $lang['youareintext'] = 'Вы в ';
 $lang['loadstylesheettext'] = 'Загружать таблицу стилей контента (рекомендовано)';
 $lang['extrastylestext'] = 'Дополнения к таблице стилей';
@@ -127,22 +156,41 @@ $lang['newdircreated'] = 'Новая папка успешно создана';
 $lang['newdirfailed'] = 'Ошибка при создании новой папки';
 $lang['nofile'] = 'Файл не был загружен';
 $lang['filetoobig'] = 'Загружаемый файл слишком большой';
+$lang['containsillegalchars'] = 'Имя файла содержит один или несколько недопустимых символов (\',",+,*,\\,/,&,$)';
 $lang['uploadfailed'] = 'Ошибка при пермещении файла';
 $lang['fileuploaded'] = 'Файл успешно загружен';
-$lang['filepickertitle'] = 'CMSMadeSimple File Selection';
+$lang['notanimage'] = 'Загруженный файл не является изображением';
+$lang['filepickertitle'] = 'CMSMadeSimple выбор файла';
 $lang['success'] = 'Успешно';
 $lang['fileoperations'] = 'Операции с файлами';
-$lang['thousanddelimiter'] = ',';
+$lang['thousanddelimiter'] = ', ';
 $lang['size'] = 'Размер';
-$lang['dimensions'] = 'Ширина х Высота';
+$lang['dimensions'] = 'ШхВ';
 $lang['advanced_tab'] = 'Дополнительно';
-$lang['help'] = '	<h3>What does this do?</h3>
+$lang['help'] = '<h3>What does this do?</h3>
 	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
 	<h3>How do I use it?</h3>
-	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>	
+	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
+  <h3>Spellchecker</h3>
+  <p>As of version 2.6.0, TinyMCE includes an online spellchecker. Please notice that SSL must be turned on in your server-configuration in order for this to work. On some setups this option is called php_openssl but that may vary</p>
+	<h3>Troubleshooting</h3>
+	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
+	things you can try before contacting me for further support.
+	<br/>
+	<ul>
+	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You\'d be amazed how many times this has helped people.</li>	
+	<li>2. If upgrading, please try to reset all settings. Not nice if you\'ve done a lot of customization, I know, but a lot of things changed from 2.3.x to 2.4.x series of the module.
+	<li>3. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based), Note that this requires your /tmp/-dir to be writable by the webserver
+	</ul>
+	<br/>
+  <h3>Plugin development</h3>
+  As of version 2.7.0 the TinyMCE-module has the ability to allow other modules to register extensions for it. Could be a custom icon allowing you to insert
+  content from some module, like Gallery etc. How to do this is pretty tech stuff, but if you are a module developer and interested in checking it out
+  please look in the TinyMCE/docs-dir for further instructions.
 ';
-$lang['utma'] = '156861353.1044124068342992300.1242846023.1243238676.1243250141.14';
-$lang['utmz'] = '156861353.1243250141.14.10.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,27626.0.html|utmcmd=referral';
+$lang['qca'] = 'P0-1938388883-1277855813144';
+$lang['utma'] = '156861353.429593658.1277855813.1291889913.1291983831.104';
+$lang['utmz'] = '156861353.1291841241.100.49.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
