@@ -19,8 +19,8 @@
 function smarty_cms_function_content($params, &$smarty)
 {
 	global $gCms;
-	$pageinfo =& $gCms->variables['pageinfo'];
-	if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
+	$contentobj = $gCms->variables['content_obj'];
+	if (is_object($contentobj))
 	{
 		$id = '';
 		$modulename = '';
@@ -93,7 +93,7 @@ function smarty_cms_function_content($params, &$smarty)
 					  }
 					else
 					  {
-					    $returnid = $pageinfo->content_id;
+					    $returnid = $contentobj->Id();
 					  }
 					$result = $cmsmodules[$modulename]['object']->DoActionBase($action, $id, $params, $returnid);
 					if ($result !== FALSE)
@@ -117,7 +117,7 @@ function smarty_cms_function_content($params, &$smarty)
 			$result = '';
 			$oldvalue = $smarty->caching;
 			$smarty->caching = false;
-			$result = $smarty->fetch(str_replace(' ', '_', 'content:' . (isset($params['block'])?$params['block']:'content_en')), '', $pageinfo->content_id);
+			$result = $smarty->fetch(str_replace(' ', '_', 'content:' . (isset($params['block'])?$params['block']:'content_en')), '', $contentobj->Id());
 			$smarty->caching = $oldvalue;
 			return _smarty_cms_function_content_return($result, $params, $smarty);
 		}
