@@ -26,18 +26,12 @@ function smarty_cms_function_page_image($params, &$smarty)
       $propname = 'thumbnail';
     }
 
-  global $gCms;
-  $pageinfo = &$gCms->variables['pageinfo'];
-  $manager =& $gCms->GetHierarchyManager();
-  $node =& $manager->sureGetNodeById($pageinfo->content_id);
-  if(is_object($node))
+  $gCms=cmsms();
+  $contentobj = &cms_utils::get_current_content();
+  if( is_object($contentobj) )
     {
-      $contentobj =& $node->GetContent();
-      if( is_object($contentobj) )
-	{
-	  $result = $contentobj->GetPropertyValue($propname);
-          if( $result == -1 ) $result = '';
-	}
+      $result = $contentobj->GetPropertyValue($propname);
+      if( $result == -1 ) $result = '';
     }
 
   if( isset($params['assign']) )
@@ -60,7 +54,7 @@ function smarty_cms_about_function_page_image() {
 	<p>Version: 1.0</p>
 	<p>
 	Change History:<br/>
-	None
+	1.01, Fix for CMSMS 1.9
 	</p>
 	<?php
 }
