@@ -18,13 +18,8 @@
 
 function smarty_cms_function_process_pagedata($params,&$smarty)
 {
-  global $gCms;
-  $manager =& $gCms->GetHierarchyManager();
-  $node =& $manager->getNodeById($gCms->variables['content_id']);
-  if( !isset($node) || $node === FALSE ) return;
-  $content =& $node->Getcontent();
-
-  if ( empty($content)) return;
+  $content = cmsms()->get_variable('content_obj');
+  if (!is_object($content) ||  empty($content)) return;
 
   $tpl = $content->GetPropertyValue('pagedata','');
   if( empty($tpl) ) return;
