@@ -22,11 +22,10 @@ function smarty_cms_function_stylesheet($params, &$smarty)
   function get_stylesheet_tag($cssid,$media='')
   {
     global $gCms;
-    $config = &$gCms->config;
+    $config = $gCms->GetConfig();
     
     $str = '';
     $url = '';
-    //if( $config['url_rewriting'] != 'none' )
 
     $base = $config['root_url'];
     if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off')
@@ -52,9 +51,9 @@ function smarty_cms_function_stylesheet($params, &$smarty)
   }
 
   global $gCms;
-  $config = &$gCms->config;
-  $pageinfo = &$gCms->variables['pageinfo'];
-  $template_id=$pageinfo->template_id;
+  $config = $gCms->GetConfig();
+  $content_obj = &$gCms->variables['content_obj'];
+  $template_id=$content_obj->TemplateId();
   if (isset($params["templateid"]) && $params["templateid"]!="") {
     $template_id=$params["templateid"];
   }
@@ -97,11 +96,7 @@ function smarty_cms_function_stylesheet($params, &$smarty)
   
   if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
     {
-      if (version_compare(phpversion(),"5.3.0","<")) {
-        $stylesheet = ereg_replace("\{\/?php\}", "", $stylesheet);
-      } else {
-        $stylesheet = preg_replace("/\{\/?php\}/", "", $stylesheet);
-      }
+      $stylesheet = preg_replace("/\{\/?php\}/", "", $stylesheet);
     }
   
   return $stylesheet;
