@@ -26,7 +26,7 @@ function smarty_cms_modifier_cms_date_format($string, $format = '',
     }
 
   $smarty =& $gCms->GetSmarty();
-  $config =& $gCms->GetConfig();
+  $config = $gCms->GetConfig();
   $fn = cms_join_path($config['root_path'],'lib','smarty','plugins','modifier.date_format.php');
   if( !file_exists($fn) ) die();
   require_once( $fn );
