@@ -2,6 +2,9 @@
 
 
 global $CMS_INSTALL_PAGE;
+global $CMS_STYLESHEET;
+$CMS_STYLESHEET = 1;
+
 // Parse pretty URLS
 if (!isset($_SERVER['REQUEST_URI']) && isset($_SERVER['QUERY_STRING']))
 {
@@ -21,7 +24,6 @@ else if( preg_match('+^/[0-9]*$+',$url,$matches) )
   }
 
 
-//require('config.php');//default
 require('fileloc.php');
 require(CONFIG_FILE_LOCATION);
 require(dirname(__FILE__).DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'misc.functions.php');
@@ -42,7 +44,6 @@ if (isset($_GET["stripbackground"])) $stripbackground = true;
 if ($name == '' && $cssid == '') return '';
 
 // Get the hash filename
-//$hashfile = $config['root_path'].DIRECTORY_SEPARATOR.'tmp'.DIRECTORY_SEPARATOR.'cache'.DIRECTORY_SEPARATOR.'csshash.dat';
 $hashfile = TMP_CACHE_LOCATION . DIRECTORY_SEPARATOR . 'csshash.dat';
 
 // Get the cache
@@ -87,19 +88,8 @@ if( isset($hash[$cssid]) && strcmp($hash[$cssid],$etag) == 0 &&
 //
 
 // connect to the database
-require(dirname(__FILE__).DIRECTORY_SEPARATOR.'version.php');
-//require(dirname(__FILE__).DIRECTORY_SEPARATOR.'fileloc.php'); //is included in top now
-require(cms_join_path(dirname(__FILE__),'lib','config.functions.php'));
-require_once(dirname(__FILE__).DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'misc.functions.php');
-require(cms_join_path(dirname(__FILE__),'lib','classes','class.global.inc.php'));
-require(cms_join_path(dirname(__FILE__),'lib','adodb.functions.php'));
-
-$gCms = new CmsObject();
-load_adodb();
-$db = $gCms->GetDb();
-
-require(cms_join_path(dirname(__FILE__),'lib','page.functions.php'));
-
+require(cms_join_path(dirname(__FILE__),'include.php'));
+$db = cmsms()->GetDb();
 
 // extract the stylesheet(s)
 $sql="SELECT css_text, css_name FROM ".$config['db_prefix']."css WHERE css_id = ".$db->qstr($cssid);
